(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1293359,      58974]*)
(*NotebookOutlinePosition[   1294331,      59006]*)
(*  CellTagsIndexPosition[   1294287,      59002]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[" APPLE  II Helical Undulator", "Title"],

Cell["\<\
June 1999
by J.Chavanne,ESRF B.P. 220 38043 Grenoble France\
\>", "Author"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellFrame->False],

Cell[TextData[
"This mathematica notebook is dedicated to the design of linear/helical(APPLE \
II) undulators. It allows in particular the optimization of the end field \
structures in view of minimising the field integral dependance with the \
magnetic gap and phase.  The study of the field integral depends on the \
longitudinal symmetry of the structure ; one can make the distinction between \
two different configurations:\n\nStructure of type \"s\" with a symmetric \
(antisymmetric) vertical  (horizontal) field meaning that the first and last \
peak of the vertical (horizontal) field have the same (opposite) polarities.\n\
Structure of type \"a\" which has an antisymmetric (symmetric) vertical \
(horizontal) field.\nBoth structures have to be addressed in view of \
determining the horizontal and vertical field integral originating at each \
extremity.\n\nThe field integral originating at the end field structure is \
due to the non zero susceptibilty (equal to \[Mu]r-1) of the anisotropic \
permanent magnet material. In particular, the sintered NdFeB material has a \
susceptibilty of 0.06 parallel to the easy axis and 0.17 perpendicular to the \
easy axis (relatively independant from the remanent induction). The end \
magnets involved are desribed in the paper entiltled \"End field structures \
for linear/helical undulators\" presented at PAC'99 Using this notebook it is \
possible to \"play\" and optimize the sizes and positions of the end magnets. \
One can for example build a conventional termination (with a half vertically \
magnetized block) and modify the end elements to improve the field integral.\n\
\nThis notebook is quite elaborated. It is  not intended to be used by a \
beginner . It is completely ready for a magnet designer interested in \
building an APPLE-II  device  with passive field integral correction.  "], 
  "Text",
  PageWidth->WindowWidth,
  CellFrame->False,
  CellMargins->{{55, 10}, {6, 6}},
  TextAlignment->Left,
  Background->RGBColor[0.927199, 0.874189, 0.929992]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load radia and needed packages", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< Radia`; \n<< \ Graphics`MultipleListPlot`; \n
    Off[General::"\<spell1\>"]; \)], "Input",
  Background->GrayLevel[0.999985]],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Radia Version: \"\>", "\[InvisibleSpace]", 
        StyleBox["4.09700000000000041`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], "\[InvisibleSpace]", "\<\" is loaded\"\>"}],
      SequenceForm[ "Radia Version: ", 4.0970000000000004, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright 1997 \
Wolfram Research, Inc."\)], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions", "Section"],

Cell[CellGroupData[{

Cell["function EpuS (create a symmetric vertical field structure )", 
  "Subsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox[
          \(EpuS[Per_, Nper_, Gap_, Gx_, Lm_List, Chamf_, Matm_List, 
            \[Alpha]m_, Nm_List, Lwi_List, Lwi2_List, \[Alpha]_, \[Alpha]w_, 
            LHL_List, LHW_List, col_List, ds_, dsext_List, Gxext_]\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[":=",
          FontColor->RGBColor[0, 0, 1]], "\n", "\t", "\n", 
        \(Module[{Grp, grp1, grp2, mag, mag1, magv, magh, Nadd, mx, ms, mz, 
            Lx, Ls, Lz, x, z, s, poly, p1, p2, p3, p4, p5, p6, mat, rt, tr, 
            tr1, tr2, tr3, try, g1, g2, g3, g4, gr1, gr2}, \n\t\t\n\t\t
          \(grp1 = radObjCnt[{}]; \); \n\t\tLx = Lm[\([1]\)]/2. ; \n\t\t
          Ls = Per/4.  - Lm[\([2]\)]; \n\t\tLz = Lm[\([3]\)]; \n\t\t
          p1 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\)}; \n\t\t
          p2 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\)}; \n\t\t
          p3 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Chamf}; \n\t\t
          p4 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Lz + Chamf}; \n\t\t
          p5 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
          p6 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
          poly = {p1, p2, p3, p4, p5, p6}; \n\t\t\n\t\t\n\t\t
          mx = Matm[\([3]\)]*Sin[\[Alpha]m*Pi/180. ]; \n\t\t
          mz = Matm[\([3]\)]*Cos[\[Alpha]m*Pi/180. ]; \n\t\t
          mag = radObjThckPgn[0. , Ls/2. , poly, {0. , mx, mz}]; \n\t\t
          radObjDivMag[mag, {Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \n\t\t
          tr = radTrfTrsl[{0. , Ls/4. , 0. }]; \n\t\t
          rt = radTrfRot[{0. , 0. , 0. }, {0. , 0. , 1. }, \(-Pi\)/2. ]; \n
          \t\tradTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
          mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, 
              Matm[\([3]\)]]; \n\t\tradMatApl[mag, mat]; \n\t\t
          radObjDrwAtr[mag, col[\([1]\)], 0.001]; \t\t\n\t\t
          radObjAddToCnt[grp1, {mag}]; \n\t\tmag1 = radObjDpl[mag]; \n\t\t\n
          \t\t\n\t\n\t\t
          mag = radObjThckPgn[0. , Ls, poly, {Matm[\([3]\)], 0. , 0. }]; \n
          \t\ttr = radTrfTrsl[{0. , Per/4. , 0. }]; \n\t\t
          radTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
          mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {
                Matm[\([3]\)], 0. , 0. }]; \n\t\tradMatApl[mag, mat]; \n\t\t
          radObjDrwAtr[mag, col[\([2]\)], 0.001]; \n\t\t
          radObjDivMag[mag, {2*Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \n\t\t
          radObjAddToCnt[grp1, {mag}]; \n\t\t\n\t\t\n\t\n\t\t
          mag = radObjThckPgn[0. , Ls, poly, {0. , \(-mx\), \(-mz\)}]; \t\n
          \t\ttr = radTrfTrsl[{0. , Per/2. , 0. }]; \n\t\t
          radTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
          mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, 
              Matm[\([3]\)]]; \n\t\tradMatApl[mag, mat]; \n\t\t
          radObjDrwAtr[mag, col[\([1]\)], 0.001]; \n\t\t
          radObjDivMag[mag, {2*Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \n\t\t
          radObjAddToCnt[grp1, {mag}]; \n\t\tmagv = radObjDpl[mag]; \n\t\t\n
          \t\t\n\t\n\t\t
          mag = radObjThckPgn[0. , Ls, poly, {\(-Matm[\([3]\)]\), 0. , 0. }]; 
          \n\t\ttr = radTrfTrsl[{0. , 3*Per/4. , 0. }]; \n\t\t
          radTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
          mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {
                \(-Matm[\([3]\)]\), 0. , 0. }]; \n\t\tradMatApl[mag, mat]; \n
          \t\tradObjDrwAtr[mag, col[\([2]\)], 0.001]; \n\t\t
          radObjDivMag[mag, {2*Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \n\t\t
          radObjAddToCnt[grp1, {mag}]; \n\t\tmagh = radObjDpl[mag]; \n\t\t\n\n
          \t\t\n\t\tNadd = Nper - 2; \n\t\t
          For[i = 1, i <= Nadd, \(i++\), \n\t\t
            tr = radTrfTrsl[{0. , Per/2. *i, 0. }]; \n\t\t
            mag = radObjDpl[magv]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
            mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {0. , 
                  \((\(-1\))\)^\((i - 1)\)*mx, \((\(-1\))\)^\((i - 1)\)*mz}]; 
            \n\t\tradMatApl[mag, mat]; \n\t\tradObjAddToCnt[grp1, {mag}]; \n
            \t\t\t\n\t\tmag = radObjDpl[magh]; \n\t\tradTrfOrnt[mag, tr]; \n
            \t\tmat = 
              radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {
                  \((\(-1\))\)^\((i - 1)\)*Matm[\([3]\)], 0. , 0. }]; \t\n\t\t
            radMatApl[mag, mat]; \n\t\tradObjAddToCnt[grp1, {mag}]; ]; \n\t\t
          \n\t\t\n\t\t\n\t\t
          tr = radTrfTrsl[{0. , 
                Nper/2. *Per - Per/8.  + dsext[\([1]\)] + Ag/2. , 0. }]; \n
          \t\tradTrfOrnt[mag1, tr]; \n\t\t
          mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {0. , 
                \((\(-1\))\)^Nper*mx, \((\(-1\))\)^Nper*mz}]; \n\t\t
          radMatApl[mag1, mat]; \n\t\tradObjAddToCnt[grp1, {mag1}]; \n\t\t\n
          \t\t\n\n\t\ \ \ Lx = Lwi[\([1]\)]/2.  - Gx/2. ; \n\t\t
          Ls = Lwi[\([2]\)]; \n\t\tLz = Lwi[\([3]\)]; \n\t\t
          p1 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\)}; \n\t\t
          p2 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\)}; \n\t\t
          p3 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Chamf}; \n\t\t
          p4 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Lz + Chamf}; \n\t\t
          p5 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
          p6 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
          poly = {p1, p2, p3, p4, p5, p6}; \n\t\t
          mx = \((\(-1\))\)^Nper*Matm[\([3]\)]*Sin[\[Alpha]*Pi/180. ]; \n\t\t
          mz = \((\(-1\))\)^Nper*Matm[\([3]\)]*Cos[\[Alpha]*Pi/180. ]; \n\t\t
          ms = 0. ; \n\t\tmag = radObjThckPgn[0. , Ls, poly, {ms, mx, mz}]; \n
          \t\tradObjDivMag[mag, {Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \n
          \t\ttr = 
            radTrfTrsl[{0. , Nper/2. *Per + Ls/2.  + dsext[\([1]\)], 0. }]; \n
          \t\tradTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
          mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {ms, mx, 
                mz}]; \n\t\tradMatApl[mag, mat]; \n\t\t
          radObjDrwAtr[mag, col[\([1]\)], 0.001]; \t\t\n\t\t
          radObjAddToCnt[grp1, {mag}]; \n\t\t
          s = Nper/2. *Per + Ls + dsext[\([1]\)]; \n\t\t\n\t\t\n\t\n\t\t
          Lx = LHL[\([1]\)]/2.  - Gx/2. ; \n\t\tLs = LHL[\([2]\)]; \n\t\t
          Lz = LHL[\([3]\)]; \n\t\t
          If[LHL[\([2]\)] \[NotEqual] 0. , \n\t\t
            p1 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\)}; \n\t\t
            p2 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\)}; \n\t\t
            p3 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Chamf}; \n\t\t
            p4 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Lz + Chamf}; \n\t\t
            p5 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
            p6 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
            poly = {p1, p2, p3, p4, p5, p6}; \n\t\t
            mx = \((\(-1\))\)^Nper*Matm[\([3]\)]; \n\t\tms = 0. ; \n\t\t
            mz = 0. ; \n\t\tmag = radObjThckPgn[0. , Ls, poly, {mx, ms, mz}]; 
            \n\t\ttr = radTrfTrsl[{0. , s + Ls/2.  + dsext[\([2]\)], 0. }]; \n
            \t\tradTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
            mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {mx, ms, 
                  mz}]; \n\t\tradMatApl[mag, mat]; \n\t\t
            radObjDrwAtr[mag, col[\([2]\)], 0.001]; \n\t\t
            radObjDivMag[mag, {2*Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \t\t
            \n\t\tradObjAddToCnt[grp1, {mag}], NULL]; \n\t\t
          s = s + Ls + dsext[\([2]\)] + dsext[\([3]\)]; \n\t\t\n\t\t
          Lx = Lwi2[\([1]\)]/2.  - Gx/2. ; \n\t\tLs = Lwi2[\([2]\)]; \n\t\t
          Lz = Lwi2[\([3]\)]; \n\t\t\n\t\t
          p1 = {\(-Gxext\)/2. , \(-Abs[Gap/2. ]\)}; \n\t\t
          p2 = {\(-Gxext\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\)}; \n\t\t
          p3 = {\(-Gxext\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Chamf}; \n\t\t
          p4 = {\(-Gxext\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Lz + Chamf}; \n\t\t
          p5 = {\(-Gxext\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
          p6 = {\(-Gxext\)/2. , \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
          poly = {p1, p2, p3, p4, p5, p6}; \n\t\t
          mx = \((\(-1\))\)^Nper*Matm[\([3]\)]*Sin[\[Alpha]*Pi/180. ]; \n\t\t
          mz = \((\(-1\))\)^Nper*Matm[\([3]\)]*Cos[\[Alpha]*Pi/180. ]; \n\t\t
          ms = 0. ; \n\t\tmag = radObjThckPgn[0. , Ls, poly, {ms, mx, mz}]; \n
          \t\tradObjDivMag[mag, {Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \n
          \t\ttr = radTrfTrsl[{0. , s + Ls/2. , 0. }]; \n\t\t
          radTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
          mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {ms, 
                \(-mx\), \(-mz\)}]; \n\t\tradMatApl[mag, mat]; \n\t\t
          radObjDrwAtr[mag, col[\([1]\)], 0.001]; \t\t\n\t\t
          radObjAddToCnt[grp1, {mag}]; \n\t\t
          s = s + Lwi2[\([2]\)] + dsext[\([4]\)]; \n\t\t\t\t\n\t\t\n\t\n\t\t
          Lx = LHW[\([1]\)]/2.  - Gx/2. ; \n\t\t
          If[LHW[\([2]\)] \[NotEqual] 0. , \n\t\tLs = LHW[\([2]\)]; \n\t\t
            Lz = LHW[\([3]\)]; \n\t\tp1 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\)}; \n
            \t\tp2 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\)}; \n\t\t
            p3 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Chamf}; \n\t\t
            p4 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Lz + Chamf}; \n\t\t
            p5 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
            p6 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
            poly = {p1, p2, p3, p4, p5, p6}; \n\t\t
            mx = \((\(-1\))\)^Nper*Matm[\([3]\)]*Cos[\[Alpha]w*Pi/180. ]; \n
            \t\tms = 0. ; \n\t\t
            mz = \((\(-1\))\)^Nper*Matm[\([3]\)]*Sin[\[Alpha]w*Pi/180. ]; \n
            \t\tmag = radObjThckPgn[0. , Ls, poly, {\(-mx\), ms, mz}]; \n\t\t
            tr = radTrfTrsl[{0. , s + Ls/2. , 0. }]; \n\t\t
            radTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
            mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {\(-mx\), 
                  ms, mz}]; \n\t\tradMatApl[mag, mat]; \n\t\t
            radObjDrwAtr[mag, col[\([2]\)], 0.001]; \n\t\t
            radObjDivMag[mag, {Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \t\t\n
            \t\tradObjAddToCnt[grp1, {mag}], Null]; \n\t\t\n\t\t
          RadTrfZerPerp[grp1, {0, 0, 0}, {1, 0, 0}]; \n\t\t
          RadTrfZerPerp[grp1, {0, 0, 0}, {0, 1, 0}]; \n\t\t\n\t\t
          Grp2 = radObjDpl[grp1, FreeSym -> True]; \n\t\t
          g1 = \(radObjCntStuf[Grp2]\)[\([1]\)]; \n\t\t
          g2 = \(radObjCntStuf[Grp2]\)[\([2]\)]; \n\t\t
          g3 = \(radObjCntStuf[Grp2]\)[\([3]\)]; \n\t\t
          g4 = \(radObjCntStuf[Grp2]\)[\([4]\)]; \n\t\t
          gr1 = radObjCnt[{g1, g3}]; \n\t\tgr2 = radObjCnt[{g2, g4}]; \n\t\t
          try = radTrfTrsl[{0. , ds, 0}]; \n\t\tradTrfOrnt[gr1, try]; \n\t\t
          Grp = radObjCnt[{gr1, gr2}]; \n\t\ttr1 = radTrfInv[]; \n\t\t
          tr2 = radTrfRot[{0. , 0. , 0. }, {0. , 1. , 0. }, Pi]; \n\t\t
          tr3 = radTrfCmbL[tr2, tr1]; \n\t\t
          If[Gap > 0, radTrfMlt[Grp, tr3, 2], Null]; \n\t\tGrp\n\t\t]\)}], 
      "\n", "\t"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
function EpuA (create an antisymmetric symmetric vertical field \
structure )\
\>", "Subsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox[
          \(EpuA[Per_, Nper_, Gap_, Gx_, Lm_List, Chamf_, Matm_List, 
            \[Alpha]m_, Nm_List, Lwi_List, Lwi2_List, \[Alpha]_, \[Alpha]w_, 
            LHL_List, LHW_List, col_List, ds_, dsext_List, Gxext_]\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[":=",
          FontColor->RGBColor[0, 0, 1]], "\n", "\t", "\n", 
        \(Module[{Grp, grp1, grp2, mag, mag1, magv, magh, Nadd, mx, ms, mz, 
            Lx, Ls, Lz, x, z, s, poly, p1, p2, p3, p4, p5, p6, mat, rt, tr, 
            tr1, tr2, tr3, try, g1, g2, g3, g4, gr1, gr2}, \n\t\t\n\t\t
          \(grp1 = radObjCnt[{}]; \); \n\t\tLx = Lm[\([1]\)]/2. ; \n\t\t
          Ls = Per/4.  - Lm[\([2]\)]; \n\t\tLz = Lm[\([3]\)]; \n\t\t
          p1 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\)}; \n\t\t
          p2 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\)}; \n\t\t
          p3 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Chamf}; \n\t\t
          p4 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Lz + Chamf}; \n\t\t
          p5 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
          p6 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
          poly = {p1, p2, p3, p4, p5, p6}; \n\t\t\n\t\t\n\t\t
          mx = Matm[\([3]\)]*Sin[\[Alpha]m*Pi/180. ]; \n\t\t
          mz = Matm[\([3]\)]*Cos[\[Alpha]m*Pi/180. ]; \n\t\t
          mag = radObjThckPgn[0. , Ls/2. , 
              poly, {\(-Matm[\([3]\)]\), 0. , 0. }]; \n\t\t
          radObjDivMag[mag, {Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \n\t\t
          tr = radTrfTrsl[{0. , Ls/4. , 0. }]; \n\t\t
          rt = radTrfRot[{0. , 0. , 0. }, {0. , 0. , 1. }, \(-Pi\)/2. ]; \n
          \t\tradTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
          mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, 
              Matm[\([3]\)]]; \n\t\tradMatApl[mag, mat]; \n\t\t
          radObjDrwAtr[mag, col[\([2]\)], 0.001]; \t\t\n\t\t
          radObjAddToCnt[grp1, {mag}]; \n\t\tmag1 = radObjDpl[mag]; \n\t\t\n
          \t\t\n\n\t\tmag = radObjThckPgn[0. , Ls, poly, {0. , mx, mz}]; \n
          \t\ttr = radTrfTrsl[{0. , Per/4. , 0. }]; \n\t\t
          radTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
          mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {0. , mx, 
                mz}]; \n\t\tradMatApl[mag, mat]; \n\t\t
          radObjDrwAtr[mag, col[\([1]\)], 0.001]; \n\t\t
          radObjDivMag[mag, {2*Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \n\t\t
          radObjAddToCnt[grp1, {mag}]; \n\t\t\n\t\t\n\t\n\t\t
          mag = radObjThckPgn[0. , Ls, poly, {Matm[\([3]\)], 0. , 0. }]; \t\n
          \t\ttr = radTrfTrsl[{0. , Per/2. , 0. }]; \n\t\t
          radTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
          mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, 
              Matm[\([3]\)]]; \n\t\tradMatApl[mag, mat]; \n\t\t
          radObjDrwAtr[mag, col[\([2]\)], 0.001]; \n\t\t
          radObjDivMag[mag, {2*Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \n\t\t
          radObjAddToCnt[grp1, {mag}]; \n\t\tmagv = radObjDpl[mag]; \n\t\t\n
          \t\t\n\t\n\t\t
          mag = radObjThckPgn[0. , Ls, poly, {0, \(-mx\), \(-mz\)}]; \n\t\t
          tr = radTrfTrsl[{0. , 3*Per/4. , 0. }]; \n\t\t
          tr1 = radTrfTrsl[{0. , 3*Per/4.  + dsext[\([1]\)], 0. }]; \n\t\t
          radTrfOrnt[mag, rt]; \n\t\t
          If[Nper <= 2, radTrfOrnt[mag, tr1], radTrfOrnt[mag, tr]]; \n\t\t\n
          \t\tmat = 
            radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {0. , 
                \(-mx\), \(-mz\)}]; \n\t\tradMatApl[mag, mat]; \n\t\t
          radObjDrwAtr[mag, col[\([1]\)], 0.001]; \n\t\t
          radObjDivMag[mag, {2*Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \n\t\t
          radObjAddToCnt[grp1, {mag}]; \n\t\tmagh = radObjDpl[mag]; \n\t\t\n\n
          \t\t\n\t\tNadd = Nper - 2; \n\t\t
          For[i = 1, i <= Nadd, \(i++\), \n\t\t
            tr = radTrfTrsl[{0. , Per/2. *i, 0. }]; \n\t\t
            tr1 = radTrfTrsl[{0. , Per/2. *i + dsext[\([1]\)], 0. }]; \t\n\t\t
            mag = radObjDpl[magv]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
            mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {
                  \((\(-1\))\)^i*Matm[\([3]\)], 0. , 0. }]; \t\n\n\t\t
            radMatApl[mag, mat]; \n\t\tradObjAddToCnt[grp1, {mag}]; \n\t\t\t\n
            \t\tmag = radObjDpl[magh]; \n\t\t
            If[i == Nadd, \n\t\t\t\tradTrfOrnt[mag, tr1], 
              radTrfOrnt[mag, tr]]; \t\n\t\t
            mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {0. , 
                  \((\(-1\))\)^\((i - 1)\)*mx, \((\(-1\))\)^\((i - 1)\)*mz}]; 
            \t\n\t\tradMatApl[mag, mat]; \n\t\t
            radObjAddToCnt[grp1, {mag}]; ]; \n\t\t\n\t\t\n\t\t
          Lx = LHL[\([1]\)]/2.  - Gx/2. ; \n\t\tLs = LHL[\([2]\)]; \n\t\t
          Lz = LHL[\([3]\)]; \n\t\t
          If[LHL[\([2]\)] \[NotEqual] 0. , \n\t\t
            p1 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\)}; \n\t\t
            p2 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\)}; \n\t\t
            p3 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Chamf}; \n\t\t
            p4 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Lz + Chamf}; \n\t\t
            p5 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
            p6 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
            poly = {p1, p2, p3, p4, p5, p6}; \n\t\t
            mx = \((\(-1\))\)^\((Nper - 1)\)*Matm[\([3]\)]; \n\t\tms = 0. ; \n
            \t\tmz = 0. ; \n\t\t
            mag = radObjThckPgn[0. , Ls, poly, {mx, ms, mz}]; \n\t\t
            tr = radTrfTrsl[{0. , 
                  Nper/2. *Per - Per/8.  + dsext[\([2]\)] + Ls/2. , 0. }]; \n
            \t\tradTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
            mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {mx, ms, 
                  mz}]; \n\t\tradMatApl[mag, mat]; \n\t\t
            radObjDrwAtr[mag, col[\([2]\)], 0.001]; \n\t\t
            radObjDivMag[mag, {2*Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \t\t
            \n\t\tradObjAddToCnt[grp1, {mag}], NULL]; \n\t\t
          s = Nper/2. *Per - Per/8.  + dsext[\([2]\)] + Ls + dsext[\([3]\)]; 
          \t\n\t\t\n\n\t\tLx = Lwi2[\([1]\)]/2.  - Gx/2. ; \n\t\t
          Ls = Lwi2[\([2]\)]; \n\t\tLz = Lwi2[\([3]\)]; \n\t\t\n\t\t
          p1 = {\(-Gxext\)/2. , \(-Abs[Gap/2. ]\)}; \n\t\t
          p2 = {\(-Gxext\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\)}; \n\t\t
          p3 = {\(-Gxext\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Chamf}; \n\t\t
          p4 = {\(-Gxext\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Lz + Chamf}; \n\t\t
          p5 = {\(-Gxext\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
          p6 = {\(-Gxext\)/2. , \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
          poly = {p1, p2, p3, p4, p5, p6}; \n\t\t
          mx = \((\(-1\))\)^\((Nper - 1)\)*Matm[\([3]\)]*
              Sin[\[Alpha]*Pi/180. ]; \n\t\t
          mz = \((\(-1\))\)^\((Nper - 1)\)*Matm[\([3]\)]*
              Cos[\[Alpha]*Pi/180. ]; \n\t\tms = 0. ; \n\t\t
          mag = radObjThckPgn[0. , Ls, poly, {ms, mx, mz}]; \n\t\t
          radObjDivMag[mag, {Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \n\t\t
          tr = radTrfTrsl[{0. , s + Ls/2. , 0. }]; \n\t\tradTrfOrnt[mag, rt]; 
          \n\t\tradTrfOrnt[mag, tr]; \n\t\t
          mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {ms, 
                \(-mx\), \(-mz\)}]; \n\t\tradMatApl[mag, mat]; \n\t\t
          radObjDrwAtr[mag, col[\([1]\)], 0.001]; \t\t\n\t\t
          radObjAddToCnt[grp1, {mag}]; \n\t\t
          s = s + Lwi2[\([2]\)] + dsext[\([4]\)]; \n\t\t\t\t\n\t\n\t\n\t\t
          Lx = LHW[\([1]\)]/2.  - Gx/2. ; \n\t\t
          If[LHW[\([2]\)] \[NotEqual] 0. , \n\t\tLs = LHW[\([2]\)]; \n\t\t
            Lz = LHW[\([3]\)]; \n\t\tp1 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\)}; \n
            \t\tp2 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\)}; \n\t\t
            p3 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Chamf}; \n\t\t
            p4 = {\(-Gx\)/2.  - Lx, \(-Abs[Gap/2. ]\) - Lz + Chamf}; \n\t\t
            p5 = {\(-Gx\)/2.  - Lx + Chamf, \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
            p6 = {\(-Gx\)/2. , \(-Abs[Gap/2. ]\) - Lz}; \n\t\t
            poly = {p1, p2, p3, p4, p5, p6}; \n\t\t
            mx = \((\(-1\))\)^\((Nper + 1)\)*Matm[\([3]\)]*
                Cos[\[Alpha]w*Pi/180. ]; \n\t\tms = 0. ; \n\t\t
            mz = \((\(-1\))\)^\((Nper + 1)\)*Matm[\([3]\)]*
                Sin[\[Alpha]w*Pi/180. ]; \n\t\t
            mag = radObjThckPgn[0. , Ls, poly, {\(-mx\), ms, mz}]; \n\t\t
            tr = radTrfTrsl[{0. , s + Ls/2. , 0. }]; \n\t\t
            radTrfOrnt[mag, rt]; \n\t\tradTrfOrnt[mag, tr]; \n\t\t
            mat = radMatLin[{Matm\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  Matm\[LeftDoubleBracket]2\[RightDoubleBracket]}, {\(-mx\), 
                  ms, mz}]; \n\t\tradMatApl[mag, mat]; \n\t\t
            radObjDrwAtr[mag, col[\([2]\)], 0.001]; \n\t\t
            radObjDivMag[mag, {Nm[\([2]\)], Nm[\([1]\)], Nm[\([3]\)]}]; \t\t\n
            \t\tradObjAddToCnt[grp1, {mag}], Null]; \n\t\t\n\t\t
          RadTrfZerPerp[grp1, {0, 0, 0}, {1, 0, 0}]; \n\t\t
          RadTrfZerPara[grp1, {0, 0, 0}, {0, 1, 0}]; \n\t\t\n\t\t
          Grp2 = radObjDpl[grp1, FreeSym -> True]; \n\t\t
          g1 = \(radObjCntStuf[Grp2]\)[\([1]\)]; \n\t\t
          g2 = \(radObjCntStuf[Grp2]\)[\([2]\)]; \n\t\t
          g3 = \(radObjCntStuf[Grp2]\)[\([3]\)]; \n\t\t
          g4 = \(radObjCntStuf[Grp2]\)[\([4]\)]; \n\t\t
          gr1 = radObjCnt[{g1, g3}]; \n\t\tgr2 = radObjCnt[{g2, g4}]; \n\t\t
          try = radTrfTrsl[{0. , ds, 0}]; \n\t\tradTrfOrnt[gr1, try]; \n\t\t
          Grp = radObjCnt[{gr1, gr2}]; \n\t\ttr1 = radTrfInv[]; \n\t\t
          tr2 = radTrfRot[{0. , 0. , 0. }, {0. , 1. , 0. }, Pi]; \n\t\t
          tr3 = radTrfCmbL[tr2, tr1]; \n\t\t
          If[Gap > 0, radTrfMlt[Grp, tr3, 2], Null]; \n\t\tGrp\n\t\t]\)}], 
      "\n", "\t"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Build[]", "Subsection"],

Cell[BoxData[
    \(Build[] := \n\t
      Module[{v1}, \n\t\t
        If[Symtype == \ "\<a\>", \n\t\t
          v1 = EpuA[Per, Nper, Gap, Gx, Lm, 0.01, Matm, 0. , 
              Nm, {2*Lx + Gx, Per/8.  - Ag/2. , Lz}, LW, 0. , 0. , LHL, LHW, 
              col, ds, {0, 0. , dsext[\([1]\)], dsext[\([2]\)]}, Gx], \ 
          v1 = EpuS[Per, Nper, Gap, Gx, Lm, 0.01, Matm, 0. , 
              Nm, {2*Lx + Gx, Per/8.  - Ag/2. , Lz}, LW, 0. , 0. , LHL, LHW, 
              col, ds, {0, 0. , dsext[\([1]\)], dsext[\([2]\)]}, Gx]]; \n\t\t
        v1\n\t\t]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["function solve", "Subsection"],

Cell[BoxData[
    \(\(solve[gap_, phi_, pri_:  1] := \n\t
      Module[{bx0, bz0, ix0, iz0}, \n\t\tGap = gap; \n\t\tds = phi; \n\t\t
        radUtiDelAll[]; \n\t\tGrp = Build[]; \n\t\tMtrx = radRlxPre[Grp]; \n
        \t\tRes = radRlxAuto[Mtrx, Prec, Nmax]; \n\t\tradUtiDel[Mtrx]; \n\t\t
        If[Symtype == "\<a\>", S0 = Per/4. , S0 = 0. ]; \n\t\t
        bz0 = radFld[Grp, "\<Bz\>", {0.001, S0 + ds/2. , 0.0001}]; \n\t\t
        bx0 = radFld[Grp, "\<Bx\>", {0.001, S0 + ds/2.  + Per/4. , 0.001}]; \n
        \t\tix0 = 
          radFldInt[Grp, "\<inf\>", 
              "\<ibx\>", {0, \(-1000. \), 0}, {0, 1000. , 0}]\ 1000; \n\t\t
        iz0 = radFldInt[Grp, "\<inf\>", 
              "\<ibz\>", {0, \(-1000. \), 0}, {0, 1000. , 0}]\ 1000; \n\t\t
        If[pri == 1, \n\t\t
          Print["\<gap=\>", Gap, "\< mm  \>", "\<phase=\>", ds, "\< mm  \>", 
            "\<relax=\>", \ Res]; \n\t\t
          Print\ ["\<Bx0=\>", NumberForm[bx0, 4], "\< T  \>", "\<Bz0=\>", 
            NumberForm[bz0, 4], "\< T  \>", "\<Ix0=\>", NumberForm[ix0, 2], 
            "\< G.cm  \>", "\<Iz0=\>", NumberForm[iz0, 2], "\< G.cm  \>"], 
          Null]; \n\t\t{bx0, bz0, ix0, iz0}\n\t\t]; \)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undulator parameters", "Section"],

Cell[CellGroupData[{

Cell["Main parts", "Subsection"],

Cell[CellGroupData[{

Cell["Notes on main parts", "Subsubsection",
  Background->RGBColor[1, 0.960006, 0.900008]],

Cell[TextData[{
  StyleBox["Description of the parameters :",
    FontWeight->"Bold"],
  "\n\n",
  StyleBox["Symtype",
    FontWeight->"Bold"],
  ": define if the vertical field is symmetric or antisymmetric (i.e. if the \
first and last peaks of the vertical field have the same or opposite \
poalrities), \"s\" means symmetric while \"a\" means antisymmetric\n",
  StyleBox["Per",
    FontWeight->"Bold"],
  ": period of the device [mm]\n",
  StyleBox["Nper",
    FontWeight->"Bold"],
  ": number of periods including extremities \n",
  StyleBox["Gap",
    FontWeight->"Bold"],
  ": magnetic gap between lower and upper jaw [mm]\n",
  StyleBox["Gx",
    FontWeight->"Bold"],
  ": horizontal air gap between magnet rows on a girder [mm]\n",
  StyleBox["Lx",
    FontWeight->"Bold"],
  ":transverse horizontal size of magnet blocks [mm]\n",
  StyleBox["Lz",
    FontWeight->"Bold"],
  ":height of magnet blocks [mm]\n",
  StyleBox["Ag",
    FontWeight->"Bold"],
  ":longitudinal air gap between blocks [mm]\n",
  StyleBox["ds",
    FontWeight->"Bold"],
  ":phase shift between fixed and movable rows [mm]\n",
  StyleBox["Matm",
    FontWeight->"Bold"],
  ":  magnet material  : { Susceptibility  parall. Susceptibility perp., \
Remanence}\n",
  StyleBox["Nm ",
    FontWeight->"Bold"],
  ": subdivision of magnet blocks\n",
  StyleBox["colv",
    FontWeight->"Bold"],
  ":RGB color of V type blocks\n",
  StyleBox["colh",
    FontWeight->"Bold"],
  ":RGB color of H type blocks\n\nThe subdivision parameter  ",
  StyleBox["Nm",
    FontWeight->"Bold"],
  "   is crucial. On should not use a value smaller than  {2,2,2} to obtain \
enough precision on the field integrals. However, if one is just interested \
in the  peak field , one may use {1,1,1} which would dramtically reduce the \
solving time.  Do not hesitate to vary ",
  StyleBox["Nm",
    FontWeight->"Bold"],
  " and watch the field integral computed.\nNote that, the order of the \
symmetries built into the structure is  2 rather than 8 ( for a planar \
undulator). \nThis increase the memory needed by a factor 4 x 4  and the cpu \
time by 4 . This is the price to pay for magnetic structures lacking  a high \
degree of symmetries. \nIf a value \"s\"( \"a\" )  is used for ",
  StyleBox["Symtype ",
    FontWeight->"Bold"],
  ", only the vertical (horizontal)  field integral differs from zero, the \
horizontal  (vertical) field integral of each extremities cancel.   The \
double field integrals  DO NOT CANCEL. They may be computed numerically from \
the field profile or  as the product  of the undulator length times the field \
integral generated at one  extremity. (more precise). The computation of the  \
horizontal (vertical) field integral generated by one extremity  is done by \
creating  a structure with   ",
  StyleBox["Symtype  ",
    FontWeight->"Bold"],
  "equal to \"s\" ( \"a\") and by dividing the total field integral by 2. "
}], "Text",
  CellFrame->True,
  ShowCellBracket->True,
  ShowGroupOpenCloseIcon->False,
  ShowClosedCellArea->False,
  ShowShortBoxForm->False,
  Evaluatable->False,
  Background->RGBColor[0.927199, 0.874189, 0.929992]],

Cell[BoxData[
    RowBox[{\(Symtype = "\<s\>"\), ";", "\n", \(Per = 56. \), ";", 
      StyleBox[" ",
        "Commentary"], "\n", \(Nper = 2\), ";", 
      StyleBox[
        StyleBox[
          RowBox[{
            StyleBox[" ",
              "Commentary"], " "}]],
        "Commentary"], "\n", \(Gap = 16. \), ";", 
      StyleBox["  ",
        "Commentary"], "\n", \(Gx = 1.0\), ";", "  ", "\n", \(Lx = 28. \), 
      ";", " ", "\n", \(Lz = 28. \), ";", "\n", \(Ag = 0.1\), ";", "  ", 
      "\n", \(ds = 0. \), ";", "  ", "\n", \(Matm = {0.06, 0.17, 1.1}\), ";", 
      "\n", \(Nm = {2, 2, 2}\), ";", " ", "\n", \(colv = {0, 1, 0}\), ";", 
      " ", "\n", \(colh = {0, 1, 1}\), ";", "\n", \(Lm = {2*Lx, Ag, Lz}\), 
      ";", "\n", \(col = {colv, colh}\), ";"}]], "Input",
  CellFrame->False,
  Background->GrayLevel[0.999985]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extremities", "Subsection"],

Cell[CellGroupData[{

Cell["Notes on extremities", "Subsubsection"],

Cell[TextData[{
  "The folowing cell describe the extremity magnet blocks. The magnet named  \
HL and HW are those of the PAC99 conference paper. \n\n-",
  StyleBox["LW",
    FontWeight->"Bold"],
  " is the size of magnet block W , {hor.,long.,vert.}\n- ",
  StyleBox["LHL",
    FontWeight->"Bold"],
  " is the size of magnet block HL\n-",
  StyleBox["LHW",
    FontWeight->"Bold"],
  " is the size of the magnet HW \n- ",
  StyleBox["dsext",
    FontWeight->"Bold"],
  " define the air gap between magnet blocks Hl | W and W|HW\nremark:\nNote \
that a conventional end field structure (with half vertically magnetized \
block)  can be generated by setting dsext to {0,0}, LW to {any vlue,",
  StyleBox["0",
    FontWeight->"Bold"],
  " ,any value} (longitudinal thickness to zero) and the longitudinal \
thickness of magnet HL to period/4 (second term of LHL)."
}], "Commentary",
  CellFrame->True,
  Evaluatable->False,
  Background->RGBColor[0.927199, 0.874189, 0.929992]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extremity parameters", "Subsubsection"],

Cell[BoxData[
    \(\(LW = {2*Lx + Gx, Per/8.  - Ag/2.  - 0.07, Lz}; \n
    LHL = \ {2*Lx + Gx, Per/6. , Lz}; \nLHW = {2*Lx + Gx, 0.62*Per/6. , Lz}; 
    \ndsext = {4.5, 1.5}; \ \)\)], "Input",
  CellFrame->False,
  Background->GrayLevel[0.999985],
  Magnification->1]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solve", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prec = 0.00001; \nNmax = 10. ; \nGap = 16; \nphi = 0; \n
    solve[Gap, phi, 1]; \)], "Input"],

Cell[BoxData[
    InterpretationBox[
      \("gap="\[InvisibleSpace]16
        \[InvisibleSpace]" mm  "\[InvisibleSpace]"phase="\[InvisibleSpace]0
        \[InvisibleSpace]" mm  "\[InvisibleSpace]"relax="\[InvisibleSpace]{
          5.72858616720305224`*^-7, 1.0998005873800858`, 
          0.971239535651932506`, 3}\),
      SequenceForm[ 
      "gap=", 16, " mm  ", "phase=", 0, " mm  ", "relax=", {
        5.7285861672030524*^-07, 1.0998005873800858, 0.97123953565193255, 
        3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Bx0=\"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox[\("4.968"\[Times]10\^"-7"\),
            4.968133357183618*^-07,
            AutoDelete->True],
          (NumberForm[ #, 4]&)], "\[InvisibleSpace]", "\<\" T  \"\>", 
        "\[InvisibleSpace]", "\<\"Bz0=\"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"0.6879\"\>",
            0.68790685800683504,
            AutoDelete->True],
          (NumberForm[ #, 4]&)], "\[InvisibleSpace]", "\<\" T  \"\>", 
        "\[InvisibleSpace]", "\<\"Ix0=\"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"0.00017\"\>",
            0.00016962089735850594,
            AutoDelete->True],
          (NumberForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" G.cm  \"\>", 
        "\[InvisibleSpace]", "\<\"Iz0=\"\>", "\[InvisibleSpace]", 
        TagBox[
          InterpretationBox["\<\"-4.7\"\>",
            -4.705808117906348,
            AutoDelete->True],
          (NumberForm[ #, 2]&)], "\[InvisibleSpace]", "\<\" G.cm  \"\>"}],
      SequenceForm[ "Bx0=", 
        NumberForm[ 4.968133357183618*^-07, 4], " T  ", "Bz0=", 
        NumberForm[ 0.68790685800683504, 4], " T  ", "Ix0=", 
        NumberForm[ 0.00016962089735850594, 2], " G.cm  ", "Iz0=", 
        NumberForm[ -4.705808117906348, 2], " G.cm  "],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Section"],

Cell[CellGroupData[{

Cell["Field integral", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
    \(zc = 0. \), ";", "\n", \(x1 = \(-50.0\)\), ";", "\n", \(x2 = 50.0\), 
      ";", "\n", \(xstep = 2.5\), ";", "\n", 
      RowBox[{"Tx0", "=", 
        RowBox[{"Table", "[", 
          RowBox[{
          \({x, radFldInt[Grp, "\<inf\>", 
                  "\<ibx\>", {x, \(-1000. \), zc}, {x, 1000. , zc}]\ 1000}\), 
            ",", 
            RowBox[{"{", 
              RowBox[{"x", ",", "x1", ",", "x2", ",", 
                StyleBox["xstep",
                  FontFamily->"Courier"]}], "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"Tz0", "=", 
        RowBox[{"Table", "[", 
          RowBox[{
          \({x, radFldInt[Grp, "\<inf\>", 
                  "\<ibz\>", {x, \(-1000. \), zc}, {x, 1000. , zc}]\ 1000}\), 
            ",", 
            RowBox[{"{", 
              RowBox[{"x", ",", "x1", ",", "x2", ",", 
                StyleBox["xstep",
                  FontFamily->"Courier"]}], "}"}]}], "]"}]}], ";", "\n", 
      \(Print["\<field integral as a function of the horizontal coordinate  \
in G.cm\>"]\), ";", "\n", 
      \(MultipleListPlot[Tx0, Tz0, PlotJoined \[Rule] {True, True}, \n\t\t
        PlotRange \[Rule] All]\), ";"}]], "Input"],

Cell[BoxData[
    \("field integral computation in G.cm"\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.00952381 0.478882 0.0396624 [
[.11905 .46638 -12.5 -14 ]
[.11905 .46638 12.5 0 ]
[.30952 .46638 -12.5 -14 ]
[.30952 .46638 12.5 0 ]
[.69048 .46638 -8 -14 ]
[.69048 .46638 8 0 ]
[.88095 .46638 -8 -14 ]
[.88095 .46638 8 0 ]
[.4875 .00293 -25 -7 ]
[.4875 .00293 0 7 ]
[.4875 .08226 -25 -7 ]
[.4875 .08226 0 7 ]
[.4875 .16158 -19 -7 ]
[.4875 .16158 0 7 ]
[.4875 .24091 -19 -7 ]
[.4875 .24091 0 7 ]
[.4875 .32023 -19 -7 ]
[.4875 .32023 0 7 ]
[.4875 .39956 -19 -7 ]
[.4875 .39956 0 7 ]
[.4875 .55821 -10 -7 ]
[.4875 .55821 0 7 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .47888 m
.11905 .48513 L
s
gsave
.11905 .46638 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.30952 .47888 m
.30952 .48513 L
s
gsave
.30952 .46638 -73.5 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.69048 .47888 m
.69048 .48513 L
s
gsave
.69048 .46638 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88095 .47888 m
.88095 .48513 L
s
gsave
.88095 .46638 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.16667 .47888 m
.16667 .48263 L
s
.21429 .47888 m
.21429 .48263 L
s
.2619 .47888 m
.2619 .48263 L
s
.35714 .47888 m
.35714 .48263 L
s
.40476 .47888 m
.40476 .48263 L
s
.45238 .47888 m
.45238 .48263 L
s
.54762 .47888 m
.54762 .48263 L
s
.59524 .47888 m
.59524 .48263 L
s
.64286 .47888 m
.64286 .48263 L
s
.7381 .47888 m
.7381 .48263 L
s
.78571 .47888 m
.78571 .48263 L
s
.83333 .47888 m
.83333 .48263 L
s
.07143 .47888 m
.07143 .48263 L
s
.02381 .47888 m
.02381 .48263 L
s
.92857 .47888 m
.92857 .48263 L
s
.97619 .47888 m
.97619 .48263 L
s
.25 Mabswid
0 .47888 m
1 .47888 L
s
.5 .00293 m
.50625 .00293 L
s
gsave
.4875 .00293 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .08226 m
.50625 .08226 L
s
gsave
.4875 .08226 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .16158 m
.50625 .16158 L
s
gsave
.4875 .16158 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .24091 m
.50625 .24091 L
s
gsave
.4875 .24091 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .32023 m
.50625 .32023 L
s
gsave
.4875 .32023 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .39956 m
.50625 .39956 L
s
gsave
.4875 .39956 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.562500 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .55821 m
.50625 .55821 L
s
gsave
.4875 .55821 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.5 .02276 m
.50375 .02276 L
s
.5 .0426 m
.50375 .0426 L
s
.5 .06243 m
.50375 .06243 L
s
.5 .10209 m
.50375 .10209 L
s
.5 .12192 m
.50375 .12192 L
s
.5 .14175 m
.50375 .14175 L
s
.5 .18141 m
.50375 .18141 L
s
.5 .20124 m
.50375 .20124 L
s
.5 .22108 m
.50375 .22108 L
s
.5 .26074 m
.50375 .26074 L
s
.5 .28057 m
.50375 .28057 L
s
.5 .3004 m
.50375 .3004 L
s
.5 .34006 m
.50375 .34006 L
s
.5 .35989 m
.50375 .35989 L
s
.5 .37973 m
.50375 .37973 L
s
.5 .41939 m
.50375 .41939 L
s
.5 .43922 m
.50375 .43922 L
s
.5 .45905 m
.50375 .45905 L
s
.5 .49871 m
.50375 .49871 L
s
.5 .51854 m
.50375 .51854 L
s
.5 .53838 m
.50375 .53838 L
s
.5 .57804 m
.50375 .57804 L
s
.5 .59787 m
.50375 .59787 L
s
.5 .6177 m
.50375 .6177 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.001 w
.02381 .47888 m
.04762 .47888 L
.07143 .47888 L
.09524 .47888 L
.11905 .47888 L
.14286 .47888 L
.16667 .47888 L
.19048 .47888 L
.21429 .47888 L
.2381 .47888 L
.2619 .47888 L
.28571 .47888 L
.30952 .47888 L
.33333 .47888 L
.35714 .47889 L
.38095 .47889 L
.40476 .47889 L
.42857 .47889 L
.45238 .47889 L
.47619 .47889 L
.5 .47889 L
.52381 .47889 L
.54762 .47889 L
.57143 .47889 L
.59524 .47889 L
.61905 .47889 L
.64286 .47889 L
.66667 .47888 L
.69048 .47888 L
.71429 .47888 L
.7381 .47888 L
.7619 .47888 L
.78571 .47888 L
.80952 .47888 L
.83333 .47888 L
.85714 .47888 L
.88095 .47888 L
.90476 .47888 L
.92857 .47888 L
.95238 .47888 L
.97619 .47888 L
s
.0001 w
.02381 .47888 -1.875 0 Mabsadd m
.02381 .47888 0 2.5 Mabsadd L
.02381 .47888 1.875 0 Mabsadd L
.02381 .47888 0 -2.5 Mabsadd L
.02381 .47888 -1.875 0 Mabsadd L closepath F
.04762 .47888 -1.875 0 Mabsadd m
.04762 .47888 0 2.5 Mabsadd L
.04762 .47888 1.875 0 Mabsadd L
.04762 .47888 0 -2.5 Mabsadd L
.04762 .47888 -1.875 0 Mabsadd L closepath F
.07143 .47888 -1.875 0 Mabsadd m
.07143 .47888 0 2.5 Mabsadd L
.07143 .47888 1.875 0 Mabsadd L
.07143 .47888 0 -2.5 Mabsadd L
.07143 .47888 -1.875 0 Mabsadd L closepath F
.09524 .47888 -1.875 0 Mabsadd m
.09524 .47888 0 2.5 Mabsadd L
.09524 .47888 1.875 0 Mabsadd L
.09524 .47888 0 -2.5 Mabsadd L
.09524 .47888 -1.875 0 Mabsadd L closepath F
.11905 .47888 -1.875 0 Mabsadd m
.11905 .47888 0 2.5 Mabsadd L
.11905 .47888 1.875 0 Mabsadd L
.11905 .47888 0 -2.5 Mabsadd L
.11905 .47888 -1.875 0 Mabsadd L closepath F
.14286 .47888 -1.875 0 Mabsadd m
.14286 .47888 0 2.5 Mabsadd L
.14286 .47888 1.875 0 Mabsadd L
.14286 .47888 0 -2.5 Mabsadd L
.14286 .47888 -1.875 0 Mabsadd L closepath F
.16667 .47888 -1.875 0 Mabsadd m
.16667 .47888 0 2.5 Mabsadd L
.16667 .47888 1.875 0 Mabsadd L
.16667 .47888 0 -2.5 Mabsadd L
.16667 .47888 -1.875 0 Mabsadd L closepath F
.19048 .47888 -1.875 0 Mabsadd m
.19048 .47888 0 2.5 Mabsadd L
.19048 .47888 1.875 0 Mabsadd L
.19048 .47888 0 -2.5 Mabsadd L
.19048 .47888 -1.875 0 Mabsadd L closepath F
.21429 .47888 -1.875 0 Mabsadd m
.21429 .47888 0 2.5 Mabsadd L
.21429 .47888 1.875 0 Mabsadd L
.21429 .47888 0 -2.5 Mabsadd L
.21429 .47888 -1.875 0 Mabsadd L closepath F
.2381 .47888 -1.875 0 Mabsadd m
.2381 .47888 0 2.5 Mabsadd L
.2381 .47888 1.875 0 Mabsadd L
.2381 .47888 0 -2.5 Mabsadd L
.2381 .47888 -1.875 0 Mabsadd L closepath F
.2619 .47888 -1.875 0 Mabsadd m
.2619 .47888 0 2.5 Mabsadd L
.2619 .47888 1.875 0 Mabsadd L
.2619 .47888 0 -2.5 Mabsadd L
.2619 .47888 -1.875 0 Mabsadd L closepath F
.28571 .47888 -1.875 0 Mabsadd m
.28571 .47888 0 2.5 Mabsadd L
.28571 .47888 1.875 0 Mabsadd L
.28571 .47888 0 -2.5 Mabsadd L
.28571 .47888 -1.875 0 Mabsadd L closepath F
.30952 .47888 -1.875 0 Mabsadd m
.30952 .47888 0 2.5 Mabsadd L
.30952 .47888 1.875 0 Mabsadd L
.30952 .47888 0 -2.5 Mabsadd L
.30952 .47888 -1.875 0 Mabsadd L closepath F
.33333 .47888 -1.875 0 Mabsadd m
.33333 .47888 0 2.5 Mabsadd L
.33333 .47888 1.875 0 Mabsadd L
.33333 .47888 0 -2.5 Mabsadd L
.33333 .47888 -1.875 0 Mabsadd L closepath F
.35714 .47889 -1.875 0 Mabsadd m
.35714 .47889 0 2.5 Mabsadd L
.35714 .47889 1.875 0 Mabsadd L
.35714 .47889 0 -2.5 Mabsadd L
.35714 .47889 -1.875 0 Mabsadd L closepath F
.38095 .47889 -1.875 0 Mabsadd m
.38095 .47889 0 2.5 Mabsadd L
.38095 .47889 1.875 0 Mabsadd L
.38095 .47889 0 -2.5 Mabsadd L
.38095 .47889 -1.875 0 Mabsadd L closepath F
.40476 .47889 -1.875 0 Mabsadd m
.40476 .47889 0 2.5 Mabsadd L
.40476 .47889 1.875 0 Mabsadd L
.40476 .47889 0 -2.5 Mabsadd L
.40476 .47889 -1.875 0 Mabsadd L closepath F
.42857 .47889 -1.875 0 Mabsadd m
.42857 .47889 0 2.5 Mabsadd L
.42857 .47889 1.875 0 Mabsadd L
.42857 .47889 0 -2.5 Mabsadd L
.42857 .47889 -1.875 0 Mabsadd L closepath F
.45238 .47889 -1.875 0 Mabsadd m
.45238 .47889 0 2.5 Mabsadd L
.45238 .47889 1.875 0 Mabsadd L
.45238 .47889 0 -2.5 Mabsadd L
.45238 .47889 -1.875 0 Mabsadd L closepath F
.47619 .47889 -1.875 0 Mabsadd m
.47619 .47889 0 2.5 Mabsadd L
.47619 .47889 1.875 0 Mabsadd L
.47619 .47889 0 -2.5 Mabsadd L
.47619 .47889 -1.875 0 Mabsadd L closepath F
.5 .47889 -1.875 0 Mabsadd m
.5 .47889 0 2.5 Mabsadd L
.5 .47889 1.875 0 Mabsadd L
.5 .47889 0 -2.5 Mabsadd L
.5 .47889 -1.875 0 Mabsadd L closepath F
.52381 .47889 -1.875 0 Mabsadd m
.52381 .47889 0 2.5 Mabsadd L
.52381 .47889 1.875 0 Mabsadd L
.52381 .47889 0 -2.5 Mabsadd L
.52381 .47889 -1.875 0 Mabsadd L closepath F
.54762 .47889 -1.875 0 Mabsadd m
.54762 .47889 0 2.5 Mabsadd L
.54762 .47889 1.875 0 Mabsadd L
.54762 .47889 0 -2.5 Mabsadd L
.54762 .47889 -1.875 0 Mabsadd L closepath F
.57143 .47889 -1.875 0 Mabsadd m
.57143 .47889 0 2.5 Mabsadd L
.57143 .47889 1.875 0 Mabsadd L
.57143 .47889 0 -2.5 Mabsadd L
.57143 .47889 -1.875 0 Mabsadd L closepath F
.59524 .47889 -1.875 0 Mabsadd m
.59524 .47889 0 2.5 Mabsadd L
.59524 .47889 1.875 0 Mabsadd L
.59524 .47889 0 -2.5 Mabsadd L
.59524 .47889 -1.875 0 Mabsadd L closepath F
.61905 .47889 -1.875 0 Mabsadd m
.61905 .47889 0 2.5 Mabsadd L
.61905 .47889 1.875 0 Mabsadd L
.61905 .47889 0 -2.5 Mabsadd L
.61905 .47889 -1.875 0 Mabsadd L closepath F
.64286 .47889 -1.875 0 Mabsadd m
.64286 .47889 0 2.5 Mabsadd L
.64286 .47889 1.875 0 Mabsadd L
.64286 .47889 0 -2.5 Mabsadd L
.64286 .47889 -1.875 0 Mabsadd L closepath F
.66667 .47888 -1.875 0 Mabsadd m
.66667 .47888 0 2.5 Mabsadd L
.66667 .47888 1.875 0 Mabsadd L
.66667 .47888 0 -2.5 Mabsadd L
.66667 .47888 -1.875 0 Mabsadd L closepath F
.69048 .47888 -1.875 0 Mabsadd m
.69048 .47888 0 2.5 Mabsadd L
.69048 .47888 1.875 0 Mabsadd L
.69048 .47888 0 -2.5 Mabsadd L
.69048 .47888 -1.875 0 Mabsadd L closepath F
.71429 .47888 -1.875 0 Mabsadd m
.71429 .47888 0 2.5 Mabsadd L
.71429 .47888 1.875 0 Mabsadd L
.71429 .47888 0 -2.5 Mabsadd L
.71429 .47888 -1.875 0 Mabsadd L closepath F
.7381 .47888 -1.875 0 Mabsadd m
.7381 .47888 0 2.5 Mabsadd L
.7381 .47888 1.875 0 Mabsadd L
.7381 .47888 0 -2.5 Mabsadd L
.7381 .47888 -1.875 0 Mabsadd L closepath F
.7619 .47888 -1.875 0 Mabsadd m
.7619 .47888 0 2.5 Mabsadd L
.7619 .47888 1.875 0 Mabsadd L
.7619 .47888 0 -2.5 Mabsadd L
.7619 .47888 -1.875 0 Mabsadd L closepath F
.78571 .47888 -1.875 0 Mabsadd m
.78571 .47888 0 2.5 Mabsadd L
.78571 .47888 1.875 0 Mabsadd L
.78571 .47888 0 -2.5 Mabsadd L
.78571 .47888 -1.875 0 Mabsadd L closepath F
.80952 .47888 -1.875 0 Mabsadd m
.80952 .47888 0 2.5 Mabsadd L
.80952 .47888 1.875 0 Mabsadd L
.80952 .47888 0 -2.5 Mabsadd L
.80952 .47888 -1.875 0 Mabsadd L closepath F
.83333 .47888 -1.875 0 Mabsadd m
.83333 .47888 0 2.5 Mabsadd L
.83333 .47888 1.875 0 Mabsadd L
.83333 .47888 0 -2.5 Mabsadd L
.83333 .47888 -1.875 0 Mabsadd L closepath F
.85714 .47888 -1.875 0 Mabsadd m
.85714 .47888 0 2.5 Mabsadd L
.85714 .47888 1.875 0 Mabsadd L
.85714 .47888 0 -2.5 Mabsadd L
.85714 .47888 -1.875 0 Mabsadd L closepath F
.88095 .47888 -1.875 0 Mabsadd m
.88095 .47888 0 2.5 Mabsadd L
.88095 .47888 1.875 0 Mabsadd L
.88095 .47888 0 -2.5 Mabsadd L
.88095 .47888 -1.875 0 Mabsadd L closepath F
.90476 .47888 -1.875 0 Mabsadd m
.90476 .47888 0 2.5 Mabsadd L
.90476 .47888 1.875 0 Mabsadd L
.90476 .47888 0 -2.5 Mabsadd L
.90476 .47888 -1.875 0 Mabsadd L closepath F
.92857 .47888 -1.875 0 Mabsadd m
.92857 .47888 0 2.5 Mabsadd L
.92857 .47888 1.875 0 Mabsadd L
.92857 .47888 0 -2.5 Mabsadd L
.92857 .47888 -1.875 0 Mabsadd L closepath F
.95238 .47888 -1.875 0 Mabsadd m
.95238 .47888 0 2.5 Mabsadd L
.95238 .47888 1.875 0 Mabsadd L
.95238 .47888 0 -2.5 Mabsadd L
.95238 .47888 -1.875 0 Mabsadd L closepath F
.97619 .47888 -1.875 0 Mabsadd m
.97619 .47888 0 2.5 Mabsadd L
.97619 .47888 1.875 0 Mabsadd L
.97619 .47888 0 -2.5 Mabsadd L
.97619 .47888 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.02381 .54291 m
.04762 .55131 L
.07143 .56225 L
.09524 .57559 L
.11905 .59004 L
.14286 .6019 L
.16667 .60332 L
.19048 .58145 L
.21429 .52342 L
.2381 .43137 L
.2619 .3286 L
.28571 .23624 L
.30952 .15669 L
.33333 .08592 L
.35714 .03177 L
.38095 .01472 L
.40476 .04481 L
.42857 .11074 L
.45238 .19185 L
.47619 .26278 L
.5 .29223 L
.52381 .26278 L
.54762 .19185 L
.57143 .11074 L
.59524 .04481 L
.61905 .01472 L
.64286 .03177 L
.66667 .08592 L
.69048 .15669 L
.71429 .23624 L
.7381 .3286 L
.7619 .43137 L
.78571 .52342 L
.80952 .58145 L
.83333 .60332 L
.85714 .6019 L
.88095 .59004 L
.90476 .57559 L
.92857 .56225 L
.95238 .55131 L
.97619 .54291 L
s
.0001 w
[ ] 0 setdash
.02381 .54291 0 2.5 Mabsadd m
.02381 .54291 -0.56518 .7779 Mabsadd L
.02381 .54291 -2.37764 .77254 Mabsadd L
.02381 .54291 -0.91448 -0.29713 Mabsadd L
.02381 .54291 -1.46946 -2.02254 Mabsadd L
.02381 .54291 0 -0.96154 Mabsadd L
.02381 .54291 1.46946 -2.02254 Mabsadd L
.02381 .54291 .91448 -0.29713 Mabsadd L
.02381 .54291 2.37764 .77254 Mabsadd L
.02381 .54291 .56518 .7779 Mabsadd L
.02381 .54291 0 2.5 Mabsadd L closepath F
.04762 .55131 0 2.5 Mabsadd m
.04762 .55131 -0.56518 .7779 Mabsadd L
.04762 .55131 -2.37764 .77254 Mabsadd L
.04762 .55131 -0.91448 -0.29713 Mabsadd L
.04762 .55131 -1.46946 -2.02254 Mabsadd L
.04762 .55131 0 -0.96154 Mabsadd L
.04762 .55131 1.46946 -2.02254 Mabsadd L
.04762 .55131 .91448 -0.29713 Mabsadd L
.04762 .55131 2.37764 .77254 Mabsadd L
.04762 .55131 .56518 .7779 Mabsadd L
.04762 .55131 0 2.5 Mabsadd L closepath F
.07143 .56225 0 2.5 Mabsadd m
.07143 .56225 -0.56518 .7779 Mabsadd L
.07143 .56225 -2.37764 .77254 Mabsadd L
.07143 .56225 -0.91448 -0.29713 Mabsadd L
.07143 .56225 -1.46946 -2.02254 Mabsadd L
.07143 .56225 0 -0.96154 Mabsadd L
.07143 .56225 1.46946 -2.02254 Mabsadd L
.07143 .56225 .91448 -0.29713 Mabsadd L
.07143 .56225 2.37764 .77254 Mabsadd L
.07143 .56225 .56518 .7779 Mabsadd L
.07143 .56225 0 2.5 Mabsadd L closepath F
.09524 .57559 0 2.5 Mabsadd m
.09524 .57559 -0.56518 .7779 Mabsadd L
.09524 .57559 -2.37764 .77254 Mabsadd L
.09524 .57559 -0.91448 -0.29713 Mabsadd L
.09524 .57559 -1.46946 -2.02254 Mabsadd L
.09524 .57559 0 -0.96154 Mabsadd L
.09524 .57559 1.46946 -2.02254 Mabsadd L
.09524 .57559 .91448 -0.29713 Mabsadd L
.09524 .57559 2.37764 .77254 Mabsadd L
.09524 .57559 .56518 .7779 Mabsadd L
.09524 .57559 0 2.5 Mabsadd L closepath F
.11905 .59004 0 2.5 Mabsadd m
.11905 .59004 -0.56518 .7779 Mabsadd L
.11905 .59004 -2.37764 .77254 Mabsadd L
.11905 .59004 -0.91448 -0.29713 Mabsadd L
.11905 .59004 -1.46946 -2.02254 Mabsadd L
.11905 .59004 0 -0.96154 Mabsadd L
.11905 .59004 1.46946 -2.02254 Mabsadd L
.11905 .59004 .91448 -0.29713 Mabsadd L
.11905 .59004 2.37764 .77254 Mabsadd L
.11905 .59004 .56518 .7779 Mabsadd L
.11905 .59004 0 2.5 Mabsadd L closepath F
.14286 .6019 0 2.5 Mabsadd m
.14286 .6019 -0.56518 .7779 Mabsadd L
.14286 .6019 -2.37764 .77254 Mabsadd L
.14286 .6019 -0.91448 -0.29713 Mabsadd L
.14286 .6019 -1.46946 -2.02254 Mabsadd L
.14286 .6019 0 -0.96154 Mabsadd L
.14286 .6019 1.46946 -2.02254 Mabsadd L
.14286 .6019 .91448 -0.29713 Mabsadd L
.14286 .6019 2.37764 .77254 Mabsadd L
.14286 .6019 .56518 .7779 Mabsadd L
.14286 .6019 0 2.5 Mabsadd L closepath F
.16667 .60332 0 2.5 Mabsadd m
.16667 .60332 -0.56518 .7779 Mabsadd L
.16667 .60332 -2.37764 .77254 Mabsadd L
.16667 .60332 -0.91448 -0.29713 Mabsadd L
.16667 .60332 -1.46946 -2.02254 Mabsadd L
.16667 .60332 0 -0.96154 Mabsadd L
.16667 .60332 1.46946 -2.02254 Mabsadd L
.16667 .60332 .91448 -0.29713 Mabsadd L
.16667 .60332 2.37764 .77254 Mabsadd L
.16667 .60332 .56518 .7779 Mabsadd L
.16667 .60332 0 2.5 Mabsadd L closepath F
.19048 .58145 0 2.5 Mabsadd m
.19048 .58145 -0.56518 .7779 Mabsadd L
.19048 .58145 -2.37764 .77254 Mabsadd L
.19048 .58145 -0.91448 -0.29713 Mabsadd L
.19048 .58145 -1.46946 -2.02254 Mabsadd L
.19048 .58145 0 -0.96154 Mabsadd L
.19048 .58145 1.46946 -2.02254 Mabsadd L
.19048 .58145 .91448 -0.29713 Mabsadd L
.19048 .58145 2.37764 .77254 Mabsadd L
.19048 .58145 .56518 .7779 Mabsadd L
.19048 .58145 0 2.5 Mabsadd L closepath F
.21429 .52342 0 2.5 Mabsadd m
.21429 .52342 -0.56518 .7779 Mabsadd L
.21429 .52342 -2.37764 .77254 Mabsadd L
.21429 .52342 -0.91448 -0.29713 Mabsadd L
.21429 .52342 -1.46946 -2.02254 Mabsadd L
.21429 .52342 0 -0.96154 Mabsadd L
.21429 .52342 1.46946 -2.02254 Mabsadd L
.21429 .52342 .91448 -0.29713 Mabsadd L
.21429 .52342 2.37764 .77254 Mabsadd L
.21429 .52342 .56518 .7779 Mabsadd L
.21429 .52342 0 2.5 Mabsadd L closepath F
.2381 .43137 0 2.5 Mabsadd m
.2381 .43137 -0.56518 .7779 Mabsadd L
.2381 .43137 -2.37764 .77254 Mabsadd L
.2381 .43137 -0.91448 -0.29713 Mabsadd L
.2381 .43137 -1.46946 -2.02254 Mabsadd L
.2381 .43137 0 -0.96154 Mabsadd L
.2381 .43137 1.46946 -2.02254 Mabsadd L
.2381 .43137 .91448 -0.29713 Mabsadd L
.2381 .43137 2.37764 .77254 Mabsadd L
.2381 .43137 .56518 .7779 Mabsadd L
.2381 .43137 0 2.5 Mabsadd L closepath F
.2619 .3286 0 2.5 Mabsadd m
.2619 .3286 -0.56518 .7779 Mabsadd L
.2619 .3286 -2.37764 .77254 Mabsadd L
.2619 .3286 -0.91448 -0.29713 Mabsadd L
.2619 .3286 -1.46946 -2.02254 Mabsadd L
.2619 .3286 0 -0.96154 Mabsadd L
.2619 .3286 1.46946 -2.02254 Mabsadd L
.2619 .3286 .91448 -0.29713 Mabsadd L
.2619 .3286 2.37764 .77254 Mabsadd L
.2619 .3286 .56518 .7779 Mabsadd L
.2619 .3286 0 2.5 Mabsadd L closepath F
.28571 .23624 0 2.5 Mabsadd m
.28571 .23624 -0.56518 .7779 Mabsadd L
.28571 .23624 -2.37764 .77254 Mabsadd L
.28571 .23624 -0.91448 -0.29713 Mabsadd L
.28571 .23624 -1.46946 -2.02254 Mabsadd L
.28571 .23624 0 -0.96154 Mabsadd L
.28571 .23624 1.46946 -2.02254 Mabsadd L
.28571 .23624 .91448 -0.29713 Mabsadd L
.28571 .23624 2.37764 .77254 Mabsadd L
.28571 .23624 .56518 .7779 Mabsadd L
.28571 .23624 0 2.5 Mabsadd L closepath F
.30952 .15669 0 2.5 Mabsadd m
.30952 .15669 -0.56518 .7779 Mabsadd L
.30952 .15669 -2.37764 .77254 Mabsadd L
.30952 .15669 -0.91448 -0.29713 Mabsadd L
.30952 .15669 -1.46946 -2.02254 Mabsadd L
.30952 .15669 0 -0.96154 Mabsadd L
.30952 .15669 1.46946 -2.02254 Mabsadd L
.30952 .15669 .91448 -0.29713 Mabsadd L
.30952 .15669 2.37764 .77254 Mabsadd L
.30952 .15669 .56518 .7779 Mabsadd L
.30952 .15669 0 2.5 Mabsadd L closepath F
.33333 .08592 0 2.5 Mabsadd m
.33333 .08592 -0.56518 .7779 Mabsadd L
.33333 .08592 -2.37764 .77254 Mabsadd L
.33333 .08592 -0.91448 -0.29713 Mabsadd L
.33333 .08592 -1.46946 -2.02254 Mabsadd L
.33333 .08592 0 -0.96154 Mabsadd L
.33333 .08592 1.46946 -2.02254 Mabsadd L
.33333 .08592 .91448 -0.29713 Mabsadd L
.33333 .08592 2.37764 .77254 Mabsadd L
.33333 .08592 .56518 .7779 Mabsadd L
.33333 .08592 0 2.5 Mabsadd L closepath F
.35714 .03177 0 2.5 Mabsadd m
.35714 .03177 -0.56518 .7779 Mabsadd L
.35714 .03177 -2.37764 .77254 Mabsadd L
.35714 .03177 -0.91448 -0.29713 Mabsadd L
.35714 .03177 -1.46946 -2.02254 Mabsadd L
.35714 .03177 0 -0.96154 Mabsadd L
.35714 .03177 1.46946 -2.02254 Mabsadd L
.35714 .03177 .91448 -0.29713 Mabsadd L
.35714 .03177 2.37764 .77254 Mabsadd L
.35714 .03177 .56518 .7779 Mabsadd L
.35714 .03177 0 2.5 Mabsadd L closepath F
.38095 .01472 0 2.5 Mabsadd m
.38095 .01472 -0.56518 .7779 Mabsadd L
.38095 .01472 -2.37764 .77254 Mabsadd L
.38095 .01472 -0.91448 -0.29713 Mabsadd L
.38095 .01472 -1.46946 -2.02254 Mabsadd L
.38095 .01472 0 -0.96154 Mabsadd L
.38095 .01472 1.46946 -2.02254 Mabsadd L
.38095 .01472 .91448 -0.29713 Mabsadd L
.38095 .01472 2.37764 .77254 Mabsadd L
.38095 .01472 .56518 .7779 Mabsadd L
.38095 .01472 0 2.5 Mabsadd L closepath F
.40476 .04481 0 2.5 Mabsadd m
.40476 .04481 -0.56518 .7779 Mabsadd L
.40476 .04481 -2.37764 .77254 Mabsadd L
.40476 .04481 -0.91448 -0.29713 Mabsadd L
.40476 .04481 -1.46946 -2.02254 Mabsadd L
.40476 .04481 0 -0.96154 Mabsadd L
.40476 .04481 1.46946 -2.02254 Mabsadd L
.40476 .04481 .91448 -0.29713 Mabsadd L
.40476 .04481 2.37764 .77254 Mabsadd L
.40476 .04481 .56518 .7779 Mabsadd L
.40476 .04481 0 2.5 Mabsadd L closepath F
.42857 .11074 0 2.5 Mabsadd m
.42857 .11074 -0.56518 .7779 Mabsadd L
.42857 .11074 -2.37764 .77254 Mabsadd L
.42857 .11074 -0.91448 -0.29713 Mabsadd L
.42857 .11074 -1.46946 -2.02254 Mabsadd L
.42857 .11074 0 -0.96154 Mabsadd L
.42857 .11074 1.46946 -2.02254 Mabsadd L
.42857 .11074 .91448 -0.29713 Mabsadd L
.42857 .11074 2.37764 .77254 Mabsadd L
.42857 .11074 .56518 .7779 Mabsadd L
.42857 .11074 0 2.5 Mabsadd L closepath F
.45238 .19185 0 2.5 Mabsadd m
.45238 .19185 -0.56518 .7779 Mabsadd L
.45238 .19185 -2.37764 .77254 Mabsadd L
.45238 .19185 -0.91448 -0.29713 Mabsadd L
.45238 .19185 -1.46946 -2.02254 Mabsadd L
.45238 .19185 0 -0.96154 Mabsadd L
.45238 .19185 1.46946 -2.02254 Mabsadd L
.45238 .19185 .91448 -0.29713 Mabsadd L
.45238 .19185 2.37764 .77254 Mabsadd L
.45238 .19185 .56518 .7779 Mabsadd L
.45238 .19185 0 2.5 Mabsadd L closepath F
.47619 .26278 0 2.5 Mabsadd m
.47619 .26278 -0.56518 .7779 Mabsadd L
.47619 .26278 -2.37764 .77254 Mabsadd L
.47619 .26278 -0.91448 -0.29713 Mabsadd L
.47619 .26278 -1.46946 -2.02254 Mabsadd L
.47619 .26278 0 -0.96154 Mabsadd L
.47619 .26278 1.46946 -2.02254 Mabsadd L
.47619 .26278 .91448 -0.29713 Mabsadd L
.47619 .26278 2.37764 .77254 Mabsadd L
.47619 .26278 .56518 .7779 Mabsadd L
.47619 .26278 0 2.5 Mabsadd L closepath F
.5 .29223 0 2.5 Mabsadd m
.5 .29223 -0.56518 .7779 Mabsadd L
.5 .29223 -2.37764 .77254 Mabsadd L
.5 .29223 -0.91448 -0.29713 Mabsadd L
.5 .29223 -1.46946 -2.02254 Mabsadd L
.5 .29223 0 -0.96154 Mabsadd L
.5 .29223 1.46946 -2.02254 Mabsadd L
.5 .29223 .91448 -0.29713 Mabsadd L
.5 .29223 2.37764 .77254 Mabsadd L
.5 .29223 .56518 .7779 Mabsadd L
.5 .29223 0 2.5 Mabsadd L closepath F
.52381 .26278 0 2.5 Mabsadd m
.52381 .26278 -0.56518 .7779 Mabsadd L
.52381 .26278 -2.37764 .77254 Mabsadd L
.52381 .26278 -0.91448 -0.29713 Mabsadd L
.52381 .26278 -1.46946 -2.02254 Mabsadd L
.52381 .26278 0 -0.96154 Mabsadd L
.52381 .26278 1.46946 -2.02254 Mabsadd L
.52381 .26278 .91448 -0.29713 Mabsadd L
.52381 .26278 2.37764 .77254 Mabsadd L
.52381 .26278 .56518 .7779 Mabsadd L
.52381 .26278 0 2.5 Mabsadd L closepath F
.54762 .19185 0 2.5 Mabsadd m
.54762 .19185 -0.56518 .7779 Mabsadd L
.54762 .19185 -2.37764 .77254 Mabsadd L
.54762 .19185 -0.91448 -0.29713 Mabsadd L
.54762 .19185 -1.46946 -2.02254 Mabsadd L
.54762 .19185 0 -0.96154 Mabsadd L
.54762 .19185 1.46946 -2.02254 Mabsadd L
.54762 .19185 .91448 -0.29713 Mabsadd L
.54762 .19185 2.37764 .77254 Mabsadd L
.54762 .19185 .56518 .7779 Mabsadd L
.54762 .19185 0 2.5 Mabsadd L closepath F
.57143 .11074 0 2.5 Mabsadd m
.57143 .11074 -0.56518 .7779 Mabsadd L
.57143 .11074 -2.37764 .77254 Mabsadd L
.57143 .11074 -0.91448 -0.29713 Mabsadd L
.57143 .11074 -1.46946 -2.02254 Mabsadd L
.57143 .11074 0 -0.96154 Mabsadd L
.57143 .11074 1.46946 -2.02254 Mabsadd L
.57143 .11074 .91448 -0.29713 Mabsadd L
.57143 .11074 2.37764 .77254 Mabsadd L
.57143 .11074 .56518 .7779 Mabsadd L
.57143 .11074 0 2.5 Mabsadd L closepath F
.59524 .04481 0 2.5 Mabsadd m
.59524 .04481 -0.56518 .7779 Mabsadd L
.59524 .04481 -2.37764 .77254 Mabsadd L
.59524 .04481 -0.91448 -0.29713 Mabsadd L
.59524 .04481 -1.46946 -2.02254 Mabsadd L
.59524 .04481 0 -0.96154 Mabsadd L
.59524 .04481 1.46946 -2.02254 Mabsadd L
.59524 .04481 .91448 -0.29713 Mabsadd L
.59524 .04481 2.37764 .77254 Mabsadd L
.59524 .04481 .56518 .7779 Mabsadd L
.59524 .04481 0 2.5 Mabsadd L closepath F
.61905 .01472 0 2.5 Mabsadd m
.61905 .01472 -0.56518 .7779 Mabsadd L
.61905 .01472 -2.37764 .77254 Mabsadd L
.61905 .01472 -0.91448 -0.29713 Mabsadd L
.61905 .01472 -1.46946 -2.02254 Mabsadd L
.61905 .01472 0 -0.96154 Mabsadd L
.61905 .01472 1.46946 -2.02254 Mabsadd L
.61905 .01472 .91448 -0.29713 Mabsadd L
.61905 .01472 2.37764 .77254 Mabsadd L
.61905 .01472 .56518 .7779 Mabsadd L
.61905 .01472 0 2.5 Mabsadd L closepath F
.64286 .03177 0 2.5 Mabsadd m
.64286 .03177 -0.56518 .7779 Mabsadd L
.64286 .03177 -2.37764 .77254 Mabsadd L
.64286 .03177 -0.91448 -0.29713 Mabsadd L
.64286 .03177 -1.46946 -2.02254 Mabsadd L
.64286 .03177 0 -0.96154 Mabsadd L
.64286 .03177 1.46946 -2.02254 Mabsadd L
.64286 .03177 .91448 -0.29713 Mabsadd L
.64286 .03177 2.37764 .77254 Mabsadd L
.64286 .03177 .56518 .7779 Mabsadd L
.64286 .03177 0 2.5 Mabsadd L closepath F
.66667 .08592 0 2.5 Mabsadd m
.66667 .08592 -0.56518 .7779 Mabsadd L
.66667 .08592 -2.37764 .77254 Mabsadd L
.66667 .08592 -0.91448 -0.29713 Mabsadd L
.66667 .08592 -1.46946 -2.02254 Mabsadd L
.66667 .08592 0 -0.96154 Mabsadd L
.66667 .08592 1.46946 -2.02254 Mabsadd L
.66667 .08592 .91448 -0.29713 Mabsadd L
.66667 .08592 2.37764 .77254 Mabsadd L
.66667 .08592 .56518 .7779 Mabsadd L
.66667 .08592 0 2.5 Mabsadd L closepath F
.69048 .15669 0 2.5 Mabsadd m
.69048 .15669 -0.56518 .7779 Mabsadd L
.69048 .15669 -2.37764 .77254 Mabsadd L
.69048 .15669 -0.91448 -0.29713 Mabsadd L
.69048 .15669 -1.46946 -2.02254 Mabsadd L
.69048 .15669 0 -0.96154 Mabsadd L
.69048 .15669 1.46946 -2.02254 Mabsadd L
.69048 .15669 .91448 -0.29713 Mabsadd L
.69048 .15669 2.37764 .77254 Mabsadd L
.69048 .15669 .56518 .7779 Mabsadd L
.69048 .15669 0 2.5 Mabsadd L closepath F
.71429 .23624 0 2.5 Mabsadd m
.71429 .23624 -0.56518 .7779 Mabsadd L
.71429 .23624 -2.37764 .77254 Mabsadd L
.71429 .23624 -0.91448 -0.29713 Mabsadd L
.71429 .23624 -1.46946 -2.02254 Mabsadd L
.71429 .23624 0 -0.96154 Mabsadd L
.71429 .23624 1.46946 -2.02254 Mabsadd L
.71429 .23624 .91448 -0.29713 Mabsadd L
.71429 .23624 2.37764 .77254 Mabsadd L
.71429 .23624 .56518 .7779 Mabsadd L
.71429 .23624 0 2.5 Mabsadd L closepath F
.7381 .3286 0 2.5 Mabsadd m
.7381 .3286 -0.56518 .7779 Mabsadd L
.7381 .3286 -2.37764 .77254 Mabsadd L
.7381 .3286 -0.91448 -0.29713 Mabsadd L
.7381 .3286 -1.46946 -2.02254 Mabsadd L
.7381 .3286 0 -0.96154 Mabsadd L
.7381 .3286 1.46946 -2.02254 Mabsadd L
.7381 .3286 .91448 -0.29713 Mabsadd L
.7381 .3286 2.37764 .77254 Mabsadd L
.7381 .3286 .56518 .7779 Mabsadd L
.7381 .3286 0 2.5 Mabsadd L closepath F
.7619 .43137 0 2.5 Mabsadd m
.7619 .43137 -0.56518 .7779 Mabsadd L
.7619 .43137 -2.37764 .77254 Mabsadd L
.7619 .43137 -0.91448 -0.29713 Mabsadd L
.7619 .43137 -1.46946 -2.02254 Mabsadd L
.7619 .43137 0 -0.96154 Mabsadd L
.7619 .43137 1.46946 -2.02254 Mabsadd L
.7619 .43137 .91448 -0.29713 Mabsadd L
.7619 .43137 2.37764 .77254 Mabsadd L
.7619 .43137 .56518 .7779 Mabsadd L
.7619 .43137 0 2.5 Mabsadd L closepath F
.78571 .52342 0 2.5 Mabsadd m
.78571 .52342 -0.56518 .7779 Mabsadd L
.78571 .52342 -2.37764 .77254 Mabsadd L
.78571 .52342 -0.91448 -0.29713 Mabsadd L
.78571 .52342 -1.46946 -2.02254 Mabsadd L
.78571 .52342 0 -0.96154 Mabsadd L
.78571 .52342 1.46946 -2.02254 Mabsadd L
.78571 .52342 .91448 -0.29713 Mabsadd L
.78571 .52342 2.37764 .77254 Mabsadd L
.78571 .52342 .56518 .7779 Mabsadd L
.78571 .52342 0 2.5 Mabsadd L closepath F
.80952 .58145 0 2.5 Mabsadd m
.80952 .58145 -0.56518 .7779 Mabsadd L
.80952 .58145 -2.37764 .77254 Mabsadd L
.80952 .58145 -0.91448 -0.29713 Mabsadd L
.80952 .58145 -1.46946 -2.02254 Mabsadd L
.80952 .58145 0 -0.96154 Mabsadd L
.80952 .58145 1.46946 -2.02254 Mabsadd L
.80952 .58145 .91448 -0.29713 Mabsadd L
.80952 .58145 2.37764 .77254 Mabsadd L
.80952 .58145 .56518 .7779 Mabsadd L
.80952 .58145 0 2.5 Mabsadd L closepath F
.83333 .60332 0 2.5 Mabsadd m
.83333 .60332 -0.56518 .7779 Mabsadd L
.83333 .60332 -2.37764 .77254 Mabsadd L
.83333 .60332 -0.91448 -0.29713 Mabsadd L
.83333 .60332 -1.46946 -2.02254 Mabsadd L
.83333 .60332 0 -0.96154 Mabsadd L
.83333 .60332 1.46946 -2.02254 Mabsadd L
.83333 .60332 .91448 -0.29713 Mabsadd L
.83333 .60332 2.37764 .77254 Mabsadd L
.83333 .60332 .56518 .7779 Mabsadd L
.83333 .60332 0 2.5 Mabsadd L closepath F
.85714 .6019 0 2.5 Mabsadd m
.85714 .6019 -0.56518 .7779 Mabsadd L
.85714 .6019 -2.37764 .77254 Mabsadd L
.85714 .6019 -0.91448 -0.29713 Mabsadd L
.85714 .6019 -1.46946 -2.02254 Mabsadd L
.85714 .6019 0 -0.96154 Mabsadd L
.85714 .6019 1.46946 -2.02254 Mabsadd L
.85714 .6019 .91448 -0.29713 Mabsadd L
.85714 .6019 2.37764 .77254 Mabsadd L
.85714 .6019 .56518 .7779 Mabsadd L
.85714 .6019 0 2.5 Mabsadd L closepath F
.88095 .59004 0 2.5 Mabsadd m
.88095 .59004 -0.56518 .7779 Mabsadd L
.88095 .59004 -2.37764 .77254 Mabsadd L
.88095 .59004 -0.91448 -0.29713 Mabsadd L
.88095 .59004 -1.46946 -2.02254 Mabsadd L
.88095 .59004 0 -0.96154 Mabsadd L
.88095 .59004 1.46946 -2.02254 Mabsadd L
.88095 .59004 .91448 -0.29713 Mabsadd L
.88095 .59004 2.37764 .77254 Mabsadd L
.88095 .59004 .56518 .7779 Mabsadd L
.88095 .59004 0 2.5 Mabsadd L closepath F
.90476 .57559 0 2.5 Mabsadd m
.90476 .57559 -0.56518 .7779 Mabsadd L
.90476 .57559 -2.37764 .77254 Mabsadd L
.90476 .57559 -0.91448 -0.29713 Mabsadd L
.90476 .57559 -1.46946 -2.02254 Mabsadd L
.90476 .57559 0 -0.96154 Mabsadd L
.90476 .57559 1.46946 -2.02254 Mabsadd L
.90476 .57559 .91448 -0.29713 Mabsadd L
.90476 .57559 2.37764 .77254 Mabsadd L
.90476 .57559 .56518 .7779 Mabsadd L
.90476 .57559 0 2.5 Mabsadd L closepath F
.92857 .56225 0 2.5 Mabsadd m
.92857 .56225 -0.56518 .7779 Mabsadd L
.92857 .56225 -2.37764 .77254 Mabsadd L
.92857 .56225 -0.91448 -0.29713 Mabsadd L
.92857 .56225 -1.46946 -2.02254 Mabsadd L
.92857 .56225 0 -0.96154 Mabsadd L
.92857 .56225 1.46946 -2.02254 Mabsadd L
.92857 .56225 .91448 -0.29713 Mabsadd L
.92857 .56225 2.37764 .77254 Mabsadd L
.92857 .56225 .56518 .7779 Mabsadd L
.92857 .56225 0 2.5 Mabsadd L closepath F
.95238 .55131 0 2.5 Mabsadd m
.95238 .55131 -0.56518 .7779 Mabsadd L
.95238 .55131 -2.37764 .77254 Mabsadd L
.95238 .55131 -0.91448 -0.29713 Mabsadd L
.95238 .55131 -1.46946 -2.02254 Mabsadd L
.95238 .55131 0 -0.96154 Mabsadd L
.95238 .55131 1.46946 -2.02254 Mabsadd L
.95238 .55131 .91448 -0.29713 Mabsadd L
.95238 .55131 2.37764 .77254 Mabsadd L
.95238 .55131 .56518 .7779 Mabsadd L
.95238 .55131 0 2.5 Mabsadd L closepath F
.97619 .54291 0 2.5 Mabsadd m
.97619 .54291 -0.56518 .7779 Mabsadd L
.97619 .54291 -2.37764 .77254 Mabsadd L
.97619 .54291 -0.91448 -0.29713 Mabsadd L
.97619 .54291 -1.46946 -2.02254 Mabsadd L
.97619 .54291 0 -0.96154 Mabsadd L
.97619 .54291 1.46946 -2.02254 Mabsadd L
.97619 .54291 .91448 -0.29713 Mabsadd L
.97619 .54291 2.37764 .77254 Mabsadd L
.97619 .54291 .56518 .7779 Mabsadd L
.97619 .54291 0 2.5 Mabsadd L closepath F
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{441.188, 272.625},
  ImageMargins->{{25, 0}, {0, 3}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006i000142000`400?l00000o`00003oo`3IfMVj
0=WIf@00o`3IfMVj0=WIf@00o`3IfMVj0=WIf@00o`3IfMVj0=WIf@00bP3IfMT3000000030=WIf@00
0000000000800000i`3IfMT00</0fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WI
f@3T0=WIf@00b`3IfMT01@000000fMWI0=WIf@3IfMT0000000`0fMWI00<000000=WIf@3IfMT0fP3I
fMT00<00fMWI1`0000040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02@3IfMT3
00000=X0fMWI003;0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0203IfMT00`00
0000fMWI0=WIf@3J0=WIf@00b`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT0fP3IfMT00</0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=X0fMWI002W0=WIf@030000003IfMT000000200fMWI
0P0000030=WIf@8000002`3IfMT00`000000fMWI0=WIf@0^0=WIf@800000ZP3IfMT00:L0fMWI0`00
000b0=WIf@030000003IfMT0fMWI02l0fMWI0P00002Y0=WIf@00Y`3IfMT400000340fMWI00<00000
0=WIf@3IfMT0;P3IfMT400000:P0fMWI002X0=WIf@030000003IfMT0fMWI0340fMWI00<000000=WI
f@3IfMT0;P3IfMT00`000000fMWI0=WIf@2Y0=WIf@00Y03IfMT00`000000fMWI0=WIf@0e0=WIf@80
0000=03IfMT200000:D0fMWI002[0=WIf@800000;`3IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI0:/0fMWI002Q0=WIf@030000003IfMT0fMWI03P0fMWI00<000000=WIf@3IfMT0;03I
fMT00`000000fMWI0=WIf@070=WIf@800000XP3IfMT009d0fMWI00<000000=WIf@000000?03IfMT0
0`000000fMWI0=WIf@0i0=WIf@030000003IfMT0000009h0fMWI002M0=WIf@<000003P3IfMT00`00
0000fMWI0=WIf@0[0=WIf@030000003IfMT0fMWI02X0fMWI00<000000=WIf@3IfMT0303IfMT30000
09h0fMWI002M0=WIf@@00000>`3IfMT00`000000fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00`0
fMWI0`00002N0=WIf@00WP3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI02T0fMWI
00<000000=WIf@3IfMT0>@3IfMT3000009h0fMWI002M0=WIf@8000004@3IfMT00`000000fMWI0=WI
f@0Y0=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT03`3IfMT2000009h0fMWI002M
0=WIf@030000003IfMT0fMWI03`0fMWI00<000000=WIf@3IfMT0fP3IfMT00;40fMWI0P00000Y0=WI
f@8000009@3IfMT200000;@0fMWI002K0=WIf@030000003IfMT0fMWI01@0fMWI0P00000X0=WIf@03
0000003IfMT0fMWI02D0fMWI0P00000E0=WIf@800000W03IfMT009/0fMWI00<000000=WIf@3IfMT0
4`3IfMT4000002L0fMWI00<000000=WIf@3IfMT0903IfMT400000;80fMWI002c0=WIf@030000003I
fMT0fMWI02H0fMWI00<000000=WIf@3IfMT0fP3IfMT00;@0fMWI00<000000=WIf@3IfMT09@3IfMT0
0`000000fMWI0=WIf@0T0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT0V@3IfMT0
09X0fMWI00<000000=WIf@3IfMT0?`3IfMT00`000000fMWI0=WIf@3J0=WIf@00]@3IfMT00`000000
fMWI0=WIf@0T0=WIf@030000003IfMT0fMWI0=X0fMWI002e0=WIf@030000003IfMT0fMWI02@0fMWI
00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI09P0fMWI
002H0=WIf@800000@P3IfMT2000002@0fMWI00<000000=WIf@3IfMT0]03IfMT00=`0fMWI00<00000
0=WIf@3IfMT0fP3IfMT00;H0fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@0R0=WI
f@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT0UP3IfMT009L0fMWI00<000000=WIf@3I
fMT0@P3IfMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3I
fMT0UP3IfMT00=`0fMWI00<000000=WIf@3IfMT0fP3IfMT00;L0fMWI00<000000=WIf@3IfMT08P3I
fMT00`000000fMWI0=WIf@120=WIf@030000003IfMT0fMWI09D0fMWI002F0=WIf@030000003IfMT0
fMWI01h0fMWI00<000000=WIf@3IfMT0403IfMT300000080fMWI0`00000:0=WIf@030000003IfMT0
fMWI0240fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@2E0=WIf@00UP3IfMT00`00
0000fMWI0=WIf@0b0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT01`3IfMT0
0`000000fMWI0=WIf@3J0=WIf@00^03IfMT00`000000fMWI0=WIf@0@0=WIf@040000003IfMT0fMWI
000000<0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3J0=WIf@00U03IfMT00`00
0000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00D0fMWI1`0000040=WIf@040000003IfMT0fMWI
000000<0fMWI00<000000=WIf@3IfMT01`3IfMT300000200fMWI00<000000=WIf@3IfMT0803IfMT2
000009D0fMWI002C0=WIf@800000=P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI00L0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0
000009@0fMWI002C0=WIf@<00000=@3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI00L0fMWI00<000000=WIf@3IfMT0@`3IfMT4000009<0fMWI002C0=WIf@030000003IfMT0fMWI
02<0fMWI00<000000=WIf@3IfMT03`3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0
fMWI00L0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0R0=WIf@800000U03IfMT0
09<0fMWI00<000000=WIf@3IfMT0=03IfMT2000000<0fMWI0`00000:0=WIf@030000003IfMT0fMWI
01h0fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@2C0=WIf@00g03IfMT00`000000
fMWI0=WIf@3J0=WIf@00^`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI04H0fMWI
00<000000=WIf@3IfMT0T@3IfMT00980fMWI00<000000=WIf@3IfMT0A`3IfMT00`000000fMWI0=WI
f@0M0=WIf@030000003IfMT0fMWI02H0fMWI00<000000=WIf@3IfMT0T@3IfMT00=`0fMWI00<00000
0=WIf@3IfMT0fP3IfMT00;`0fMWI00<000000=WIf@3IfMT07@3IfMT200000=/0fMWI002A0=WIf@03
0000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT0T03IfMT00940fMWI00<000000=WIf@3IfMT0
9`3IfMT2000001l0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0000002m0=WIf@00_03I
fMT2000001h0fMWI00<000000=WIf@3IfMT06P3IfMT300000;d0fMWI002k0=WIf@@000007@3IfMT0
0`000000fMWI0=WIf@0J0=WIf@@00000:P3IfMT00`000000fMWI0=WIf@2?0=WIf@00T03IfMT00`00
0000fMWI0=WIf@0Y0=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT06`3IfMT00`00
0000fMWI0=WIf@2l0=WIf@00g03IfMT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI0;`0
fMWI002n0=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0B@3IfMT00`000000fMWI
0=WIf@2>0=WIf@00S`3IfMT00`000000fMWI0=WIf@1:0=WIf@8000006`3IfMT00`000000fMWI0=WI
f@0/0=WIf@030000003IfMT0fMWI08h0fMWI003L0=WIf@030000003IfMT0fMWI0=X0fMWI002o0=WI
f@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0BP3IfMT00`000000fMWI0=WIf@2=0=WI
f@00SP3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3I
fMT06@3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0fMWI08d0fMWI002=0=WIf@030000
003IfMT0fMWI04`0fMWI00<000000=WIf@3IfMT0fP3IfMT00=`0fMWI00<000000=WIf@3IfMT0fP3I
fMT00<00fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0H0=WIf@030000003IfMT0
fMWI0300fMWI0P00002=0=WIf@00S03IfMT00`000000fMWI0=WIf@1=0=WIf@030000003IfMT0fMWI
01P0fMWI00<000000=WIf@3IfMT0_`3IfMT00=`0fMWI00<000000=WIf@3IfMT0fP3IfMT00<40fMWI
00<000000=WIf@3IfMT0603IfMT2000004d0fMWI00<000000=WIf@3IfMT0R`3IfMT008/0fMWI00<0
00000=WIf@3IfMT0CP3IfMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI03<0fMWI00<0
00000=WIf@3IfMT0RP3IfMT00=`0fMWI00<000000=WIf@3IfMT0fP3IfMT00<80fMWI00<000000=WI
f@3IfMT05`3IfMT00`000000fMWI0=WIf@1>0=WIf@030000003IfMT0fMWI08T0fMWI002:0=WIf@03
0000003IfMT0fMWI03D0fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@0F0=WIf@03
0000003IfMT0fMWI03D0fMWI00<000000=WIf@3IfMT0R@3IfMT008P0fMWI0`0000140=WIf@<00000
2P3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI03@0fMWI0P00002;0=WIf@00R@3I
fMT2000004<0fMWI00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI04h0fMWI
0P00002:0=WIf@00R03IfMT4000003L0fMWI00<000000=WIf@3IfMT0203IfMT01@000000fMWI0=WI
f@3IfMT0000000T0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@0e0=WIf@@00000
R@3IfMT008T0fMWI00<000000=WIf@3IfMT0>P3IfMT7000000030=WIf@000000fMWI0080fMWI00<0
00000=WIf@3IfMT01`3IfMT3000001D0fMWI00<000000=WIf@3IfMT0=P3IfMT00`000000fMWI0=WI
f@290=WIf@00c`3IfMT3000000X0fMWI00<000000=WIf@3IfMT0fP3IfMT00<@0fMWI00<000000=WI
f@3IfMT01`3IfMT01@000000fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT0D03IfMT0
0`000000fMWI0=WIf@270=WIf@00R03IfMT00`000000fMWI0=WIf@130=WIf@050000003IfMT0fMWI
0=WIf@0000002@3IfMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI03T0fMWI00<00000
0=WIf@3IfMT0Q`3IfMT00<l0fMWI0`00000:0=WIf@030000003IfMT0fMWI0=X0fMWI00350=WIf@03
0000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0D@3IfMT00`000000fMWI0=WIf@260=WIf@00
Q`3IfMT00`000000fMWI0=WIf@0k0=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0
4`3IfMT00`000000fMWI0=WIf@0k0=WIf@030000003IfMT0fMWI08H0fMWI00270=WIf@030000003I
fMT0fMWI0580fMWI00<000000=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@340=WIf@00g03IfMT0
0`000000fMWI0=WIf@3J0=WIf@00aP3IfMT00`000000fMWI0=WIf@0C0=WIf@8000004`3IfMT00`00
0000fMWI0=WIf@0m0=WIf@030000003IfMT0fMWI08D0fMWI00260=WIf@030000003IfMT0fMWI05<0
fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@350=WIf@00g03IfMT00`000000fMWI
0=WIf@3J0=WIf@00aP3IfMT3000001<0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0000
00100=WIf@030000003IfMT0fMWI08@0fMWI00250=WIf@030000003IfMT0fMWI03h0fMWI0`00000C
0=WIf@030000003IfMT0fMWI0100fMWI0`0000100=WIf@030000003IfMT0fMWI08@0fMWI00360=WI
f@<000004`3IfMT00`000000fMWI0=WIf@0@0=WIf@<00000a`3IfMT00<L0fMWI0P00000C0=WIf@03
0000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0@03IfMT00`000000fMWI0=WIf@230=WIf@00
Q03IfMT00`000000fMWI0=WIf@100=WIf@8000004`3IfMT00`000000fMWI0=WIf@0@0=WIf@800000
@P3IfMT00`000000fMWI0=WIf@230=WIf@00Q03IfMT00`000000fMWI0=WIf@1E0=WIf@8000004@3I
fMT00`000000fMWI0=WIf@370=WIf@00g03IfMT00`000000fMWI0=WIf@3J0=WIf@00b@3IfMT00`00
0000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0@`3IfMT00`00
0000fMWI0=WIf@220=WIf@00P`3IfMT00`000000fMWI0=WIf@1F0=WIf@030000003IfMT0fMWI00l0
fMWI00<000000=WIf@3IfMT0b03IfMT00=`0fMWI00<000000=WIf@3IfMT0fP3IfMT00<X0fMWI00<0
00000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@1F0=WIf@030000003IfMT0fMWI0840fMWI0022
0=WIf@030000003IfMT0fMWI04D0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@0>
0=WIf@030000003IfMT0fMWI04D0fMWI00<000000=WIf@3IfMT0P@3IfMT00=`0fMWI00<000000=WI
f@3IfMT0fP3IfMT00</0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@3J0=WIf@00
P@3IfMT00`000000fMWI0=WIf@170=WIf@030000003IfMT0fMWI00h0fMWI0P00000>0=WIf@030000
003IfMT0fMWI04L0fMWI00<000000=WIf@3IfMT0P03IfMT00840fMWI00<000000=WIf@3IfMT0F03I
fMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI0<X0fMWI003L0=WIf@030000003IfMT0
fMWI0=X0fMWI003<0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0303IfMT00`00
0000fMWI0=WIf@190=WIf@030000003IfMT0fMWI07l0fMWI00200=WIf@030000003IfMT0fMWI05T0
fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@3<0=WIf@00OP3IfMT00`000000fMWI
0000001>0=WIf@<000002P3IfMT00`000000fMWI0=WIf@1G0=WIf@800000P@3IfMT007h0fMWI0`00
001<0=WIf@8000000`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI05P0fMWI0P00
00200=WIf@00OP3IfMT4000004`0fMWI00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0BP3IfMT4000007l0fMWI001o0=WIf@030000003IfMT0
fMWI04@0fMWI1`0000000`3IfMT000000=WIf@020=WIf@030000003IfMT0fMWI00L0fMWI0`00001H
0=WIf@030000003IfMT0fMWI07l0fMWI001o0=WIf@030000003IfMT0fMWI04`0fMWI1000000:0=WI
f@030000003IfMT0fMWI0=X0fMWI001n0=WIf@030000003IfMT0fMWI04h0fMWI00<000000=WIf@3I
fMT02P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI04h0fMWI00<000000=WIf@3I
fMT0O@3IfMT007h0fMWI00<000000=WIf@3IfMT0CP3IfMT2000000/0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@3>0=WIf@00d@3IfMT2000000T0fMWI00<000000=WIf@3IfMT0fP3I
fMT00=00fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI0500fMWI00<000000=WIf@3IfMT0O03IfMT007d0fMWI00<000000=WIf@3IfMT0G03IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0500fMWI00<000000=WIf@3IfMT0O03IfMT00=`0
fMWI00<000000=WIf@3IfMT0fP3IfMT00=40fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
0=WIf@1K0=WIf@030000003IfMT0fMWI07`0fMWI001m0=WIf@030000003IfMT0fMWI0500fMWI00<0
00000=WIf@0000002@3IfMT2000000L0fMWI0P00001D0=WIf@030000003IfMT0fMWI07/0fMWI001l
0=WIf@030000003IfMT0fMWI0540fMWI100000080=WIf@030000003IfMT0fMWI00D0fMWI1000003A
0=WIf@00d@3IfMT3000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@3A0=WI
f@00d@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0E03IfMT00`000000fMWI0=WIf@1k0=WIf@00O03IfMT00`000000fMWI0=WIf@1M0=WIf@030000
003IfMT0fMWI0=X0fMWI003E0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@3D0=WIf@00g03IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI05L0fMWI00<000000=WIf@3IfMT0NP3IfMT007/0fMWI00<000000=WIf@3IfMT0F@3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI05d0fMWI00<000000=WIf@3IfMT0NP3IfMT00=L0
fMWI00<000000=WIf@3IfMT00P3IfMT200000080fMWI00<000000=WIf@3IfMT0eP3IfMT00=`0fMWI
00<000000=WIf@3IfMT0fP3IfMT007X0fMWI00<000000=WIf@3IfMT0G03IfMT010000000fMWI0=WI
f@00001P0=WIf@030000003IfMT0fMWI07T0fMWI001j0=WIf@030000003IfMT0fMWI05`0fMWI00<0
00000=WIf@3IfMT00`00003J0=WIf@00fP3IfMT300000=`0fMWI003K0=WIf@800000H@3IfMT00`00
0000fMWI0=WIf@1h0=WIf@00N@3IfMT00`000000fMWI0=WIf@1N0=WIf@@00000f`3IfMT00=/0fMWI
0P00003L0=WIf@00g03IfMT00`000000fMWI0=WIf@1P0=WIf@030000003IfMT0fMWI07L0fMWI001h
0=WIf@030000003IfMT0fMWI0640fMWI0P00001Q0=WIf@030000003IfMT0fMWI07L0fMWI001h0=WI
f@030000003IfMT0fMWI0640fMWI00<000000=WIf@3IfMT0fP3IfMT00=`0fMWI00<000000=WIf@3I
fMT0fP3IfMT00=`0fMWI00<000000=WIf@3IfMT0H@3IfMT00`000000fMWI0=WIf@1f0=WIf@00M`3I
fMT00`000000fMWI0=WIf@1R0=WIf@030000003IfMT0fMWI0=X0fMWI003A0=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT0fP3IfMT00=40fMWI00<000000=WIf@3IfMT0203IfMT00`00
0000fMWI0=WIf@1Q0=WIf@030000003IfMT0fMWI07H0fMWI001f0=WIf@030000003IfMT0fMWI05D0
fMWI1P0000080=WIf@030000003IfMT0fMWI0680fMWI00<000000=WIf@3IfMT0M@3IfMT00<H0fMWI
1`0000001@3IfMT000000=WIf@3IfMT0000000X0fMWI0`00003J0=WIf@00c`3IfMT00`000000fMWI
0000000:0=WIf@030000003IfMT0fMWI0=X0fMWI001f0=WIf@030000003IfMT0fMWI05L0fMWI0P00
000:0=WIf@030000003IfMT0fMWI0680fMWI00<000000=WIf@3IfMT0M@3IfMT007@0fMWI0`00001I
0=WIf@8000002P3IfMT00`000000fMWI0=WIf@1R0=WIf@030000003IfMT0fMWI07D0fMWI001d0=WI
f@<00000FP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0680fMWI0P00001f0=WI
f@00M03IfMT4000006@0fMWI00<000000=WIf@3IfMT0HP3IfMT3000007D0fMWI001e0=WIf@030000
003IfMT0fMWI06@0fMWI00<000000=WIf@3IfMT0H`3IfMT00`000000fMWI0=WIf@1d0=WIf@00g03I
fMT00`000000fMWI0=WIf@3J0=WIf@00g03IfMT00`000000fMWI0=WIf@1T0=WIf@030000003IfMT0
fMWI07<0fMWI001d0=WIf@030000003IfMT0fMWI06D0fMWI0P00001U0=WIf@030000003IfMT0fMWI
07<0fMWI001d0=WIf@030000003IfMT0fMWI06D0fMWI00<000000=WIf@3IfMT0fP3IfMT00=`0fMWI
00<000000=WIf@3IfMT0fP3IfMT00=`0fMWI00<000000=WIf@3IfMT0I@3IfMT00`000000fMWI0=WI
f@1b0=WIf@00L`3IfMT00`000000fMWI0=WIf@1V0=WIf@030000003IfMT0fMWI0=X0fMWI003L0=WI
f@030000003IfMT0fMWI0=X0fMWI003L0=WIf@030000003IfMT0fMWI06H0fMWI00<000000=WIf@3I
fMT0L@3IfMT00780fMWI00<000000=WIf@3IfMT0I`3IfMT00`000000fMWI0=WIf@1V0=WIf@030000
003IfMT0fMWI0740fMWI003L0=WIf@800000f`3IfMT00=`0fMWI00<000000=WIf@3IfMT0fP3IfMT0
0780fMWI00<000000=WIf@3IfMT0I`3IfMT00`000000fMWI0=WIf@1V0=WIf@030000003IfMT0fMWI
0740fMWI001a0=WIf@030000003IfMT0fMWI06P0fMWI00<000000=WIf@3IfMT0fP3IfMT00=`0fMWI
00<000000=WIf@3IfMT0fP3IfMT00=`0fMWI00<000000=WIf@3IfMT0I`3IfMT00`000000fMWI0=WI
f@1`0=WIf@00L@3IfMT00`000000fMWI0=WIf@1X0=WIf@030000003IfMT0fMWI0=X0fMWI003L0=WI
f@030000003IfMT0fMWI0=X0fMWI003L0=WIf@030000003IfMT0fMWI06P0fMWI00<000000=WIf@3I
fMT0K`3IfMT00700fMWI00<000000=WIf@3IfMT0J@3IfMT2000006T0fMWI00<000000=WIf@3IfMT0
K`3IfMT00700fMWI00<000000=WIf@3IfMT0J@3IfMT00`000000fMWI0=WIf@3J0=WIf@00g03IfMT0
0`000000fMWI0=WIf@3J0=WIf@00g03IfMT00`000000fMWI0=WIf@1Y0=WIf@030000003IfMT0fMWI
06h0fMWI001_0=WIf@030000003IfMT0fMWI06X0fMWI00<000000=WIf@3IfMT0fP3IfMT00=`0fMWI
00<000000=WIf@3IfMT0fP3IfMT00<h0fMWI1000000:0=WIf@030000003IfMT0fMWI06X0fMWI00<0
00000=WIf@3IfMT0K@3IfMT006h0fMWI00<000000=WIf@3IfMT0G@3IfMT01@000000fMWI0=WIf@3I
fMT0000000T0fMWI00<000000=WIf@3IfMT0JP3IfMT00`000000fMWI0=WIf@1]0=WIf@00c`3IfMT0
0`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=X0fMWI00360=WIf@L000000`3IfMT00`00
0000fMWI0=WIf@090=WIf@<00000fP3IfMT006h0fMWI00<000000=WIf@3IfMT0H03IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI06X0fMWI00<000000=WIf@3IfMT0K@3IfMT006h0fMWI
00<000000=WIf@3IfMT0H03IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=X0fMWI
003>0=WIf@040000003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0fP3IfMT00<l0fMWI0P00
000;0=WIf@030000003IfMT0fMWI06/0fMWI00<000000=WIf@3IfMT0K03IfMT006d0fMWI00<00000
0=WIf@3IfMT0K03IfMT00`000000fMWI0=WIf@1[0=WIf@030000003IfMT0fMWI06`0fMWI003L0=WI
f@030000003IfMT0fMWI0=X0fMWI003L0=WIf@030000003IfMT0fMWI06`0fMWI00<000000=WIf@3I
fMT0J`3IfMT006`0fMWI00<000000=WIf@3IfMT0K@3IfMT2000006d0fMWI00<000000=WIf@3IfMT0
J`3IfMT006`0fMWI00<000000=WIf@3IfMT0K@3IfMT00`000000fMWI0=WIf@3J0=WIf@00g03IfMT0
0`000000fMWI0=WIf@3J0=WIf@00g03IfMT00`000000fMWI0=WIf@1]0=WIf@030000003IfMT0fMWI
06X0fMWI001Y0=WIf@<00000L03IfMT00`000000fMWI0=WIf@1/0=WIf@030000003IfMT0000006/0
fMWI001Z0=WIf@800000L03IfMT00`000000fMWI0=WIf@1/0=WIf@<00000J`3IfMT006X0fMWI0`00
001_0=WIf@030000003IfMT0fMWI06`0fMWI1000001Z0=WIf@00JP3IfMT00`000000fMWI0=WIf@1_
0=WIf@030000003IfMT0fMWI06d0fMWI0P00001[0=WIf@00JP3IfMT00`000000fMWI0=WIf@1_0=WI
f@030000003IfMT0fMWI06d0fMWI00<000000=WIf@3IfMT0JP3IfMT00=`0fMWI0P00003K0=WIf@00
>@3IfMT010000000fMWI0=WIf@3IfMT3000002X0fMWI00<000000=WIf@3IfMT06`3IfMT4000000<0
fMWI0`00001:0=WIf@030000003IfMT0fMWI04T0fMWI100000030=WIf@<000006`3IfMT2000002d0
fMWI00@000000=WIf@3IfMT0fMWI0`00000f0=WIf@00>@3IfMT010000000fMWI0=WIf@0000030=WI
f@030000003IfMT0fMWI02H0fMWI00<000000=WIf@3IfMT0703IfMT01`000000fMWI0=WIf@3IfMT0
00000=WIf@0000000`3IfMT00`000000fMWI0=WIf@170=WIf@030000003IfMT0fMWI04T0fMWI00L0
00000=WIf@3IfMT0fMWI0000003IfMT0000000<0fMWI00<000000=WIf@3IfMT0A`3IfMT010000000
fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI03<0fMWI000f0=WIf@L000000`3IfMT00`000000
fMWI0=WIf@160=WIf@030000003IfMT0fMWI0080fMWI00D000000=WIf@3IfMT0fMWI000000190=WI
f@030000003IfMT0fMWI04X0fMWI00<000000=WIf@3IfMT00P3IfMT01@000000fMWI0=WIf@3IfMT0
000004H0fMWI1`0000030=WIf@030000003IfMT0fMWI03<0fMWI000^0=WIf@L0000000D0fMWI0000
003IfMT0fMWI000000020=WIf@050000003IfMT0fMWI0=WIf@000000?`3IfMT7000000<0fMWI00D0
00000=WIf@3IfMT0fMWI000000030=WIf@030000003IfMT0fMWI04L0fMWI00<000000=WIf@3IfMT0
B`3IfMT01@000000fMWI0=WIf@3IfMT0000000<0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000
fMWI0=WIf@0X0=WIf@040000003IfMT0fMWI00000080fMWI00D000000=WIf@3IfMT0fMWI0000000e
0=WIf@00=`3IfMT00`000000fMWI000000020=WIf@050000003IfMT0fMWI0=WIf@000000:03IfMT0
0`000000fMWI0=WIf@0O0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0A`3I
fMT00`000000fMWI0=WIf@1<0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0
6@3IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003IfMT000000080fMWI00D000000=WIf@3IfMT0
fMWI0000000e0=WIf@00>03IfMT200000080fMWI00D000000=WIf@3IfMT0fMWI0000001:0=WIf@04
0000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0A`3IfMT00`000000fMWI0=WIf@1<0=WI
f@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0AP3IfMT200000080fMWI00D00000
0=WIf@3IfMT0fMWI0000000e0=WIf@00>03IfMT200000080fMWI00D000000=WIf@3IfMT0fMWI0000
00170=WIf@040000003IfMT0fMWI00000080fMWI00D000000=WIf@3IfMT0fMWI000000190=WIf@03
0000003IfMT0fMWI04T0fMWI00@000000=WIf@3IfMT000000P3IfMT01@000000fMWI0=WIf@3IfMT0
000001`0fMWI00<000000=WIf@3IfMT0:@3IfMT200000080fMWI00D000000=WIf@3IfMT0fMWI0000
000e0=WIf@00>@3IfMT010000000fMWI0=WIf@3IfMT3000002P0fMWI00<000000=WIf@3IfMT07P3I
fMT2000000@0fMWI0`00001:0=WIf@800000B`3IfMT2000000@0fMWI0`00000M0=WIf@030000003I
fMT0fMWI02X0fMWI00@000000=WIf@3IfMT0fMWI0`00000f0=WIf@00J03IfMT00`000000fMWI0=WI
f@1a0=WIf@030000003IfMT0fMWI0=X0fMWI003L0=WIf@030000003IfMT0fMWI0=X0fMWI003L0=WI
f@030000003IfMT0fMWI0740fMWI00<000000=WIf@3IfMT0IP3IfMT006L0fMWI00<000000=WIf@3I
fMT0LP3IfMT00`000000fMWI0=WIf@3J0=WIf@00g03IfMT00`000000fMWI0=WIf@3J0=WIf@00g03I
fMT00`000000fMWI0=WIf@1b0=WIf@030000003IfMT0fMWI06D0fMWI001V0=WIf@030000003IfMT0
fMWI07<0fMWI00<000000=WIf@3IfMT0LP3IfMT00`000000fMWI0=WIf@1U0=WIf@003`3IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00h0fMWI00040=WIfOl00000/@0000050=WIf@00
3P3IfMT3000000L0fMWI0`0000070=WIf@<000001`3IfMT3000000P0fMWI0`0000070=WIf@<00000
1`3IfMT3000000L0fMWI0`0000080=WIf@<000000P3IfMT00`000000fMWI0=WIf@020=WIf@<00000
1`3IfMT3000000L0fMWI0`0000080=WIf@<000001`3IfMT3000000L0fMWI0`0000070=WIf@<00000
203IfMT2000000P0fMWI0`0000070=WIf@<000001`3IfMT3000000P0fMWI0P0000080=WIf@<00000
1`3IfMT3000000L0fMWI0`0000080=WIf@800000203IfMT3000000L0fMWI0`0000070=WIf@<00000
203IfMT2000000P0fMWI0`0000070=WIf@<000001`3IfMT3000000@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000080=WIf@<000001`3IfMT3000000L0fMWI0`0000070=WIf@<00000203IfMT3000000L0
fMWI0`0000070=WIf@<000001`3IfMT3000000l0fMWI000?0=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT0203IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@0>0=WIf@00g03IfMT00`000000fMWI0=WIf@3J0=WIf@00g03I
fMT00`000000fMWI0=WIf@1d0=WIf@030000003IfMT0fMWI06<0fMWI001T0=WIf@030000003IfMT0
fMWI07D0fMWI00<000000=WIf@3IfMT0fP3IfMT00=`0fMWI00<000000=WIf@3IfMT0fP3IfMT00=`0
fMWI00<000000=WIf@3IfMT0M@3IfMT00`000000fMWI0=WIf@1R0=WIf@00H`3IfMT00`000000fMWI
0=WIf@1f0=WIf@800000MP3IfMT00`000000fMWI0=WIf@1R0=WIf@00H`3IfMT00`000000fMWI0=WI
f@1f0=WIf@030000003IfMT0fMWI0=X0fMWI003L0=WIf@030000003IfMT0fMWI0=X0fMWI003L0=WI
f@030000003IfMT0fMWI07D0fMWI0P00001S0=WIf@00HP3IfMT2000007P0fMWI00<000000=WIf@3I
fMT0fP3IfMT00=`0fMWI00<000000=WIf@3IfMT0fP3IfMT00=`0fMWI00<000000=WIf@3IfMT0MP3I
fMT00`000000fMWI0=WIf@1Q0=WIf@00HP3IfMT00`000000fMWI0=WIf@1g0=WIf@030000003IfMT0
fMWI07H0fMWI00<000000=WIf@3IfMT0H@3IfMT00=`0fMWI00<000000=WIf@3IfMT0fP3IfMT00=`0
fMWI0P00003K0=WIf@00H03IfMT2000007X0fMWI00<000000=WIf@3IfMT0M`3IfMT00`000000fMWI
0=WIf@1P0=WIf@00H03IfMT2000007X0fMWI00<000000=WIf@3IfMT0M`3IfMT200000640fMWI001O
0=WIf@@00000N@3IfMT00`000000fMWI0=WIf@1f0=WIf@@00000H03IfMT00=`0fMWI00<000000=WI
f@3IfMT0N03IfMT200000600fMWI001O0=WIf@800000N`3IfMT00`000000fMWI0=WIf@3J0=WIf@00
g03IfMT00`000000fMWI0=WIf@3J0=WIf@00g03IfMT00`000000fMWI0=WIf@1j0=WIf@030000003I
fMT0fMWI05d0fMWI001N0=WIf@030000003IfMT0fMWI07/0fMWI0P00001k0=WIf@030000003IfMT0
fMWI05d0fMWI000=0=WIf@800000c@3IfMT00`000000fMWI0=WIf@380=WIf@030000003IfMT00000
00l0fMWI000>0=WIf@800000c03IfMT00`000000fMWI0=WIf@1k0=WIf@030000003IfMT0fMWI04/0
fMWI0P00000?0=WIf@003@3IfMT4000000030=WIf@000000fMWI04T0fMWI00<000000=WIf@3IfMT0
O03IfMT00`000000fMWI0=WIf@1k0=WIf@030000003IfMT0fMWI04X0fMWI1000000>0=WIf@003P3I
fMT01@000000fMWI0=WIf@3IfMT000000<T0fMWI00<000000=WIf@3IfMT0a@3IfMT01@000000fMWI
0=WIf@3IfMT000000100fMWI000E0=WIf@80000000<0fMWI0000003IfMT0`P3IfMT00`000000fMWI
0=WIf@2n0=WIf@050000003IfMT000000=WIf@0000001P3IfMT00`000000fMWI0=WIf@0>0=WIf@00
603IfMT200000480fMWI00<000000=WIf@3IfMT0K`3IfMT4000000X0fMWI00<000000=WIf@3IfMT0
O03IfMT00`000000fMWI0=WIf@0o0=WIf@<000006@3IfMT001P0fMWI0`0000000`3IfMT000000=WI
f@0m0=WIf@030000003IfMT0fMWI0700fMWI00D000000=WIf@3IfMT0fMWI000000090=WIf@030000
003IfMT0fMWI0;`0fMWI00<000000=WIf@0000000`00000H0=WIf@006@3IfMT00`000000fMWI0=WI
f@2c0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0^`3IfMT01@000000fMWI0=WI
f@3IfMT0000001X0fMWI000O0=WIf@030000003IfMT0fMWI0:h0fMWI00<000000=WIf@3IfMT02@3I
fMT3000007h0fMWI00<000000=WIf@3IfMT0=`3IfMT00`000000fMWI0=WIf@0O0=WIf@008P3IfMT3
000003D0fMWI00<000000=WIf@3IfMT0M03IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI0;@0fMWI0P00000T0=WIf@008P3IfMT400000:/0fMWI00<000000=WIf@3IfMT0203IfMT00`00
0000fMWI0=WIf@2d0=WIf@<000008`3IfMT002<0fMWI00@000000=WIf@0000000000Y`3IfMT01000
0000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI07l0fMWI00<000000=WIf@3IfMT0<03IfMT0
10000000fMWI00000000000T0=WIf@008`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI02h0fMWI00<000000=WIf@3IfMT0L`3IfMT2000000/0fMWI00<000000=WIf@3IfMT0]@3IfMT0
0`000000fMWI0=WIf@0R0=WIf@00:@3IfMT00`000000fMWI0=WIf@2`0=WIf@030000003IfMT0fMWI
0:l0fMWI00<000000=WIf@3IfMT0:03IfMT002/0fMWI0P0000000`3IfMT000000=WIf@2/0=WIf@03
0000003IfMT0fMWI0800fMWI00<000000=WIf@3IfMT09P3IfMT2000000030=WIf@000000fMWI02`0
fMWI000]0=WIf@800000:03IfMT2000008<0fMWI00<000000=WIf@3IfMT0P03IfMT00`000000fMWI
0=WIf@0W0=WIf@<00000;@3IfMT002`0fMWI1000002/0=WIf@800000ZP3IfMT4000002d0fMWI000]
0=WIf@030000003IfMT0fMWI02L0fMWI00<000000=WIf@3IfMT0PP3IfMT00`000000fMWI0=WIf@21
0=WIf@8000009`3IfMT00`000000fMWI0=WIf@0]0=WIf@00;@3IfMT010000000fMWI0=WIf@3IfMT2
000002<0fMWI0P0000240=WIf@030000003IfMT0fMWI0840fMWI0P00000S0=WIf@030000003IfMT0
fMWI0340fMWI000d0=WIf@030000003IfMT0fMWI01h0fMWI100000230=WIf@030000003IfMT0fMWI
0800fMWI1000001F0=WIf@00=@3IfMT3000001/0fMWI00@000000=WIf@3IfMT00000Q@3IfMT00`00
0000fMWI0=WIf@240=WIf@030000003IfMT0fMWI01P0fMWI00D000000=WIf@000000fMWI0000000f
0=WIf@00=`3IfMT2000001X0fMWI00<000000=WIf@3IfMT0QP3IfMT00`000000fMWI0=WIf@2P0=WI
f@800000>03IfMT003H0fMWI1000002R0=WIf@030000003IfMT0fMWI08L0fMWI00<000000=WIf@3I
fMT05@3IfMT4000003L0fMWI000g0=WIf@030000003IfMT0fMWI008000005@3IfMT00`000000fMWI
0=WIf@280=WIf@030000003IfMT0fMWI08L0fMWI00<000000=WIf@3IfMT04`3IfMT010000000fMWI
0=WIf@00000i0=WIf@00?P3IfMT00`000000fMWI0=WIf@2K0=WIf@030000003IfMT0fMWI0:00fMWI
00<000000=WIf@3IfMT0=`3IfMT003h0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WI
f@2;0=WIf@800000RP3IfMT2000000h0fMWI0P00000o0=WIf@00@@3IfMT00`000000fMWI0=WIf@07
0=WIf@040000003IfMT00000000008d0fMWI00<000000=WIf@3IfMT0R`3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT000000480fMWI00110=WIf@D000000P3IfMT00`000000fMWI0=WIf@03
000008h0fMWI00<000000=WIf@3IfMT0R`3IfMT200000080fMWI0P0000020=WIf@030000003IfMT0
000000<00000@@3IfMT00440fMWI0P0000080=WIf@@00000S@3IfMT00`000000fMWI0=WIf@2;0=WI
f@<00000203IfMT00`000000fMWI0=WIf@110=WIf@00@P3IfMT00`000000fMWI0=WIf@070=WIf@03
0000003IfMT0fMWI08d0fMWI00<000000=WIf@3IfMT0R`3IfMT2000000T0fMWI00<000000=WIf@3I
fMT0@@3IfMT004`0fMWI00<000000=WIf@3IfMT0S@3IfMT00`000000fMWI0=WIf@2<0=WIf@030000
003IfMT0fMWI04/0fMWI003L0=WIf@030000003IfMT0fMWI0=X0fMWI003L0=WIf@030000003IfMT0
fMWI0=X0fMWI003L0=WIf@800000f`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 440.188}, {271.625, 0}} -> {-53.7175, -12.4104, 
  0.244067, 0.0586057}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Store field integral under text tab delimited file", "Subsubsection"],

Cell[BoxData[{
    \(tmp = OpenWrite["\<my_intg_file.dta\>", FormatType \[Rule] OutputForm]; 
    \n\(Do[Write[tmp, 
        CForm[Tx0\[LeftDoubleBracket]i, 1\[RightDoubleBracket]], "\<\t\>", 
        CForm[Tx0\[LeftDoubleBracket]i, 2\[RightDoubleBracket]], "\<\t\>", 
        CForm[Tz0\[LeftDoubleBracket]i, 2\[RightDoubleBracket]]], {i, 
        Length[Tz0]}]; \)\), 
    \(Close[tmp]\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tbz0 = 
      Table[{y, radFld[Grp, "\<Bz\>", {0., y, 0.}]}, {y, \(-250.\), 250., 
          2.}]; \nTbx0 = 
      Table[{y, radFld[Grp, "\<Bx\>", {0., y, 0.}]}, {y, \(-250.\), 250., 
          2.}]; \n\n
    MultipleListPlot[Tbx0, Tbz0, PlotJoined \[Rule] {True, True}, \n\t\t
      PlotRange \[Rule] All]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00190476 0.309017 0.74171 [
[.11905 .29652 -12 -9 ]
[.11905 .29652 12 0 ]
[.30952 .29652 -12 -9 ]
[.30952 .29652 12 0 ]
[.69048 .29652 -9 -9 ]
[.69048 .29652 9 0 ]
[.88095 .29652 -9 -9 ]
[.88095 .29652 9 0 ]
[.4875 .01233 -24 -4.5 ]
[.4875 .01233 0 4.5 ]
[.4875 .16068 -24 -4.5 ]
[.4875 .16068 0 4.5 ]
[.4875 .45736 -18 -4.5 ]
[.4875 .45736 0 4.5 ]
[.4875 .6057 -18 -4.5 ]
[.4875 .6057 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-200)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-100)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(100)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(200)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.15714 .30902 m
.15714 .31277 L
s
.19524 .30902 m
.19524 .31277 L
s
.23333 .30902 m
.23333 .31277 L
s
.27143 .30902 m
.27143 .31277 L
s
.34762 .30902 m
.34762 .31277 L
s
.38571 .30902 m
.38571 .31277 L
s
.42381 .30902 m
.42381 .31277 L
s
.4619 .30902 m
.4619 .31277 L
s
.5381 .30902 m
.5381 .31277 L
s
.57619 .30902 m
.57619 .31277 L
s
.61429 .30902 m
.61429 .31277 L
s
.65238 .30902 m
.65238 .31277 L
s
.72857 .30902 m
.72857 .31277 L
s
.76667 .30902 m
.76667 .31277 L
s
.80476 .30902 m
.80476 .31277 L
s
.84286 .30902 m
.84286 .31277 L
s
.08095 .30902 m
.08095 .31277 L
s
.04286 .30902 m
.04286 .31277 L
s
.00476 .30902 m
.00476 .31277 L
s
.91905 .30902 m
.91905 .31277 L
s
.95714 .30902 m
.95714 .31277 L
s
.99524 .30902 m
.99524 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .01233 m
.50625 .01233 L
s
[(-0.4)] .4875 .01233 1 0 Mshowa
.5 .16068 m
.50625 .16068 L
s
[(-0.2)] .4875 .16068 1 0 Mshowa
.5 .45736 m
.50625 .45736 L
s
[(0.2)] .4875 .45736 1 0 Mshowa
.5 .6057 m
.50625 .6057 L
s
[(0.4)] .4875 .6057 1 0 Mshowa
.125 Mabswid
.5 .04942 m
.50375 .04942 L
s
.5 .0865 m
.50375 .0865 L
s
.5 .12359 m
.50375 .12359 L
s
.5 .19776 m
.50375 .19776 L
s
.5 .23485 m
.50375 .23485 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .38319 m
.50375 .38319 L
s
.5 .42027 m
.50375 .42027 L
s
.5 .49444 m
.50375 .49444 L
s
.5 .53153 m
.50375 .53153 L
s
.5 .56862 m
.50375 .56862 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.001 w
.02381 .30901 m
.02762 .30901 L
.03143 .30901 L
.03524 .30901 L
.03905 .30901 L
.04286 .30901 L
.04667 .30901 L
.05048 .30901 L
.05429 .30901 L
.0581 .30901 L
.0619 .30901 L
.06571 .30901 L
.06952 .30901 L
.07333 .30901 L
.07714 .30901 L
.08095 .30901 L
.08476 .30901 L
.08857 .30901 L
.09238 .30901 L
.09619 .30901 L
.1 .30901 L
.10381 .30901 L
.10762 .30901 L
.11143 .30901 L
.11524 .309 L
.11905 .309 L
.12286 .309 L
.12667 .309 L
.13048 .309 L
.13429 .309 L
.1381 .309 L
.1419 .309 L
.14571 .30899 L
.14952 .30899 L
.15333 .30899 L
.15714 .30899 L
.16095 .30899 L
.16476 .30898 L
.16857 .30898 L
.17238 .30898 L
.17619 .30898 L
.18 .30897 L
.18381 .30897 L
.18762 .30896 L
.19143 .30896 L
.19524 .30895 L
.19905 .30895 L
.20286 .30894 L
.20667 .30893 L
.21048 .30893 L
Mistroke
.21429 .30892 L
.2181 .30891 L
.2219 .30889 L
.22571 .30888 L
.22952 .30887 L
.23333 .30885 L
.23714 .30883 L
.24095 .30881 L
.24476 .30879 L
.24857 .30876 L
.25238 .30874 L
.25619 .3087 L
.26 .30867 L
.26381 .30863 L
.26762 .30858 L
.27143 .30853 L
.27524 .30848 L
.27905 .30841 L
.28286 .30835 L
.28667 .30827 L
.29048 .3082 L
.29429 .30812 L
.2981 .30804 L
.3019 .30796 L
.30571 .3079 L
.30952 .30786 L
.31333 .30787 L
.31714 .30795 L
.32095 .30813 L
.32476 .3085 L
.32857 .30912 L
.33238 .31015 L
.33619 .31178 L
.34 .31428 L
.34381 .318 L
.34762 .32335 L
.35143 .33061 L
.35524 .33966 L
.35905 .34972 L
.36286 .35925 L
.36667 .36616 L
.37048 .36831 L
.37429 .36394 L
.3781 .35206 L
.3819 .33274 L
.38571 .30716 L
.38952 .27742 L
.39333 .24624 L
.39714 .21658 L
.40095 .19127 L
Mistroke
.40476 .17273 L
.40857 .16271 L
.41238 .16217 L
.41619 .17134 L
.42 .18974 L
.42381 .21635 L
.42762 .24963 L
.43143 .28751 L
.43524 .32742 L
.43905 .36668 L
.44286 .40289 L
.44667 .43424 L
.45048 .45936 L
.45429 .47708 L
.4581 .48637 L
.4619 .48658 L
.46571 .47769 L
.46952 .46034 L
.47333 .43549 L
.47714 .40427 L
.48095 .36795 L
.48476 .32821 L
.48857 .28724 L
.49238 .24746 L
.49619 .21105 L
.5 .17971 L
.50381 .15471 L
.50762 .13717 L
.51143 .12809 L
.51524 .12809 L
.51905 .13717 L
.52286 .15471 L
.52667 .17971 L
.53048 .21105 L
.53429 .24746 L
.5381 .28724 L
.5419 .32821 L
.54571 .36795 L
.54952 .40427 L
.55333 .43549 L
.55714 .46034 L
.56095 .47769 L
.56476 .48658 L
.56857 .48637 L
.57238 .47708 L
.57619 .45936 L
.58 .43425 L
.58381 .40289 L
.58762 .36668 L
.59143 .32742 L
Mistroke
.59524 .28751 L
.59905 .24963 L
.60286 .21635 L
.60667 .18974 L
.61048 .17134 L
.61429 .16217 L
.6181 .16271 L
.6219 .17273 L
.62571 .19127 L
.62952 .21658 L
.63333 .24624 L
.63714 .27742 L
.64095 .30716 L
.64476 .33274 L
.64857 .35206 L
.65238 .36394 L
.65619 .36831 L
.66 .36616 L
.66381 .35925 L
.66762 .34972 L
.67143 .33966 L
.67524 .33061 L
.67905 .32335 L
.68286 .318 L
.68667 .31428 L
.69048 .31178 L
.69429 .31015 L
.6981 .30912 L
.7019 .3085 L
.70571 .30813 L
.70952 .30795 L
.71333 .30787 L
.71714 .30786 L
.72095 .3079 L
.72476 .30796 L
.72857 .30804 L
.73238 .30812 L
.73619 .3082 L
.74 .30827 L
.74381 .30835 L
.74762 .30841 L
.75143 .30848 L
.75524 .30853 L
.75905 .30858 L
.76286 .30863 L
.76667 .30867 L
.77048 .3087 L
.77429 .30874 L
.7781 .30876 L
.7819 .30879 L
Mistroke
.78571 .30881 L
.78952 .30883 L
.79333 .30885 L
.79714 .30887 L
.80095 .30888 L
.80476 .30889 L
.80857 .30891 L
.81238 .30892 L
.81619 .30893 L
.82 .30893 L
.82381 .30894 L
.82762 .30895 L
.83143 .30895 L
.83524 .30896 L
.83905 .30896 L
.84286 .30897 L
.84667 .30897 L
.85048 .30898 L
.85429 .30898 L
.8581 .30898 L
.8619 .30898 L
.86571 .30899 L
.86952 .30899 L
.87333 .30899 L
.87714 .30899 L
.88095 .30899 L
.88476 .309 L
.88857 .309 L
.89238 .309 L
.89619 .309 L
.9 .309 L
.90381 .309 L
.90762 .309 L
.91143 .309 L
.91524 .309 L
.91905 .30901 L
.92286 .30901 L
.92667 .30901 L
.93048 .30901 L
.93429 .30901 L
.9381 .30901 L
.9419 .30901 L
.94571 .30901 L
.94952 .30901 L
.95333 .30901 L
.95714 .30901 L
.96095 .30901 L
.96476 .30901 L
.96857 .30901 L
.97238 .30901 L
Mistroke
.97619 .30901 L
Mfstroke
.0001 w
.02381 .30901 -1.875 0 Mabsadd m
.02381 .30901 0 2.5 Mabsadd L
.02381 .30901 1.875 0 Mabsadd L
.02381 .30901 0 -2.5 Mabsadd L
.02381 .30901 -1.875 0 Mabsadd L closepath F
.02762 .30901 -1.875 0 Mabsadd m
.02762 .30901 0 2.5 Mabsadd L
.02762 .30901 1.875 0 Mabsadd L
.02762 .30901 0 -2.5 Mabsadd L
.02762 .30901 -1.875 0 Mabsadd L closepath F
.03143 .30901 -1.875 0 Mabsadd m
.03143 .30901 0 2.5 Mabsadd L
.03143 .30901 1.875 0 Mabsadd L
.03143 .30901 0 -2.5 Mabsadd L
.03143 .30901 -1.875 0 Mabsadd L closepath F
.03524 .30901 -1.875 0 Mabsadd m
.03524 .30901 0 2.5 Mabsadd L
.03524 .30901 1.875 0 Mabsadd L
.03524 .30901 0 -2.5 Mabsadd L
.03524 .30901 -1.875 0 Mabsadd L closepath F
.03905 .30901 -1.875 0 Mabsadd m
.03905 .30901 0 2.5 Mabsadd L
.03905 .30901 1.875 0 Mabsadd L
.03905 .30901 0 -2.5 Mabsadd L
.03905 .30901 -1.875 0 Mabsadd L closepath F
.04286 .30901 -1.875 0 Mabsadd m
.04286 .30901 0 2.5 Mabsadd L
.04286 .30901 1.875 0 Mabsadd L
.04286 .30901 0 -2.5 Mabsadd L
.04286 .30901 -1.875 0 Mabsadd L closepath F
.04667 .30901 -1.875 0 Mabsadd m
.04667 .30901 0 2.5 Mabsadd L
.04667 .30901 1.875 0 Mabsadd L
.04667 .30901 0 -2.5 Mabsadd L
.04667 .30901 -1.875 0 Mabsadd L closepath F
.05048 .30901 -1.875 0 Mabsadd m
.05048 .30901 0 2.5 Mabsadd L
.05048 .30901 1.875 0 Mabsadd L
.05048 .30901 0 -2.5 Mabsadd L
.05048 .30901 -1.875 0 Mabsadd L closepath F
.05429 .30901 -1.875 0 Mabsadd m
.05429 .30901 0 2.5 Mabsadd L
.05429 .30901 1.875 0 Mabsadd L
.05429 .30901 0 -2.5 Mabsadd L
.05429 .30901 -1.875 0 Mabsadd L closepath F
.0581 .30901 -1.875 0 Mabsadd m
.0581 .30901 0 2.5 Mabsadd L
.0581 .30901 1.875 0 Mabsadd L
.0581 .30901 0 -2.5 Mabsadd L
.0581 .30901 -1.875 0 Mabsadd L closepath F
.0619 .30901 -1.875 0 Mabsadd m
.0619 .30901 0 2.5 Mabsadd L
.0619 .30901 1.875 0 Mabsadd L
.0619 .30901 0 -2.5 Mabsadd L
.0619 .30901 -1.875 0 Mabsadd L closepath F
.06571 .30901 -1.875 0 Mabsadd m
.06571 .30901 0 2.5 Mabsadd L
.06571 .30901 1.875 0 Mabsadd L
.06571 .30901 0 -2.5 Mabsadd L
.06571 .30901 -1.875 0 Mabsadd L closepath F
.06952 .30901 -1.875 0 Mabsadd m
.06952 .30901 0 2.5 Mabsadd L
.06952 .30901 1.875 0 Mabsadd L
.06952 .30901 0 -2.5 Mabsadd L
.06952 .30901 -1.875 0 Mabsadd L closepath F
.07333 .30901 -1.875 0 Mabsadd m
.07333 .30901 0 2.5 Mabsadd L
.07333 .30901 1.875 0 Mabsadd L
.07333 .30901 0 -2.5 Mabsadd L
.07333 .30901 -1.875 0 Mabsadd L closepath F
.07714 .30901 -1.875 0 Mabsadd m
.07714 .30901 0 2.5 Mabsadd L
.07714 .30901 1.875 0 Mabsadd L
.07714 .30901 0 -2.5 Mabsadd L
.07714 .30901 -1.875 0 Mabsadd L closepath F
.08095 .30901 -1.875 0 Mabsadd m
.08095 .30901 0 2.5 Mabsadd L
.08095 .30901 1.875 0 Mabsadd L
.08095 .30901 0 -2.5 Mabsadd L
.08095 .30901 -1.875 0 Mabsadd L closepath F
.08476 .30901 -1.875 0 Mabsadd m
.08476 .30901 0 2.5 Mabsadd L
.08476 .30901 1.875 0 Mabsadd L
.08476 .30901 0 -2.5 Mabsadd L
.08476 .30901 -1.875 0 Mabsadd L closepath F
.08857 .30901 -1.875 0 Mabsadd m
.08857 .30901 0 2.5 Mabsadd L
.08857 .30901 1.875 0 Mabsadd L
.08857 .30901 0 -2.5 Mabsadd L
.08857 .30901 -1.875 0 Mabsadd L closepath F
.09238 .30901 -1.875 0 Mabsadd m
.09238 .30901 0 2.5 Mabsadd L
.09238 .30901 1.875 0 Mabsadd L
.09238 .30901 0 -2.5 Mabsadd L
.09238 .30901 -1.875 0 Mabsadd L closepath F
.09619 .30901 -1.875 0 Mabsadd m
.09619 .30901 0 2.5 Mabsadd L
.09619 .30901 1.875 0 Mabsadd L
.09619 .30901 0 -2.5 Mabsadd L
.09619 .30901 -1.875 0 Mabsadd L closepath F
.1 .30901 -1.875 0 Mabsadd m
.1 .30901 0 2.5 Mabsadd L
.1 .30901 1.875 0 Mabsadd L
.1 .30901 0 -2.5 Mabsadd L
.1 .30901 -1.875 0 Mabsadd L closepath F
.10381 .30901 -1.875 0 Mabsadd m
.10381 .30901 0 2.5 Mabsadd L
.10381 .30901 1.875 0 Mabsadd L
.10381 .30901 0 -2.5 Mabsadd L
.10381 .30901 -1.875 0 Mabsadd L closepath F
.10762 .30901 -1.875 0 Mabsadd m
.10762 .30901 0 2.5 Mabsadd L
.10762 .30901 1.875 0 Mabsadd L
.10762 .30901 0 -2.5 Mabsadd L
.10762 .30901 -1.875 0 Mabsadd L closepath F
.11143 .30901 -1.875 0 Mabsadd m
.11143 .30901 0 2.5 Mabsadd L
.11143 .30901 1.875 0 Mabsadd L
.11143 .30901 0 -2.5 Mabsadd L
.11143 .30901 -1.875 0 Mabsadd L closepath F
.11524 .309 -1.875 0 Mabsadd m
.11524 .309 0 2.5 Mabsadd L
.11524 .309 1.875 0 Mabsadd L
.11524 .309 0 -2.5 Mabsadd L
.11524 .309 -1.875 0 Mabsadd L closepath F
.11905 .309 -1.875 0 Mabsadd m
.11905 .309 0 2.5 Mabsadd L
.11905 .309 1.875 0 Mabsadd L
.11905 .309 0 -2.5 Mabsadd L
.11905 .309 -1.875 0 Mabsadd L closepath F
.12286 .309 -1.875 0 Mabsadd m
.12286 .309 0 2.5 Mabsadd L
.12286 .309 1.875 0 Mabsadd L
.12286 .309 0 -2.5 Mabsadd L
.12286 .309 -1.875 0 Mabsadd L closepath F
.12667 .309 -1.875 0 Mabsadd m
.12667 .309 0 2.5 Mabsadd L
.12667 .309 1.875 0 Mabsadd L
.12667 .309 0 -2.5 Mabsadd L
.12667 .309 -1.875 0 Mabsadd L closepath F
.13048 .309 -1.875 0 Mabsadd m
.13048 .309 0 2.5 Mabsadd L
.13048 .309 1.875 0 Mabsadd L
.13048 .309 0 -2.5 Mabsadd L
.13048 .309 -1.875 0 Mabsadd L closepath F
.13429 .309 -1.875 0 Mabsadd m
.13429 .309 0 2.5 Mabsadd L
.13429 .309 1.875 0 Mabsadd L
.13429 .309 0 -2.5 Mabsadd L
.13429 .309 -1.875 0 Mabsadd L closepath F
.1381 .309 -1.875 0 Mabsadd m
.1381 .309 0 2.5 Mabsadd L
.1381 .309 1.875 0 Mabsadd L
.1381 .309 0 -2.5 Mabsadd L
.1381 .309 -1.875 0 Mabsadd L closepath F
.1419 .309 -1.875 0 Mabsadd m
.1419 .309 0 2.5 Mabsadd L
.1419 .309 1.875 0 Mabsadd L
.1419 .309 0 -2.5 Mabsadd L
.1419 .309 -1.875 0 Mabsadd L closepath F
.14571 .30899 -1.875 0 Mabsadd m
.14571 .30899 0 2.5 Mabsadd L
.14571 .30899 1.875 0 Mabsadd L
.14571 .30899 0 -2.5 Mabsadd L
.14571 .30899 -1.875 0 Mabsadd L closepath F
.14952 .30899 -1.875 0 Mabsadd m
.14952 .30899 0 2.5 Mabsadd L
.14952 .30899 1.875 0 Mabsadd L
.14952 .30899 0 -2.5 Mabsadd L
.14952 .30899 -1.875 0 Mabsadd L closepath F
.15333 .30899 -1.875 0 Mabsadd m
.15333 .30899 0 2.5 Mabsadd L
.15333 .30899 1.875 0 Mabsadd L
.15333 .30899 0 -2.5 Mabsadd L
.15333 .30899 -1.875 0 Mabsadd L closepath F
.15714 .30899 -1.875 0 Mabsadd m
.15714 .30899 0 2.5 Mabsadd L
.15714 .30899 1.875 0 Mabsadd L
.15714 .30899 0 -2.5 Mabsadd L
.15714 .30899 -1.875 0 Mabsadd L closepath F
.16095 .30899 -1.875 0 Mabsadd m
.16095 .30899 0 2.5 Mabsadd L
.16095 .30899 1.875 0 Mabsadd L
.16095 .30899 0 -2.5 Mabsadd L
.16095 .30899 -1.875 0 Mabsadd L closepath F
.16476 .30898 -1.875 0 Mabsadd m
.16476 .30898 0 2.5 Mabsadd L
.16476 .30898 1.875 0 Mabsadd L
.16476 .30898 0 -2.5 Mabsadd L
.16476 .30898 -1.875 0 Mabsadd L closepath F
.16857 .30898 -1.875 0 Mabsadd m
.16857 .30898 0 2.5 Mabsadd L
.16857 .30898 1.875 0 Mabsadd L
.16857 .30898 0 -2.5 Mabsadd L
.16857 .30898 -1.875 0 Mabsadd L closepath F
.17238 .30898 -1.875 0 Mabsadd m
.17238 .30898 0 2.5 Mabsadd L
.17238 .30898 1.875 0 Mabsadd L
.17238 .30898 0 -2.5 Mabsadd L
.17238 .30898 -1.875 0 Mabsadd L closepath F
.17619 .30898 -1.875 0 Mabsadd m
.17619 .30898 0 2.5 Mabsadd L
.17619 .30898 1.875 0 Mabsadd L
.17619 .30898 0 -2.5 Mabsadd L
.17619 .30898 -1.875 0 Mabsadd L closepath F
.18 .30897 -1.875 0 Mabsadd m
.18 .30897 0 2.5 Mabsadd L
.18 .30897 1.875 0 Mabsadd L
.18 .30897 0 -2.5 Mabsadd L
.18 .30897 -1.875 0 Mabsadd L closepath F
.18381 .30897 -1.875 0 Mabsadd m
.18381 .30897 0 2.5 Mabsadd L
.18381 .30897 1.875 0 Mabsadd L
.18381 .30897 0 -2.5 Mabsadd L
.18381 .30897 -1.875 0 Mabsadd L closepath F
.18762 .30896 -1.875 0 Mabsadd m
.18762 .30896 0 2.5 Mabsadd L
.18762 .30896 1.875 0 Mabsadd L
.18762 .30896 0 -2.5 Mabsadd L
.18762 .30896 -1.875 0 Mabsadd L closepath F
.19143 .30896 -1.875 0 Mabsadd m
.19143 .30896 0 2.5 Mabsadd L
.19143 .30896 1.875 0 Mabsadd L
.19143 .30896 0 -2.5 Mabsadd L
.19143 .30896 -1.875 0 Mabsadd L closepath F
.19524 .30895 -1.875 0 Mabsadd m
.19524 .30895 0 2.5 Mabsadd L
.19524 .30895 1.875 0 Mabsadd L
.19524 .30895 0 -2.5 Mabsadd L
.19524 .30895 -1.875 0 Mabsadd L closepath F
.19905 .30895 -1.875 0 Mabsadd m
.19905 .30895 0 2.5 Mabsadd L
.19905 .30895 1.875 0 Mabsadd L
.19905 .30895 0 -2.5 Mabsadd L
.19905 .30895 -1.875 0 Mabsadd L closepath F
.20286 .30894 -1.875 0 Mabsadd m
.20286 .30894 0 2.5 Mabsadd L
.20286 .30894 1.875 0 Mabsadd L
.20286 .30894 0 -2.5 Mabsadd L
.20286 .30894 -1.875 0 Mabsadd L closepath F
.20667 .30893 -1.875 0 Mabsadd m
.20667 .30893 0 2.5 Mabsadd L
.20667 .30893 1.875 0 Mabsadd L
.20667 .30893 0 -2.5 Mabsadd L
.20667 .30893 -1.875 0 Mabsadd L closepath F
.21048 .30893 -1.875 0 Mabsadd m
.21048 .30893 0 2.5 Mabsadd L
.21048 .30893 1.875 0 Mabsadd L
.21048 .30893 0 -2.5 Mabsadd L
.21048 .30893 -1.875 0 Mabsadd L closepath F
.21429 .30892 -1.875 0 Mabsadd m
.21429 .30892 0 2.5 Mabsadd L
.21429 .30892 1.875 0 Mabsadd L
.21429 .30892 0 -2.5 Mabsadd L
.21429 .30892 -1.875 0 Mabsadd L closepath F
.2181 .30891 -1.875 0 Mabsadd m
.2181 .30891 0 2.5 Mabsadd L
.2181 .30891 1.875 0 Mabsadd L
.2181 .30891 0 -2.5 Mabsadd L
.2181 .30891 -1.875 0 Mabsadd L closepath F
.2219 .30889 -1.875 0 Mabsadd m
.2219 .30889 0 2.5 Mabsadd L
.2219 .30889 1.875 0 Mabsadd L
.2219 .30889 0 -2.5 Mabsadd L
.2219 .30889 -1.875 0 Mabsadd L closepath F
.22571 .30888 -1.875 0 Mabsadd m
.22571 .30888 0 2.5 Mabsadd L
.22571 .30888 1.875 0 Mabsadd L
.22571 .30888 0 -2.5 Mabsadd L
.22571 .30888 -1.875 0 Mabsadd L closepath F
.22952 .30887 -1.875 0 Mabsadd m
.22952 .30887 0 2.5 Mabsadd L
.22952 .30887 1.875 0 Mabsadd L
.22952 .30887 0 -2.5 Mabsadd L
.22952 .30887 -1.875 0 Mabsadd L closepath F
.23333 .30885 -1.875 0 Mabsadd m
.23333 .30885 0 2.5 Mabsadd L
.23333 .30885 1.875 0 Mabsadd L
.23333 .30885 0 -2.5 Mabsadd L
.23333 .30885 -1.875 0 Mabsadd L closepath F
.23714 .30883 -1.875 0 Mabsadd m
.23714 .30883 0 2.5 Mabsadd L
.23714 .30883 1.875 0 Mabsadd L
.23714 .30883 0 -2.5 Mabsadd L
.23714 .30883 -1.875 0 Mabsadd L closepath F
.24095 .30881 -1.875 0 Mabsadd m
.24095 .30881 0 2.5 Mabsadd L
.24095 .30881 1.875 0 Mabsadd L
.24095 .30881 0 -2.5 Mabsadd L
.24095 .30881 -1.875 0 Mabsadd L closepath F
.24476 .30879 -1.875 0 Mabsadd m
.24476 .30879 0 2.5 Mabsadd L
.24476 .30879 1.875 0 Mabsadd L
.24476 .30879 0 -2.5 Mabsadd L
.24476 .30879 -1.875 0 Mabsadd L closepath F
.24857 .30876 -1.875 0 Mabsadd m
.24857 .30876 0 2.5 Mabsadd L
.24857 .30876 1.875 0 Mabsadd L
.24857 .30876 0 -2.5 Mabsadd L
.24857 .30876 -1.875 0 Mabsadd L closepath F
.25238 .30874 -1.875 0 Mabsadd m
.25238 .30874 0 2.5 Mabsadd L
.25238 .30874 1.875 0 Mabsadd L
.25238 .30874 0 -2.5 Mabsadd L
.25238 .30874 -1.875 0 Mabsadd L closepath F
.25619 .3087 -1.875 0 Mabsadd m
.25619 .3087 0 2.5 Mabsadd L
.25619 .3087 1.875 0 Mabsadd L
.25619 .3087 0 -2.5 Mabsadd L
.25619 .3087 -1.875 0 Mabsadd L closepath F
.26 .30867 -1.875 0 Mabsadd m
.26 .30867 0 2.5 Mabsadd L
.26 .30867 1.875 0 Mabsadd L
.26 .30867 0 -2.5 Mabsadd L
.26 .30867 -1.875 0 Mabsadd L closepath F
.26381 .30863 -1.875 0 Mabsadd m
.26381 .30863 0 2.5 Mabsadd L
.26381 .30863 1.875 0 Mabsadd L
.26381 .30863 0 -2.5 Mabsadd L
.26381 .30863 -1.875 0 Mabsadd L closepath F
.26762 .30858 -1.875 0 Mabsadd m
.26762 .30858 0 2.5 Mabsadd L
.26762 .30858 1.875 0 Mabsadd L
.26762 .30858 0 -2.5 Mabsadd L
.26762 .30858 -1.875 0 Mabsadd L closepath F
.27143 .30853 -1.875 0 Mabsadd m
.27143 .30853 0 2.5 Mabsadd L
.27143 .30853 1.875 0 Mabsadd L
.27143 .30853 0 -2.5 Mabsadd L
.27143 .30853 -1.875 0 Mabsadd L closepath F
.27524 .30848 -1.875 0 Mabsadd m
.27524 .30848 0 2.5 Mabsadd L
.27524 .30848 1.875 0 Mabsadd L
.27524 .30848 0 -2.5 Mabsadd L
.27524 .30848 -1.875 0 Mabsadd L closepath F
.27905 .30841 -1.875 0 Mabsadd m
.27905 .30841 0 2.5 Mabsadd L
.27905 .30841 1.875 0 Mabsadd L
.27905 .30841 0 -2.5 Mabsadd L
.27905 .30841 -1.875 0 Mabsadd L closepath F
.28286 .30835 -1.875 0 Mabsadd m
.28286 .30835 0 2.5 Mabsadd L
.28286 .30835 1.875 0 Mabsadd L
.28286 .30835 0 -2.5 Mabsadd L
.28286 .30835 -1.875 0 Mabsadd L closepath F
.28667 .30827 -1.875 0 Mabsadd m
.28667 .30827 0 2.5 Mabsadd L
.28667 .30827 1.875 0 Mabsadd L
.28667 .30827 0 -2.5 Mabsadd L
.28667 .30827 -1.875 0 Mabsadd L closepath F
.29048 .3082 -1.875 0 Mabsadd m
.29048 .3082 0 2.5 Mabsadd L
.29048 .3082 1.875 0 Mabsadd L
.29048 .3082 0 -2.5 Mabsadd L
.29048 .3082 -1.875 0 Mabsadd L closepath F
.29429 .30812 -1.875 0 Mabsadd m
.29429 .30812 0 2.5 Mabsadd L
.29429 .30812 1.875 0 Mabsadd L
.29429 .30812 0 -2.5 Mabsadd L
.29429 .30812 -1.875 0 Mabsadd L closepath F
.2981 .30804 -1.875 0 Mabsadd m
.2981 .30804 0 2.5 Mabsadd L
.2981 .30804 1.875 0 Mabsadd L
.2981 .30804 0 -2.5 Mabsadd L
.2981 .30804 -1.875 0 Mabsadd L closepath F
.3019 .30796 -1.875 0 Mabsadd m
.3019 .30796 0 2.5 Mabsadd L
.3019 .30796 1.875 0 Mabsadd L
.3019 .30796 0 -2.5 Mabsadd L
.3019 .30796 -1.875 0 Mabsadd L closepath F
.30571 .3079 -1.875 0 Mabsadd m
.30571 .3079 0 2.5 Mabsadd L
.30571 .3079 1.875 0 Mabsadd L
.30571 .3079 0 -2.5 Mabsadd L
.30571 .3079 -1.875 0 Mabsadd L closepath F
.30952 .30786 -1.875 0 Mabsadd m
.30952 .30786 0 2.5 Mabsadd L
.30952 .30786 1.875 0 Mabsadd L
.30952 .30786 0 -2.5 Mabsadd L
.30952 .30786 -1.875 0 Mabsadd L closepath F
.31333 .30787 -1.875 0 Mabsadd m
.31333 .30787 0 2.5 Mabsadd L
.31333 .30787 1.875 0 Mabsadd L
.31333 .30787 0 -2.5 Mabsadd L
.31333 .30787 -1.875 0 Mabsadd L closepath F
.31714 .30795 -1.875 0 Mabsadd m
.31714 .30795 0 2.5 Mabsadd L
.31714 .30795 1.875 0 Mabsadd L
.31714 .30795 0 -2.5 Mabsadd L
.31714 .30795 -1.875 0 Mabsadd L closepath F
.32095 .30813 -1.875 0 Mabsadd m
.32095 .30813 0 2.5 Mabsadd L
.32095 .30813 1.875 0 Mabsadd L
.32095 .30813 0 -2.5 Mabsadd L
.32095 .30813 -1.875 0 Mabsadd L closepath F
.32476 .3085 -1.875 0 Mabsadd m
.32476 .3085 0 2.5 Mabsadd L
.32476 .3085 1.875 0 Mabsadd L
.32476 .3085 0 -2.5 Mabsadd L
.32476 .3085 -1.875 0 Mabsadd L closepath F
.32857 .30912 -1.875 0 Mabsadd m
.32857 .30912 0 2.5 Mabsadd L
.32857 .30912 1.875 0 Mabsadd L
.32857 .30912 0 -2.5 Mabsadd L
.32857 .30912 -1.875 0 Mabsadd L closepath F
.33238 .31015 -1.875 0 Mabsadd m
.33238 .31015 0 2.5 Mabsadd L
.33238 .31015 1.875 0 Mabsadd L
.33238 .31015 0 -2.5 Mabsadd L
.33238 .31015 -1.875 0 Mabsadd L closepath F
.33619 .31178 -1.875 0 Mabsadd m
.33619 .31178 0 2.5 Mabsadd L
.33619 .31178 1.875 0 Mabsadd L
.33619 .31178 0 -2.5 Mabsadd L
.33619 .31178 -1.875 0 Mabsadd L closepath F
.34 .31428 -1.875 0 Mabsadd m
.34 .31428 0 2.5 Mabsadd L
.34 .31428 1.875 0 Mabsadd L
.34 .31428 0 -2.5 Mabsadd L
.34 .31428 -1.875 0 Mabsadd L closepath F
.34381 .318 -1.875 0 Mabsadd m
.34381 .318 0 2.5 Mabsadd L
.34381 .318 1.875 0 Mabsadd L
.34381 .318 0 -2.5 Mabsadd L
.34381 .318 -1.875 0 Mabsadd L closepath F
.34762 .32335 -1.875 0 Mabsadd m
.34762 .32335 0 2.5 Mabsadd L
.34762 .32335 1.875 0 Mabsadd L
.34762 .32335 0 -2.5 Mabsadd L
.34762 .32335 -1.875 0 Mabsadd L closepath F
.35143 .33061 -1.875 0 Mabsadd m
.35143 .33061 0 2.5 Mabsadd L
.35143 .33061 1.875 0 Mabsadd L
.35143 .33061 0 -2.5 Mabsadd L
.35143 .33061 -1.875 0 Mabsadd L closepath F
.35524 .33966 -1.875 0 Mabsadd m
.35524 .33966 0 2.5 Mabsadd L
.35524 .33966 1.875 0 Mabsadd L
.35524 .33966 0 -2.5 Mabsadd L
.35524 .33966 -1.875 0 Mabsadd L closepath F
.35905 .34972 -1.875 0 Mabsadd m
.35905 .34972 0 2.5 Mabsadd L
.35905 .34972 1.875 0 Mabsadd L
.35905 .34972 0 -2.5 Mabsadd L
.35905 .34972 -1.875 0 Mabsadd L closepath F
.36286 .35925 -1.875 0 Mabsadd m
.36286 .35925 0 2.5 Mabsadd L
.36286 .35925 1.875 0 Mabsadd L
.36286 .35925 0 -2.5 Mabsadd L
.36286 .35925 -1.875 0 Mabsadd L closepath F
.36667 .36616 -1.875 0 Mabsadd m
.36667 .36616 0 2.5 Mabsadd L
.36667 .36616 1.875 0 Mabsadd L
.36667 .36616 0 -2.5 Mabsadd L
.36667 .36616 -1.875 0 Mabsadd L closepath F
.37048 .36831 -1.875 0 Mabsadd m
.37048 .36831 0 2.5 Mabsadd L
.37048 .36831 1.875 0 Mabsadd L
.37048 .36831 0 -2.5 Mabsadd L
.37048 .36831 -1.875 0 Mabsadd L closepath F
.37429 .36394 -1.875 0 Mabsadd m
.37429 .36394 0 2.5 Mabsadd L
.37429 .36394 1.875 0 Mabsadd L
.37429 .36394 0 -2.5 Mabsadd L
.37429 .36394 -1.875 0 Mabsadd L closepath F
.3781 .35206 -1.875 0 Mabsadd m
.3781 .35206 0 2.5 Mabsadd L
.3781 .35206 1.875 0 Mabsadd L
.3781 .35206 0 -2.5 Mabsadd L
.3781 .35206 -1.875 0 Mabsadd L closepath F
.3819 .33274 -1.875 0 Mabsadd m
.3819 .33274 0 2.5 Mabsadd L
.3819 .33274 1.875 0 Mabsadd L
.3819 .33274 0 -2.5 Mabsadd L
.3819 .33274 -1.875 0 Mabsadd L closepath F
.38571 .30716 -1.875 0 Mabsadd m
.38571 .30716 0 2.5 Mabsadd L
.38571 .30716 1.875 0 Mabsadd L
.38571 .30716 0 -2.5 Mabsadd L
.38571 .30716 -1.875 0 Mabsadd L closepath F
.38952 .27742 -1.875 0 Mabsadd m
.38952 .27742 0 2.5 Mabsadd L
.38952 .27742 1.875 0 Mabsadd L
.38952 .27742 0 -2.5 Mabsadd L
.38952 .27742 -1.875 0 Mabsadd L closepath F
.39333 .24624 -1.875 0 Mabsadd m
.39333 .24624 0 2.5 Mabsadd L
.39333 .24624 1.875 0 Mabsadd L
.39333 .24624 0 -2.5 Mabsadd L
.39333 .24624 -1.875 0 Mabsadd L closepath F
.39714 .21658 -1.875 0 Mabsadd m
.39714 .21658 0 2.5 Mabsadd L
.39714 .21658 1.875 0 Mabsadd L
.39714 .21658 0 -2.5 Mabsadd L
.39714 .21658 -1.875 0 Mabsadd L closepath F
.40095 .19127 -1.875 0 Mabsadd m
.40095 .19127 0 2.5 Mabsadd L
.40095 .19127 1.875 0 Mabsadd L
.40095 .19127 0 -2.5 Mabsadd L
.40095 .19127 -1.875 0 Mabsadd L closepath F
.40476 .17273 -1.875 0 Mabsadd m
.40476 .17273 0 2.5 Mabsadd L
.40476 .17273 1.875 0 Mabsadd L
.40476 .17273 0 -2.5 Mabsadd L
.40476 .17273 -1.875 0 Mabsadd L closepath F
.40857 .16271 -1.875 0 Mabsadd m
.40857 .16271 0 2.5 Mabsadd L
.40857 .16271 1.875 0 Mabsadd L
.40857 .16271 0 -2.5 Mabsadd L
.40857 .16271 -1.875 0 Mabsadd L closepath F
.41238 .16217 -1.875 0 Mabsadd m
.41238 .16217 0 2.5 Mabsadd L
.41238 .16217 1.875 0 Mabsadd L
.41238 .16217 0 -2.5 Mabsadd L
.41238 .16217 -1.875 0 Mabsadd L closepath F
.41619 .17134 -1.875 0 Mabsadd m
.41619 .17134 0 2.5 Mabsadd L
.41619 .17134 1.875 0 Mabsadd L
.41619 .17134 0 -2.5 Mabsadd L
.41619 .17134 -1.875 0 Mabsadd L closepath F
.42 .18974 -1.875 0 Mabsadd m
.42 .18974 0 2.5 Mabsadd L
.42 .18974 1.875 0 Mabsadd L
.42 .18974 0 -2.5 Mabsadd L
.42 .18974 -1.875 0 Mabsadd L closepath F
.42381 .21635 -1.875 0 Mabsadd m
.42381 .21635 0 2.5 Mabsadd L
.42381 .21635 1.875 0 Mabsadd L
.42381 .21635 0 -2.5 Mabsadd L
.42381 .21635 -1.875 0 Mabsadd L closepath F
.42762 .24963 -1.875 0 Mabsadd m
.42762 .24963 0 2.5 Mabsadd L
.42762 .24963 1.875 0 Mabsadd L
.42762 .24963 0 -2.5 Mabsadd L
.42762 .24963 -1.875 0 Mabsadd L closepath F
.43143 .28751 -1.875 0 Mabsadd m
.43143 .28751 0 2.5 Mabsadd L
.43143 .28751 1.875 0 Mabsadd L
.43143 .28751 0 -2.5 Mabsadd L
.43143 .28751 -1.875 0 Mabsadd L closepath F
.43524 .32742 -1.875 0 Mabsadd m
.43524 .32742 0 2.5 Mabsadd L
.43524 .32742 1.875 0 Mabsadd L
.43524 .32742 0 -2.5 Mabsadd L
.43524 .32742 -1.875 0 Mabsadd L closepath F
.43905 .36668 -1.875 0 Mabsadd m
.43905 .36668 0 2.5 Mabsadd L
.43905 .36668 1.875 0 Mabsadd L
.43905 .36668 0 -2.5 Mabsadd L
.43905 .36668 -1.875 0 Mabsadd L closepath F
.44286 .40289 -1.875 0 Mabsadd m
.44286 .40289 0 2.5 Mabsadd L
.44286 .40289 1.875 0 Mabsadd L
.44286 .40289 0 -2.5 Mabsadd L
.44286 .40289 -1.875 0 Mabsadd L closepath F
.44667 .43424 -1.875 0 Mabsadd m
.44667 .43424 0 2.5 Mabsadd L
.44667 .43424 1.875 0 Mabsadd L
.44667 .43424 0 -2.5 Mabsadd L
.44667 .43424 -1.875 0 Mabsadd L closepath F
.45048 .45936 -1.875 0 Mabsadd m
.45048 .45936 0 2.5 Mabsadd L
.45048 .45936 1.875 0 Mabsadd L
.45048 .45936 0 -2.5 Mabsadd L
.45048 .45936 -1.875 0 Mabsadd L closepath F
.45429 .47708 -1.875 0 Mabsadd m
.45429 .47708 0 2.5 Mabsadd L
.45429 .47708 1.875 0 Mabsadd L
.45429 .47708 0 -2.5 Mabsadd L
.45429 .47708 -1.875 0 Mabsadd L closepath F
.4581 .48637 -1.875 0 Mabsadd m
.4581 .48637 0 2.5 Mabsadd L
.4581 .48637 1.875 0 Mabsadd L
.4581 .48637 0 -2.5 Mabsadd L
.4581 .48637 -1.875 0 Mabsadd L closepath F
.4619 .48658 -1.875 0 Mabsadd m
.4619 .48658 0 2.5 Mabsadd L
.4619 .48658 1.875 0 Mabsadd L
.4619 .48658 0 -2.5 Mabsadd L
.4619 .48658 -1.875 0 Mabsadd L closepath F
.46571 .47769 -1.875 0 Mabsadd m
.46571 .47769 0 2.5 Mabsadd L
.46571 .47769 1.875 0 Mabsadd L
.46571 .47769 0 -2.5 Mabsadd L
.46571 .47769 -1.875 0 Mabsadd L closepath F
.46952 .46034 -1.875 0 Mabsadd m
.46952 .46034 0 2.5 Mabsadd L
.46952 .46034 1.875 0 Mabsadd L
.46952 .46034 0 -2.5 Mabsadd L
.46952 .46034 -1.875 0 Mabsadd L closepath F
.47333 .43549 -1.875 0 Mabsadd m
.47333 .43549 0 2.5 Mabsadd L
.47333 .43549 1.875 0 Mabsadd L
.47333 .43549 0 -2.5 Mabsadd L
.47333 .43549 -1.875 0 Mabsadd L closepath F
.47714 .40427 -1.875 0 Mabsadd m
.47714 .40427 0 2.5 Mabsadd L
.47714 .40427 1.875 0 Mabsadd L
.47714 .40427 0 -2.5 Mabsadd L
.47714 .40427 -1.875 0 Mabsadd L closepath F
.48095 .36795 -1.875 0 Mabsadd m
.48095 .36795 0 2.5 Mabsadd L
.48095 .36795 1.875 0 Mabsadd L
.48095 .36795 0 -2.5 Mabsadd L
.48095 .36795 -1.875 0 Mabsadd L closepath F
.48476 .32821 -1.875 0 Mabsadd m
.48476 .32821 0 2.5 Mabsadd L
.48476 .32821 1.875 0 Mabsadd L
.48476 .32821 0 -2.5 Mabsadd L
.48476 .32821 -1.875 0 Mabsadd L closepath F
.48857 .28724 -1.875 0 Mabsadd m
.48857 .28724 0 2.5 Mabsadd L
.48857 .28724 1.875 0 Mabsadd L
.48857 .28724 0 -2.5 Mabsadd L
.48857 .28724 -1.875 0 Mabsadd L closepath F
.49238 .24746 -1.875 0 Mabsadd m
.49238 .24746 0 2.5 Mabsadd L
.49238 .24746 1.875 0 Mabsadd L
.49238 .24746 0 -2.5 Mabsadd L
.49238 .24746 -1.875 0 Mabsadd L closepath F
.49619 .21105 -1.875 0 Mabsadd m
.49619 .21105 0 2.5 Mabsadd L
.49619 .21105 1.875 0 Mabsadd L
.49619 .21105 0 -2.5 Mabsadd L
.49619 .21105 -1.875 0 Mabsadd L closepath F
.5 .17971 -1.875 0 Mabsadd m
.5 .17971 0 2.5 Mabsadd L
.5 .17971 1.875 0 Mabsadd L
.5 .17971 0 -2.5 Mabsadd L
.5 .17971 -1.875 0 Mabsadd L closepath F
.50381 .15471 -1.875 0 Mabsadd m
.50381 .15471 0 2.5 Mabsadd L
.50381 .15471 1.875 0 Mabsadd L
.50381 .15471 0 -2.5 Mabsadd L
.50381 .15471 -1.875 0 Mabsadd L closepath F
.50762 .13717 -1.875 0 Mabsadd m
.50762 .13717 0 2.5 Mabsadd L
.50762 .13717 1.875 0 Mabsadd L
.50762 .13717 0 -2.5 Mabsadd L
.50762 .13717 -1.875 0 Mabsadd L closepath F
.51143 .12809 -1.875 0 Mabsadd m
.51143 .12809 0 2.5 Mabsadd L
.51143 .12809 1.875 0 Mabsadd L
.51143 .12809 0 -2.5 Mabsadd L
.51143 .12809 -1.875 0 Mabsadd L closepath F
.51524 .12809 -1.875 0 Mabsadd m
.51524 .12809 0 2.5 Mabsadd L
.51524 .12809 1.875 0 Mabsadd L
.51524 .12809 0 -2.5 Mabsadd L
.51524 .12809 -1.875 0 Mabsadd L closepath F
.51905 .13717 -1.875 0 Mabsadd m
.51905 .13717 0 2.5 Mabsadd L
.51905 .13717 1.875 0 Mabsadd L
.51905 .13717 0 -2.5 Mabsadd L
.51905 .13717 -1.875 0 Mabsadd L closepath F
.52286 .15471 -1.875 0 Mabsadd m
.52286 .15471 0 2.5 Mabsadd L
.52286 .15471 1.875 0 Mabsadd L
.52286 .15471 0 -2.5 Mabsadd L
.52286 .15471 -1.875 0 Mabsadd L closepath F
.52667 .17971 -1.875 0 Mabsadd m
.52667 .17971 0 2.5 Mabsadd L
.52667 .17971 1.875 0 Mabsadd L
.52667 .17971 0 -2.5 Mabsadd L
.52667 .17971 -1.875 0 Mabsadd L closepath F
.53048 .21105 -1.875 0 Mabsadd m
.53048 .21105 0 2.5 Mabsadd L
.53048 .21105 1.875 0 Mabsadd L
.53048 .21105 0 -2.5 Mabsadd L
.53048 .21105 -1.875 0 Mabsadd L closepath F
.53429 .24746 -1.875 0 Mabsadd m
.53429 .24746 0 2.5 Mabsadd L
.53429 .24746 1.875 0 Mabsadd L
.53429 .24746 0 -2.5 Mabsadd L
.53429 .24746 -1.875 0 Mabsadd L closepath F
.5381 .28724 -1.875 0 Mabsadd m
.5381 .28724 0 2.5 Mabsadd L
.5381 .28724 1.875 0 Mabsadd L
.5381 .28724 0 -2.5 Mabsadd L
.5381 .28724 -1.875 0 Mabsadd L closepath F
.5419 .32821 -1.875 0 Mabsadd m
.5419 .32821 0 2.5 Mabsadd L
.5419 .32821 1.875 0 Mabsadd L
.5419 .32821 0 -2.5 Mabsadd L
.5419 .32821 -1.875 0 Mabsadd L closepath F
.54571 .36795 -1.875 0 Mabsadd m
.54571 .36795 0 2.5 Mabsadd L
.54571 .36795 1.875 0 Mabsadd L
.54571 .36795 0 -2.5 Mabsadd L
.54571 .36795 -1.875 0 Mabsadd L closepath F
.54952 .40427 -1.875 0 Mabsadd m
.54952 .40427 0 2.5 Mabsadd L
.54952 .40427 1.875 0 Mabsadd L
.54952 .40427 0 -2.5 Mabsadd L
.54952 .40427 -1.875 0 Mabsadd L closepath F
.55333 .43549 -1.875 0 Mabsadd m
.55333 .43549 0 2.5 Mabsadd L
.55333 .43549 1.875 0 Mabsadd L
.55333 .43549 0 -2.5 Mabsadd L
.55333 .43549 -1.875 0 Mabsadd L closepath F
.55714 .46034 -1.875 0 Mabsadd m
.55714 .46034 0 2.5 Mabsadd L
.55714 .46034 1.875 0 Mabsadd L
.55714 .46034 0 -2.5 Mabsadd L
.55714 .46034 -1.875 0 Mabsadd L closepath F
.56095 .47769 -1.875 0 Mabsadd m
.56095 .47769 0 2.5 Mabsadd L
.56095 .47769 1.875 0 Mabsadd L
.56095 .47769 0 -2.5 Mabsadd L
.56095 .47769 -1.875 0 Mabsadd L closepath F
.56476 .48658 -1.875 0 Mabsadd m
.56476 .48658 0 2.5 Mabsadd L
.56476 .48658 1.875 0 Mabsadd L
.56476 .48658 0 -2.5 Mabsadd L
.56476 .48658 -1.875 0 Mabsadd L closepath F
.56857 .48637 -1.875 0 Mabsadd m
.56857 .48637 0 2.5 Mabsadd L
.56857 .48637 1.875 0 Mabsadd L
.56857 .48637 0 -2.5 Mabsadd L
.56857 .48637 -1.875 0 Mabsadd L closepath F
.57238 .47708 -1.875 0 Mabsadd m
.57238 .47708 0 2.5 Mabsadd L
.57238 .47708 1.875 0 Mabsadd L
.57238 .47708 0 -2.5 Mabsadd L
.57238 .47708 -1.875 0 Mabsadd L closepath F
.57619 .45936 -1.875 0 Mabsadd m
.57619 .45936 0 2.5 Mabsadd L
.57619 .45936 1.875 0 Mabsadd L
.57619 .45936 0 -2.5 Mabsadd L
.57619 .45936 -1.875 0 Mabsadd L closepath F
.58 .43425 -1.875 0 Mabsadd m
.58 .43425 0 2.5 Mabsadd L
.58 .43425 1.875 0 Mabsadd L
.58 .43425 0 -2.5 Mabsadd L
.58 .43425 -1.875 0 Mabsadd L closepath F
.58381 .40289 -1.875 0 Mabsadd m
.58381 .40289 0 2.5 Mabsadd L
.58381 .40289 1.875 0 Mabsadd L
.58381 .40289 0 -2.5 Mabsadd L
.58381 .40289 -1.875 0 Mabsadd L closepath F
.58762 .36668 -1.875 0 Mabsadd m
.58762 .36668 0 2.5 Mabsadd L
.58762 .36668 1.875 0 Mabsadd L
.58762 .36668 0 -2.5 Mabsadd L
.58762 .36668 -1.875 0 Mabsadd L closepath F
.59143 .32742 -1.875 0 Mabsadd m
.59143 .32742 0 2.5 Mabsadd L
.59143 .32742 1.875 0 Mabsadd L
.59143 .32742 0 -2.5 Mabsadd L
.59143 .32742 -1.875 0 Mabsadd L closepath F
.59524 .28751 -1.875 0 Mabsadd m
.59524 .28751 0 2.5 Mabsadd L
.59524 .28751 1.875 0 Mabsadd L
.59524 .28751 0 -2.5 Mabsadd L
.59524 .28751 -1.875 0 Mabsadd L closepath F
.59905 .24963 -1.875 0 Mabsadd m
.59905 .24963 0 2.5 Mabsadd L
.59905 .24963 1.875 0 Mabsadd L
.59905 .24963 0 -2.5 Mabsadd L
.59905 .24963 -1.875 0 Mabsadd L closepath F
.60286 .21635 -1.875 0 Mabsadd m
.60286 .21635 0 2.5 Mabsadd L
.60286 .21635 1.875 0 Mabsadd L
.60286 .21635 0 -2.5 Mabsadd L
.60286 .21635 -1.875 0 Mabsadd L closepath F
.60667 .18974 -1.875 0 Mabsadd m
.60667 .18974 0 2.5 Mabsadd L
.60667 .18974 1.875 0 Mabsadd L
.60667 .18974 0 -2.5 Mabsadd L
.60667 .18974 -1.875 0 Mabsadd L closepath F
.61048 .17134 -1.875 0 Mabsadd m
.61048 .17134 0 2.5 Mabsadd L
.61048 .17134 1.875 0 Mabsadd L
.61048 .17134 0 -2.5 Mabsadd L
.61048 .17134 -1.875 0 Mabsadd L closepath F
.61429 .16217 -1.875 0 Mabsadd m
.61429 .16217 0 2.5 Mabsadd L
.61429 .16217 1.875 0 Mabsadd L
.61429 .16217 0 -2.5 Mabsadd L
.61429 .16217 -1.875 0 Mabsadd L closepath F
.6181 .16271 -1.875 0 Mabsadd m
.6181 .16271 0 2.5 Mabsadd L
.6181 .16271 1.875 0 Mabsadd L
.6181 .16271 0 -2.5 Mabsadd L
.6181 .16271 -1.875 0 Mabsadd L closepath F
.6219 .17273 -1.875 0 Mabsadd m
.6219 .17273 0 2.5 Mabsadd L
.6219 .17273 1.875 0 Mabsadd L
.6219 .17273 0 -2.5 Mabsadd L
.6219 .17273 -1.875 0 Mabsadd L closepath F
.62571 .19127 -1.875 0 Mabsadd m
.62571 .19127 0 2.5 Mabsadd L
.62571 .19127 1.875 0 Mabsadd L
.62571 .19127 0 -2.5 Mabsadd L
.62571 .19127 -1.875 0 Mabsadd L closepath F
.62952 .21658 -1.875 0 Mabsadd m
.62952 .21658 0 2.5 Mabsadd L
.62952 .21658 1.875 0 Mabsadd L
.62952 .21658 0 -2.5 Mabsadd L
.62952 .21658 -1.875 0 Mabsadd L closepath F
.63333 .24624 -1.875 0 Mabsadd m
.63333 .24624 0 2.5 Mabsadd L
.63333 .24624 1.875 0 Mabsadd L
.63333 .24624 0 -2.5 Mabsadd L
.63333 .24624 -1.875 0 Mabsadd L closepath F
.63714 .27742 -1.875 0 Mabsadd m
.63714 .27742 0 2.5 Mabsadd L
.63714 .27742 1.875 0 Mabsadd L
.63714 .27742 0 -2.5 Mabsadd L
.63714 .27742 -1.875 0 Mabsadd L closepath F
.64095 .30716 -1.875 0 Mabsadd m
.64095 .30716 0 2.5 Mabsadd L
.64095 .30716 1.875 0 Mabsadd L
.64095 .30716 0 -2.5 Mabsadd L
.64095 .30716 -1.875 0 Mabsadd L closepath F
.64476 .33274 -1.875 0 Mabsadd m
.64476 .33274 0 2.5 Mabsadd L
.64476 .33274 1.875 0 Mabsadd L
.64476 .33274 0 -2.5 Mabsadd L
.64476 .33274 -1.875 0 Mabsadd L closepath F
.64857 .35206 -1.875 0 Mabsadd m
.64857 .35206 0 2.5 Mabsadd L
.64857 .35206 1.875 0 Mabsadd L
.64857 .35206 0 -2.5 Mabsadd L
.64857 .35206 -1.875 0 Mabsadd L closepath F
.65238 .36394 -1.875 0 Mabsadd m
.65238 .36394 0 2.5 Mabsadd L
.65238 .36394 1.875 0 Mabsadd L
.65238 .36394 0 -2.5 Mabsadd L
.65238 .36394 -1.875 0 Mabsadd L closepath F
.65619 .36831 -1.875 0 Mabsadd m
.65619 .36831 0 2.5 Mabsadd L
.65619 .36831 1.875 0 Mabsadd L
.65619 .36831 0 -2.5 Mabsadd L
.65619 .36831 -1.875 0 Mabsadd L closepath F
.66 .36616 -1.875 0 Mabsadd m
.66 .36616 0 2.5 Mabsadd L
.66 .36616 1.875 0 Mabsadd L
.66 .36616 0 -2.5 Mabsadd L
.66 .36616 -1.875 0 Mabsadd L closepath F
.66381 .35925 -1.875 0 Mabsadd m
.66381 .35925 0 2.5 Mabsadd L
.66381 .35925 1.875 0 Mabsadd L
.66381 .35925 0 -2.5 Mabsadd L
.66381 .35925 -1.875 0 Mabsadd L closepath F
.66762 .34972 -1.875 0 Mabsadd m
.66762 .34972 0 2.5 Mabsadd L
.66762 .34972 1.875 0 Mabsadd L
.66762 .34972 0 -2.5 Mabsadd L
.66762 .34972 -1.875 0 Mabsadd L closepath F
.67143 .33966 -1.875 0 Mabsadd m
.67143 .33966 0 2.5 Mabsadd L
.67143 .33966 1.875 0 Mabsadd L
.67143 .33966 0 -2.5 Mabsadd L
.67143 .33966 -1.875 0 Mabsadd L closepath F
.67524 .33061 -1.875 0 Mabsadd m
.67524 .33061 0 2.5 Mabsadd L
.67524 .33061 1.875 0 Mabsadd L
.67524 .33061 0 -2.5 Mabsadd L
.67524 .33061 -1.875 0 Mabsadd L closepath F
.67905 .32335 -1.875 0 Mabsadd m
.67905 .32335 0 2.5 Mabsadd L
.67905 .32335 1.875 0 Mabsadd L
.67905 .32335 0 -2.5 Mabsadd L
.67905 .32335 -1.875 0 Mabsadd L closepath F
.68286 .318 -1.875 0 Mabsadd m
.68286 .318 0 2.5 Mabsadd L
.68286 .318 1.875 0 Mabsadd L
.68286 .318 0 -2.5 Mabsadd L
.68286 .318 -1.875 0 Mabsadd L closepath F
.68667 .31428 -1.875 0 Mabsadd m
.68667 .31428 0 2.5 Mabsadd L
.68667 .31428 1.875 0 Mabsadd L
.68667 .31428 0 -2.5 Mabsadd L
.68667 .31428 -1.875 0 Mabsadd L closepath F
.69048 .31178 -1.875 0 Mabsadd m
.69048 .31178 0 2.5 Mabsadd L
.69048 .31178 1.875 0 Mabsadd L
.69048 .31178 0 -2.5 Mabsadd L
.69048 .31178 -1.875 0 Mabsadd L closepath F
.69429 .31015 -1.875 0 Mabsadd m
.69429 .31015 0 2.5 Mabsadd L
.69429 .31015 1.875 0 Mabsadd L
.69429 .31015 0 -2.5 Mabsadd L
.69429 .31015 -1.875 0 Mabsadd L closepath F
.6981 .30912 -1.875 0 Mabsadd m
.6981 .30912 0 2.5 Mabsadd L
.6981 .30912 1.875 0 Mabsadd L
.6981 .30912 0 -2.5 Mabsadd L
.6981 .30912 -1.875 0 Mabsadd L closepath F
.7019 .3085 -1.875 0 Mabsadd m
.7019 .3085 0 2.5 Mabsadd L
.7019 .3085 1.875 0 Mabsadd L
.7019 .3085 0 -2.5 Mabsadd L
.7019 .3085 -1.875 0 Mabsadd L closepath F
.70571 .30813 -1.875 0 Mabsadd m
.70571 .30813 0 2.5 Mabsadd L
.70571 .30813 1.875 0 Mabsadd L
.70571 .30813 0 -2.5 Mabsadd L
.70571 .30813 -1.875 0 Mabsadd L closepath F
.70952 .30795 -1.875 0 Mabsadd m
.70952 .30795 0 2.5 Mabsadd L
.70952 .30795 1.875 0 Mabsadd L
.70952 .30795 0 -2.5 Mabsadd L
.70952 .30795 -1.875 0 Mabsadd L closepath F
.71333 .30787 -1.875 0 Mabsadd m
.71333 .30787 0 2.5 Mabsadd L
.71333 .30787 1.875 0 Mabsadd L
.71333 .30787 0 -2.5 Mabsadd L
.71333 .30787 -1.875 0 Mabsadd L closepath F
.71714 .30786 -1.875 0 Mabsadd m
.71714 .30786 0 2.5 Mabsadd L
.71714 .30786 1.875 0 Mabsadd L
.71714 .30786 0 -2.5 Mabsadd L
.71714 .30786 -1.875 0 Mabsadd L closepath F
.72095 .3079 -1.875 0 Mabsadd m
.72095 .3079 0 2.5 Mabsadd L
.72095 .3079 1.875 0 Mabsadd L
.72095 .3079 0 -2.5 Mabsadd L
.72095 .3079 -1.875 0 Mabsadd L closepath F
.72476 .30796 -1.875 0 Mabsadd m
.72476 .30796 0 2.5 Mabsadd L
.72476 .30796 1.875 0 Mabsadd L
.72476 .30796 0 -2.5 Mabsadd L
.72476 .30796 -1.875 0 Mabsadd L closepath F
.72857 .30804 -1.875 0 Mabsadd m
.72857 .30804 0 2.5 Mabsadd L
.72857 .30804 1.875 0 Mabsadd L
.72857 .30804 0 -2.5 Mabsadd L
.72857 .30804 -1.875 0 Mabsadd L closepath F
.73238 .30812 -1.875 0 Mabsadd m
.73238 .30812 0 2.5 Mabsadd L
.73238 .30812 1.875 0 Mabsadd L
.73238 .30812 0 -2.5 Mabsadd L
.73238 .30812 -1.875 0 Mabsadd L closepath F
.73619 .3082 -1.875 0 Mabsadd m
.73619 .3082 0 2.5 Mabsadd L
.73619 .3082 1.875 0 Mabsadd L
.73619 .3082 0 -2.5 Mabsadd L
.73619 .3082 -1.875 0 Mabsadd L closepath F
.74 .30827 -1.875 0 Mabsadd m
.74 .30827 0 2.5 Mabsadd L
.74 .30827 1.875 0 Mabsadd L
.74 .30827 0 -2.5 Mabsadd L
.74 .30827 -1.875 0 Mabsadd L closepath F
.74381 .30835 -1.875 0 Mabsadd m
.74381 .30835 0 2.5 Mabsadd L
.74381 .30835 1.875 0 Mabsadd L
.74381 .30835 0 -2.5 Mabsadd L
.74381 .30835 -1.875 0 Mabsadd L closepath F
.74762 .30841 -1.875 0 Mabsadd m
.74762 .30841 0 2.5 Mabsadd L
.74762 .30841 1.875 0 Mabsadd L
.74762 .30841 0 -2.5 Mabsadd L
.74762 .30841 -1.875 0 Mabsadd L closepath F
.75143 .30848 -1.875 0 Mabsadd m
.75143 .30848 0 2.5 Mabsadd L
.75143 .30848 1.875 0 Mabsadd L
.75143 .30848 0 -2.5 Mabsadd L
.75143 .30848 -1.875 0 Mabsadd L closepath F
.75524 .30853 -1.875 0 Mabsadd m
.75524 .30853 0 2.5 Mabsadd L
.75524 .30853 1.875 0 Mabsadd L
.75524 .30853 0 -2.5 Mabsadd L
.75524 .30853 -1.875 0 Mabsadd L closepath F
.75905 .30858 -1.875 0 Mabsadd m
.75905 .30858 0 2.5 Mabsadd L
.75905 .30858 1.875 0 Mabsadd L
.75905 .30858 0 -2.5 Mabsadd L
.75905 .30858 -1.875 0 Mabsadd L closepath F
.76286 .30863 -1.875 0 Mabsadd m
.76286 .30863 0 2.5 Mabsadd L
.76286 .30863 1.875 0 Mabsadd L
.76286 .30863 0 -2.5 Mabsadd L
.76286 .30863 -1.875 0 Mabsadd L closepath F
.76667 .30867 -1.875 0 Mabsadd m
.76667 .30867 0 2.5 Mabsadd L
.76667 .30867 1.875 0 Mabsadd L
.76667 .30867 0 -2.5 Mabsadd L
.76667 .30867 -1.875 0 Mabsadd L closepath F
.77048 .3087 -1.875 0 Mabsadd m
.77048 .3087 0 2.5 Mabsadd L
.77048 .3087 1.875 0 Mabsadd L
.77048 .3087 0 -2.5 Mabsadd L
.77048 .3087 -1.875 0 Mabsadd L closepath F
.77429 .30874 -1.875 0 Mabsadd m
.77429 .30874 0 2.5 Mabsadd L
.77429 .30874 1.875 0 Mabsadd L
.77429 .30874 0 -2.5 Mabsadd L
.77429 .30874 -1.875 0 Mabsadd L closepath F
.7781 .30876 -1.875 0 Mabsadd m
.7781 .30876 0 2.5 Mabsadd L
.7781 .30876 1.875 0 Mabsadd L
.7781 .30876 0 -2.5 Mabsadd L
.7781 .30876 -1.875 0 Mabsadd L closepath F
.7819 .30879 -1.875 0 Mabsadd m
.7819 .30879 0 2.5 Mabsadd L
.7819 .30879 1.875 0 Mabsadd L
.7819 .30879 0 -2.5 Mabsadd L
.7819 .30879 -1.875 0 Mabsadd L closepath F
.78571 .30881 -1.875 0 Mabsadd m
.78571 .30881 0 2.5 Mabsadd L
.78571 .30881 1.875 0 Mabsadd L
.78571 .30881 0 -2.5 Mabsadd L
.78571 .30881 -1.875 0 Mabsadd L closepath F
.78952 .30883 -1.875 0 Mabsadd m
.78952 .30883 0 2.5 Mabsadd L
.78952 .30883 1.875 0 Mabsadd L
.78952 .30883 0 -2.5 Mabsadd L
.78952 .30883 -1.875 0 Mabsadd L closepath F
.79333 .30885 -1.875 0 Mabsadd m
.79333 .30885 0 2.5 Mabsadd L
.79333 .30885 1.875 0 Mabsadd L
.79333 .30885 0 -2.5 Mabsadd L
.79333 .30885 -1.875 0 Mabsadd L closepath F
.79714 .30887 -1.875 0 Mabsadd m
.79714 .30887 0 2.5 Mabsadd L
.79714 .30887 1.875 0 Mabsadd L
.79714 .30887 0 -2.5 Mabsadd L
.79714 .30887 -1.875 0 Mabsadd L closepath F
.80095 .30888 -1.875 0 Mabsadd m
.80095 .30888 0 2.5 Mabsadd L
.80095 .30888 1.875 0 Mabsadd L
.80095 .30888 0 -2.5 Mabsadd L
.80095 .30888 -1.875 0 Mabsadd L closepath F
.80476 .30889 -1.875 0 Mabsadd m
.80476 .30889 0 2.5 Mabsadd L
.80476 .30889 1.875 0 Mabsadd L
.80476 .30889 0 -2.5 Mabsadd L
.80476 .30889 -1.875 0 Mabsadd L closepath F
.80857 .30891 -1.875 0 Mabsadd m
.80857 .30891 0 2.5 Mabsadd L
.80857 .30891 1.875 0 Mabsadd L
.80857 .30891 0 -2.5 Mabsadd L
.80857 .30891 -1.875 0 Mabsadd L closepath F
.81238 .30892 -1.875 0 Mabsadd m
.81238 .30892 0 2.5 Mabsadd L
.81238 .30892 1.875 0 Mabsadd L
.81238 .30892 0 -2.5 Mabsadd L
.81238 .30892 -1.875 0 Mabsadd L closepath F
.81619 .30893 -1.875 0 Mabsadd m
.81619 .30893 0 2.5 Mabsadd L
.81619 .30893 1.875 0 Mabsadd L
.81619 .30893 0 -2.5 Mabsadd L
.81619 .30893 -1.875 0 Mabsadd L closepath F
.82 .30893 -1.875 0 Mabsadd m
.82 .30893 0 2.5 Mabsadd L
.82 .30893 1.875 0 Mabsadd L
.82 .30893 0 -2.5 Mabsadd L
.82 .30893 -1.875 0 Mabsadd L closepath F
.82381 .30894 -1.875 0 Mabsadd m
.82381 .30894 0 2.5 Mabsadd L
.82381 .30894 1.875 0 Mabsadd L
.82381 .30894 0 -2.5 Mabsadd L
.82381 .30894 -1.875 0 Mabsadd L closepath F
.82762 .30895 -1.875 0 Mabsadd m
.82762 .30895 0 2.5 Mabsadd L
.82762 .30895 1.875 0 Mabsadd L
.82762 .30895 0 -2.5 Mabsadd L
.82762 .30895 -1.875 0 Mabsadd L closepath F
.83143 .30895 -1.875 0 Mabsadd m
.83143 .30895 0 2.5 Mabsadd L
.83143 .30895 1.875 0 Mabsadd L
.83143 .30895 0 -2.5 Mabsadd L
.83143 .30895 -1.875 0 Mabsadd L closepath F
.83524 .30896 -1.875 0 Mabsadd m
.83524 .30896 0 2.5 Mabsadd L
.83524 .30896 1.875 0 Mabsadd L
.83524 .30896 0 -2.5 Mabsadd L
.83524 .30896 -1.875 0 Mabsadd L closepath F
.83905 .30896 -1.875 0 Mabsadd m
.83905 .30896 0 2.5 Mabsadd L
.83905 .30896 1.875 0 Mabsadd L
.83905 .30896 0 -2.5 Mabsadd L
.83905 .30896 -1.875 0 Mabsadd L closepath F
.84286 .30897 -1.875 0 Mabsadd m
.84286 .30897 0 2.5 Mabsadd L
.84286 .30897 1.875 0 Mabsadd L
.84286 .30897 0 -2.5 Mabsadd L
.84286 .30897 -1.875 0 Mabsadd L closepath F
.84667 .30897 -1.875 0 Mabsadd m
.84667 .30897 0 2.5 Mabsadd L
.84667 .30897 1.875 0 Mabsadd L
.84667 .30897 0 -2.5 Mabsadd L
.84667 .30897 -1.875 0 Mabsadd L closepath F
.85048 .30898 -1.875 0 Mabsadd m
.85048 .30898 0 2.5 Mabsadd L
.85048 .30898 1.875 0 Mabsadd L
.85048 .30898 0 -2.5 Mabsadd L
.85048 .30898 -1.875 0 Mabsadd L closepath F
.85429 .30898 -1.875 0 Mabsadd m
.85429 .30898 0 2.5 Mabsadd L
.85429 .30898 1.875 0 Mabsadd L
.85429 .30898 0 -2.5 Mabsadd L
.85429 .30898 -1.875 0 Mabsadd L closepath F
.8581 .30898 -1.875 0 Mabsadd m
.8581 .30898 0 2.5 Mabsadd L
.8581 .30898 1.875 0 Mabsadd L
.8581 .30898 0 -2.5 Mabsadd L
.8581 .30898 -1.875 0 Mabsadd L closepath F
.8619 .30898 -1.875 0 Mabsadd m
.8619 .30898 0 2.5 Mabsadd L
.8619 .30898 1.875 0 Mabsadd L
.8619 .30898 0 -2.5 Mabsadd L
.8619 .30898 -1.875 0 Mabsadd L closepath F
.86571 .30899 -1.875 0 Mabsadd m
.86571 .30899 0 2.5 Mabsadd L
.86571 .30899 1.875 0 Mabsadd L
.86571 .30899 0 -2.5 Mabsadd L
.86571 .30899 -1.875 0 Mabsadd L closepath F
.86952 .30899 -1.875 0 Mabsadd m
.86952 .30899 0 2.5 Mabsadd L
.86952 .30899 1.875 0 Mabsadd L
.86952 .30899 0 -2.5 Mabsadd L
.86952 .30899 -1.875 0 Mabsadd L closepath F
.87333 .30899 -1.875 0 Mabsadd m
.87333 .30899 0 2.5 Mabsadd L
.87333 .30899 1.875 0 Mabsadd L
.87333 .30899 0 -2.5 Mabsadd L
.87333 .30899 -1.875 0 Mabsadd L closepath F
.87714 .30899 -1.875 0 Mabsadd m
.87714 .30899 0 2.5 Mabsadd L
.87714 .30899 1.875 0 Mabsadd L
.87714 .30899 0 -2.5 Mabsadd L
.87714 .30899 -1.875 0 Mabsadd L closepath F
.88095 .30899 -1.875 0 Mabsadd m
.88095 .30899 0 2.5 Mabsadd L
.88095 .30899 1.875 0 Mabsadd L
.88095 .30899 0 -2.5 Mabsadd L
.88095 .30899 -1.875 0 Mabsadd L closepath F
.88476 .309 -1.875 0 Mabsadd m
.88476 .309 0 2.5 Mabsadd L
.88476 .309 1.875 0 Mabsadd L
.88476 .309 0 -2.5 Mabsadd L
.88476 .309 -1.875 0 Mabsadd L closepath F
.88857 .309 -1.875 0 Mabsadd m
.88857 .309 0 2.5 Mabsadd L
.88857 .309 1.875 0 Mabsadd L
.88857 .309 0 -2.5 Mabsadd L
.88857 .309 -1.875 0 Mabsadd L closepath F
.89238 .309 -1.875 0 Mabsadd m
.89238 .309 0 2.5 Mabsadd L
.89238 .309 1.875 0 Mabsadd L
.89238 .309 0 -2.5 Mabsadd L
.89238 .309 -1.875 0 Mabsadd L closepath F
.89619 .309 -1.875 0 Mabsadd m
.89619 .309 0 2.5 Mabsadd L
.89619 .309 1.875 0 Mabsadd L
.89619 .309 0 -2.5 Mabsadd L
.89619 .309 -1.875 0 Mabsadd L closepath F
.9 .309 -1.875 0 Mabsadd m
.9 .309 0 2.5 Mabsadd L
.9 .309 1.875 0 Mabsadd L
.9 .309 0 -2.5 Mabsadd L
.9 .309 -1.875 0 Mabsadd L closepath F
.90381 .309 -1.875 0 Mabsadd m
.90381 .309 0 2.5 Mabsadd L
.90381 .309 1.875 0 Mabsadd L
.90381 .309 0 -2.5 Mabsadd L
.90381 .309 -1.875 0 Mabsadd L closepath F
.90762 .309 -1.875 0 Mabsadd m
.90762 .309 0 2.5 Mabsadd L
.90762 .309 1.875 0 Mabsadd L
.90762 .309 0 -2.5 Mabsadd L
.90762 .309 -1.875 0 Mabsadd L closepath F
.91143 .309 -1.875 0 Mabsadd m
.91143 .309 0 2.5 Mabsadd L
.91143 .309 1.875 0 Mabsadd L
.91143 .309 0 -2.5 Mabsadd L
.91143 .309 -1.875 0 Mabsadd L closepath F
.91524 .309 -1.875 0 Mabsadd m
.91524 .309 0 2.5 Mabsadd L
.91524 .309 1.875 0 Mabsadd L
.91524 .309 0 -2.5 Mabsadd L
.91524 .309 -1.875 0 Mabsadd L closepath F
.91905 .30901 -1.875 0 Mabsadd m
.91905 .30901 0 2.5 Mabsadd L
.91905 .30901 1.875 0 Mabsadd L
.91905 .30901 0 -2.5 Mabsadd L
.91905 .30901 -1.875 0 Mabsadd L closepath F
.92286 .30901 -1.875 0 Mabsadd m
.92286 .30901 0 2.5 Mabsadd L
.92286 .30901 1.875 0 Mabsadd L
.92286 .30901 0 -2.5 Mabsadd L
.92286 .30901 -1.875 0 Mabsadd L closepath F
.92667 .30901 -1.875 0 Mabsadd m
.92667 .30901 0 2.5 Mabsadd L
.92667 .30901 1.875 0 Mabsadd L
.92667 .30901 0 -2.5 Mabsadd L
.92667 .30901 -1.875 0 Mabsadd L closepath F
.93048 .30901 -1.875 0 Mabsadd m
.93048 .30901 0 2.5 Mabsadd L
.93048 .30901 1.875 0 Mabsadd L
.93048 .30901 0 -2.5 Mabsadd L
.93048 .30901 -1.875 0 Mabsadd L closepath F
.93429 .30901 -1.875 0 Mabsadd m
.93429 .30901 0 2.5 Mabsadd L
.93429 .30901 1.875 0 Mabsadd L
.93429 .30901 0 -2.5 Mabsadd L
.93429 .30901 -1.875 0 Mabsadd L closepath F
.9381 .30901 -1.875 0 Mabsadd m
.9381 .30901 0 2.5 Mabsadd L
.9381 .30901 1.875 0 Mabsadd L
.9381 .30901 0 -2.5 Mabsadd L
.9381 .30901 -1.875 0 Mabsadd L closepath F
.9419 .30901 -1.875 0 Mabsadd m
.9419 .30901 0 2.5 Mabsadd L
.9419 .30901 1.875 0 Mabsadd L
.9419 .30901 0 -2.5 Mabsadd L
.9419 .30901 -1.875 0 Mabsadd L closepath F
.94571 .30901 -1.875 0 Mabsadd m
.94571 .30901 0 2.5 Mabsadd L
.94571 .30901 1.875 0 Mabsadd L
.94571 .30901 0 -2.5 Mabsadd L
.94571 .30901 -1.875 0 Mabsadd L closepath F
.94952 .30901 -1.875 0 Mabsadd m
.94952 .30901 0 2.5 Mabsadd L
.94952 .30901 1.875 0 Mabsadd L
.94952 .30901 0 -2.5 Mabsadd L
.94952 .30901 -1.875 0 Mabsadd L closepath F
.95333 .30901 -1.875 0 Mabsadd m
.95333 .30901 0 2.5 Mabsadd L
.95333 .30901 1.875 0 Mabsadd L
.95333 .30901 0 -2.5 Mabsadd L
.95333 .30901 -1.875 0 Mabsadd L closepath F
.95714 .30901 -1.875 0 Mabsadd m
.95714 .30901 0 2.5 Mabsadd L
.95714 .30901 1.875 0 Mabsadd L
.95714 .30901 0 -2.5 Mabsadd L
.95714 .30901 -1.875 0 Mabsadd L closepath F
.96095 .30901 -1.875 0 Mabsadd m
.96095 .30901 0 2.5 Mabsadd L
.96095 .30901 1.875 0 Mabsadd L
.96095 .30901 0 -2.5 Mabsadd L
.96095 .30901 -1.875 0 Mabsadd L closepath F
.96476 .30901 -1.875 0 Mabsadd m
.96476 .30901 0 2.5 Mabsadd L
.96476 .30901 1.875 0 Mabsadd L
.96476 .30901 0 -2.5 Mabsadd L
.96476 .30901 -1.875 0 Mabsadd L closepath F
.96857 .30901 -1.875 0 Mabsadd m
.96857 .30901 0 2.5 Mabsadd L
.96857 .30901 1.875 0 Mabsadd L
.96857 .30901 0 -2.5 Mabsadd L
.96857 .30901 -1.875 0 Mabsadd L closepath F
.97238 .30901 -1.875 0 Mabsadd m
.97238 .30901 0 2.5 Mabsadd L
.97238 .30901 1.875 0 Mabsadd L
.97238 .30901 0 -2.5 Mabsadd L
.97238 .30901 -1.875 0 Mabsadd L closepath F
.97619 .30901 -1.875 0 Mabsadd m
.97619 .30901 0 2.5 Mabsadd L
.97619 .30901 1.875 0 Mabsadd L
.97619 .30901 0 -2.5 Mabsadd L
.97619 .30901 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.02381 .30909 m
.02762 .30909 L
.03143 .3091 L
.03524 .3091 L
.03905 .3091 L
.04286 .30911 L
.04667 .30911 L
.05048 .30911 L
.05429 .30912 L
.0581 .30912 L
.0619 .30913 L
.06571 .30913 L
.06952 .30914 L
.07333 .30914 L
.07714 .30915 L
.08095 .30916 L
.08476 .30916 L
.08857 .30917 L
.09238 .30918 L
.09619 .30919 L
.1 .30919 L
.10381 .3092 L
.10762 .30921 L
.11143 .30922 L
.11524 .30923 L
.11905 .30925 L
.12286 .30926 L
.12667 .30927 L
.13048 .30929 L
.13429 .3093 L
.1381 .30932 L
.1419 .30933 L
.14571 .30935 L
.14952 .30937 L
.15333 .3094 L
.15714 .30942 L
.16095 .30944 L
.16476 .30947 L
.16857 .3095 L
.17238 .30953 L
.17619 .30957 L
.18 .30961 L
.18381 .30965 L
.18762 .30969 L
.19143 .30974 L
.19524 .30979 L
.19905 .30985 L
.20286 .30992 L
.20667 .30998 L
.21048 .31006 L
Mistroke
.21429 .31014 L
.2181 .31024 L
.2219 .31034 L
.22571 .31045 L
.22952 .31057 L
.23333 .31071 L
.23714 .31086 L
.24095 .31102 L
.24476 .31121 L
.24857 .31141 L
.25238 .31164 L
.25619 .3119 L
.26 .31218 L
.26381 .3125 L
.26762 .31286 L
.27143 .31326 L
.27524 .3137 L
.27905 .3142 L
.28286 .31476 L
.28667 .31538 L
.29048 .31608 L
.29429 .31686 L
.2981 .31773 L
.3019 .31868 L
.30571 .31974 L
.30952 .32088 L
.31333 .32211 L
.31714 .3234 L
.32095 .32471 L
.32476 .32595 L
.32857 .32701 L
.33238 .32765 L
.33619 .3275 L
.34 .32597 L
.34381 .32221 L
.34762 .31506 L
.35143 .30338 L
.35524 .28667 L
.35905 .26573 L
.36286 .24285 L
.36667 .2211 L
.37048 .20317 L
.37429 .19051 L
.3781 .18314 L
.3819 .18039 L
.38571 .18224 L
.38952 .19007 L
.39333 .20609 L
.39714 .23192 L
.40095 .26749 L
Mistroke
.40476 .3107 L
.40857 .358 L
.41238 .40575 L
.41619 .45128 L
.42 .49273 L
.42381 .52811 L
.42762 .55478 L
.43143 .56983 L
.43524 .57108 L
.43905 .55798 L
.44286 .53156 L
.44667 .49354 L
.45048 .44557 L
.45429 .38935 L
.4581 .32732 L
.4619 .26306 L
.46571 .20074 L
.46952 .14394 L
.47333 .09514 L
.47714 .05613 L
.48095 .02869 L
.48476 .01472 L
.48857 .0156 L
.49238 .03136 L
.49619 .06064 L
.5 .10154 L
.50381 .15231 L
.50762 .21118 L
.51143 .27571 L
.51524 .34232 L
.51905 .40685 L
.52286 .46573 L
.52667 .5165 L
.53048 .55739 L
.53429 .58667 L
.5381 .60243 L
.5419 .60332 L
.54571 .58935 L
.54952 .5619 L
.55333 .52289 L
.55714 .4741 L
.56095 .4173 L
.56476 .35497 L
.56857 .29071 L
.57238 .22869 L
.57619 .17247 L
.58 .12449 L
.58381 .08647 L
.58762 .06006 L
.59143 .04695 L
Mistroke
.59524 .0482 L
.59905 .06325 L
.60286 .08992 L
.60667 .1253 L
.61048 .16676 L
.61429 .21229 L
.6181 .26004 L
.6219 .30734 L
.62571 .35055 L
.62952 .38611 L
.63333 .41194 L
.63714 .42796 L
.64095 .4358 L
.64476 .43764 L
.64857 .43489 L
.65238 .42752 L
.65619 .41487 L
.66 .39694 L
.66381 .37518 L
.66762 .3523 L
.67143 .33136 L
.67524 .31465 L
.67905 .30298 L
.68286 .29583 L
.68667 .29206 L
.69048 .29054 L
.69429 .29039 L
.6981 .29102 L
.7019 .29208 L
.70571 .29333 L
.70952 .29463 L
.71333 .29592 L
.71714 .29715 L
.72095 .2983 L
.72476 .29935 L
.72857 .30031 L
.73238 .30117 L
.73619 .30195 L
.74 .30265 L
.74381 .30327 L
.74762 .30383 L
.75143 .30433 L
.75524 .30478 L
.75905 .30518 L
.76286 .30553 L
.76667 .30585 L
.77048 .30614 L
.77429 .30639 L
.7781 .30662 L
.7819 .30683 L
Mistroke
.78571 .30701 L
.78952 .30718 L
.79333 .30733 L
.79714 .30746 L
.80095 .30759 L
.80476 .3077 L
.80857 .3078 L
.81238 .30789 L
.81619 .30797 L
.82 .30805 L
.82381 .30812 L
.82762 .30818 L
.83143 .30824 L
.83524 .30829 L
.83905 .30834 L
.84286 .30839 L
.84667 .30843 L
.85048 .30847 L
.85429 .3085 L
.8581 .30853 L
.8619 .30856 L
.86571 .30859 L
.86952 .30861 L
.87333 .30864 L
.87714 .30866 L
.88095 .30868 L
.88476 .3087 L
.88857 .30872 L
.89238 .30873 L
.89619 .30875 L
.9 .30876 L
.90381 .30878 L
.90762 .30879 L
.91143 .3088 L
.91524 .30881 L
.91905 .30882 L
.92286 .30883 L
.92667 .30884 L
.93048 .30885 L
.93429 .30886 L
.9381 .30886 L
.9419 .30887 L
.94571 .30888 L
.94952 .30888 L
.95333 .30889 L
.95714 .3089 L
.96095 .3089 L
.96476 .30891 L
.96857 .30891 L
.97238 .30892 L
Mistroke
.97619 .30892 L
Mfstroke
.0001 w
[ ] 0 setdash
.02381 .30909 0 2.5 Mabsadd m
.02381 .30909 -0.56518 .7779 Mabsadd L
.02381 .30909 -2.37764 .77254 Mabsadd L
.02381 .30909 -0.91448 -0.29713 Mabsadd L
.02381 .30909 -1.46946 -2.02254 Mabsadd L
.02381 .30909 0 -0.96154 Mabsadd L
.02381 .30909 1.46946 -2.02254 Mabsadd L
.02381 .30909 .91448 -0.29713 Mabsadd L
.02381 .30909 2.37764 .77254 Mabsadd L
.02381 .30909 .56518 .7779 Mabsadd L
.02381 .30909 0 2.5 Mabsadd L closepath F
.02762 .30909 0 2.5 Mabsadd m
.02762 .30909 -0.56518 .7779 Mabsadd L
.02762 .30909 -2.37764 .77254 Mabsadd L
.02762 .30909 -0.91448 -0.29713 Mabsadd L
.02762 .30909 -1.46946 -2.02254 Mabsadd L
.02762 .30909 0 -0.96154 Mabsadd L
.02762 .30909 1.46946 -2.02254 Mabsadd L
.02762 .30909 .91448 -0.29713 Mabsadd L
.02762 .30909 2.37764 .77254 Mabsadd L
.02762 .30909 .56518 .7779 Mabsadd L
.02762 .30909 0 2.5 Mabsadd L closepath F
.03143 .3091 0 2.5 Mabsadd m
.03143 .3091 -0.56518 .7779 Mabsadd L
.03143 .3091 -2.37764 .77254 Mabsadd L
.03143 .3091 -0.91448 -0.29713 Mabsadd L
.03143 .3091 -1.46946 -2.02254 Mabsadd L
.03143 .3091 0 -0.96154 Mabsadd L
.03143 .3091 1.46946 -2.02254 Mabsadd L
.03143 .3091 .91448 -0.29713 Mabsadd L
.03143 .3091 2.37764 .77254 Mabsadd L
.03143 .3091 .56518 .7779 Mabsadd L
.03143 .3091 0 2.5 Mabsadd L closepath F
.03524 .3091 0 2.5 Mabsadd m
.03524 .3091 -0.56518 .7779 Mabsadd L
.03524 .3091 -2.37764 .77254 Mabsadd L
.03524 .3091 -0.91448 -0.29713 Mabsadd L
.03524 .3091 -1.46946 -2.02254 Mabsadd L
.03524 .3091 0 -0.96154 Mabsadd L
.03524 .3091 1.46946 -2.02254 Mabsadd L
.03524 .3091 .91448 -0.29713 Mabsadd L
.03524 .3091 2.37764 .77254 Mabsadd L
.03524 .3091 .56518 .7779 Mabsadd L
.03524 .3091 0 2.5 Mabsadd L closepath F
.03905 .3091 0 2.5 Mabsadd m
.03905 .3091 -0.56518 .7779 Mabsadd L
.03905 .3091 -2.37764 .77254 Mabsadd L
.03905 .3091 -0.91448 -0.29713 Mabsadd L
.03905 .3091 -1.46946 -2.02254 Mabsadd L
.03905 .3091 0 -0.96154 Mabsadd L
.03905 .3091 1.46946 -2.02254 Mabsadd L
.03905 .3091 .91448 -0.29713 Mabsadd L
.03905 .3091 2.37764 .77254 Mabsadd L
.03905 .3091 .56518 .7779 Mabsadd L
.03905 .3091 0 2.5 Mabsadd L closepath F
.04286 .30911 0 2.5 Mabsadd m
.04286 .30911 -0.56518 .7779 Mabsadd L
.04286 .30911 -2.37764 .77254 Mabsadd L
.04286 .30911 -0.91448 -0.29713 Mabsadd L
.04286 .30911 -1.46946 -2.02254 Mabsadd L
.04286 .30911 0 -0.96154 Mabsadd L
.04286 .30911 1.46946 -2.02254 Mabsadd L
.04286 .30911 .91448 -0.29713 Mabsadd L
.04286 .30911 2.37764 .77254 Mabsadd L
.04286 .30911 .56518 .7779 Mabsadd L
.04286 .30911 0 2.5 Mabsadd L closepath F
.04667 .30911 0 2.5 Mabsadd m
.04667 .30911 -0.56518 .7779 Mabsadd L
.04667 .30911 -2.37764 .77254 Mabsadd L
.04667 .30911 -0.91448 -0.29713 Mabsadd L
.04667 .30911 -1.46946 -2.02254 Mabsadd L
.04667 .30911 0 -0.96154 Mabsadd L
.04667 .30911 1.46946 -2.02254 Mabsadd L
.04667 .30911 .91448 -0.29713 Mabsadd L
.04667 .30911 2.37764 .77254 Mabsadd L
.04667 .30911 .56518 .7779 Mabsadd L
.04667 .30911 0 2.5 Mabsadd L closepath F
.05048 .30911 0 2.5 Mabsadd m
.05048 .30911 -0.56518 .7779 Mabsadd L
.05048 .30911 -2.37764 .77254 Mabsadd L
.05048 .30911 -0.91448 -0.29713 Mabsadd L
.05048 .30911 -1.46946 -2.02254 Mabsadd L
.05048 .30911 0 -0.96154 Mabsadd L
.05048 .30911 1.46946 -2.02254 Mabsadd L
.05048 .30911 .91448 -0.29713 Mabsadd L
.05048 .30911 2.37764 .77254 Mabsadd L
.05048 .30911 .56518 .7779 Mabsadd L
.05048 .30911 0 2.5 Mabsadd L closepath F
.05429 .30912 0 2.5 Mabsadd m
.05429 .30912 -0.56518 .7779 Mabsadd L
.05429 .30912 -2.37764 .77254 Mabsadd L
.05429 .30912 -0.91448 -0.29713 Mabsadd L
.05429 .30912 -1.46946 -2.02254 Mabsadd L
.05429 .30912 0 -0.96154 Mabsadd L
.05429 .30912 1.46946 -2.02254 Mabsadd L
.05429 .30912 .91448 -0.29713 Mabsadd L
.05429 .30912 2.37764 .77254 Mabsadd L
.05429 .30912 .56518 .7779 Mabsadd L
.05429 .30912 0 2.5 Mabsadd L closepath F
.0581 .30912 0 2.5 Mabsadd m
.0581 .30912 -0.56518 .7779 Mabsadd L
.0581 .30912 -2.37764 .77254 Mabsadd L
.0581 .30912 -0.91448 -0.29713 Mabsadd L
.0581 .30912 -1.46946 -2.02254 Mabsadd L
.0581 .30912 0 -0.96154 Mabsadd L
.0581 .30912 1.46946 -2.02254 Mabsadd L
.0581 .30912 .91448 -0.29713 Mabsadd L
.0581 .30912 2.37764 .77254 Mabsadd L
.0581 .30912 .56518 .7779 Mabsadd L
.0581 .30912 0 2.5 Mabsadd L closepath F
.0619 .30913 0 2.5 Mabsadd m
.0619 .30913 -0.56518 .7779 Mabsadd L
.0619 .30913 -2.37764 .77254 Mabsadd L
.0619 .30913 -0.91448 -0.29713 Mabsadd L
.0619 .30913 -1.46946 -2.02254 Mabsadd L
.0619 .30913 0 -0.96154 Mabsadd L
.0619 .30913 1.46946 -2.02254 Mabsadd L
.0619 .30913 .91448 -0.29713 Mabsadd L
.0619 .30913 2.37764 .77254 Mabsadd L
.0619 .30913 .56518 .7779 Mabsadd L
.0619 .30913 0 2.5 Mabsadd L closepath F
.06571 .30913 0 2.5 Mabsadd m
.06571 .30913 -0.56518 .7779 Mabsadd L
.06571 .30913 -2.37764 .77254 Mabsadd L
.06571 .30913 -0.91448 -0.29713 Mabsadd L
.06571 .30913 -1.46946 -2.02254 Mabsadd L
.06571 .30913 0 -0.96154 Mabsadd L
.06571 .30913 1.46946 -2.02254 Mabsadd L
.06571 .30913 .91448 -0.29713 Mabsadd L
.06571 .30913 2.37764 .77254 Mabsadd L
.06571 .30913 .56518 .7779 Mabsadd L
.06571 .30913 0 2.5 Mabsadd L closepath F
.06952 .30914 0 2.5 Mabsadd m
.06952 .30914 -0.56518 .7779 Mabsadd L
.06952 .30914 -2.37764 .77254 Mabsadd L
.06952 .30914 -0.91448 -0.29713 Mabsadd L
.06952 .30914 -1.46946 -2.02254 Mabsadd L
.06952 .30914 0 -0.96154 Mabsadd L
.06952 .30914 1.46946 -2.02254 Mabsadd L
.06952 .30914 .91448 -0.29713 Mabsadd L
.06952 .30914 2.37764 .77254 Mabsadd L
.06952 .30914 .56518 .7779 Mabsadd L
.06952 .30914 0 2.5 Mabsadd L closepath F
.07333 .30914 0 2.5 Mabsadd m
.07333 .30914 -0.56518 .7779 Mabsadd L
.07333 .30914 -2.37764 .77254 Mabsadd L
.07333 .30914 -0.91448 -0.29713 Mabsadd L
.07333 .30914 -1.46946 -2.02254 Mabsadd L
.07333 .30914 0 -0.96154 Mabsadd L
.07333 .30914 1.46946 -2.02254 Mabsadd L
.07333 .30914 .91448 -0.29713 Mabsadd L
.07333 .30914 2.37764 .77254 Mabsadd L
.07333 .30914 .56518 .7779 Mabsadd L
.07333 .30914 0 2.5 Mabsadd L closepath F
.07714 .30915 0 2.5 Mabsadd m
.07714 .30915 -0.56518 .7779 Mabsadd L
.07714 .30915 -2.37764 .77254 Mabsadd L
.07714 .30915 -0.91448 -0.29713 Mabsadd L
.07714 .30915 -1.46946 -2.02254 Mabsadd L
.07714 .30915 0 -0.96154 Mabsadd L
.07714 .30915 1.46946 -2.02254 Mabsadd L
.07714 .30915 .91448 -0.29713 Mabsadd L
.07714 .30915 2.37764 .77254 Mabsadd L
.07714 .30915 .56518 .7779 Mabsadd L
.07714 .30915 0 2.5 Mabsadd L closepath F
.08095 .30916 0 2.5 Mabsadd m
.08095 .30916 -0.56518 .7779 Mabsadd L
.08095 .30916 -2.37764 .77254 Mabsadd L
.08095 .30916 -0.91448 -0.29713 Mabsadd L
.08095 .30916 -1.46946 -2.02254 Mabsadd L
.08095 .30916 0 -0.96154 Mabsadd L
.08095 .30916 1.46946 -2.02254 Mabsadd L
.08095 .30916 .91448 -0.29713 Mabsadd L
.08095 .30916 2.37764 .77254 Mabsadd L
.08095 .30916 .56518 .7779 Mabsadd L
.08095 .30916 0 2.5 Mabsadd L closepath F
.08476 .30916 0 2.5 Mabsadd m
.08476 .30916 -0.56518 .7779 Mabsadd L
.08476 .30916 -2.37764 .77254 Mabsadd L
.08476 .30916 -0.91448 -0.29713 Mabsadd L
.08476 .30916 -1.46946 -2.02254 Mabsadd L
.08476 .30916 0 -0.96154 Mabsadd L
.08476 .30916 1.46946 -2.02254 Mabsadd L
.08476 .30916 .91448 -0.29713 Mabsadd L
.08476 .30916 2.37764 .77254 Mabsadd L
.08476 .30916 .56518 .7779 Mabsadd L
.08476 .30916 0 2.5 Mabsadd L closepath F
.08857 .30917 0 2.5 Mabsadd m
.08857 .30917 -0.56518 .7779 Mabsadd L
.08857 .30917 -2.37764 .77254 Mabsadd L
.08857 .30917 -0.91448 -0.29713 Mabsadd L
.08857 .30917 -1.46946 -2.02254 Mabsadd L
.08857 .30917 0 -0.96154 Mabsadd L
.08857 .30917 1.46946 -2.02254 Mabsadd L
.08857 .30917 .91448 -0.29713 Mabsadd L
.08857 .30917 2.37764 .77254 Mabsadd L
.08857 .30917 .56518 .7779 Mabsadd L
.08857 .30917 0 2.5 Mabsadd L closepath F
.09238 .30918 0 2.5 Mabsadd m
.09238 .30918 -0.56518 .7779 Mabsadd L
.09238 .30918 -2.37764 .77254 Mabsadd L
.09238 .30918 -0.91448 -0.29713 Mabsadd L
.09238 .30918 -1.46946 -2.02254 Mabsadd L
.09238 .30918 0 -0.96154 Mabsadd L
.09238 .30918 1.46946 -2.02254 Mabsadd L
.09238 .30918 .91448 -0.29713 Mabsadd L
.09238 .30918 2.37764 .77254 Mabsadd L
.09238 .30918 .56518 .7779 Mabsadd L
.09238 .30918 0 2.5 Mabsadd L closepath F
.09619 .30919 0 2.5 Mabsadd m
.09619 .30919 -0.56518 .7779 Mabsadd L
.09619 .30919 -2.37764 .77254 Mabsadd L
.09619 .30919 -0.91448 -0.29713 Mabsadd L
.09619 .30919 -1.46946 -2.02254 Mabsadd L
.09619 .30919 0 -0.96154 Mabsadd L
.09619 .30919 1.46946 -2.02254 Mabsadd L
.09619 .30919 .91448 -0.29713 Mabsadd L
.09619 .30919 2.37764 .77254 Mabsadd L
.09619 .30919 .56518 .7779 Mabsadd L
.09619 .30919 0 2.5 Mabsadd L closepath F
.1 .30919 0 2.5 Mabsadd m
.1 .30919 -0.56518 .7779 Mabsadd L
.1 .30919 -2.37764 .77254 Mabsadd L
.1 .30919 -0.91448 -0.29713 Mabsadd L
.1 .30919 -1.46946 -2.02254 Mabsadd L
.1 .30919 0 -0.96154 Mabsadd L
.1 .30919 1.46946 -2.02254 Mabsadd L
.1 .30919 .91448 -0.29713 Mabsadd L
.1 .30919 2.37764 .77254 Mabsadd L
.1 .30919 .56518 .7779 Mabsadd L
.1 .30919 0 2.5 Mabsadd L closepath F
.10381 .3092 0 2.5 Mabsadd m
.10381 .3092 -0.56518 .7779 Mabsadd L
.10381 .3092 -2.37764 .77254 Mabsadd L
.10381 .3092 -0.91448 -0.29713 Mabsadd L
.10381 .3092 -1.46946 -2.02254 Mabsadd L
.10381 .3092 0 -0.96154 Mabsadd L
.10381 .3092 1.46946 -2.02254 Mabsadd L
.10381 .3092 .91448 -0.29713 Mabsadd L
.10381 .3092 2.37764 .77254 Mabsadd L
.10381 .3092 .56518 .7779 Mabsadd L
.10381 .3092 0 2.5 Mabsadd L closepath F
.10762 .30921 0 2.5 Mabsadd m
.10762 .30921 -0.56518 .7779 Mabsadd L
.10762 .30921 -2.37764 .77254 Mabsadd L
.10762 .30921 -0.91448 -0.29713 Mabsadd L
.10762 .30921 -1.46946 -2.02254 Mabsadd L
.10762 .30921 0 -0.96154 Mabsadd L
.10762 .30921 1.46946 -2.02254 Mabsadd L
.10762 .30921 .91448 -0.29713 Mabsadd L
.10762 .30921 2.37764 .77254 Mabsadd L
.10762 .30921 .56518 .7779 Mabsadd L
.10762 .30921 0 2.5 Mabsadd L closepath F
.11143 .30922 0 2.5 Mabsadd m
.11143 .30922 -0.56518 .7779 Mabsadd L
.11143 .30922 -2.37764 .77254 Mabsadd L
.11143 .30922 -0.91448 -0.29713 Mabsadd L
.11143 .30922 -1.46946 -2.02254 Mabsadd L
.11143 .30922 0 -0.96154 Mabsadd L
.11143 .30922 1.46946 -2.02254 Mabsadd L
.11143 .30922 .91448 -0.29713 Mabsadd L
.11143 .30922 2.37764 .77254 Mabsadd L
.11143 .30922 .56518 .7779 Mabsadd L
.11143 .30922 0 2.5 Mabsadd L closepath F
.11524 .30923 0 2.5 Mabsadd m
.11524 .30923 -0.56518 .7779 Mabsadd L
.11524 .30923 -2.37764 .77254 Mabsadd L
.11524 .30923 -0.91448 -0.29713 Mabsadd L
.11524 .30923 -1.46946 -2.02254 Mabsadd L
.11524 .30923 0 -0.96154 Mabsadd L
.11524 .30923 1.46946 -2.02254 Mabsadd L
.11524 .30923 .91448 -0.29713 Mabsadd L
.11524 .30923 2.37764 .77254 Mabsadd L
.11524 .30923 .56518 .7779 Mabsadd L
.11524 .30923 0 2.5 Mabsadd L closepath F
.11905 .30925 0 2.5 Mabsadd m
.11905 .30925 -0.56518 .7779 Mabsadd L
.11905 .30925 -2.37764 .77254 Mabsadd L
.11905 .30925 -0.91448 -0.29713 Mabsadd L
.11905 .30925 -1.46946 -2.02254 Mabsadd L
.11905 .30925 0 -0.96154 Mabsadd L
.11905 .30925 1.46946 -2.02254 Mabsadd L
.11905 .30925 .91448 -0.29713 Mabsadd L
.11905 .30925 2.37764 .77254 Mabsadd L
.11905 .30925 .56518 .7779 Mabsadd L
.11905 .30925 0 2.5 Mabsadd L closepath F
.12286 .30926 0 2.5 Mabsadd m
.12286 .30926 -0.56518 .7779 Mabsadd L
.12286 .30926 -2.37764 .77254 Mabsadd L
.12286 .30926 -0.91448 -0.29713 Mabsadd L
.12286 .30926 -1.46946 -2.02254 Mabsadd L
.12286 .30926 0 -0.96154 Mabsadd L
.12286 .30926 1.46946 -2.02254 Mabsadd L
.12286 .30926 .91448 -0.29713 Mabsadd L
.12286 .30926 2.37764 .77254 Mabsadd L
.12286 .30926 .56518 .7779 Mabsadd L
.12286 .30926 0 2.5 Mabsadd L closepath F
.12667 .30927 0 2.5 Mabsadd m
.12667 .30927 -0.56518 .7779 Mabsadd L
.12667 .30927 -2.37764 .77254 Mabsadd L
.12667 .30927 -0.91448 -0.29713 Mabsadd L
.12667 .30927 -1.46946 -2.02254 Mabsadd L
.12667 .30927 0 -0.96154 Mabsadd L
.12667 .30927 1.46946 -2.02254 Mabsadd L
.12667 .30927 .91448 -0.29713 Mabsadd L
.12667 .30927 2.37764 .77254 Mabsadd L
.12667 .30927 .56518 .7779 Mabsadd L
.12667 .30927 0 2.5 Mabsadd L closepath F
.13048 .30929 0 2.5 Mabsadd m
.13048 .30929 -0.56518 .7779 Mabsadd L
.13048 .30929 -2.37764 .77254 Mabsadd L
.13048 .30929 -0.91448 -0.29713 Mabsadd L
.13048 .30929 -1.46946 -2.02254 Mabsadd L
.13048 .30929 0 -0.96154 Mabsadd L
.13048 .30929 1.46946 -2.02254 Mabsadd L
.13048 .30929 .91448 -0.29713 Mabsadd L
.13048 .30929 2.37764 .77254 Mabsadd L
.13048 .30929 .56518 .7779 Mabsadd L
.13048 .30929 0 2.5 Mabsadd L closepath F
.13429 .3093 0 2.5 Mabsadd m
.13429 .3093 -0.56518 .7779 Mabsadd L
.13429 .3093 -2.37764 .77254 Mabsadd L
.13429 .3093 -0.91448 -0.29713 Mabsadd L
.13429 .3093 -1.46946 -2.02254 Mabsadd L
.13429 .3093 0 -0.96154 Mabsadd L
.13429 .3093 1.46946 -2.02254 Mabsadd L
.13429 .3093 .91448 -0.29713 Mabsadd L
.13429 .3093 2.37764 .77254 Mabsadd L
.13429 .3093 .56518 .7779 Mabsadd L
.13429 .3093 0 2.5 Mabsadd L closepath F
.1381 .30932 0 2.5 Mabsadd m
.1381 .30932 -0.56518 .7779 Mabsadd L
.1381 .30932 -2.37764 .77254 Mabsadd L
.1381 .30932 -0.91448 -0.29713 Mabsadd L
.1381 .30932 -1.46946 -2.02254 Mabsadd L
.1381 .30932 0 -0.96154 Mabsadd L
.1381 .30932 1.46946 -2.02254 Mabsadd L
.1381 .30932 .91448 -0.29713 Mabsadd L
.1381 .30932 2.37764 .77254 Mabsadd L
.1381 .30932 .56518 .7779 Mabsadd L
.1381 .30932 0 2.5 Mabsadd L closepath F
.1419 .30933 0 2.5 Mabsadd m
.1419 .30933 -0.56518 .7779 Mabsadd L
.1419 .30933 -2.37764 .77254 Mabsadd L
.1419 .30933 -0.91448 -0.29713 Mabsadd L
.1419 .30933 -1.46946 -2.02254 Mabsadd L
.1419 .30933 0 -0.96154 Mabsadd L
.1419 .30933 1.46946 -2.02254 Mabsadd L
.1419 .30933 .91448 -0.29713 Mabsadd L
.1419 .30933 2.37764 .77254 Mabsadd L
.1419 .30933 .56518 .7779 Mabsadd L
.1419 .30933 0 2.5 Mabsadd L closepath F
.14571 .30935 0 2.5 Mabsadd m
.14571 .30935 -0.56518 .7779 Mabsadd L
.14571 .30935 -2.37764 .77254 Mabsadd L
.14571 .30935 -0.91448 -0.29713 Mabsadd L
.14571 .30935 -1.46946 -2.02254 Mabsadd L
.14571 .30935 0 -0.96154 Mabsadd L
.14571 .30935 1.46946 -2.02254 Mabsadd L
.14571 .30935 .91448 -0.29713 Mabsadd L
.14571 .30935 2.37764 .77254 Mabsadd L
.14571 .30935 .56518 .7779 Mabsadd L
.14571 .30935 0 2.5 Mabsadd L closepath F
.14952 .30937 0 2.5 Mabsadd m
.14952 .30937 -0.56518 .7779 Mabsadd L
.14952 .30937 -2.37764 .77254 Mabsadd L
.14952 .30937 -0.91448 -0.29713 Mabsadd L
.14952 .30937 -1.46946 -2.02254 Mabsadd L
.14952 .30937 0 -0.96154 Mabsadd L
.14952 .30937 1.46946 -2.02254 Mabsadd L
.14952 .30937 .91448 -0.29713 Mabsadd L
.14952 .30937 2.37764 .77254 Mabsadd L
.14952 .30937 .56518 .7779 Mabsadd L
.14952 .30937 0 2.5 Mabsadd L closepath F
.15333 .3094 0 2.5 Mabsadd m
.15333 .3094 -0.56518 .7779 Mabsadd L
.15333 .3094 -2.37764 .77254 Mabsadd L
.15333 .3094 -0.91448 -0.29713 Mabsadd L
.15333 .3094 -1.46946 -2.02254 Mabsadd L
.15333 .3094 0 -0.96154 Mabsadd L
.15333 .3094 1.46946 -2.02254 Mabsadd L
.15333 .3094 .91448 -0.29713 Mabsadd L
.15333 .3094 2.37764 .77254 Mabsadd L
.15333 .3094 .56518 .7779 Mabsadd L
.15333 .3094 0 2.5 Mabsadd L closepath F
.15714 .30942 0 2.5 Mabsadd m
.15714 .30942 -0.56518 .7779 Mabsadd L
.15714 .30942 -2.37764 .77254 Mabsadd L
.15714 .30942 -0.91448 -0.29713 Mabsadd L
.15714 .30942 -1.46946 -2.02254 Mabsadd L
.15714 .30942 0 -0.96154 Mabsadd L
.15714 .30942 1.46946 -2.02254 Mabsadd L
.15714 .30942 .91448 -0.29713 Mabsadd L
.15714 .30942 2.37764 .77254 Mabsadd L
.15714 .30942 .56518 .7779 Mabsadd L
.15714 .30942 0 2.5 Mabsadd L closepath F
.16095 .30944 0 2.5 Mabsadd m
.16095 .30944 -0.56518 .7779 Mabsadd L
.16095 .30944 -2.37764 .77254 Mabsadd L
.16095 .30944 -0.91448 -0.29713 Mabsadd L
.16095 .30944 -1.46946 -2.02254 Mabsadd L
.16095 .30944 0 -0.96154 Mabsadd L
.16095 .30944 1.46946 -2.02254 Mabsadd L
.16095 .30944 .91448 -0.29713 Mabsadd L
.16095 .30944 2.37764 .77254 Mabsadd L
.16095 .30944 .56518 .7779 Mabsadd L
.16095 .30944 0 2.5 Mabsadd L closepath F
.16476 .30947 0 2.5 Mabsadd m
.16476 .30947 -0.56518 .7779 Mabsadd L
.16476 .30947 -2.37764 .77254 Mabsadd L
.16476 .30947 -0.91448 -0.29713 Mabsadd L
.16476 .30947 -1.46946 -2.02254 Mabsadd L
.16476 .30947 0 -0.96154 Mabsadd L
.16476 .30947 1.46946 -2.02254 Mabsadd L
.16476 .30947 .91448 -0.29713 Mabsadd L
.16476 .30947 2.37764 .77254 Mabsadd L
.16476 .30947 .56518 .7779 Mabsadd L
.16476 .30947 0 2.5 Mabsadd L closepath F
.16857 .3095 0 2.5 Mabsadd m
.16857 .3095 -0.56518 .7779 Mabsadd L
.16857 .3095 -2.37764 .77254 Mabsadd L
.16857 .3095 -0.91448 -0.29713 Mabsadd L
.16857 .3095 -1.46946 -2.02254 Mabsadd L
.16857 .3095 0 -0.96154 Mabsadd L
.16857 .3095 1.46946 -2.02254 Mabsadd L
.16857 .3095 .91448 -0.29713 Mabsadd L
.16857 .3095 2.37764 .77254 Mabsadd L
.16857 .3095 .56518 .7779 Mabsadd L
.16857 .3095 0 2.5 Mabsadd L closepath F
.17238 .30953 0 2.5 Mabsadd m
.17238 .30953 -0.56518 .7779 Mabsadd L
.17238 .30953 -2.37764 .77254 Mabsadd L
.17238 .30953 -0.91448 -0.29713 Mabsadd L
.17238 .30953 -1.46946 -2.02254 Mabsadd L
.17238 .30953 0 -0.96154 Mabsadd L
.17238 .30953 1.46946 -2.02254 Mabsadd L
.17238 .30953 .91448 -0.29713 Mabsadd L
.17238 .30953 2.37764 .77254 Mabsadd L
.17238 .30953 .56518 .7779 Mabsadd L
.17238 .30953 0 2.5 Mabsadd L closepath F
.17619 .30957 0 2.5 Mabsadd m
.17619 .30957 -0.56518 .7779 Mabsadd L
.17619 .30957 -2.37764 .77254 Mabsadd L
.17619 .30957 -0.91448 -0.29713 Mabsadd L
.17619 .30957 -1.46946 -2.02254 Mabsadd L
.17619 .30957 0 -0.96154 Mabsadd L
.17619 .30957 1.46946 -2.02254 Mabsadd L
.17619 .30957 .91448 -0.29713 Mabsadd L
.17619 .30957 2.37764 .77254 Mabsadd L
.17619 .30957 .56518 .7779 Mabsadd L
.17619 .30957 0 2.5 Mabsadd L closepath F
.18 .30961 0 2.5 Mabsadd m
.18 .30961 -0.56518 .7779 Mabsadd L
.18 .30961 -2.37764 .77254 Mabsadd L
.18 .30961 -0.91448 -0.29713 Mabsadd L
.18 .30961 -1.46946 -2.02254 Mabsadd L
.18 .30961 0 -0.96154 Mabsadd L
.18 .30961 1.46946 -2.02254 Mabsadd L
.18 .30961 .91448 -0.29713 Mabsadd L
.18 .30961 2.37764 .77254 Mabsadd L
.18 .30961 .56518 .7779 Mabsadd L
.18 .30961 0 2.5 Mabsadd L closepath F
.18381 .30965 0 2.5 Mabsadd m
.18381 .30965 -0.56518 .7779 Mabsadd L
.18381 .30965 -2.37764 .77254 Mabsadd L
.18381 .30965 -0.91448 -0.29713 Mabsadd L
.18381 .30965 -1.46946 -2.02254 Mabsadd L
.18381 .30965 0 -0.96154 Mabsadd L
.18381 .30965 1.46946 -2.02254 Mabsadd L
.18381 .30965 .91448 -0.29713 Mabsadd L
.18381 .30965 2.37764 .77254 Mabsadd L
.18381 .30965 .56518 .7779 Mabsadd L
.18381 .30965 0 2.5 Mabsadd L closepath F
.18762 .30969 0 2.5 Mabsadd m
.18762 .30969 -0.56518 .7779 Mabsadd L
.18762 .30969 -2.37764 .77254 Mabsadd L
.18762 .30969 -0.91448 -0.29713 Mabsadd L
.18762 .30969 -1.46946 -2.02254 Mabsadd L
.18762 .30969 0 -0.96154 Mabsadd L
.18762 .30969 1.46946 -2.02254 Mabsadd L
.18762 .30969 .91448 -0.29713 Mabsadd L
.18762 .30969 2.37764 .77254 Mabsadd L
.18762 .30969 .56518 .7779 Mabsadd L
.18762 .30969 0 2.5 Mabsadd L closepath F
.19143 .30974 0 2.5 Mabsadd m
.19143 .30974 -0.56518 .7779 Mabsadd L
.19143 .30974 -2.37764 .77254 Mabsadd L
.19143 .30974 -0.91448 -0.29713 Mabsadd L
.19143 .30974 -1.46946 -2.02254 Mabsadd L
.19143 .30974 0 -0.96154 Mabsadd L
.19143 .30974 1.46946 -2.02254 Mabsadd L
.19143 .30974 .91448 -0.29713 Mabsadd L
.19143 .30974 2.37764 .77254 Mabsadd L
.19143 .30974 .56518 .7779 Mabsadd L
.19143 .30974 0 2.5 Mabsadd L closepath F
.19524 .30979 0 2.5 Mabsadd m
.19524 .30979 -0.56518 .7779 Mabsadd L
.19524 .30979 -2.37764 .77254 Mabsadd L
.19524 .30979 -0.91448 -0.29713 Mabsadd L
.19524 .30979 -1.46946 -2.02254 Mabsadd L
.19524 .30979 0 -0.96154 Mabsadd L
.19524 .30979 1.46946 -2.02254 Mabsadd L
.19524 .30979 .91448 -0.29713 Mabsadd L
.19524 .30979 2.37764 .77254 Mabsadd L
.19524 .30979 .56518 .7779 Mabsadd L
.19524 .30979 0 2.5 Mabsadd L closepath F
.19905 .30985 0 2.5 Mabsadd m
.19905 .30985 -0.56518 .7779 Mabsadd L
.19905 .30985 -2.37764 .77254 Mabsadd L
.19905 .30985 -0.91448 -0.29713 Mabsadd L
.19905 .30985 -1.46946 -2.02254 Mabsadd L
.19905 .30985 0 -0.96154 Mabsadd L
.19905 .30985 1.46946 -2.02254 Mabsadd L
.19905 .30985 .91448 -0.29713 Mabsadd L
.19905 .30985 2.37764 .77254 Mabsadd L
.19905 .30985 .56518 .7779 Mabsadd L
.19905 .30985 0 2.5 Mabsadd L closepath F
.20286 .30992 0 2.5 Mabsadd m
.20286 .30992 -0.56518 .7779 Mabsadd L
.20286 .30992 -2.37764 .77254 Mabsadd L
.20286 .30992 -0.91448 -0.29713 Mabsadd L
.20286 .30992 -1.46946 -2.02254 Mabsadd L
.20286 .30992 0 -0.96154 Mabsadd L
.20286 .30992 1.46946 -2.02254 Mabsadd L
.20286 .30992 .91448 -0.29713 Mabsadd L
.20286 .30992 2.37764 .77254 Mabsadd L
.20286 .30992 .56518 .7779 Mabsadd L
.20286 .30992 0 2.5 Mabsadd L closepath F
.20667 .30998 0 2.5 Mabsadd m
.20667 .30998 -0.56518 .7779 Mabsadd L
.20667 .30998 -2.37764 .77254 Mabsadd L
.20667 .30998 -0.91448 -0.29713 Mabsadd L
.20667 .30998 -1.46946 -2.02254 Mabsadd L
.20667 .30998 0 -0.96154 Mabsadd L
.20667 .30998 1.46946 -2.02254 Mabsadd L
.20667 .30998 .91448 -0.29713 Mabsadd L
.20667 .30998 2.37764 .77254 Mabsadd L
.20667 .30998 .56518 .7779 Mabsadd L
.20667 .30998 0 2.5 Mabsadd L closepath F
.21048 .31006 0 2.5 Mabsadd m
.21048 .31006 -0.56518 .7779 Mabsadd L
.21048 .31006 -2.37764 .77254 Mabsadd L
.21048 .31006 -0.91448 -0.29713 Mabsadd L
.21048 .31006 -1.46946 -2.02254 Mabsadd L
.21048 .31006 0 -0.96154 Mabsadd L
.21048 .31006 1.46946 -2.02254 Mabsadd L
.21048 .31006 .91448 -0.29713 Mabsadd L
.21048 .31006 2.37764 .77254 Mabsadd L
.21048 .31006 .56518 .7779 Mabsadd L
.21048 .31006 0 2.5 Mabsadd L closepath F
.21429 .31014 0 2.5 Mabsadd m
.21429 .31014 -0.56518 .7779 Mabsadd L
.21429 .31014 -2.37764 .77254 Mabsadd L
.21429 .31014 -0.91448 -0.29713 Mabsadd L
.21429 .31014 -1.46946 -2.02254 Mabsadd L
.21429 .31014 0 -0.96154 Mabsadd L
.21429 .31014 1.46946 -2.02254 Mabsadd L
.21429 .31014 .91448 -0.29713 Mabsadd L
.21429 .31014 2.37764 .77254 Mabsadd L
.21429 .31014 .56518 .7779 Mabsadd L
.21429 .31014 0 2.5 Mabsadd L closepath F
.2181 .31024 0 2.5 Mabsadd m
.2181 .31024 -0.56518 .7779 Mabsadd L
.2181 .31024 -2.37764 .77254 Mabsadd L
.2181 .31024 -0.91448 -0.29713 Mabsadd L
.2181 .31024 -1.46946 -2.02254 Mabsadd L
.2181 .31024 0 -0.96154 Mabsadd L
.2181 .31024 1.46946 -2.02254 Mabsadd L
.2181 .31024 .91448 -0.29713 Mabsadd L
.2181 .31024 2.37764 .77254 Mabsadd L
.2181 .31024 .56518 .7779 Mabsadd L
.2181 .31024 0 2.5 Mabsadd L closepath F
.2219 .31034 0 2.5 Mabsadd m
.2219 .31034 -0.56518 .7779 Mabsadd L
.2219 .31034 -2.37764 .77254 Mabsadd L
.2219 .31034 -0.91448 -0.29713 Mabsadd L
.2219 .31034 -1.46946 -2.02254 Mabsadd L
.2219 .31034 0 -0.96154 Mabsadd L
.2219 .31034 1.46946 -2.02254 Mabsadd L
.2219 .31034 .91448 -0.29713 Mabsadd L
.2219 .31034 2.37764 .77254 Mabsadd L
.2219 .31034 .56518 .7779 Mabsadd L
.2219 .31034 0 2.5 Mabsadd L closepath F
.22571 .31045 0 2.5 Mabsadd m
.22571 .31045 -0.56518 .7779 Mabsadd L
.22571 .31045 -2.37764 .77254 Mabsadd L
.22571 .31045 -0.91448 -0.29713 Mabsadd L
.22571 .31045 -1.46946 -2.02254 Mabsadd L
.22571 .31045 0 -0.96154 Mabsadd L
.22571 .31045 1.46946 -2.02254 Mabsadd L
.22571 .31045 .91448 -0.29713 Mabsadd L
.22571 .31045 2.37764 .77254 Mabsadd L
.22571 .31045 .56518 .7779 Mabsadd L
.22571 .31045 0 2.5 Mabsadd L closepath F
.22952 .31057 0 2.5 Mabsadd m
.22952 .31057 -0.56518 .7779 Mabsadd L
.22952 .31057 -2.37764 .77254 Mabsadd L
.22952 .31057 -0.91448 -0.29713 Mabsadd L
.22952 .31057 -1.46946 -2.02254 Mabsadd L
.22952 .31057 0 -0.96154 Mabsadd L
.22952 .31057 1.46946 -2.02254 Mabsadd L
.22952 .31057 .91448 -0.29713 Mabsadd L
.22952 .31057 2.37764 .77254 Mabsadd L
.22952 .31057 .56518 .7779 Mabsadd L
.22952 .31057 0 2.5 Mabsadd L closepath F
.23333 .31071 0 2.5 Mabsadd m
.23333 .31071 -0.56518 .7779 Mabsadd L
.23333 .31071 -2.37764 .77254 Mabsadd L
.23333 .31071 -0.91448 -0.29713 Mabsadd L
.23333 .31071 -1.46946 -2.02254 Mabsadd L
.23333 .31071 0 -0.96154 Mabsadd L
.23333 .31071 1.46946 -2.02254 Mabsadd L
.23333 .31071 .91448 -0.29713 Mabsadd L
.23333 .31071 2.37764 .77254 Mabsadd L
.23333 .31071 .56518 .7779 Mabsadd L
.23333 .31071 0 2.5 Mabsadd L closepath F
.23714 .31086 0 2.5 Mabsadd m
.23714 .31086 -0.56518 .7779 Mabsadd L
.23714 .31086 -2.37764 .77254 Mabsadd L
.23714 .31086 -0.91448 -0.29713 Mabsadd L
.23714 .31086 -1.46946 -2.02254 Mabsadd L
.23714 .31086 0 -0.96154 Mabsadd L
.23714 .31086 1.46946 -2.02254 Mabsadd L
.23714 .31086 .91448 -0.29713 Mabsadd L
.23714 .31086 2.37764 .77254 Mabsadd L
.23714 .31086 .56518 .7779 Mabsadd L
.23714 .31086 0 2.5 Mabsadd L closepath F
.24095 .31102 0 2.5 Mabsadd m
.24095 .31102 -0.56518 .7779 Mabsadd L
.24095 .31102 -2.37764 .77254 Mabsadd L
.24095 .31102 -0.91448 -0.29713 Mabsadd L
.24095 .31102 -1.46946 -2.02254 Mabsadd L
.24095 .31102 0 -0.96154 Mabsadd L
.24095 .31102 1.46946 -2.02254 Mabsadd L
.24095 .31102 .91448 -0.29713 Mabsadd L
.24095 .31102 2.37764 .77254 Mabsadd L
.24095 .31102 .56518 .7779 Mabsadd L
.24095 .31102 0 2.5 Mabsadd L closepath F
.24476 .31121 0 2.5 Mabsadd m
.24476 .31121 -0.56518 .7779 Mabsadd L
.24476 .31121 -2.37764 .77254 Mabsadd L
.24476 .31121 -0.91448 -0.29713 Mabsadd L
.24476 .31121 -1.46946 -2.02254 Mabsadd L
.24476 .31121 0 -0.96154 Mabsadd L
.24476 .31121 1.46946 -2.02254 Mabsadd L
.24476 .31121 .91448 -0.29713 Mabsadd L
.24476 .31121 2.37764 .77254 Mabsadd L
.24476 .31121 .56518 .7779 Mabsadd L
.24476 .31121 0 2.5 Mabsadd L closepath F
.24857 .31141 0 2.5 Mabsadd m
.24857 .31141 -0.56518 .7779 Mabsadd L
.24857 .31141 -2.37764 .77254 Mabsadd L
.24857 .31141 -0.91448 -0.29713 Mabsadd L
.24857 .31141 -1.46946 -2.02254 Mabsadd L
.24857 .31141 0 -0.96154 Mabsadd L
.24857 .31141 1.46946 -2.02254 Mabsadd L
.24857 .31141 .91448 -0.29713 Mabsadd L
.24857 .31141 2.37764 .77254 Mabsadd L
.24857 .31141 .56518 .7779 Mabsadd L
.24857 .31141 0 2.5 Mabsadd L closepath F
.25238 .31164 0 2.5 Mabsadd m
.25238 .31164 -0.56518 .7779 Mabsadd L
.25238 .31164 -2.37764 .77254 Mabsadd L
.25238 .31164 -0.91448 -0.29713 Mabsadd L
.25238 .31164 -1.46946 -2.02254 Mabsadd L
.25238 .31164 0 -0.96154 Mabsadd L
.25238 .31164 1.46946 -2.02254 Mabsadd L
.25238 .31164 .91448 -0.29713 Mabsadd L
.25238 .31164 2.37764 .77254 Mabsadd L
.25238 .31164 .56518 .7779 Mabsadd L
.25238 .31164 0 2.5 Mabsadd L closepath F
.25619 .3119 0 2.5 Mabsadd m
.25619 .3119 -0.56518 .7779 Mabsadd L
.25619 .3119 -2.37764 .77254 Mabsadd L
.25619 .3119 -0.91448 -0.29713 Mabsadd L
.25619 .3119 -1.46946 -2.02254 Mabsadd L
.25619 .3119 0 -0.96154 Mabsadd L
.25619 .3119 1.46946 -2.02254 Mabsadd L
.25619 .3119 .91448 -0.29713 Mabsadd L
.25619 .3119 2.37764 .77254 Mabsadd L
.25619 .3119 .56518 .7779 Mabsadd L
.25619 .3119 0 2.5 Mabsadd L closepath F
.26 .31218 0 2.5 Mabsadd m
.26 .31218 -0.56518 .7779 Mabsadd L
.26 .31218 -2.37764 .77254 Mabsadd L
.26 .31218 -0.91448 -0.29713 Mabsadd L
.26 .31218 -1.46946 -2.02254 Mabsadd L
.26 .31218 0 -0.96154 Mabsadd L
.26 .31218 1.46946 -2.02254 Mabsadd L
.26 .31218 .91448 -0.29713 Mabsadd L
.26 .31218 2.37764 .77254 Mabsadd L
.26 .31218 .56518 .7779 Mabsadd L
.26 .31218 0 2.5 Mabsadd L closepath F
.26381 .3125 0 2.5 Mabsadd m
.26381 .3125 -0.56518 .7779 Mabsadd L
.26381 .3125 -2.37764 .77254 Mabsadd L
.26381 .3125 -0.91448 -0.29713 Mabsadd L
.26381 .3125 -1.46946 -2.02254 Mabsadd L
.26381 .3125 0 -0.96154 Mabsadd L
.26381 .3125 1.46946 -2.02254 Mabsadd L
.26381 .3125 .91448 -0.29713 Mabsadd L
.26381 .3125 2.37764 .77254 Mabsadd L
.26381 .3125 .56518 .7779 Mabsadd L
.26381 .3125 0 2.5 Mabsadd L closepath F
.26762 .31286 0 2.5 Mabsadd m
.26762 .31286 -0.56518 .7779 Mabsadd L
.26762 .31286 -2.37764 .77254 Mabsadd L
.26762 .31286 -0.91448 -0.29713 Mabsadd L
.26762 .31286 -1.46946 -2.02254 Mabsadd L
.26762 .31286 0 -0.96154 Mabsadd L
.26762 .31286 1.46946 -2.02254 Mabsadd L
.26762 .31286 .91448 -0.29713 Mabsadd L
.26762 .31286 2.37764 .77254 Mabsadd L
.26762 .31286 .56518 .7779 Mabsadd L
.26762 .31286 0 2.5 Mabsadd L closepath F
.27143 .31326 0 2.5 Mabsadd m
.27143 .31326 -0.56518 .7779 Mabsadd L
.27143 .31326 -2.37764 .77254 Mabsadd L
.27143 .31326 -0.91448 -0.29713 Mabsadd L
.27143 .31326 -1.46946 -2.02254 Mabsadd L
.27143 .31326 0 -0.96154 Mabsadd L
.27143 .31326 1.46946 -2.02254 Mabsadd L
.27143 .31326 .91448 -0.29713 Mabsadd L
.27143 .31326 2.37764 .77254 Mabsadd L
.27143 .31326 .56518 .7779 Mabsadd L
.27143 .31326 0 2.5 Mabsadd L closepath F
.27524 .3137 0 2.5 Mabsadd m
.27524 .3137 -0.56518 .7779 Mabsadd L
.27524 .3137 -2.37764 .77254 Mabsadd L
.27524 .3137 -0.91448 -0.29713 Mabsadd L
.27524 .3137 -1.46946 -2.02254 Mabsadd L
.27524 .3137 0 -0.96154 Mabsadd L
.27524 .3137 1.46946 -2.02254 Mabsadd L
.27524 .3137 .91448 -0.29713 Mabsadd L
.27524 .3137 2.37764 .77254 Mabsadd L
.27524 .3137 .56518 .7779 Mabsadd L
.27524 .3137 0 2.5 Mabsadd L closepath F
.27905 .3142 0 2.5 Mabsadd m
.27905 .3142 -0.56518 .7779 Mabsadd L
.27905 .3142 -2.37764 .77254 Mabsadd L
.27905 .3142 -0.91448 -0.29713 Mabsadd L
.27905 .3142 -1.46946 -2.02254 Mabsadd L
.27905 .3142 0 -0.96154 Mabsadd L
.27905 .3142 1.46946 -2.02254 Mabsadd L
.27905 .3142 .91448 -0.29713 Mabsadd L
.27905 .3142 2.37764 .77254 Mabsadd L
.27905 .3142 .56518 .7779 Mabsadd L
.27905 .3142 0 2.5 Mabsadd L closepath F
.28286 .31476 0 2.5 Mabsadd m
.28286 .31476 -0.56518 .7779 Mabsadd L
.28286 .31476 -2.37764 .77254 Mabsadd L
.28286 .31476 -0.91448 -0.29713 Mabsadd L
.28286 .31476 -1.46946 -2.02254 Mabsadd L
.28286 .31476 0 -0.96154 Mabsadd L
.28286 .31476 1.46946 -2.02254 Mabsadd L
.28286 .31476 .91448 -0.29713 Mabsadd L
.28286 .31476 2.37764 .77254 Mabsadd L
.28286 .31476 .56518 .7779 Mabsadd L
.28286 .31476 0 2.5 Mabsadd L closepath F
.28667 .31538 0 2.5 Mabsadd m
.28667 .31538 -0.56518 .7779 Mabsadd L
.28667 .31538 -2.37764 .77254 Mabsadd L
.28667 .31538 -0.91448 -0.29713 Mabsadd L
.28667 .31538 -1.46946 -2.02254 Mabsadd L
.28667 .31538 0 -0.96154 Mabsadd L
.28667 .31538 1.46946 -2.02254 Mabsadd L
.28667 .31538 .91448 -0.29713 Mabsadd L
.28667 .31538 2.37764 .77254 Mabsadd L
.28667 .31538 .56518 .7779 Mabsadd L
.28667 .31538 0 2.5 Mabsadd L closepath F
.29048 .31608 0 2.5 Mabsadd m
.29048 .31608 -0.56518 .7779 Mabsadd L
.29048 .31608 -2.37764 .77254 Mabsadd L
.29048 .31608 -0.91448 -0.29713 Mabsadd L
.29048 .31608 -1.46946 -2.02254 Mabsadd L
.29048 .31608 0 -0.96154 Mabsadd L
.29048 .31608 1.46946 -2.02254 Mabsadd L
.29048 .31608 .91448 -0.29713 Mabsadd L
.29048 .31608 2.37764 .77254 Mabsadd L
.29048 .31608 .56518 .7779 Mabsadd L
.29048 .31608 0 2.5 Mabsadd L closepath F
.29429 .31686 0 2.5 Mabsadd m
.29429 .31686 -0.56518 .7779 Mabsadd L
.29429 .31686 -2.37764 .77254 Mabsadd L
.29429 .31686 -0.91448 -0.29713 Mabsadd L
.29429 .31686 -1.46946 -2.02254 Mabsadd L
.29429 .31686 0 -0.96154 Mabsadd L
.29429 .31686 1.46946 -2.02254 Mabsadd L
.29429 .31686 .91448 -0.29713 Mabsadd L
.29429 .31686 2.37764 .77254 Mabsadd L
.29429 .31686 .56518 .7779 Mabsadd L
.29429 .31686 0 2.5 Mabsadd L closepath F
.2981 .31773 0 2.5 Mabsadd m
.2981 .31773 -0.56518 .7779 Mabsadd L
.2981 .31773 -2.37764 .77254 Mabsadd L
.2981 .31773 -0.91448 -0.29713 Mabsadd L
.2981 .31773 -1.46946 -2.02254 Mabsadd L
.2981 .31773 0 -0.96154 Mabsadd L
.2981 .31773 1.46946 -2.02254 Mabsadd L
.2981 .31773 .91448 -0.29713 Mabsadd L
.2981 .31773 2.37764 .77254 Mabsadd L
.2981 .31773 .56518 .7779 Mabsadd L
.2981 .31773 0 2.5 Mabsadd L closepath F
.3019 .31868 0 2.5 Mabsadd m
.3019 .31868 -0.56518 .7779 Mabsadd L
.3019 .31868 -2.37764 .77254 Mabsadd L
.3019 .31868 -0.91448 -0.29713 Mabsadd L
.3019 .31868 -1.46946 -2.02254 Mabsadd L
.3019 .31868 0 -0.96154 Mabsadd L
.3019 .31868 1.46946 -2.02254 Mabsadd L
.3019 .31868 .91448 -0.29713 Mabsadd L
.3019 .31868 2.37764 .77254 Mabsadd L
.3019 .31868 .56518 .7779 Mabsadd L
.3019 .31868 0 2.5 Mabsadd L closepath F
.30571 .31974 0 2.5 Mabsadd m
.30571 .31974 -0.56518 .7779 Mabsadd L
.30571 .31974 -2.37764 .77254 Mabsadd L
.30571 .31974 -0.91448 -0.29713 Mabsadd L
.30571 .31974 -1.46946 -2.02254 Mabsadd L
.30571 .31974 0 -0.96154 Mabsadd L
.30571 .31974 1.46946 -2.02254 Mabsadd L
.30571 .31974 .91448 -0.29713 Mabsadd L
.30571 .31974 2.37764 .77254 Mabsadd L
.30571 .31974 .56518 .7779 Mabsadd L
.30571 .31974 0 2.5 Mabsadd L closepath F
.30952 .32088 0 2.5 Mabsadd m
.30952 .32088 -0.56518 .7779 Mabsadd L
.30952 .32088 -2.37764 .77254 Mabsadd L
.30952 .32088 -0.91448 -0.29713 Mabsadd L
.30952 .32088 -1.46946 -2.02254 Mabsadd L
.30952 .32088 0 -0.96154 Mabsadd L
.30952 .32088 1.46946 -2.02254 Mabsadd L
.30952 .32088 .91448 -0.29713 Mabsadd L
.30952 .32088 2.37764 .77254 Mabsadd L
.30952 .32088 .56518 .7779 Mabsadd L
.30952 .32088 0 2.5 Mabsadd L closepath F
.31333 .32211 0 2.5 Mabsadd m
.31333 .32211 -0.56518 .7779 Mabsadd L
.31333 .32211 -2.37764 .77254 Mabsadd L
.31333 .32211 -0.91448 -0.29713 Mabsadd L
.31333 .32211 -1.46946 -2.02254 Mabsadd L
.31333 .32211 0 -0.96154 Mabsadd L
.31333 .32211 1.46946 -2.02254 Mabsadd L
.31333 .32211 .91448 -0.29713 Mabsadd L
.31333 .32211 2.37764 .77254 Mabsadd L
.31333 .32211 .56518 .7779 Mabsadd L
.31333 .32211 0 2.5 Mabsadd L closepath F
.31714 .3234 0 2.5 Mabsadd m
.31714 .3234 -0.56518 .7779 Mabsadd L
.31714 .3234 -2.37764 .77254 Mabsadd L
.31714 .3234 -0.91448 -0.29713 Mabsadd L
.31714 .3234 -1.46946 -2.02254 Mabsadd L
.31714 .3234 0 -0.96154 Mabsadd L
.31714 .3234 1.46946 -2.02254 Mabsadd L
.31714 .3234 .91448 -0.29713 Mabsadd L
.31714 .3234 2.37764 .77254 Mabsadd L
.31714 .3234 .56518 .7779 Mabsadd L
.31714 .3234 0 2.5 Mabsadd L closepath F
.32095 .32471 0 2.5 Mabsadd m
.32095 .32471 -0.56518 .7779 Mabsadd L
.32095 .32471 -2.37764 .77254 Mabsadd L
.32095 .32471 -0.91448 -0.29713 Mabsadd L
.32095 .32471 -1.46946 -2.02254 Mabsadd L
.32095 .32471 0 -0.96154 Mabsadd L
.32095 .32471 1.46946 -2.02254 Mabsadd L
.32095 .32471 .91448 -0.29713 Mabsadd L
.32095 .32471 2.37764 .77254 Mabsadd L
.32095 .32471 .56518 .7779 Mabsadd L
.32095 .32471 0 2.5 Mabsadd L closepath F
.32476 .32595 0 2.5 Mabsadd m
.32476 .32595 -0.56518 .7779 Mabsadd L
.32476 .32595 -2.37764 .77254 Mabsadd L
.32476 .32595 -0.91448 -0.29713 Mabsadd L
.32476 .32595 -1.46946 -2.02254 Mabsadd L
.32476 .32595 0 -0.96154 Mabsadd L
.32476 .32595 1.46946 -2.02254 Mabsadd L
.32476 .32595 .91448 -0.29713 Mabsadd L
.32476 .32595 2.37764 .77254 Mabsadd L
.32476 .32595 .56518 .7779 Mabsadd L
.32476 .32595 0 2.5 Mabsadd L closepath F
.32857 .32701 0 2.5 Mabsadd m
.32857 .32701 -0.56518 .7779 Mabsadd L
.32857 .32701 -2.37764 .77254 Mabsadd L
.32857 .32701 -0.91448 -0.29713 Mabsadd L
.32857 .32701 -1.46946 -2.02254 Mabsadd L
.32857 .32701 0 -0.96154 Mabsadd L
.32857 .32701 1.46946 -2.02254 Mabsadd L
.32857 .32701 .91448 -0.29713 Mabsadd L
.32857 .32701 2.37764 .77254 Mabsadd L
.32857 .32701 .56518 .7779 Mabsadd L
.32857 .32701 0 2.5 Mabsadd L closepath F
.33238 .32765 0 2.5 Mabsadd m
.33238 .32765 -0.56518 .7779 Mabsadd L
.33238 .32765 -2.37764 .77254 Mabsadd L
.33238 .32765 -0.91448 -0.29713 Mabsadd L
.33238 .32765 -1.46946 -2.02254 Mabsadd L
.33238 .32765 0 -0.96154 Mabsadd L
.33238 .32765 1.46946 -2.02254 Mabsadd L
.33238 .32765 .91448 -0.29713 Mabsadd L
.33238 .32765 2.37764 .77254 Mabsadd L
.33238 .32765 .56518 .7779 Mabsadd L
.33238 .32765 0 2.5 Mabsadd L closepath F
.33619 .3275 0 2.5 Mabsadd m
.33619 .3275 -0.56518 .7779 Mabsadd L
.33619 .3275 -2.37764 .77254 Mabsadd L
.33619 .3275 -0.91448 -0.29713 Mabsadd L
.33619 .3275 -1.46946 -2.02254 Mabsadd L
.33619 .3275 0 -0.96154 Mabsadd L
.33619 .3275 1.46946 -2.02254 Mabsadd L
.33619 .3275 .91448 -0.29713 Mabsadd L
.33619 .3275 2.37764 .77254 Mabsadd L
.33619 .3275 .56518 .7779 Mabsadd L
.33619 .3275 0 2.5 Mabsadd L closepath F
.34 .32597 0 2.5 Mabsadd m
.34 .32597 -0.56518 .7779 Mabsadd L
.34 .32597 -2.37764 .77254 Mabsadd L
.34 .32597 -0.91448 -0.29713 Mabsadd L
.34 .32597 -1.46946 -2.02254 Mabsadd L
.34 .32597 0 -0.96154 Mabsadd L
.34 .32597 1.46946 -2.02254 Mabsadd L
.34 .32597 .91448 -0.29713 Mabsadd L
.34 .32597 2.37764 .77254 Mabsadd L
.34 .32597 .56518 .7779 Mabsadd L
.34 .32597 0 2.5 Mabsadd L closepath F
.34381 .32221 0 2.5 Mabsadd m
.34381 .32221 -0.56518 .7779 Mabsadd L
.34381 .32221 -2.37764 .77254 Mabsadd L
.34381 .32221 -0.91448 -0.29713 Mabsadd L
.34381 .32221 -1.46946 -2.02254 Mabsadd L
.34381 .32221 0 -0.96154 Mabsadd L
.34381 .32221 1.46946 -2.02254 Mabsadd L
.34381 .32221 .91448 -0.29713 Mabsadd L
.34381 .32221 2.37764 .77254 Mabsadd L
.34381 .32221 .56518 .7779 Mabsadd L
.34381 .32221 0 2.5 Mabsadd L closepath F
.34762 .31506 0 2.5 Mabsadd m
.34762 .31506 -0.56518 .7779 Mabsadd L
.34762 .31506 -2.37764 .77254 Mabsadd L
.34762 .31506 -0.91448 -0.29713 Mabsadd L
.34762 .31506 -1.46946 -2.02254 Mabsadd L
.34762 .31506 0 -0.96154 Mabsadd L
.34762 .31506 1.46946 -2.02254 Mabsadd L
.34762 .31506 .91448 -0.29713 Mabsadd L
.34762 .31506 2.37764 .77254 Mabsadd L
.34762 .31506 .56518 .7779 Mabsadd L
.34762 .31506 0 2.5 Mabsadd L closepath F
.35143 .30338 0 2.5 Mabsadd m
.35143 .30338 -0.56518 .7779 Mabsadd L
.35143 .30338 -2.37764 .77254 Mabsadd L
.35143 .30338 -0.91448 -0.29713 Mabsadd L
.35143 .30338 -1.46946 -2.02254 Mabsadd L
.35143 .30338 0 -0.96154 Mabsadd L
.35143 .30338 1.46946 -2.02254 Mabsadd L
.35143 .30338 .91448 -0.29713 Mabsadd L
.35143 .30338 2.37764 .77254 Mabsadd L
.35143 .30338 .56518 .7779 Mabsadd L
.35143 .30338 0 2.5 Mabsadd L closepath F
.35524 .28667 0 2.5 Mabsadd m
.35524 .28667 -0.56518 .7779 Mabsadd L
.35524 .28667 -2.37764 .77254 Mabsadd L
.35524 .28667 -0.91448 -0.29713 Mabsadd L
.35524 .28667 -1.46946 -2.02254 Mabsadd L
.35524 .28667 0 -0.96154 Mabsadd L
.35524 .28667 1.46946 -2.02254 Mabsadd L
.35524 .28667 .91448 -0.29713 Mabsadd L
.35524 .28667 2.37764 .77254 Mabsadd L
.35524 .28667 .56518 .7779 Mabsadd L
.35524 .28667 0 2.5 Mabsadd L closepath F
.35905 .26573 0 2.5 Mabsadd m
.35905 .26573 -0.56518 .7779 Mabsadd L
.35905 .26573 -2.37764 .77254 Mabsadd L
.35905 .26573 -0.91448 -0.29713 Mabsadd L
.35905 .26573 -1.46946 -2.02254 Mabsadd L
.35905 .26573 0 -0.96154 Mabsadd L
.35905 .26573 1.46946 -2.02254 Mabsadd L
.35905 .26573 .91448 -0.29713 Mabsadd L
.35905 .26573 2.37764 .77254 Mabsadd L
.35905 .26573 .56518 .7779 Mabsadd L
.35905 .26573 0 2.5 Mabsadd L closepath F
.36286 .24285 0 2.5 Mabsadd m
.36286 .24285 -0.56518 .7779 Mabsadd L
.36286 .24285 -2.37764 .77254 Mabsadd L
.36286 .24285 -0.91448 -0.29713 Mabsadd L
.36286 .24285 -1.46946 -2.02254 Mabsadd L
.36286 .24285 0 -0.96154 Mabsadd L
.36286 .24285 1.46946 -2.02254 Mabsadd L
.36286 .24285 .91448 -0.29713 Mabsadd L
.36286 .24285 2.37764 .77254 Mabsadd L
.36286 .24285 .56518 .7779 Mabsadd L
.36286 .24285 0 2.5 Mabsadd L closepath F
.36667 .2211 0 2.5 Mabsadd m
.36667 .2211 -0.56518 .7779 Mabsadd L
.36667 .2211 -2.37764 .77254 Mabsadd L
.36667 .2211 -0.91448 -0.29713 Mabsadd L
.36667 .2211 -1.46946 -2.02254 Mabsadd L
.36667 .2211 0 -0.96154 Mabsadd L
.36667 .2211 1.46946 -2.02254 Mabsadd L
.36667 .2211 .91448 -0.29713 Mabsadd L
.36667 .2211 2.37764 .77254 Mabsadd L
.36667 .2211 .56518 .7779 Mabsadd L
.36667 .2211 0 2.5 Mabsadd L closepath F
.37048 .20317 0 2.5 Mabsadd m
.37048 .20317 -0.56518 .7779 Mabsadd L
.37048 .20317 -2.37764 .77254 Mabsadd L
.37048 .20317 -0.91448 -0.29713 Mabsadd L
.37048 .20317 -1.46946 -2.02254 Mabsadd L
.37048 .20317 0 -0.96154 Mabsadd L
.37048 .20317 1.46946 -2.02254 Mabsadd L
.37048 .20317 .91448 -0.29713 Mabsadd L
.37048 .20317 2.37764 .77254 Mabsadd L
.37048 .20317 .56518 .7779 Mabsadd L
.37048 .20317 0 2.5 Mabsadd L closepath F
.37429 .19051 0 2.5 Mabsadd m
.37429 .19051 -0.56518 .7779 Mabsadd L
.37429 .19051 -2.37764 .77254 Mabsadd L
.37429 .19051 -0.91448 -0.29713 Mabsadd L
.37429 .19051 -1.46946 -2.02254 Mabsadd L
.37429 .19051 0 -0.96154 Mabsadd L
.37429 .19051 1.46946 -2.02254 Mabsadd L
.37429 .19051 .91448 -0.29713 Mabsadd L
.37429 .19051 2.37764 .77254 Mabsadd L
.37429 .19051 .56518 .7779 Mabsadd L
.37429 .19051 0 2.5 Mabsadd L closepath F
.3781 .18314 0 2.5 Mabsadd m
.3781 .18314 -0.56518 .7779 Mabsadd L
.3781 .18314 -2.37764 .77254 Mabsadd L
.3781 .18314 -0.91448 -0.29713 Mabsadd L
.3781 .18314 -1.46946 -2.02254 Mabsadd L
.3781 .18314 0 -0.96154 Mabsadd L
.3781 .18314 1.46946 -2.02254 Mabsadd L
.3781 .18314 .91448 -0.29713 Mabsadd L
.3781 .18314 2.37764 .77254 Mabsadd L
.3781 .18314 .56518 .7779 Mabsadd L
.3781 .18314 0 2.5 Mabsadd L closepath F
.3819 .18039 0 2.5 Mabsadd m
.3819 .18039 -0.56518 .7779 Mabsadd L
.3819 .18039 -2.37764 .77254 Mabsadd L
.3819 .18039 -0.91448 -0.29713 Mabsadd L
.3819 .18039 -1.46946 -2.02254 Mabsadd L
.3819 .18039 0 -0.96154 Mabsadd L
.3819 .18039 1.46946 -2.02254 Mabsadd L
.3819 .18039 .91448 -0.29713 Mabsadd L
.3819 .18039 2.37764 .77254 Mabsadd L
.3819 .18039 .56518 .7779 Mabsadd L
.3819 .18039 0 2.5 Mabsadd L closepath F
.38571 .18224 0 2.5 Mabsadd m
.38571 .18224 -0.56518 .7779 Mabsadd L
.38571 .18224 -2.37764 .77254 Mabsadd L
.38571 .18224 -0.91448 -0.29713 Mabsadd L
.38571 .18224 -1.46946 -2.02254 Mabsadd L
.38571 .18224 0 -0.96154 Mabsadd L
.38571 .18224 1.46946 -2.02254 Mabsadd L
.38571 .18224 .91448 -0.29713 Mabsadd L
.38571 .18224 2.37764 .77254 Mabsadd L
.38571 .18224 .56518 .7779 Mabsadd L
.38571 .18224 0 2.5 Mabsadd L closepath F
.38952 .19007 0 2.5 Mabsadd m
.38952 .19007 -0.56518 .7779 Mabsadd L
.38952 .19007 -2.37764 .77254 Mabsadd L
.38952 .19007 -0.91448 -0.29713 Mabsadd L
.38952 .19007 -1.46946 -2.02254 Mabsadd L
.38952 .19007 0 -0.96154 Mabsadd L
.38952 .19007 1.46946 -2.02254 Mabsadd L
.38952 .19007 .91448 -0.29713 Mabsadd L
.38952 .19007 2.37764 .77254 Mabsadd L
.38952 .19007 .56518 .7779 Mabsadd L
.38952 .19007 0 2.5 Mabsadd L closepath F
.39333 .20609 0 2.5 Mabsadd m
.39333 .20609 -0.56518 .7779 Mabsadd L
.39333 .20609 -2.37764 .77254 Mabsadd L
.39333 .20609 -0.91448 -0.29713 Mabsadd L
.39333 .20609 -1.46946 -2.02254 Mabsadd L
.39333 .20609 0 -0.96154 Mabsadd L
.39333 .20609 1.46946 -2.02254 Mabsadd L
.39333 .20609 .91448 -0.29713 Mabsadd L
.39333 .20609 2.37764 .77254 Mabsadd L
.39333 .20609 .56518 .7779 Mabsadd L
.39333 .20609 0 2.5 Mabsadd L closepath F
.39714 .23192 0 2.5 Mabsadd m
.39714 .23192 -0.56518 .7779 Mabsadd L
.39714 .23192 -2.37764 .77254 Mabsadd L
.39714 .23192 -0.91448 -0.29713 Mabsadd L
.39714 .23192 -1.46946 -2.02254 Mabsadd L
.39714 .23192 0 -0.96154 Mabsadd L
.39714 .23192 1.46946 -2.02254 Mabsadd L
.39714 .23192 .91448 -0.29713 Mabsadd L
.39714 .23192 2.37764 .77254 Mabsadd L
.39714 .23192 .56518 .7779 Mabsadd L
.39714 .23192 0 2.5 Mabsadd L closepath F
.40095 .26749 0 2.5 Mabsadd m
.40095 .26749 -0.56518 .7779 Mabsadd L
.40095 .26749 -2.37764 .77254 Mabsadd L
.40095 .26749 -0.91448 -0.29713 Mabsadd L
.40095 .26749 -1.46946 -2.02254 Mabsadd L
.40095 .26749 0 -0.96154 Mabsadd L
.40095 .26749 1.46946 -2.02254 Mabsadd L
.40095 .26749 .91448 -0.29713 Mabsadd L
.40095 .26749 2.37764 .77254 Mabsadd L
.40095 .26749 .56518 .7779 Mabsadd L
.40095 .26749 0 2.5 Mabsadd L closepath F
.40476 .3107 0 2.5 Mabsadd m
.40476 .3107 -0.56518 .7779 Mabsadd L
.40476 .3107 -2.37764 .77254 Mabsadd L
.40476 .3107 -0.91448 -0.29713 Mabsadd L
.40476 .3107 -1.46946 -2.02254 Mabsadd L
.40476 .3107 0 -0.96154 Mabsadd L
.40476 .3107 1.46946 -2.02254 Mabsadd L
.40476 .3107 .91448 -0.29713 Mabsadd L
.40476 .3107 2.37764 .77254 Mabsadd L
.40476 .3107 .56518 .7779 Mabsadd L
.40476 .3107 0 2.5 Mabsadd L closepath F
.40857 .358 0 2.5 Mabsadd m
.40857 .358 -0.56518 .7779 Mabsadd L
.40857 .358 -2.37764 .77254 Mabsadd L
.40857 .358 -0.91448 -0.29713 Mabsadd L
.40857 .358 -1.46946 -2.02254 Mabsadd L
.40857 .358 0 -0.96154 Mabsadd L
.40857 .358 1.46946 -2.02254 Mabsadd L
.40857 .358 .91448 -0.29713 Mabsadd L
.40857 .358 2.37764 .77254 Mabsadd L
.40857 .358 .56518 .7779 Mabsadd L
.40857 .358 0 2.5 Mabsadd L closepath F
.41238 .40575 0 2.5 Mabsadd m
.41238 .40575 -0.56518 .7779 Mabsadd L
.41238 .40575 -2.37764 .77254 Mabsadd L
.41238 .40575 -0.91448 -0.29713 Mabsadd L
.41238 .40575 -1.46946 -2.02254 Mabsadd L
.41238 .40575 0 -0.96154 Mabsadd L
.41238 .40575 1.46946 -2.02254 Mabsadd L
.41238 .40575 .91448 -0.29713 Mabsadd L
.41238 .40575 2.37764 .77254 Mabsadd L
.41238 .40575 .56518 .7779 Mabsadd L
.41238 .40575 0 2.5 Mabsadd L closepath F
.41619 .45128 0 2.5 Mabsadd m
.41619 .45128 -0.56518 .7779 Mabsadd L
.41619 .45128 -2.37764 .77254 Mabsadd L
.41619 .45128 -0.91448 -0.29713 Mabsadd L
.41619 .45128 -1.46946 -2.02254 Mabsadd L
.41619 .45128 0 -0.96154 Mabsadd L
.41619 .45128 1.46946 -2.02254 Mabsadd L
.41619 .45128 .91448 -0.29713 Mabsadd L
.41619 .45128 2.37764 .77254 Mabsadd L
.41619 .45128 .56518 .7779 Mabsadd L
.41619 .45128 0 2.5 Mabsadd L closepath F
.42 .49273 0 2.5 Mabsadd m
.42 .49273 -0.56518 .7779 Mabsadd L
.42 .49273 -2.37764 .77254 Mabsadd L
.42 .49273 -0.91448 -0.29713 Mabsadd L
.42 .49273 -1.46946 -2.02254 Mabsadd L
.42 .49273 0 -0.96154 Mabsadd L
.42 .49273 1.46946 -2.02254 Mabsadd L
.42 .49273 .91448 -0.29713 Mabsadd L
.42 .49273 2.37764 .77254 Mabsadd L
.42 .49273 .56518 .7779 Mabsadd L
.42 .49273 0 2.5 Mabsadd L closepath F
.42381 .52811 0 2.5 Mabsadd m
.42381 .52811 -0.56518 .7779 Mabsadd L
.42381 .52811 -2.37764 .77254 Mabsadd L
.42381 .52811 -0.91448 -0.29713 Mabsadd L
.42381 .52811 -1.46946 -2.02254 Mabsadd L
.42381 .52811 0 -0.96154 Mabsadd L
.42381 .52811 1.46946 -2.02254 Mabsadd L
.42381 .52811 .91448 -0.29713 Mabsadd L
.42381 .52811 2.37764 .77254 Mabsadd L
.42381 .52811 .56518 .7779 Mabsadd L
.42381 .52811 0 2.5 Mabsadd L closepath F
.42762 .55478 0 2.5 Mabsadd m
.42762 .55478 -0.56518 .7779 Mabsadd L
.42762 .55478 -2.37764 .77254 Mabsadd L
.42762 .55478 -0.91448 -0.29713 Mabsadd L
.42762 .55478 -1.46946 -2.02254 Mabsadd L
.42762 .55478 0 -0.96154 Mabsadd L
.42762 .55478 1.46946 -2.02254 Mabsadd L
.42762 .55478 .91448 -0.29713 Mabsadd L
.42762 .55478 2.37764 .77254 Mabsadd L
.42762 .55478 .56518 .7779 Mabsadd L
.42762 .55478 0 2.5 Mabsadd L closepath F
.43143 .56983 0 2.5 Mabsadd m
.43143 .56983 -0.56518 .7779 Mabsadd L
.43143 .56983 -2.37764 .77254 Mabsadd L
.43143 .56983 -0.91448 -0.29713 Mabsadd L
.43143 .56983 -1.46946 -2.02254 Mabsadd L
.43143 .56983 0 -0.96154 Mabsadd L
.43143 .56983 1.46946 -2.02254 Mabsadd L
.43143 .56983 .91448 -0.29713 Mabsadd L
.43143 .56983 2.37764 .77254 Mabsadd L
.43143 .56983 .56518 .7779 Mabsadd L
.43143 .56983 0 2.5 Mabsadd L closepath F
.43524 .57108 0 2.5 Mabsadd m
.43524 .57108 -0.56518 .7779 Mabsadd L
.43524 .57108 -2.37764 .77254 Mabsadd L
.43524 .57108 -0.91448 -0.29713 Mabsadd L
.43524 .57108 -1.46946 -2.02254 Mabsadd L
.43524 .57108 0 -0.96154 Mabsadd L
.43524 .57108 1.46946 -2.02254 Mabsadd L
.43524 .57108 .91448 -0.29713 Mabsadd L
.43524 .57108 2.37764 .77254 Mabsadd L
.43524 .57108 .56518 .7779 Mabsadd L
.43524 .57108 0 2.5 Mabsadd L closepath F
.43905 .55798 0 2.5 Mabsadd m
.43905 .55798 -0.56518 .7779 Mabsadd L
.43905 .55798 -2.37764 .77254 Mabsadd L
.43905 .55798 -0.91448 -0.29713 Mabsadd L
.43905 .55798 -1.46946 -2.02254 Mabsadd L
.43905 .55798 0 -0.96154 Mabsadd L
.43905 .55798 1.46946 -2.02254 Mabsadd L
.43905 .55798 .91448 -0.29713 Mabsadd L
.43905 .55798 2.37764 .77254 Mabsadd L
.43905 .55798 .56518 .7779 Mabsadd L
.43905 .55798 0 2.5 Mabsadd L closepath F
.44286 .53156 0 2.5 Mabsadd m
.44286 .53156 -0.56518 .7779 Mabsadd L
.44286 .53156 -2.37764 .77254 Mabsadd L
.44286 .53156 -0.91448 -0.29713 Mabsadd L
.44286 .53156 -1.46946 -2.02254 Mabsadd L
.44286 .53156 0 -0.96154 Mabsadd L
.44286 .53156 1.46946 -2.02254 Mabsadd L
.44286 .53156 .91448 -0.29713 Mabsadd L
.44286 .53156 2.37764 .77254 Mabsadd L
.44286 .53156 .56518 .7779 Mabsadd L
.44286 .53156 0 2.5 Mabsadd L closepath F
.44667 .49354 0 2.5 Mabsadd m
.44667 .49354 -0.56518 .7779 Mabsadd L
.44667 .49354 -2.37764 .77254 Mabsadd L
.44667 .49354 -0.91448 -0.29713 Mabsadd L
.44667 .49354 -1.46946 -2.02254 Mabsadd L
.44667 .49354 0 -0.96154 Mabsadd L
.44667 .49354 1.46946 -2.02254 Mabsadd L
.44667 .49354 .91448 -0.29713 Mabsadd L
.44667 .49354 2.37764 .77254 Mabsadd L
.44667 .49354 .56518 .7779 Mabsadd L
.44667 .49354 0 2.5 Mabsadd L closepath F
.45048 .44557 0 2.5 Mabsadd m
.45048 .44557 -0.56518 .7779 Mabsadd L
.45048 .44557 -2.37764 .77254 Mabsadd L
.45048 .44557 -0.91448 -0.29713 Mabsadd L
.45048 .44557 -1.46946 -2.02254 Mabsadd L
.45048 .44557 0 -0.96154 Mabsadd L
.45048 .44557 1.46946 -2.02254 Mabsadd L
.45048 .44557 .91448 -0.29713 Mabsadd L
.45048 .44557 2.37764 .77254 Mabsadd L
.45048 .44557 .56518 .7779 Mabsadd L
.45048 .44557 0 2.5 Mabsadd L closepath F
.45429 .38935 0 2.5 Mabsadd m
.45429 .38935 -0.56518 .7779 Mabsadd L
.45429 .38935 -2.37764 .77254 Mabsadd L
.45429 .38935 -0.91448 -0.29713 Mabsadd L
.45429 .38935 -1.46946 -2.02254 Mabsadd L
.45429 .38935 0 -0.96154 Mabsadd L
.45429 .38935 1.46946 -2.02254 Mabsadd L
.45429 .38935 .91448 -0.29713 Mabsadd L
.45429 .38935 2.37764 .77254 Mabsadd L
.45429 .38935 .56518 .7779 Mabsadd L
.45429 .38935 0 2.5 Mabsadd L closepath F
.4581 .32732 0 2.5 Mabsadd m
.4581 .32732 -0.56518 .7779 Mabsadd L
.4581 .32732 -2.37764 .77254 Mabsadd L
.4581 .32732 -0.91448 -0.29713 Mabsadd L
.4581 .32732 -1.46946 -2.02254 Mabsadd L
.4581 .32732 0 -0.96154 Mabsadd L
.4581 .32732 1.46946 -2.02254 Mabsadd L
.4581 .32732 .91448 -0.29713 Mabsadd L
.4581 .32732 2.37764 .77254 Mabsadd L
.4581 .32732 .56518 .7779 Mabsadd L
.4581 .32732 0 2.5 Mabsadd L closepath F
.4619 .26306 0 2.5 Mabsadd m
.4619 .26306 -0.56518 .7779 Mabsadd L
.4619 .26306 -2.37764 .77254 Mabsadd L
.4619 .26306 -0.91448 -0.29713 Mabsadd L
.4619 .26306 -1.46946 -2.02254 Mabsadd L
.4619 .26306 0 -0.96154 Mabsadd L
.4619 .26306 1.46946 -2.02254 Mabsadd L
.4619 .26306 .91448 -0.29713 Mabsadd L
.4619 .26306 2.37764 .77254 Mabsadd L
.4619 .26306 .56518 .7779 Mabsadd L
.4619 .26306 0 2.5 Mabsadd L closepath F
.46571 .20074 0 2.5 Mabsadd m
.46571 .20074 -0.56518 .7779 Mabsadd L
.46571 .20074 -2.37764 .77254 Mabsadd L
.46571 .20074 -0.91448 -0.29713 Mabsadd L
.46571 .20074 -1.46946 -2.02254 Mabsadd L
.46571 .20074 0 -0.96154 Mabsadd L
.46571 .20074 1.46946 -2.02254 Mabsadd L
.46571 .20074 .91448 -0.29713 Mabsadd L
.46571 .20074 2.37764 .77254 Mabsadd L
.46571 .20074 .56518 .7779 Mabsadd L
.46571 .20074 0 2.5 Mabsadd L closepath F
.46952 .14394 0 2.5 Mabsadd m
.46952 .14394 -0.56518 .7779 Mabsadd L
.46952 .14394 -2.37764 .77254 Mabsadd L
.46952 .14394 -0.91448 -0.29713 Mabsadd L
.46952 .14394 -1.46946 -2.02254 Mabsadd L
.46952 .14394 0 -0.96154 Mabsadd L
.46952 .14394 1.46946 -2.02254 Mabsadd L
.46952 .14394 .91448 -0.29713 Mabsadd L
.46952 .14394 2.37764 .77254 Mabsadd L
.46952 .14394 .56518 .7779 Mabsadd L
.46952 .14394 0 2.5 Mabsadd L closepath F
.47333 .09514 0 2.5 Mabsadd m
.47333 .09514 -0.56518 .7779 Mabsadd L
.47333 .09514 -2.37764 .77254 Mabsadd L
.47333 .09514 -0.91448 -0.29713 Mabsadd L
.47333 .09514 -1.46946 -2.02254 Mabsadd L
.47333 .09514 0 -0.96154 Mabsadd L
.47333 .09514 1.46946 -2.02254 Mabsadd L
.47333 .09514 .91448 -0.29713 Mabsadd L
.47333 .09514 2.37764 .77254 Mabsadd L
.47333 .09514 .56518 .7779 Mabsadd L
.47333 .09514 0 2.5 Mabsadd L closepath F
.47714 .05613 0 2.5 Mabsadd m
.47714 .05613 -0.56518 .7779 Mabsadd L
.47714 .05613 -2.37764 .77254 Mabsadd L
.47714 .05613 -0.91448 -0.29713 Mabsadd L
.47714 .05613 -1.46946 -2.02254 Mabsadd L
.47714 .05613 0 -0.96154 Mabsadd L
.47714 .05613 1.46946 -2.02254 Mabsadd L
.47714 .05613 .91448 -0.29713 Mabsadd L
.47714 .05613 2.37764 .77254 Mabsadd L
.47714 .05613 .56518 .7779 Mabsadd L
.47714 .05613 0 2.5 Mabsadd L closepath F
.48095 .02869 0 2.5 Mabsadd m
.48095 .02869 -0.56518 .7779 Mabsadd L
.48095 .02869 -2.37764 .77254 Mabsadd L
.48095 .02869 -0.91448 -0.29713 Mabsadd L
.48095 .02869 -1.46946 -2.02254 Mabsadd L
.48095 .02869 0 -0.96154 Mabsadd L
.48095 .02869 1.46946 -2.02254 Mabsadd L
.48095 .02869 .91448 -0.29713 Mabsadd L
.48095 .02869 2.37764 .77254 Mabsadd L
.48095 .02869 .56518 .7779 Mabsadd L
.48095 .02869 0 2.5 Mabsadd L closepath F
.48476 .01472 0 2.5 Mabsadd m
.48476 .01472 -0.56518 .7779 Mabsadd L
.48476 .01472 -2.37764 .77254 Mabsadd L
.48476 .01472 -0.91448 -0.29713 Mabsadd L
.48476 .01472 -1.46946 -2.02254 Mabsadd L
.48476 .01472 0 -0.96154 Mabsadd L
.48476 .01472 1.46946 -2.02254 Mabsadd L
.48476 .01472 .91448 -0.29713 Mabsadd L
.48476 .01472 2.37764 .77254 Mabsadd L
.48476 .01472 .56518 .7779 Mabsadd L
.48476 .01472 0 2.5 Mabsadd L closepath F
.48857 .0156 0 2.5 Mabsadd m
.48857 .0156 -0.56518 .7779 Mabsadd L
.48857 .0156 -2.37764 .77254 Mabsadd L
.48857 .0156 -0.91448 -0.29713 Mabsadd L
.48857 .0156 -1.46946 -2.02254 Mabsadd L
.48857 .0156 0 -0.96154 Mabsadd L
.48857 .0156 1.46946 -2.02254 Mabsadd L
.48857 .0156 .91448 -0.29713 Mabsadd L
.48857 .0156 2.37764 .77254 Mabsadd L
.48857 .0156 .56518 .7779 Mabsadd L
.48857 .0156 0 2.5 Mabsadd L closepath F
.49238 .03136 0 2.5 Mabsadd m
.49238 .03136 -0.56518 .7779 Mabsadd L
.49238 .03136 -2.37764 .77254 Mabsadd L
.49238 .03136 -0.91448 -0.29713 Mabsadd L
.49238 .03136 -1.46946 -2.02254 Mabsadd L
.49238 .03136 0 -0.96154 Mabsadd L
.49238 .03136 1.46946 -2.02254 Mabsadd L
.49238 .03136 .91448 -0.29713 Mabsadd L
.49238 .03136 2.37764 .77254 Mabsadd L
.49238 .03136 .56518 .7779 Mabsadd L
.49238 .03136 0 2.5 Mabsadd L closepath F
.49619 .06064 0 2.5 Mabsadd m
.49619 .06064 -0.56518 .7779 Mabsadd L
.49619 .06064 -2.37764 .77254 Mabsadd L
.49619 .06064 -0.91448 -0.29713 Mabsadd L
.49619 .06064 -1.46946 -2.02254 Mabsadd L
.49619 .06064 0 -0.96154 Mabsadd L
.49619 .06064 1.46946 -2.02254 Mabsadd L
.49619 .06064 .91448 -0.29713 Mabsadd L
.49619 .06064 2.37764 .77254 Mabsadd L
.49619 .06064 .56518 .7779 Mabsadd L
.49619 .06064 0 2.5 Mabsadd L closepath F
.5 .10154 0 2.5 Mabsadd m
.5 .10154 -0.56518 .7779 Mabsadd L
.5 .10154 -2.37764 .77254 Mabsadd L
.5 .10154 -0.91448 -0.29713 Mabsadd L
.5 .10154 -1.46946 -2.02254 Mabsadd L
.5 .10154 0 -0.96154 Mabsadd L
.5 .10154 1.46946 -2.02254 Mabsadd L
.5 .10154 .91448 -0.29713 Mabsadd L
.5 .10154 2.37764 .77254 Mabsadd L
.5 .10154 .56518 .7779 Mabsadd L
.5 .10154 0 2.5 Mabsadd L closepath F
.50381 .15231 0 2.5 Mabsadd m
.50381 .15231 -0.56518 .7779 Mabsadd L
.50381 .15231 -2.37764 .77254 Mabsadd L
.50381 .15231 -0.91448 -0.29713 Mabsadd L
.50381 .15231 -1.46946 -2.02254 Mabsadd L
.50381 .15231 0 -0.96154 Mabsadd L
.50381 .15231 1.46946 -2.02254 Mabsadd L
.50381 .15231 .91448 -0.29713 Mabsadd L
.50381 .15231 2.37764 .77254 Mabsadd L
.50381 .15231 .56518 .7779 Mabsadd L
.50381 .15231 0 2.5 Mabsadd L closepath F
.50762 .21118 0 2.5 Mabsadd m
.50762 .21118 -0.56518 .7779 Mabsadd L
.50762 .21118 -2.37764 .77254 Mabsadd L
.50762 .21118 -0.91448 -0.29713 Mabsadd L
.50762 .21118 -1.46946 -2.02254 Mabsadd L
.50762 .21118 0 -0.96154 Mabsadd L
.50762 .21118 1.46946 -2.02254 Mabsadd L
.50762 .21118 .91448 -0.29713 Mabsadd L
.50762 .21118 2.37764 .77254 Mabsadd L
.50762 .21118 .56518 .7779 Mabsadd L
.50762 .21118 0 2.5 Mabsadd L closepath F
.51143 .27571 0 2.5 Mabsadd m
.51143 .27571 -0.56518 .7779 Mabsadd L
.51143 .27571 -2.37764 .77254 Mabsadd L
.51143 .27571 -0.91448 -0.29713 Mabsadd L
.51143 .27571 -1.46946 -2.02254 Mabsadd L
.51143 .27571 0 -0.96154 Mabsadd L
.51143 .27571 1.46946 -2.02254 Mabsadd L
.51143 .27571 .91448 -0.29713 Mabsadd L
.51143 .27571 2.37764 .77254 Mabsadd L
.51143 .27571 .56518 .7779 Mabsadd L
.51143 .27571 0 2.5 Mabsadd L closepath F
.51524 .34232 0 2.5 Mabsadd m
.51524 .34232 -0.56518 .7779 Mabsadd L
.51524 .34232 -2.37764 .77254 Mabsadd L
.51524 .34232 -0.91448 -0.29713 Mabsadd L
.51524 .34232 -1.46946 -2.02254 Mabsadd L
.51524 .34232 0 -0.96154 Mabsadd L
.51524 .34232 1.46946 -2.02254 Mabsadd L
.51524 .34232 .91448 -0.29713 Mabsadd L
.51524 .34232 2.37764 .77254 Mabsadd L
.51524 .34232 .56518 .7779 Mabsadd L
.51524 .34232 0 2.5 Mabsadd L closepath F
.51905 .40685 0 2.5 Mabsadd m
.51905 .40685 -0.56518 .7779 Mabsadd L
.51905 .40685 -2.37764 .77254 Mabsadd L
.51905 .40685 -0.91448 -0.29713 Mabsadd L
.51905 .40685 -1.46946 -2.02254 Mabsadd L
.51905 .40685 0 -0.96154 Mabsadd L
.51905 .40685 1.46946 -2.02254 Mabsadd L
.51905 .40685 .91448 -0.29713 Mabsadd L
.51905 .40685 2.37764 .77254 Mabsadd L
.51905 .40685 .56518 .7779 Mabsadd L
.51905 .40685 0 2.5 Mabsadd L closepath F
.52286 .46573 0 2.5 Mabsadd m
.52286 .46573 -0.56518 .7779 Mabsadd L
.52286 .46573 -2.37764 .77254 Mabsadd L
.52286 .46573 -0.91448 -0.29713 Mabsadd L
.52286 .46573 -1.46946 -2.02254 Mabsadd L
.52286 .46573 0 -0.96154 Mabsadd L
.52286 .46573 1.46946 -2.02254 Mabsadd L
.52286 .46573 .91448 -0.29713 Mabsadd L
.52286 .46573 2.37764 .77254 Mabsadd L
.52286 .46573 .56518 .7779 Mabsadd L
.52286 .46573 0 2.5 Mabsadd L closepath F
.52667 .5165 0 2.5 Mabsadd m
.52667 .5165 -0.56518 .7779 Mabsadd L
.52667 .5165 -2.37764 .77254 Mabsadd L
.52667 .5165 -0.91448 -0.29713 Mabsadd L
.52667 .5165 -1.46946 -2.02254 Mabsadd L
.52667 .5165 0 -0.96154 Mabsadd L
.52667 .5165 1.46946 -2.02254 Mabsadd L
.52667 .5165 .91448 -0.29713 Mabsadd L
.52667 .5165 2.37764 .77254 Mabsadd L
.52667 .5165 .56518 .7779 Mabsadd L
.52667 .5165 0 2.5 Mabsadd L closepath F
.53048 .55739 0 2.5 Mabsadd m
.53048 .55739 -0.56518 .7779 Mabsadd L
.53048 .55739 -2.37764 .77254 Mabsadd L
.53048 .55739 -0.91448 -0.29713 Mabsadd L
.53048 .55739 -1.46946 -2.02254 Mabsadd L
.53048 .55739 0 -0.96154 Mabsadd L
.53048 .55739 1.46946 -2.02254 Mabsadd L
.53048 .55739 .91448 -0.29713 Mabsadd L
.53048 .55739 2.37764 .77254 Mabsadd L
.53048 .55739 .56518 .7779 Mabsadd L
.53048 .55739 0 2.5 Mabsadd L closepath F
.53429 .58667 0 2.5 Mabsadd m
.53429 .58667 -0.56518 .7779 Mabsadd L
.53429 .58667 -2.37764 .77254 Mabsadd L
.53429 .58667 -0.91448 -0.29713 Mabsadd L
.53429 .58667 -1.46946 -2.02254 Mabsadd L
.53429 .58667 0 -0.96154 Mabsadd L
.53429 .58667 1.46946 -2.02254 Mabsadd L
.53429 .58667 .91448 -0.29713 Mabsadd L
.53429 .58667 2.37764 .77254 Mabsadd L
.53429 .58667 .56518 .7779 Mabsadd L
.53429 .58667 0 2.5 Mabsadd L closepath F
.5381 .60243 0 2.5 Mabsadd m
.5381 .60243 -0.56518 .7779 Mabsadd L
.5381 .60243 -2.37764 .77254 Mabsadd L
.5381 .60243 -0.91448 -0.29713 Mabsadd L
.5381 .60243 -1.46946 -2.02254 Mabsadd L
.5381 .60243 0 -0.96154 Mabsadd L
.5381 .60243 1.46946 -2.02254 Mabsadd L
.5381 .60243 .91448 -0.29713 Mabsadd L
.5381 .60243 2.37764 .77254 Mabsadd L
.5381 .60243 .56518 .7779 Mabsadd L
.5381 .60243 0 2.5 Mabsadd L closepath F
.5419 .60332 0 2.5 Mabsadd m
.5419 .60332 -0.56518 .7779 Mabsadd L
.5419 .60332 -2.37764 .77254 Mabsadd L
.5419 .60332 -0.91448 -0.29713 Mabsadd L
.5419 .60332 -1.46946 -2.02254 Mabsadd L
.5419 .60332 0 -0.96154 Mabsadd L
.5419 .60332 1.46946 -2.02254 Mabsadd L
.5419 .60332 .91448 -0.29713 Mabsadd L
.5419 .60332 2.37764 .77254 Mabsadd L
.5419 .60332 .56518 .7779 Mabsadd L
.5419 .60332 0 2.5 Mabsadd L closepath F
.54571 .58935 0 2.5 Mabsadd m
.54571 .58935 -0.56518 .7779 Mabsadd L
.54571 .58935 -2.37764 .77254 Mabsadd L
.54571 .58935 -0.91448 -0.29713 Mabsadd L
.54571 .58935 -1.46946 -2.02254 Mabsadd L
.54571 .58935 0 -0.96154 Mabsadd L
.54571 .58935 1.46946 -2.02254 Mabsadd L
.54571 .58935 .91448 -0.29713 Mabsadd L
.54571 .58935 2.37764 .77254 Mabsadd L
.54571 .58935 .56518 .7779 Mabsadd L
.54571 .58935 0 2.5 Mabsadd L closepath F
.54952 .5619 0 2.5 Mabsadd m
.54952 .5619 -0.56518 .7779 Mabsadd L
.54952 .5619 -2.37764 .77254 Mabsadd L
.54952 .5619 -0.91448 -0.29713 Mabsadd L
.54952 .5619 -1.46946 -2.02254 Mabsadd L
.54952 .5619 0 -0.96154 Mabsadd L
.54952 .5619 1.46946 -2.02254 Mabsadd L
.54952 .5619 .91448 -0.29713 Mabsadd L
.54952 .5619 2.37764 .77254 Mabsadd L
.54952 .5619 .56518 .7779 Mabsadd L
.54952 .5619 0 2.5 Mabsadd L closepath F
.55333 .52289 0 2.5 Mabsadd m
.55333 .52289 -0.56518 .7779 Mabsadd L
.55333 .52289 -2.37764 .77254 Mabsadd L
.55333 .52289 -0.91448 -0.29713 Mabsadd L
.55333 .52289 -1.46946 -2.02254 Mabsadd L
.55333 .52289 0 -0.96154 Mabsadd L
.55333 .52289 1.46946 -2.02254 Mabsadd L
.55333 .52289 .91448 -0.29713 Mabsadd L
.55333 .52289 2.37764 .77254 Mabsadd L
.55333 .52289 .56518 .7779 Mabsadd L
.55333 .52289 0 2.5 Mabsadd L closepath F
.55714 .4741 0 2.5 Mabsadd m
.55714 .4741 -0.56518 .7779 Mabsadd L
.55714 .4741 -2.37764 .77254 Mabsadd L
.55714 .4741 -0.91448 -0.29713 Mabsadd L
.55714 .4741 -1.46946 -2.02254 Mabsadd L
.55714 .4741 0 -0.96154 Mabsadd L
.55714 .4741 1.46946 -2.02254 Mabsadd L
.55714 .4741 .91448 -0.29713 Mabsadd L
.55714 .4741 2.37764 .77254 Mabsadd L
.55714 .4741 .56518 .7779 Mabsadd L
.55714 .4741 0 2.5 Mabsadd L closepath F
.56095 .4173 0 2.5 Mabsadd m
.56095 .4173 -0.56518 .7779 Mabsadd L
.56095 .4173 -2.37764 .77254 Mabsadd L
.56095 .4173 -0.91448 -0.29713 Mabsadd L
.56095 .4173 -1.46946 -2.02254 Mabsadd L
.56095 .4173 0 -0.96154 Mabsadd L
.56095 .4173 1.46946 -2.02254 Mabsadd L
.56095 .4173 .91448 -0.29713 Mabsadd L
.56095 .4173 2.37764 .77254 Mabsadd L
.56095 .4173 .56518 .7779 Mabsadd L
.56095 .4173 0 2.5 Mabsadd L closepath F
.56476 .35497 0 2.5 Mabsadd m
.56476 .35497 -0.56518 .7779 Mabsadd L
.56476 .35497 -2.37764 .77254 Mabsadd L
.56476 .35497 -0.91448 -0.29713 Mabsadd L
.56476 .35497 -1.46946 -2.02254 Mabsadd L
.56476 .35497 0 -0.96154 Mabsadd L
.56476 .35497 1.46946 -2.02254 Mabsadd L
.56476 .35497 .91448 -0.29713 Mabsadd L
.56476 .35497 2.37764 .77254 Mabsadd L
.56476 .35497 .56518 .7779 Mabsadd L
.56476 .35497 0 2.5 Mabsadd L closepath F
.56857 .29071 0 2.5 Mabsadd m
.56857 .29071 -0.56518 .7779 Mabsadd L
.56857 .29071 -2.37764 .77254 Mabsadd L
.56857 .29071 -0.91448 -0.29713 Mabsadd L
.56857 .29071 -1.46946 -2.02254 Mabsadd L
.56857 .29071 0 -0.96154 Mabsadd L
.56857 .29071 1.46946 -2.02254 Mabsadd L
.56857 .29071 .91448 -0.29713 Mabsadd L
.56857 .29071 2.37764 .77254 Mabsadd L
.56857 .29071 .56518 .7779 Mabsadd L
.56857 .29071 0 2.5 Mabsadd L closepath F
.57238 .22869 0 2.5 Mabsadd m
.57238 .22869 -0.56518 .7779 Mabsadd L
.57238 .22869 -2.37764 .77254 Mabsadd L
.57238 .22869 -0.91448 -0.29713 Mabsadd L
.57238 .22869 -1.46946 -2.02254 Mabsadd L
.57238 .22869 0 -0.96154 Mabsadd L
.57238 .22869 1.46946 -2.02254 Mabsadd L
.57238 .22869 .91448 -0.29713 Mabsadd L
.57238 .22869 2.37764 .77254 Mabsadd L
.57238 .22869 .56518 .7779 Mabsadd L
.57238 .22869 0 2.5 Mabsadd L closepath F
.57619 .17247 0 2.5 Mabsadd m
.57619 .17247 -0.56518 .7779 Mabsadd L
.57619 .17247 -2.37764 .77254 Mabsadd L
.57619 .17247 -0.91448 -0.29713 Mabsadd L
.57619 .17247 -1.46946 -2.02254 Mabsadd L
.57619 .17247 0 -0.96154 Mabsadd L
.57619 .17247 1.46946 -2.02254 Mabsadd L
.57619 .17247 .91448 -0.29713 Mabsadd L
.57619 .17247 2.37764 .77254 Mabsadd L
.57619 .17247 .56518 .7779 Mabsadd L
.57619 .17247 0 2.5 Mabsadd L closepath F
.58 .12449 0 2.5 Mabsadd m
.58 .12449 -0.56518 .7779 Mabsadd L
.58 .12449 -2.37764 .77254 Mabsadd L
.58 .12449 -0.91448 -0.29713 Mabsadd L
.58 .12449 -1.46946 -2.02254 Mabsadd L
.58 .12449 0 -0.96154 Mabsadd L
.58 .12449 1.46946 -2.02254 Mabsadd L
.58 .12449 .91448 -0.29713 Mabsadd L
.58 .12449 2.37764 .77254 Mabsadd L
.58 .12449 .56518 .7779 Mabsadd L
.58 .12449 0 2.5 Mabsadd L closepath F
.58381 .08647 0 2.5 Mabsadd m
.58381 .08647 -0.56518 .7779 Mabsadd L
.58381 .08647 -2.37764 .77254 Mabsadd L
.58381 .08647 -0.91448 -0.29713 Mabsadd L
.58381 .08647 -1.46946 -2.02254 Mabsadd L
.58381 .08647 0 -0.96154 Mabsadd L
.58381 .08647 1.46946 -2.02254 Mabsadd L
.58381 .08647 .91448 -0.29713 Mabsadd L
.58381 .08647 2.37764 .77254 Mabsadd L
.58381 .08647 .56518 .7779 Mabsadd L
.58381 .08647 0 2.5 Mabsadd L closepath F
.58762 .06006 0 2.5 Mabsadd m
.58762 .06006 -0.56518 .7779 Mabsadd L
.58762 .06006 -2.37764 .77254 Mabsadd L
.58762 .06006 -0.91448 -0.29713 Mabsadd L
.58762 .06006 -1.46946 -2.02254 Mabsadd L
.58762 .06006 0 -0.96154 Mabsadd L
.58762 .06006 1.46946 -2.02254 Mabsadd L
.58762 .06006 .91448 -0.29713 Mabsadd L
.58762 .06006 2.37764 .77254 Mabsadd L
.58762 .06006 .56518 .7779 Mabsadd L
.58762 .06006 0 2.5 Mabsadd L closepath F
.59143 .04695 0 2.5 Mabsadd m
.59143 .04695 -0.56518 .7779 Mabsadd L
.59143 .04695 -2.37764 .77254 Mabsadd L
.59143 .04695 -0.91448 -0.29713 Mabsadd L
.59143 .04695 -1.46946 -2.02254 Mabsadd L
.59143 .04695 0 -0.96154 Mabsadd L
.59143 .04695 1.46946 -2.02254 Mabsadd L
.59143 .04695 .91448 -0.29713 Mabsadd L
.59143 .04695 2.37764 .77254 Mabsadd L
.59143 .04695 .56518 .7779 Mabsadd L
.59143 .04695 0 2.5 Mabsadd L closepath F
.59524 .0482 0 2.5 Mabsadd m
.59524 .0482 -0.56518 .7779 Mabsadd L
.59524 .0482 -2.37764 .77254 Mabsadd L
.59524 .0482 -0.91448 -0.29713 Mabsadd L
.59524 .0482 -1.46946 -2.02254 Mabsadd L
.59524 .0482 0 -0.96154 Mabsadd L
.59524 .0482 1.46946 -2.02254 Mabsadd L
.59524 .0482 .91448 -0.29713 Mabsadd L
.59524 .0482 2.37764 .77254 Mabsadd L
.59524 .0482 .56518 .7779 Mabsadd L
.59524 .0482 0 2.5 Mabsadd L closepath F
.59905 .06325 0 2.5 Mabsadd m
.59905 .06325 -0.56518 .7779 Mabsadd L
.59905 .06325 -2.37764 .77254 Mabsadd L
.59905 .06325 -0.91448 -0.29713 Mabsadd L
.59905 .06325 -1.46946 -2.02254 Mabsadd L
.59905 .06325 0 -0.96154 Mabsadd L
.59905 .06325 1.46946 -2.02254 Mabsadd L
.59905 .06325 .91448 -0.29713 Mabsadd L
.59905 .06325 2.37764 .77254 Mabsadd L
.59905 .06325 .56518 .7779 Mabsadd L
.59905 .06325 0 2.5 Mabsadd L closepath F
.60286 .08992 0 2.5 Mabsadd m
.60286 .08992 -0.56518 .7779 Mabsadd L
.60286 .08992 -2.37764 .77254 Mabsadd L
.60286 .08992 -0.91448 -0.29713 Mabsadd L
.60286 .08992 -1.46946 -2.02254 Mabsadd L
.60286 .08992 0 -0.96154 Mabsadd L
.60286 .08992 1.46946 -2.02254 Mabsadd L
.60286 .08992 .91448 -0.29713 Mabsadd L
.60286 .08992 2.37764 .77254 Mabsadd L
.60286 .08992 .56518 .7779 Mabsadd L
.60286 .08992 0 2.5 Mabsadd L closepath F
.60667 .1253 0 2.5 Mabsadd m
.60667 .1253 -0.56518 .7779 Mabsadd L
.60667 .1253 -2.37764 .77254 Mabsadd L
.60667 .1253 -0.91448 -0.29713 Mabsadd L
.60667 .1253 -1.46946 -2.02254 Mabsadd L
.60667 .1253 0 -0.96154 Mabsadd L
.60667 .1253 1.46946 -2.02254 Mabsadd L
.60667 .1253 .91448 -0.29713 Mabsadd L
.60667 .1253 2.37764 .77254 Mabsadd L
.60667 .1253 .56518 .7779 Mabsadd L
.60667 .1253 0 2.5 Mabsadd L closepath F
.61048 .16676 0 2.5 Mabsadd m
.61048 .16676 -0.56518 .7779 Mabsadd L
.61048 .16676 -2.37764 .77254 Mabsadd L
.61048 .16676 -0.91448 -0.29713 Mabsadd L
.61048 .16676 -1.46946 -2.02254 Mabsadd L
.61048 .16676 0 -0.96154 Mabsadd L
.61048 .16676 1.46946 -2.02254 Mabsadd L
.61048 .16676 .91448 -0.29713 Mabsadd L
.61048 .16676 2.37764 .77254 Mabsadd L
.61048 .16676 .56518 .7779 Mabsadd L
.61048 .16676 0 2.5 Mabsadd L closepath F
.61429 .21229 0 2.5 Mabsadd m
.61429 .21229 -0.56518 .7779 Mabsadd L
.61429 .21229 -2.37764 .77254 Mabsadd L
.61429 .21229 -0.91448 -0.29713 Mabsadd L
.61429 .21229 -1.46946 -2.02254 Mabsadd L
.61429 .21229 0 -0.96154 Mabsadd L
.61429 .21229 1.46946 -2.02254 Mabsadd L
.61429 .21229 .91448 -0.29713 Mabsadd L
.61429 .21229 2.37764 .77254 Mabsadd L
.61429 .21229 .56518 .7779 Mabsadd L
.61429 .21229 0 2.5 Mabsadd L closepath F
.6181 .26004 0 2.5 Mabsadd m
.6181 .26004 -0.56518 .7779 Mabsadd L
.6181 .26004 -2.37764 .77254 Mabsadd L
.6181 .26004 -0.91448 -0.29713 Mabsadd L
.6181 .26004 -1.46946 -2.02254 Mabsadd L
.6181 .26004 0 -0.96154 Mabsadd L
.6181 .26004 1.46946 -2.02254 Mabsadd L
.6181 .26004 .91448 -0.29713 Mabsadd L
.6181 .26004 2.37764 .77254 Mabsadd L
.6181 .26004 .56518 .7779 Mabsadd L
.6181 .26004 0 2.5 Mabsadd L closepath F
.6219 .30734 0 2.5 Mabsadd m
.6219 .30734 -0.56518 .7779 Mabsadd L
.6219 .30734 -2.37764 .77254 Mabsadd L
.6219 .30734 -0.91448 -0.29713 Mabsadd L
.6219 .30734 -1.46946 -2.02254 Mabsadd L
.6219 .30734 0 -0.96154 Mabsadd L
.6219 .30734 1.46946 -2.02254 Mabsadd L
.6219 .30734 .91448 -0.29713 Mabsadd L
.6219 .30734 2.37764 .77254 Mabsadd L
.6219 .30734 .56518 .7779 Mabsadd L
.6219 .30734 0 2.5 Mabsadd L closepath F
.62571 .35055 0 2.5 Mabsadd m
.62571 .35055 -0.56518 .7779 Mabsadd L
.62571 .35055 -2.37764 .77254 Mabsadd L
.62571 .35055 -0.91448 -0.29713 Mabsadd L
.62571 .35055 -1.46946 -2.02254 Mabsadd L
.62571 .35055 0 -0.96154 Mabsadd L
.62571 .35055 1.46946 -2.02254 Mabsadd L
.62571 .35055 .91448 -0.29713 Mabsadd L
.62571 .35055 2.37764 .77254 Mabsadd L
.62571 .35055 .56518 .7779 Mabsadd L
.62571 .35055 0 2.5 Mabsadd L closepath F
.62952 .38611 0 2.5 Mabsadd m
.62952 .38611 -0.56518 .7779 Mabsadd L
.62952 .38611 -2.37764 .77254 Mabsadd L
.62952 .38611 -0.91448 -0.29713 Mabsadd L
.62952 .38611 -1.46946 -2.02254 Mabsadd L
.62952 .38611 0 -0.96154 Mabsadd L
.62952 .38611 1.46946 -2.02254 Mabsadd L
.62952 .38611 .91448 -0.29713 Mabsadd L
.62952 .38611 2.37764 .77254 Mabsadd L
.62952 .38611 .56518 .7779 Mabsadd L
.62952 .38611 0 2.5 Mabsadd L closepath F
.63333 .41194 0 2.5 Mabsadd m
.63333 .41194 -0.56518 .7779 Mabsadd L
.63333 .41194 -2.37764 .77254 Mabsadd L
.63333 .41194 -0.91448 -0.29713 Mabsadd L
.63333 .41194 -1.46946 -2.02254 Mabsadd L
.63333 .41194 0 -0.96154 Mabsadd L
.63333 .41194 1.46946 -2.02254 Mabsadd L
.63333 .41194 .91448 -0.29713 Mabsadd L
.63333 .41194 2.37764 .77254 Mabsadd L
.63333 .41194 .56518 .7779 Mabsadd L
.63333 .41194 0 2.5 Mabsadd L closepath F
.63714 .42796 0 2.5 Mabsadd m
.63714 .42796 -0.56518 .7779 Mabsadd L
.63714 .42796 -2.37764 .77254 Mabsadd L
.63714 .42796 -0.91448 -0.29713 Mabsadd L
.63714 .42796 -1.46946 -2.02254 Mabsadd L
.63714 .42796 0 -0.96154 Mabsadd L
.63714 .42796 1.46946 -2.02254 Mabsadd L
.63714 .42796 .91448 -0.29713 Mabsadd L
.63714 .42796 2.37764 .77254 Mabsadd L
.63714 .42796 .56518 .7779 Mabsadd L
.63714 .42796 0 2.5 Mabsadd L closepath F
.64095 .4358 0 2.5 Mabsadd m
.64095 .4358 -0.56518 .7779 Mabsadd L
.64095 .4358 -2.37764 .77254 Mabsadd L
.64095 .4358 -0.91448 -0.29713 Mabsadd L
.64095 .4358 -1.46946 -2.02254 Mabsadd L
.64095 .4358 0 -0.96154 Mabsadd L
.64095 .4358 1.46946 -2.02254 Mabsadd L
.64095 .4358 .91448 -0.29713 Mabsadd L
.64095 .4358 2.37764 .77254 Mabsadd L
.64095 .4358 .56518 .7779 Mabsadd L
.64095 .4358 0 2.5 Mabsadd L closepath F
.64476 .43764 0 2.5 Mabsadd m
.64476 .43764 -0.56518 .7779 Mabsadd L
.64476 .43764 -2.37764 .77254 Mabsadd L
.64476 .43764 -0.91448 -0.29713 Mabsadd L
.64476 .43764 -1.46946 -2.02254 Mabsadd L
.64476 .43764 0 -0.96154 Mabsadd L
.64476 .43764 1.46946 -2.02254 Mabsadd L
.64476 .43764 .91448 -0.29713 Mabsadd L
.64476 .43764 2.37764 .77254 Mabsadd L
.64476 .43764 .56518 .7779 Mabsadd L
.64476 .43764 0 2.5 Mabsadd L closepath F
.64857 .43489 0 2.5 Mabsadd m
.64857 .43489 -0.56518 .7779 Mabsadd L
.64857 .43489 -2.37764 .77254 Mabsadd L
.64857 .43489 -0.91448 -0.29713 Mabsadd L
.64857 .43489 -1.46946 -2.02254 Mabsadd L
.64857 .43489 0 -0.96154 Mabsadd L
.64857 .43489 1.46946 -2.02254 Mabsadd L
.64857 .43489 .91448 -0.29713 Mabsadd L
.64857 .43489 2.37764 .77254 Mabsadd L
.64857 .43489 .56518 .7779 Mabsadd L
.64857 .43489 0 2.5 Mabsadd L closepath F
.65238 .42752 0 2.5 Mabsadd m
.65238 .42752 -0.56518 .7779 Mabsadd L
.65238 .42752 -2.37764 .77254 Mabsadd L
.65238 .42752 -0.91448 -0.29713 Mabsadd L
.65238 .42752 -1.46946 -2.02254 Mabsadd L
.65238 .42752 0 -0.96154 Mabsadd L
.65238 .42752 1.46946 -2.02254 Mabsadd L
.65238 .42752 .91448 -0.29713 Mabsadd L
.65238 .42752 2.37764 .77254 Mabsadd L
.65238 .42752 .56518 .7779 Mabsadd L
.65238 .42752 0 2.5 Mabsadd L closepath F
.65619 .41487 0 2.5 Mabsadd m
.65619 .41487 -0.56518 .7779 Mabsadd L
.65619 .41487 -2.37764 .77254 Mabsadd L
.65619 .41487 -0.91448 -0.29713 Mabsadd L
.65619 .41487 -1.46946 -2.02254 Mabsadd L
.65619 .41487 0 -0.96154 Mabsadd L
.65619 .41487 1.46946 -2.02254 Mabsadd L
.65619 .41487 .91448 -0.29713 Mabsadd L
.65619 .41487 2.37764 .77254 Mabsadd L
.65619 .41487 .56518 .7779 Mabsadd L
.65619 .41487 0 2.5 Mabsadd L closepath F
.66 .39694 0 2.5 Mabsadd m
.66 .39694 -0.56518 .7779 Mabsadd L
.66 .39694 -2.37764 .77254 Mabsadd L
.66 .39694 -0.91448 -0.29713 Mabsadd L
.66 .39694 -1.46946 -2.02254 Mabsadd L
.66 .39694 0 -0.96154 Mabsadd L
.66 .39694 1.46946 -2.02254 Mabsadd L
.66 .39694 .91448 -0.29713 Mabsadd L
.66 .39694 2.37764 .77254 Mabsadd L
.66 .39694 .56518 .7779 Mabsadd L
.66 .39694 0 2.5 Mabsadd L closepath F
.66381 .37518 0 2.5 Mabsadd m
.66381 .37518 -0.56518 .7779 Mabsadd L
.66381 .37518 -2.37764 .77254 Mabsadd L
.66381 .37518 -0.91448 -0.29713 Mabsadd L
.66381 .37518 -1.46946 -2.02254 Mabsadd L
.66381 .37518 0 -0.96154 Mabsadd L
.66381 .37518 1.46946 -2.02254 Mabsadd L
.66381 .37518 .91448 -0.29713 Mabsadd L
.66381 .37518 2.37764 .77254 Mabsadd L
.66381 .37518 .56518 .7779 Mabsadd L
.66381 .37518 0 2.5 Mabsadd L closepath F
.66762 .3523 0 2.5 Mabsadd m
.66762 .3523 -0.56518 .7779 Mabsadd L
.66762 .3523 -2.37764 .77254 Mabsadd L
.66762 .3523 -0.91448 -0.29713 Mabsadd L
.66762 .3523 -1.46946 -2.02254 Mabsadd L
.66762 .3523 0 -0.96154 Mabsadd L
.66762 .3523 1.46946 -2.02254 Mabsadd L
.66762 .3523 .91448 -0.29713 Mabsadd L
.66762 .3523 2.37764 .77254 Mabsadd L
.66762 .3523 .56518 .7779 Mabsadd L
.66762 .3523 0 2.5 Mabsadd L closepath F
.67143 .33136 0 2.5 Mabsadd m
.67143 .33136 -0.56518 .7779 Mabsadd L
.67143 .33136 -2.37764 .77254 Mabsadd L
.67143 .33136 -0.91448 -0.29713 Mabsadd L
.67143 .33136 -1.46946 -2.02254 Mabsadd L
.67143 .33136 0 -0.96154 Mabsadd L
.67143 .33136 1.46946 -2.02254 Mabsadd L
.67143 .33136 .91448 -0.29713 Mabsadd L
.67143 .33136 2.37764 .77254 Mabsadd L
.67143 .33136 .56518 .7779 Mabsadd L
.67143 .33136 0 2.5 Mabsadd L closepath F
.67524 .31465 0 2.5 Mabsadd m
.67524 .31465 -0.56518 .7779 Mabsadd L
.67524 .31465 -2.37764 .77254 Mabsadd L
.67524 .31465 -0.91448 -0.29713 Mabsadd L
.67524 .31465 -1.46946 -2.02254 Mabsadd L
.67524 .31465 0 -0.96154 Mabsadd L
.67524 .31465 1.46946 -2.02254 Mabsadd L
.67524 .31465 .91448 -0.29713 Mabsadd L
.67524 .31465 2.37764 .77254 Mabsadd L
.67524 .31465 .56518 .7779 Mabsadd L
.67524 .31465 0 2.5 Mabsadd L closepath F
.67905 .30298 0 2.5 Mabsadd m
.67905 .30298 -0.56518 .7779 Mabsadd L
.67905 .30298 -2.37764 .77254 Mabsadd L
.67905 .30298 -0.91448 -0.29713 Mabsadd L
.67905 .30298 -1.46946 -2.02254 Mabsadd L
.67905 .30298 0 -0.96154 Mabsadd L
.67905 .30298 1.46946 -2.02254 Mabsadd L
.67905 .30298 .91448 -0.29713 Mabsadd L
.67905 .30298 2.37764 .77254 Mabsadd L
.67905 .30298 .56518 .7779 Mabsadd L
.67905 .30298 0 2.5 Mabsadd L closepath F
.68286 .29583 0 2.5 Mabsadd m
.68286 .29583 -0.56518 .7779 Mabsadd L
.68286 .29583 -2.37764 .77254 Mabsadd L
.68286 .29583 -0.91448 -0.29713 Mabsadd L
.68286 .29583 -1.46946 -2.02254 Mabsadd L
.68286 .29583 0 -0.96154 Mabsadd L
.68286 .29583 1.46946 -2.02254 Mabsadd L
.68286 .29583 .91448 -0.29713 Mabsadd L
.68286 .29583 2.37764 .77254 Mabsadd L
.68286 .29583 .56518 .7779 Mabsadd L
.68286 .29583 0 2.5 Mabsadd L closepath F
.68667 .29206 0 2.5 Mabsadd m
.68667 .29206 -0.56518 .7779 Mabsadd L
.68667 .29206 -2.37764 .77254 Mabsadd L
.68667 .29206 -0.91448 -0.29713 Mabsadd L
.68667 .29206 -1.46946 -2.02254 Mabsadd L
.68667 .29206 0 -0.96154 Mabsadd L
.68667 .29206 1.46946 -2.02254 Mabsadd L
.68667 .29206 .91448 -0.29713 Mabsadd L
.68667 .29206 2.37764 .77254 Mabsadd L
.68667 .29206 .56518 .7779 Mabsadd L
.68667 .29206 0 2.5 Mabsadd L closepath F
.69048 .29054 0 2.5 Mabsadd m
.69048 .29054 -0.56518 .7779 Mabsadd L
.69048 .29054 -2.37764 .77254 Mabsadd L
.69048 .29054 -0.91448 -0.29713 Mabsadd L
.69048 .29054 -1.46946 -2.02254 Mabsadd L
.69048 .29054 0 -0.96154 Mabsadd L
.69048 .29054 1.46946 -2.02254 Mabsadd L
.69048 .29054 .91448 -0.29713 Mabsadd L
.69048 .29054 2.37764 .77254 Mabsadd L
.69048 .29054 .56518 .7779 Mabsadd L
.69048 .29054 0 2.5 Mabsadd L closepath F
.69429 .29039 0 2.5 Mabsadd m
.69429 .29039 -0.56518 .7779 Mabsadd L
.69429 .29039 -2.37764 .77254 Mabsadd L
.69429 .29039 -0.91448 -0.29713 Mabsadd L
.69429 .29039 -1.46946 -2.02254 Mabsadd L
.69429 .29039 0 -0.96154 Mabsadd L
.69429 .29039 1.46946 -2.02254 Mabsadd L
.69429 .29039 .91448 -0.29713 Mabsadd L
.69429 .29039 2.37764 .77254 Mabsadd L
.69429 .29039 .56518 .7779 Mabsadd L
.69429 .29039 0 2.5 Mabsadd L closepath F
.6981 .29102 0 2.5 Mabsadd m
.6981 .29102 -0.56518 .7779 Mabsadd L
.6981 .29102 -2.37764 .77254 Mabsadd L
.6981 .29102 -0.91448 -0.29713 Mabsadd L
.6981 .29102 -1.46946 -2.02254 Mabsadd L
.6981 .29102 0 -0.96154 Mabsadd L
.6981 .29102 1.46946 -2.02254 Mabsadd L
.6981 .29102 .91448 -0.29713 Mabsadd L
.6981 .29102 2.37764 .77254 Mabsadd L
.6981 .29102 .56518 .7779 Mabsadd L
.6981 .29102 0 2.5 Mabsadd L closepath F
.7019 .29208 0 2.5 Mabsadd m
.7019 .29208 -0.56518 .7779 Mabsadd L
.7019 .29208 -2.37764 .77254 Mabsadd L
.7019 .29208 -0.91448 -0.29713 Mabsadd L
.7019 .29208 -1.46946 -2.02254 Mabsadd L
.7019 .29208 0 -0.96154 Mabsadd L
.7019 .29208 1.46946 -2.02254 Mabsadd L
.7019 .29208 .91448 -0.29713 Mabsadd L
.7019 .29208 2.37764 .77254 Mabsadd L
.7019 .29208 .56518 .7779 Mabsadd L
.7019 .29208 0 2.5 Mabsadd L closepath F
.70571 .29333 0 2.5 Mabsadd m
.70571 .29333 -0.56518 .7779 Mabsadd L
.70571 .29333 -2.37764 .77254 Mabsadd L
.70571 .29333 -0.91448 -0.29713 Mabsadd L
.70571 .29333 -1.46946 -2.02254 Mabsadd L
.70571 .29333 0 -0.96154 Mabsadd L
.70571 .29333 1.46946 -2.02254 Mabsadd L
.70571 .29333 .91448 -0.29713 Mabsadd L
.70571 .29333 2.37764 .77254 Mabsadd L
.70571 .29333 .56518 .7779 Mabsadd L
.70571 .29333 0 2.5 Mabsadd L closepath F
.70952 .29463 0 2.5 Mabsadd m
.70952 .29463 -0.56518 .7779 Mabsadd L
.70952 .29463 -2.37764 .77254 Mabsadd L
.70952 .29463 -0.91448 -0.29713 Mabsadd L
.70952 .29463 -1.46946 -2.02254 Mabsadd L
.70952 .29463 0 -0.96154 Mabsadd L
.70952 .29463 1.46946 -2.02254 Mabsadd L
.70952 .29463 .91448 -0.29713 Mabsadd L
.70952 .29463 2.37764 .77254 Mabsadd L
.70952 .29463 .56518 .7779 Mabsadd L
.70952 .29463 0 2.5 Mabsadd L closepath F
.71333 .29592 0 2.5 Mabsadd m
.71333 .29592 -0.56518 .7779 Mabsadd L
.71333 .29592 -2.37764 .77254 Mabsadd L
.71333 .29592 -0.91448 -0.29713 Mabsadd L
.71333 .29592 -1.46946 -2.02254 Mabsadd L
.71333 .29592 0 -0.96154 Mabsadd L
.71333 .29592 1.46946 -2.02254 Mabsadd L
.71333 .29592 .91448 -0.29713 Mabsadd L
.71333 .29592 2.37764 .77254 Mabsadd L
.71333 .29592 .56518 .7779 Mabsadd L
.71333 .29592 0 2.5 Mabsadd L closepath F
.71714 .29715 0 2.5 Mabsadd m
.71714 .29715 -0.56518 .7779 Mabsadd L
.71714 .29715 -2.37764 .77254 Mabsadd L
.71714 .29715 -0.91448 -0.29713 Mabsadd L
.71714 .29715 -1.46946 -2.02254 Mabsadd L
.71714 .29715 0 -0.96154 Mabsadd L
.71714 .29715 1.46946 -2.02254 Mabsadd L
.71714 .29715 .91448 -0.29713 Mabsadd L
.71714 .29715 2.37764 .77254 Mabsadd L
.71714 .29715 .56518 .7779 Mabsadd L
.71714 .29715 0 2.5 Mabsadd L closepath F
.72095 .2983 0 2.5 Mabsadd m
.72095 .2983 -0.56518 .7779 Mabsadd L
.72095 .2983 -2.37764 .77254 Mabsadd L
.72095 .2983 -0.91448 -0.29713 Mabsadd L
.72095 .2983 -1.46946 -2.02254 Mabsadd L
.72095 .2983 0 -0.96154 Mabsadd L
.72095 .2983 1.46946 -2.02254 Mabsadd L
.72095 .2983 .91448 -0.29713 Mabsadd L
.72095 .2983 2.37764 .77254 Mabsadd L
.72095 .2983 .56518 .7779 Mabsadd L
.72095 .2983 0 2.5 Mabsadd L closepath F
.72476 .29935 0 2.5 Mabsadd m
.72476 .29935 -0.56518 .7779 Mabsadd L
.72476 .29935 -2.37764 .77254 Mabsadd L
.72476 .29935 -0.91448 -0.29713 Mabsadd L
.72476 .29935 -1.46946 -2.02254 Mabsadd L
.72476 .29935 0 -0.96154 Mabsadd L
.72476 .29935 1.46946 -2.02254 Mabsadd L
.72476 .29935 .91448 -0.29713 Mabsadd L
.72476 .29935 2.37764 .77254 Mabsadd L
.72476 .29935 .56518 .7779 Mabsadd L
.72476 .29935 0 2.5 Mabsadd L closepath F
.72857 .30031 0 2.5 Mabsadd m
.72857 .30031 -0.56518 .7779 Mabsadd L
.72857 .30031 -2.37764 .77254 Mabsadd L
.72857 .30031 -0.91448 -0.29713 Mabsadd L
.72857 .30031 -1.46946 -2.02254 Mabsadd L
.72857 .30031 0 -0.96154 Mabsadd L
.72857 .30031 1.46946 -2.02254 Mabsadd L
.72857 .30031 .91448 -0.29713 Mabsadd L
.72857 .30031 2.37764 .77254 Mabsadd L
.72857 .30031 .56518 .7779 Mabsadd L
.72857 .30031 0 2.5 Mabsadd L closepath F
.73238 .30117 0 2.5 Mabsadd m
.73238 .30117 -0.56518 .7779 Mabsadd L
.73238 .30117 -2.37764 .77254 Mabsadd L
.73238 .30117 -0.91448 -0.29713 Mabsadd L
.73238 .30117 -1.46946 -2.02254 Mabsadd L
.73238 .30117 0 -0.96154 Mabsadd L
.73238 .30117 1.46946 -2.02254 Mabsadd L
.73238 .30117 .91448 -0.29713 Mabsadd L
.73238 .30117 2.37764 .77254 Mabsadd L
.73238 .30117 .56518 .7779 Mabsadd L
.73238 .30117 0 2.5 Mabsadd L closepath F
.73619 .30195 0 2.5 Mabsadd m
.73619 .30195 -0.56518 .7779 Mabsadd L
.73619 .30195 -2.37764 .77254 Mabsadd L
.73619 .30195 -0.91448 -0.29713 Mabsadd L
.73619 .30195 -1.46946 -2.02254 Mabsadd L
.73619 .30195 0 -0.96154 Mabsadd L
.73619 .30195 1.46946 -2.02254 Mabsadd L
.73619 .30195 .91448 -0.29713 Mabsadd L
.73619 .30195 2.37764 .77254 Mabsadd L
.73619 .30195 .56518 .7779 Mabsadd L
.73619 .30195 0 2.5 Mabsadd L closepath F
.74 .30265 0 2.5 Mabsadd m
.74 .30265 -0.56518 .7779 Mabsadd L
.74 .30265 -2.37764 .77254 Mabsadd L
.74 .30265 -0.91448 -0.29713 Mabsadd L
.74 .30265 -1.46946 -2.02254 Mabsadd L
.74 .30265 0 -0.96154 Mabsadd L
.74 .30265 1.46946 -2.02254 Mabsadd L
.74 .30265 .91448 -0.29713 Mabsadd L
.74 .30265 2.37764 .77254 Mabsadd L
.74 .30265 .56518 .7779 Mabsadd L
.74 .30265 0 2.5 Mabsadd L closepath F
.74381 .30327 0 2.5 Mabsadd m
.74381 .30327 -0.56518 .7779 Mabsadd L
.74381 .30327 -2.37764 .77254 Mabsadd L
.74381 .30327 -0.91448 -0.29713 Mabsadd L
.74381 .30327 -1.46946 -2.02254 Mabsadd L
.74381 .30327 0 -0.96154 Mabsadd L
.74381 .30327 1.46946 -2.02254 Mabsadd L
.74381 .30327 .91448 -0.29713 Mabsadd L
.74381 .30327 2.37764 .77254 Mabsadd L
.74381 .30327 .56518 .7779 Mabsadd L
.74381 .30327 0 2.5 Mabsadd L closepath F
.74762 .30383 0 2.5 Mabsadd m
.74762 .30383 -0.56518 .7779 Mabsadd L
.74762 .30383 -2.37764 .77254 Mabsadd L
.74762 .30383 -0.91448 -0.29713 Mabsadd L
.74762 .30383 -1.46946 -2.02254 Mabsadd L
.74762 .30383 0 -0.96154 Mabsadd L
.74762 .30383 1.46946 -2.02254 Mabsadd L
.74762 .30383 .91448 -0.29713 Mabsadd L
.74762 .30383 2.37764 .77254 Mabsadd L
.74762 .30383 .56518 .7779 Mabsadd L
.74762 .30383 0 2.5 Mabsadd L closepath F
.75143 .30433 0 2.5 Mabsadd m
.75143 .30433 -0.56518 .7779 Mabsadd L
.75143 .30433 -2.37764 .77254 Mabsadd L
.75143 .30433 -0.91448 -0.29713 Mabsadd L
.75143 .30433 -1.46946 -2.02254 Mabsadd L
.75143 .30433 0 -0.96154 Mabsadd L
.75143 .30433 1.46946 -2.02254 Mabsadd L
.75143 .30433 .91448 -0.29713 Mabsadd L
.75143 .30433 2.37764 .77254 Mabsadd L
.75143 .30433 .56518 .7779 Mabsadd L
.75143 .30433 0 2.5 Mabsadd L closepath F
.75524 .30478 0 2.5 Mabsadd m
.75524 .30478 -0.56518 .7779 Mabsadd L
.75524 .30478 -2.37764 .77254 Mabsadd L
.75524 .30478 -0.91448 -0.29713 Mabsadd L
.75524 .30478 -1.46946 -2.02254 Mabsadd L
.75524 .30478 0 -0.96154 Mabsadd L
.75524 .30478 1.46946 -2.02254 Mabsadd L
.75524 .30478 .91448 -0.29713 Mabsadd L
.75524 .30478 2.37764 .77254 Mabsadd L
.75524 .30478 .56518 .7779 Mabsadd L
.75524 .30478 0 2.5 Mabsadd L closepath F
.75905 .30518 0 2.5 Mabsadd m
.75905 .30518 -0.56518 .7779 Mabsadd L
.75905 .30518 -2.37764 .77254 Mabsadd L
.75905 .30518 -0.91448 -0.29713 Mabsadd L
.75905 .30518 -1.46946 -2.02254 Mabsadd L
.75905 .30518 0 -0.96154 Mabsadd L
.75905 .30518 1.46946 -2.02254 Mabsadd L
.75905 .30518 .91448 -0.29713 Mabsadd L
.75905 .30518 2.37764 .77254 Mabsadd L
.75905 .30518 .56518 .7779 Mabsadd L
.75905 .30518 0 2.5 Mabsadd L closepath F
.76286 .30553 0 2.5 Mabsadd m
.76286 .30553 -0.56518 .7779 Mabsadd L
.76286 .30553 -2.37764 .77254 Mabsadd L
.76286 .30553 -0.91448 -0.29713 Mabsadd L
.76286 .30553 -1.46946 -2.02254 Mabsadd L
.76286 .30553 0 -0.96154 Mabsadd L
.76286 .30553 1.46946 -2.02254 Mabsadd L
.76286 .30553 .91448 -0.29713 Mabsadd L
.76286 .30553 2.37764 .77254 Mabsadd L
.76286 .30553 .56518 .7779 Mabsadd L
.76286 .30553 0 2.5 Mabsadd L closepath F
.76667 .30585 0 2.5 Mabsadd m
.76667 .30585 -0.56518 .7779 Mabsadd L
.76667 .30585 -2.37764 .77254 Mabsadd L
.76667 .30585 -0.91448 -0.29713 Mabsadd L
.76667 .30585 -1.46946 -2.02254 Mabsadd L
.76667 .30585 0 -0.96154 Mabsadd L
.76667 .30585 1.46946 -2.02254 Mabsadd L
.76667 .30585 .91448 -0.29713 Mabsadd L
.76667 .30585 2.37764 .77254 Mabsadd L
.76667 .30585 .56518 .7779 Mabsadd L
.76667 .30585 0 2.5 Mabsadd L closepath F
.77048 .30614 0 2.5 Mabsadd m
.77048 .30614 -0.56518 .7779 Mabsadd L
.77048 .30614 -2.37764 .77254 Mabsadd L
.77048 .30614 -0.91448 -0.29713 Mabsadd L
.77048 .30614 -1.46946 -2.02254 Mabsadd L
.77048 .30614 0 -0.96154 Mabsadd L
.77048 .30614 1.46946 -2.02254 Mabsadd L
.77048 .30614 .91448 -0.29713 Mabsadd L
.77048 .30614 2.37764 .77254 Mabsadd L
.77048 .30614 .56518 .7779 Mabsadd L
.77048 .30614 0 2.5 Mabsadd L closepath F
.77429 .30639 0 2.5 Mabsadd m
.77429 .30639 -0.56518 .7779 Mabsadd L
.77429 .30639 -2.37764 .77254 Mabsadd L
.77429 .30639 -0.91448 -0.29713 Mabsadd L
.77429 .30639 -1.46946 -2.02254 Mabsadd L
.77429 .30639 0 -0.96154 Mabsadd L
.77429 .30639 1.46946 -2.02254 Mabsadd L
.77429 .30639 .91448 -0.29713 Mabsadd L
.77429 .30639 2.37764 .77254 Mabsadd L
.77429 .30639 .56518 .7779 Mabsadd L
.77429 .30639 0 2.5 Mabsadd L closepath F
.7781 .30662 0 2.5 Mabsadd m
.7781 .30662 -0.56518 .7779 Mabsadd L
.7781 .30662 -2.37764 .77254 Mabsadd L
.7781 .30662 -0.91448 -0.29713 Mabsadd L
.7781 .30662 -1.46946 -2.02254 Mabsadd L
.7781 .30662 0 -0.96154 Mabsadd L
.7781 .30662 1.46946 -2.02254 Mabsadd L
.7781 .30662 .91448 -0.29713 Mabsadd L
.7781 .30662 2.37764 .77254 Mabsadd L
.7781 .30662 .56518 .7779 Mabsadd L
.7781 .30662 0 2.5 Mabsadd L closepath F
.7819 .30683 0 2.5 Mabsadd m
.7819 .30683 -0.56518 .7779 Mabsadd L
.7819 .30683 -2.37764 .77254 Mabsadd L
.7819 .30683 -0.91448 -0.29713 Mabsadd L
.7819 .30683 -1.46946 -2.02254 Mabsadd L
.7819 .30683 0 -0.96154 Mabsadd L
.7819 .30683 1.46946 -2.02254 Mabsadd L
.7819 .30683 .91448 -0.29713 Mabsadd L
.7819 .30683 2.37764 .77254 Mabsadd L
.7819 .30683 .56518 .7779 Mabsadd L
.7819 .30683 0 2.5 Mabsadd L closepath F
.78571 .30701 0 2.5 Mabsadd m
.78571 .30701 -0.56518 .7779 Mabsadd L
.78571 .30701 -2.37764 .77254 Mabsadd L
.78571 .30701 -0.91448 -0.29713 Mabsadd L
.78571 .30701 -1.46946 -2.02254 Mabsadd L
.78571 .30701 0 -0.96154 Mabsadd L
.78571 .30701 1.46946 -2.02254 Mabsadd L
.78571 .30701 .91448 -0.29713 Mabsadd L
.78571 .30701 2.37764 .77254 Mabsadd L
.78571 .30701 .56518 .7779 Mabsadd L
.78571 .30701 0 2.5 Mabsadd L closepath F
.78952 .30718 0 2.5 Mabsadd m
.78952 .30718 -0.56518 .7779 Mabsadd L
.78952 .30718 -2.37764 .77254 Mabsadd L
.78952 .30718 -0.91448 -0.29713 Mabsadd L
.78952 .30718 -1.46946 -2.02254 Mabsadd L
.78952 .30718 0 -0.96154 Mabsadd L
.78952 .30718 1.46946 -2.02254 Mabsadd L
.78952 .30718 .91448 -0.29713 Mabsadd L
.78952 .30718 2.37764 .77254 Mabsadd L
.78952 .30718 .56518 .7779 Mabsadd L
.78952 .30718 0 2.5 Mabsadd L closepath F
.79333 .30733 0 2.5 Mabsadd m
.79333 .30733 -0.56518 .7779 Mabsadd L
.79333 .30733 -2.37764 .77254 Mabsadd L
.79333 .30733 -0.91448 -0.29713 Mabsadd L
.79333 .30733 -1.46946 -2.02254 Mabsadd L
.79333 .30733 0 -0.96154 Mabsadd L
.79333 .30733 1.46946 -2.02254 Mabsadd L
.79333 .30733 .91448 -0.29713 Mabsadd L
.79333 .30733 2.37764 .77254 Mabsadd L
.79333 .30733 .56518 .7779 Mabsadd L
.79333 .30733 0 2.5 Mabsadd L closepath F
.79714 .30746 0 2.5 Mabsadd m
.79714 .30746 -0.56518 .7779 Mabsadd L
.79714 .30746 -2.37764 .77254 Mabsadd L
.79714 .30746 -0.91448 -0.29713 Mabsadd L
.79714 .30746 -1.46946 -2.02254 Mabsadd L
.79714 .30746 0 -0.96154 Mabsadd L
.79714 .30746 1.46946 -2.02254 Mabsadd L
.79714 .30746 .91448 -0.29713 Mabsadd L
.79714 .30746 2.37764 .77254 Mabsadd L
.79714 .30746 .56518 .7779 Mabsadd L
.79714 .30746 0 2.5 Mabsadd L closepath F
.80095 .30759 0 2.5 Mabsadd m
.80095 .30759 -0.56518 .7779 Mabsadd L
.80095 .30759 -2.37764 .77254 Mabsadd L
.80095 .30759 -0.91448 -0.29713 Mabsadd L
.80095 .30759 -1.46946 -2.02254 Mabsadd L
.80095 .30759 0 -0.96154 Mabsadd L
.80095 .30759 1.46946 -2.02254 Mabsadd L
.80095 .30759 .91448 -0.29713 Mabsadd L
.80095 .30759 2.37764 .77254 Mabsadd L
.80095 .30759 .56518 .7779 Mabsadd L
.80095 .30759 0 2.5 Mabsadd L closepath F
.80476 .3077 0 2.5 Mabsadd m
.80476 .3077 -0.56518 .7779 Mabsadd L
.80476 .3077 -2.37764 .77254 Mabsadd L
.80476 .3077 -0.91448 -0.29713 Mabsadd L
.80476 .3077 -1.46946 -2.02254 Mabsadd L
.80476 .3077 0 -0.96154 Mabsadd L
.80476 .3077 1.46946 -2.02254 Mabsadd L
.80476 .3077 .91448 -0.29713 Mabsadd L
.80476 .3077 2.37764 .77254 Mabsadd L
.80476 .3077 .56518 .7779 Mabsadd L
.80476 .3077 0 2.5 Mabsadd L closepath F
.80857 .3078 0 2.5 Mabsadd m
.80857 .3078 -0.56518 .7779 Mabsadd L
.80857 .3078 -2.37764 .77254 Mabsadd L
.80857 .3078 -0.91448 -0.29713 Mabsadd L
.80857 .3078 -1.46946 -2.02254 Mabsadd L
.80857 .3078 0 -0.96154 Mabsadd L
.80857 .3078 1.46946 -2.02254 Mabsadd L
.80857 .3078 .91448 -0.29713 Mabsadd L
.80857 .3078 2.37764 .77254 Mabsadd L
.80857 .3078 .56518 .7779 Mabsadd L
.80857 .3078 0 2.5 Mabsadd L closepath F
.81238 .30789 0 2.5 Mabsadd m
.81238 .30789 -0.56518 .7779 Mabsadd L
.81238 .30789 -2.37764 .77254 Mabsadd L
.81238 .30789 -0.91448 -0.29713 Mabsadd L
.81238 .30789 -1.46946 -2.02254 Mabsadd L
.81238 .30789 0 -0.96154 Mabsadd L
.81238 .30789 1.46946 -2.02254 Mabsadd L
.81238 .30789 .91448 -0.29713 Mabsadd L
.81238 .30789 2.37764 .77254 Mabsadd L
.81238 .30789 .56518 .7779 Mabsadd L
.81238 .30789 0 2.5 Mabsadd L closepath F
.81619 .30797 0 2.5 Mabsadd m
.81619 .30797 -0.56518 .7779 Mabsadd L
.81619 .30797 -2.37764 .77254 Mabsadd L
.81619 .30797 -0.91448 -0.29713 Mabsadd L
.81619 .30797 -1.46946 -2.02254 Mabsadd L
.81619 .30797 0 -0.96154 Mabsadd L
.81619 .30797 1.46946 -2.02254 Mabsadd L
.81619 .30797 .91448 -0.29713 Mabsadd L
.81619 .30797 2.37764 .77254 Mabsadd L
.81619 .30797 .56518 .7779 Mabsadd L
.81619 .30797 0 2.5 Mabsadd L closepath F
.82 .30805 0 2.5 Mabsadd m
.82 .30805 -0.56518 .7779 Mabsadd L
.82 .30805 -2.37764 .77254 Mabsadd L
.82 .30805 -0.91448 -0.29713 Mabsadd L
.82 .30805 -1.46946 -2.02254 Mabsadd L
.82 .30805 0 -0.96154 Mabsadd L
.82 .30805 1.46946 -2.02254 Mabsadd L
.82 .30805 .91448 -0.29713 Mabsadd L
.82 .30805 2.37764 .77254 Mabsadd L
.82 .30805 .56518 .7779 Mabsadd L
.82 .30805 0 2.5 Mabsadd L closepath F
.82381 .30812 0 2.5 Mabsadd m
.82381 .30812 -0.56518 .7779 Mabsadd L
.82381 .30812 -2.37764 .77254 Mabsadd L
.82381 .30812 -0.91448 -0.29713 Mabsadd L
.82381 .30812 -1.46946 -2.02254 Mabsadd L
.82381 .30812 0 -0.96154 Mabsadd L
.82381 .30812 1.46946 -2.02254 Mabsadd L
.82381 .30812 .91448 -0.29713 Mabsadd L
.82381 .30812 2.37764 .77254 Mabsadd L
.82381 .30812 .56518 .7779 Mabsadd L
.82381 .30812 0 2.5 Mabsadd L closepath F
.82762 .30818 0 2.5 Mabsadd m
.82762 .30818 -0.56518 .7779 Mabsadd L
.82762 .30818 -2.37764 .77254 Mabsadd L
.82762 .30818 -0.91448 -0.29713 Mabsadd L
.82762 .30818 -1.46946 -2.02254 Mabsadd L
.82762 .30818 0 -0.96154 Mabsadd L
.82762 .30818 1.46946 -2.02254 Mabsadd L
.82762 .30818 .91448 -0.29713 Mabsadd L
.82762 .30818 2.37764 .77254 Mabsadd L
.82762 .30818 .56518 .7779 Mabsadd L
.82762 .30818 0 2.5 Mabsadd L closepath F
.83143 .30824 0 2.5 Mabsadd m
.83143 .30824 -0.56518 .7779 Mabsadd L
.83143 .30824 -2.37764 .77254 Mabsadd L
.83143 .30824 -0.91448 -0.29713 Mabsadd L
.83143 .30824 -1.46946 -2.02254 Mabsadd L
.83143 .30824 0 -0.96154 Mabsadd L
.83143 .30824 1.46946 -2.02254 Mabsadd L
.83143 .30824 .91448 -0.29713 Mabsadd L
.83143 .30824 2.37764 .77254 Mabsadd L
.83143 .30824 .56518 .7779 Mabsadd L
.83143 .30824 0 2.5 Mabsadd L closepath F
.83524 .30829 0 2.5 Mabsadd m
.83524 .30829 -0.56518 .7779 Mabsadd L
.83524 .30829 -2.37764 .77254 Mabsadd L
.83524 .30829 -0.91448 -0.29713 Mabsadd L
.83524 .30829 -1.46946 -2.02254 Mabsadd L
.83524 .30829 0 -0.96154 Mabsadd L
.83524 .30829 1.46946 -2.02254 Mabsadd L
.83524 .30829 .91448 -0.29713 Mabsadd L
.83524 .30829 2.37764 .77254 Mabsadd L
.83524 .30829 .56518 .7779 Mabsadd L
.83524 .30829 0 2.5 Mabsadd L closepath F
.83905 .30834 0 2.5 Mabsadd m
.83905 .30834 -0.56518 .7779 Mabsadd L
.83905 .30834 -2.37764 .77254 Mabsadd L
.83905 .30834 -0.91448 -0.29713 Mabsadd L
.83905 .30834 -1.46946 -2.02254 Mabsadd L
.83905 .30834 0 -0.96154 Mabsadd L
.83905 .30834 1.46946 -2.02254 Mabsadd L
.83905 .30834 .91448 -0.29713 Mabsadd L
.83905 .30834 2.37764 .77254 Mabsadd L
.83905 .30834 .56518 .7779 Mabsadd L
.83905 .30834 0 2.5 Mabsadd L closepath F
.84286 .30839 0 2.5 Mabsadd m
.84286 .30839 -0.56518 .7779 Mabsadd L
.84286 .30839 -2.37764 .77254 Mabsadd L
.84286 .30839 -0.91448 -0.29713 Mabsadd L
.84286 .30839 -1.46946 -2.02254 Mabsadd L
.84286 .30839 0 -0.96154 Mabsadd L
.84286 .30839 1.46946 -2.02254 Mabsadd L
.84286 .30839 .91448 -0.29713 Mabsadd L
.84286 .30839 2.37764 .77254 Mabsadd L
.84286 .30839 .56518 .7779 Mabsadd L
.84286 .30839 0 2.5 Mabsadd L closepath F
.84667 .30843 0 2.5 Mabsadd m
.84667 .30843 -0.56518 .7779 Mabsadd L
.84667 .30843 -2.37764 .77254 Mabsadd L
.84667 .30843 -0.91448 -0.29713 Mabsadd L
.84667 .30843 -1.46946 -2.02254 Mabsadd L
.84667 .30843 0 -0.96154 Mabsadd L
.84667 .30843 1.46946 -2.02254 Mabsadd L
.84667 .30843 .91448 -0.29713 Mabsadd L
.84667 .30843 2.37764 .77254 Mabsadd L
.84667 .30843 .56518 .7779 Mabsadd L
.84667 .30843 0 2.5 Mabsadd L closepath F
.85048 .30847 0 2.5 Mabsadd m
.85048 .30847 -0.56518 .7779 Mabsadd L
.85048 .30847 -2.37764 .77254 Mabsadd L
.85048 .30847 -0.91448 -0.29713 Mabsadd L
.85048 .30847 -1.46946 -2.02254 Mabsadd L
.85048 .30847 0 -0.96154 Mabsadd L
.85048 .30847 1.46946 -2.02254 Mabsadd L
.85048 .30847 .91448 -0.29713 Mabsadd L
.85048 .30847 2.37764 .77254 Mabsadd L
.85048 .30847 .56518 .7779 Mabsadd L
.85048 .30847 0 2.5 Mabsadd L closepath F
.85429 .3085 0 2.5 Mabsadd m
.85429 .3085 -0.56518 .7779 Mabsadd L
.85429 .3085 -2.37764 .77254 Mabsadd L
.85429 .3085 -0.91448 -0.29713 Mabsadd L
.85429 .3085 -1.46946 -2.02254 Mabsadd L
.85429 .3085 0 -0.96154 Mabsadd L
.85429 .3085 1.46946 -2.02254 Mabsadd L
.85429 .3085 .91448 -0.29713 Mabsadd L
.85429 .3085 2.37764 .77254 Mabsadd L
.85429 .3085 .56518 .7779 Mabsadd L
.85429 .3085 0 2.5 Mabsadd L closepath F
.8581 .30853 0 2.5 Mabsadd m
.8581 .30853 -0.56518 .7779 Mabsadd L
.8581 .30853 -2.37764 .77254 Mabsadd L
.8581 .30853 -0.91448 -0.29713 Mabsadd L
.8581 .30853 -1.46946 -2.02254 Mabsadd L
.8581 .30853 0 -0.96154 Mabsadd L
.8581 .30853 1.46946 -2.02254 Mabsadd L
.8581 .30853 .91448 -0.29713 Mabsadd L
.8581 .30853 2.37764 .77254 Mabsadd L
.8581 .30853 .56518 .7779 Mabsadd L
.8581 .30853 0 2.5 Mabsadd L closepath F
.8619 .30856 0 2.5 Mabsadd m
.8619 .30856 -0.56518 .7779 Mabsadd L
.8619 .30856 -2.37764 .77254 Mabsadd L
.8619 .30856 -0.91448 -0.29713 Mabsadd L
.8619 .30856 -1.46946 -2.02254 Mabsadd L
.8619 .30856 0 -0.96154 Mabsadd L
.8619 .30856 1.46946 -2.02254 Mabsadd L
.8619 .30856 .91448 -0.29713 Mabsadd L
.8619 .30856 2.37764 .77254 Mabsadd L
.8619 .30856 .56518 .7779 Mabsadd L
.8619 .30856 0 2.5 Mabsadd L closepath F
.86571 .30859 0 2.5 Mabsadd m
.86571 .30859 -0.56518 .7779 Mabsadd L
.86571 .30859 -2.37764 .77254 Mabsadd L
.86571 .30859 -0.91448 -0.29713 Mabsadd L
.86571 .30859 -1.46946 -2.02254 Mabsadd L
.86571 .30859 0 -0.96154 Mabsadd L
.86571 .30859 1.46946 -2.02254 Mabsadd L
.86571 .30859 .91448 -0.29713 Mabsadd L
.86571 .30859 2.37764 .77254 Mabsadd L
.86571 .30859 .56518 .7779 Mabsadd L
.86571 .30859 0 2.5 Mabsadd L closepath F
.86952 .30861 0 2.5 Mabsadd m
.86952 .30861 -0.56518 .7779 Mabsadd L
.86952 .30861 -2.37764 .77254 Mabsadd L
.86952 .30861 -0.91448 -0.29713 Mabsadd L
.86952 .30861 -1.46946 -2.02254 Mabsadd L
.86952 .30861 0 -0.96154 Mabsadd L
.86952 .30861 1.46946 -2.02254 Mabsadd L
.86952 .30861 .91448 -0.29713 Mabsadd L
.86952 .30861 2.37764 .77254 Mabsadd L
.86952 .30861 .56518 .7779 Mabsadd L
.86952 .30861 0 2.5 Mabsadd L closepath F
.87333 .30864 0 2.5 Mabsadd m
.87333 .30864 -0.56518 .7779 Mabsadd L
.87333 .30864 -2.37764 .77254 Mabsadd L
.87333 .30864 -0.91448 -0.29713 Mabsadd L
.87333 .30864 -1.46946 -2.02254 Mabsadd L
.87333 .30864 0 -0.96154 Mabsadd L
.87333 .30864 1.46946 -2.02254 Mabsadd L
.87333 .30864 .91448 -0.29713 Mabsadd L
.87333 .30864 2.37764 .77254 Mabsadd L
.87333 .30864 .56518 .7779 Mabsadd L
.87333 .30864 0 2.5 Mabsadd L closepath F
.87714 .30866 0 2.5 Mabsadd m
.87714 .30866 -0.56518 .7779 Mabsadd L
.87714 .30866 -2.37764 .77254 Mabsadd L
.87714 .30866 -0.91448 -0.29713 Mabsadd L
.87714 .30866 -1.46946 -2.02254 Mabsadd L
.87714 .30866 0 -0.96154 Mabsadd L
.87714 .30866 1.46946 -2.02254 Mabsadd L
.87714 .30866 .91448 -0.29713 Mabsadd L
.87714 .30866 2.37764 .77254 Mabsadd L
.87714 .30866 .56518 .7779 Mabsadd L
.87714 .30866 0 2.5 Mabsadd L closepath F
.88095 .30868 0 2.5 Mabsadd m
.88095 .30868 -0.56518 .7779 Mabsadd L
.88095 .30868 -2.37764 .77254 Mabsadd L
.88095 .30868 -0.91448 -0.29713 Mabsadd L
.88095 .30868 -1.46946 -2.02254 Mabsadd L
.88095 .30868 0 -0.96154 Mabsadd L
.88095 .30868 1.46946 -2.02254 Mabsadd L
.88095 .30868 .91448 -0.29713 Mabsadd L
.88095 .30868 2.37764 .77254 Mabsadd L
.88095 .30868 .56518 .7779 Mabsadd L
.88095 .30868 0 2.5 Mabsadd L closepath F
.88476 .3087 0 2.5 Mabsadd m
.88476 .3087 -0.56518 .7779 Mabsadd L
.88476 .3087 -2.37764 .77254 Mabsadd L
.88476 .3087 -0.91448 -0.29713 Mabsadd L
.88476 .3087 -1.46946 -2.02254 Mabsadd L
.88476 .3087 0 -0.96154 Mabsadd L
.88476 .3087 1.46946 -2.02254 Mabsadd L
.88476 .3087 .91448 -0.29713 Mabsadd L
.88476 .3087 2.37764 .77254 Mabsadd L
.88476 .3087 .56518 .7779 Mabsadd L
.88476 .3087 0 2.5 Mabsadd L closepath F
.88857 .30872 0 2.5 Mabsadd m
.88857 .30872 -0.56518 .7779 Mabsadd L
.88857 .30872 -2.37764 .77254 Mabsadd L
.88857 .30872 -0.91448 -0.29713 Mabsadd L
.88857 .30872 -1.46946 -2.02254 Mabsadd L
.88857 .30872 0 -0.96154 Mabsadd L
.88857 .30872 1.46946 -2.02254 Mabsadd L
.88857 .30872 .91448 -0.29713 Mabsadd L
.88857 .30872 2.37764 .77254 Mabsadd L
.88857 .30872 .56518 .7779 Mabsadd L
.88857 .30872 0 2.5 Mabsadd L closepath F
.89238 .30873 0 2.5 Mabsadd m
.89238 .30873 -0.56518 .7779 Mabsadd L
.89238 .30873 -2.37764 .77254 Mabsadd L
.89238 .30873 -0.91448 -0.29713 Mabsadd L
.89238 .30873 -1.46946 -2.02254 Mabsadd L
.89238 .30873 0 -0.96154 Mabsadd L
.89238 .30873 1.46946 -2.02254 Mabsadd L
.89238 .30873 .91448 -0.29713 Mabsadd L
.89238 .30873 2.37764 .77254 Mabsadd L
.89238 .30873 .56518 .7779 Mabsadd L
.89238 .30873 0 2.5 Mabsadd L closepath F
.89619 .30875 0 2.5 Mabsadd m
.89619 .30875 -0.56518 .7779 Mabsadd L
.89619 .30875 -2.37764 .77254 Mabsadd L
.89619 .30875 -0.91448 -0.29713 Mabsadd L
.89619 .30875 -1.46946 -2.02254 Mabsadd L
.89619 .30875 0 -0.96154 Mabsadd L
.89619 .30875 1.46946 -2.02254 Mabsadd L
.89619 .30875 .91448 -0.29713 Mabsadd L
.89619 .30875 2.37764 .77254 Mabsadd L
.89619 .30875 .56518 .7779 Mabsadd L
.89619 .30875 0 2.5 Mabsadd L closepath F
.9 .30876 0 2.5 Mabsadd m
.9 .30876 -0.56518 .7779 Mabsadd L
.9 .30876 -2.37764 .77254 Mabsadd L
.9 .30876 -0.91448 -0.29713 Mabsadd L
.9 .30876 -1.46946 -2.02254 Mabsadd L
.9 .30876 0 -0.96154 Mabsadd L
.9 .30876 1.46946 -2.02254 Mabsadd L
.9 .30876 .91448 -0.29713 Mabsadd L
.9 .30876 2.37764 .77254 Mabsadd L
.9 .30876 .56518 .7779 Mabsadd L
.9 .30876 0 2.5 Mabsadd L closepath F
.90381 .30878 0 2.5 Mabsadd m
.90381 .30878 -0.56518 .7779 Mabsadd L
.90381 .30878 -2.37764 .77254 Mabsadd L
.90381 .30878 -0.91448 -0.29713 Mabsadd L
.90381 .30878 -1.46946 -2.02254 Mabsadd L
.90381 .30878 0 -0.96154 Mabsadd L
.90381 .30878 1.46946 -2.02254 Mabsadd L
.90381 .30878 .91448 -0.29713 Mabsadd L
.90381 .30878 2.37764 .77254 Mabsadd L
.90381 .30878 .56518 .7779 Mabsadd L
.90381 .30878 0 2.5 Mabsadd L closepath F
.90762 .30879 0 2.5 Mabsadd m
.90762 .30879 -0.56518 .7779 Mabsadd L
.90762 .30879 -2.37764 .77254 Mabsadd L
.90762 .30879 -0.91448 -0.29713 Mabsadd L
.90762 .30879 -1.46946 -2.02254 Mabsadd L
.90762 .30879 0 -0.96154 Mabsadd L
.90762 .30879 1.46946 -2.02254 Mabsadd L
.90762 .30879 .91448 -0.29713 Mabsadd L
.90762 .30879 2.37764 .77254 Mabsadd L
.90762 .30879 .56518 .7779 Mabsadd L
.90762 .30879 0 2.5 Mabsadd L closepath F
.91143 .3088 0 2.5 Mabsadd m
.91143 .3088 -0.56518 .7779 Mabsadd L
.91143 .3088 -2.37764 .77254 Mabsadd L
.91143 .3088 -0.91448 -0.29713 Mabsadd L
.91143 .3088 -1.46946 -2.02254 Mabsadd L
.91143 .3088 0 -0.96154 Mabsadd L
.91143 .3088 1.46946 -2.02254 Mabsadd L
.91143 .3088 .91448 -0.29713 Mabsadd L
.91143 .3088 2.37764 .77254 Mabsadd L
.91143 .3088 .56518 .7779 Mabsadd L
.91143 .3088 0 2.5 Mabsadd L closepath F
.91524 .30881 0 2.5 Mabsadd m
.91524 .30881 -0.56518 .7779 Mabsadd L
.91524 .30881 -2.37764 .77254 Mabsadd L
.91524 .30881 -0.91448 -0.29713 Mabsadd L
.91524 .30881 -1.46946 -2.02254 Mabsadd L
.91524 .30881 0 -0.96154 Mabsadd L
.91524 .30881 1.46946 -2.02254 Mabsadd L
.91524 .30881 .91448 -0.29713 Mabsadd L
.91524 .30881 2.37764 .77254 Mabsadd L
.91524 .30881 .56518 .7779 Mabsadd L
.91524 .30881 0 2.5 Mabsadd L closepath F
.91905 .30882 0 2.5 Mabsadd m
.91905 .30882 -0.56518 .7779 Mabsadd L
.91905 .30882 -2.37764 .77254 Mabsadd L
.91905 .30882 -0.91448 -0.29713 Mabsadd L
.91905 .30882 -1.46946 -2.02254 Mabsadd L
.91905 .30882 0 -0.96154 Mabsadd L
.91905 .30882 1.46946 -2.02254 Mabsadd L
.91905 .30882 .91448 -0.29713 Mabsadd L
.91905 .30882 2.37764 .77254 Mabsadd L
.91905 .30882 .56518 .7779 Mabsadd L
.91905 .30882 0 2.5 Mabsadd L closepath F
.92286 .30883 0 2.5 Mabsadd m
.92286 .30883 -0.56518 .7779 Mabsadd L
.92286 .30883 -2.37764 .77254 Mabsadd L
.92286 .30883 -0.91448 -0.29713 Mabsadd L
.92286 .30883 -1.46946 -2.02254 Mabsadd L
.92286 .30883 0 -0.96154 Mabsadd L
.92286 .30883 1.46946 -2.02254 Mabsadd L
.92286 .30883 .91448 -0.29713 Mabsadd L
.92286 .30883 2.37764 .77254 Mabsadd L
.92286 .30883 .56518 .7779 Mabsadd L
.92286 .30883 0 2.5 Mabsadd L closepath F
.92667 .30884 0 2.5 Mabsadd m
.92667 .30884 -0.56518 .7779 Mabsadd L
.92667 .30884 -2.37764 .77254 Mabsadd L
.92667 .30884 -0.91448 -0.29713 Mabsadd L
.92667 .30884 -1.46946 -2.02254 Mabsadd L
.92667 .30884 0 -0.96154 Mabsadd L
.92667 .30884 1.46946 -2.02254 Mabsadd L
.92667 .30884 .91448 -0.29713 Mabsadd L
.92667 .30884 2.37764 .77254 Mabsadd L
.92667 .30884 .56518 .7779 Mabsadd L
.92667 .30884 0 2.5 Mabsadd L closepath F
.93048 .30885 0 2.5 Mabsadd m
.93048 .30885 -0.56518 .7779 Mabsadd L
.93048 .30885 -2.37764 .77254 Mabsadd L
.93048 .30885 -0.91448 -0.29713 Mabsadd L
.93048 .30885 -1.46946 -2.02254 Mabsadd L
.93048 .30885 0 -0.96154 Mabsadd L
.93048 .30885 1.46946 -2.02254 Mabsadd L
.93048 .30885 .91448 -0.29713 Mabsadd L
.93048 .30885 2.37764 .77254 Mabsadd L
.93048 .30885 .56518 .7779 Mabsadd L
.93048 .30885 0 2.5 Mabsadd L closepath F
.93429 .30886 0 2.5 Mabsadd m
.93429 .30886 -0.56518 .7779 Mabsadd L
.93429 .30886 -2.37764 .77254 Mabsadd L
.93429 .30886 -0.91448 -0.29713 Mabsadd L
.93429 .30886 -1.46946 -2.02254 Mabsadd L
.93429 .30886 0 -0.96154 Mabsadd L
.93429 .30886 1.46946 -2.02254 Mabsadd L
.93429 .30886 .91448 -0.29713 Mabsadd L
.93429 .30886 2.37764 .77254 Mabsadd L
.93429 .30886 .56518 .7779 Mabsadd L
.93429 .30886 0 2.5 Mabsadd L closepath F
.9381 .30886 0 2.5 Mabsadd m
.9381 .30886 -0.56518 .7779 Mabsadd L
.9381 .30886 -2.37764 .77254 Mabsadd L
.9381 .30886 -0.91448 -0.29713 Mabsadd L
.9381 .30886 -1.46946 -2.02254 Mabsadd L
.9381 .30886 0 -0.96154 Mabsadd L
.9381 .30886 1.46946 -2.02254 Mabsadd L
.9381 .30886 .91448 -0.29713 Mabsadd L
.9381 .30886 2.37764 .77254 Mabsadd L
.9381 .30886 .56518 .7779 Mabsadd L
.9381 .30886 0 2.5 Mabsadd L closepath F
.9419 .30887 0 2.5 Mabsadd m
.9419 .30887 -0.56518 .7779 Mabsadd L
.9419 .30887 -2.37764 .77254 Mabsadd L
.9419 .30887 -0.91448 -0.29713 Mabsadd L
.9419 .30887 -1.46946 -2.02254 Mabsadd L
.9419 .30887 0 -0.96154 Mabsadd L
.9419 .30887 1.46946 -2.02254 Mabsadd L
.9419 .30887 .91448 -0.29713 Mabsadd L
.9419 .30887 2.37764 .77254 Mabsadd L
.9419 .30887 .56518 .7779 Mabsadd L
.9419 .30887 0 2.5 Mabsadd L closepath F
.94571 .30888 0 2.5 Mabsadd m
.94571 .30888 -0.56518 .7779 Mabsadd L
.94571 .30888 -2.37764 .77254 Mabsadd L
.94571 .30888 -0.91448 -0.29713 Mabsadd L
.94571 .30888 -1.46946 -2.02254 Mabsadd L
.94571 .30888 0 -0.96154 Mabsadd L
.94571 .30888 1.46946 -2.02254 Mabsadd L
.94571 .30888 .91448 -0.29713 Mabsadd L
.94571 .30888 2.37764 .77254 Mabsadd L
.94571 .30888 .56518 .7779 Mabsadd L
.94571 .30888 0 2.5 Mabsadd L closepath F
.94952 .30888 0 2.5 Mabsadd m
.94952 .30888 -0.56518 .7779 Mabsadd L
.94952 .30888 -2.37764 .77254 Mabsadd L
.94952 .30888 -0.91448 -0.29713 Mabsadd L
.94952 .30888 -1.46946 -2.02254 Mabsadd L
.94952 .30888 0 -0.96154 Mabsadd L
.94952 .30888 1.46946 -2.02254 Mabsadd L
.94952 .30888 .91448 -0.29713 Mabsadd L
.94952 .30888 2.37764 .77254 Mabsadd L
.94952 .30888 .56518 .7779 Mabsadd L
.94952 .30888 0 2.5 Mabsadd L closepath F
.95333 .30889 0 2.5 Mabsadd m
.95333 .30889 -0.56518 .7779 Mabsadd L
.95333 .30889 -2.37764 .77254 Mabsadd L
.95333 .30889 -0.91448 -0.29713 Mabsadd L
.95333 .30889 -1.46946 -2.02254 Mabsadd L
.95333 .30889 0 -0.96154 Mabsadd L
.95333 .30889 1.46946 -2.02254 Mabsadd L
.95333 .30889 .91448 -0.29713 Mabsadd L
.95333 .30889 2.37764 .77254 Mabsadd L
.95333 .30889 .56518 .7779 Mabsadd L
.95333 .30889 0 2.5 Mabsadd L closepath F
.95714 .3089 0 2.5 Mabsadd m
.95714 .3089 -0.56518 .7779 Mabsadd L
.95714 .3089 -2.37764 .77254 Mabsadd L
.95714 .3089 -0.91448 -0.29713 Mabsadd L
.95714 .3089 -1.46946 -2.02254 Mabsadd L
.95714 .3089 0 -0.96154 Mabsadd L
.95714 .3089 1.46946 -2.02254 Mabsadd L
.95714 .3089 .91448 -0.29713 Mabsadd L
.95714 .3089 2.37764 .77254 Mabsadd L
.95714 .3089 .56518 .7779 Mabsadd L
.95714 .3089 0 2.5 Mabsadd L closepath F
.96095 .3089 0 2.5 Mabsadd m
.96095 .3089 -0.56518 .7779 Mabsadd L
.96095 .3089 -2.37764 .77254 Mabsadd L
.96095 .3089 -0.91448 -0.29713 Mabsadd L
.96095 .3089 -1.46946 -2.02254 Mabsadd L
.96095 .3089 0 -0.96154 Mabsadd L
.96095 .3089 1.46946 -2.02254 Mabsadd L
.96095 .3089 .91448 -0.29713 Mabsadd L
.96095 .3089 2.37764 .77254 Mabsadd L
.96095 .3089 .56518 .7779 Mabsadd L
.96095 .3089 0 2.5 Mabsadd L closepath F
.96476 .30891 0 2.5 Mabsadd m
.96476 .30891 -0.56518 .7779 Mabsadd L
.96476 .30891 -2.37764 .77254 Mabsadd L
.96476 .30891 -0.91448 -0.29713 Mabsadd L
.96476 .30891 -1.46946 -2.02254 Mabsadd L
.96476 .30891 0 -0.96154 Mabsadd L
.96476 .30891 1.46946 -2.02254 Mabsadd L
.96476 .30891 .91448 -0.29713 Mabsadd L
.96476 .30891 2.37764 .77254 Mabsadd L
.96476 .30891 .56518 .7779 Mabsadd L
.96476 .30891 0 2.5 Mabsadd L closepath F
.96857 .30891 0 2.5 Mabsadd m
.96857 .30891 -0.56518 .7779 Mabsadd L
.96857 .30891 -2.37764 .77254 Mabsadd L
.96857 .30891 -0.91448 -0.29713 Mabsadd L
.96857 .30891 -1.46946 -2.02254 Mabsadd L
.96857 .30891 0 -0.96154 Mabsadd L
.96857 .30891 1.46946 -2.02254 Mabsadd L
.96857 .30891 .91448 -0.29713 Mabsadd L
.96857 .30891 2.37764 .77254 Mabsadd L
.96857 .30891 .56518 .7779 Mabsadd L
.96857 .30891 0 2.5 Mabsadd L closepath F
.97238 .30892 0 2.5 Mabsadd m
.97238 .30892 -0.56518 .7779 Mabsadd L
.97238 .30892 -2.37764 .77254 Mabsadd L
.97238 .30892 -0.91448 -0.29713 Mabsadd L
.97238 .30892 -1.46946 -2.02254 Mabsadd L
.97238 .30892 0 -0.96154 Mabsadd L
.97238 .30892 1.46946 -2.02254 Mabsadd L
.97238 .30892 .91448 -0.29713 Mabsadd L
.97238 .30892 2.37764 .77254 Mabsadd L
.97238 .30892 .56518 .7779 Mabsadd L
.97238 .30892 0 2.5 Mabsadd L closepath F
.97619 .30892 0 2.5 Mabsadd m
.97619 .30892 -0.56518 .7779 Mabsadd L
.97619 .30892 -2.37764 .77254 Mabsadd L
.97619 .30892 -0.91448 -0.29713 Mabsadd L
.97619 .30892 -1.46946 -2.02254 Mabsadd L
.97619 .30892 0 -0.96154 Mabsadd L
.97619 .30892 1.46946 -2.02254 Mabsadd L
.97619 .30892 .91448 -0.29713 Mabsadd L
.97619 .30892 2.37764 .77254 Mabsadd L
.97619 .30892 .56518 .7779 Mabsadd L
.97619 .30892 0 2.5 Mabsadd L closepath F
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{440.375, 272.062},
  ImageMargins->{{3, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006h000142000`400?l00000o`00003of`3IfMT0
0`000000fMWI0=WIf@3J0=WIf@00f`3IfMT00`000000fMWI0=WIf@3J0=WIf@00f`3IfMT00`000000
fMWI0=WIf@3J0=WIf@00f`3IfMT00`000000fMWI0=WIf@3J0=WIf@00aP3IfMT2000000@0fMWI0P00
00040=WIf@<000001P3IfMT00`000000fMWI0=WIf@3J0=WIf@00a@3IfMT010000000fMWI0=WIf@00
00030=WIf@8000001@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=X0fMWI002o
0=WIf@D0000000D0fMWI0000003IfMT0fMWI000000080=WIf@D0000000<0fMWI0000003IfMT00P3I
fMT400000=T0fMWI00350=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@0000001000
00030=WIf@030000003IfMT0fMWI0=X0fMWI00350=WIf@040000003IfMT0fMWI000000P0fMWI00<0
00000=WIf@0000001@0000020=WIf@030000003IfMT0fMWI0=X0fMWI00360=WIf@8000002P3IfMT2
00000080fMWI0P0000030=WIf@030000003IfMT0fMWI0=X0fMWI003D0=WIf@040000003IfMT00000
000000<0fMWI00<000000=WIf@3IfMT0fP3IfMT00=/0fMWI00<000000=WIf@3IfMT0fP3IfMT00=40
fMWI0P0000080=WIf@030000003IfMT0fMWI0=X0fMWI003B0=WIf@8000000P3IfMT300000080fMWI
00<000000=WIf@3IfMT0fP3IfMT00=40fMWI100000020=WIf@8000000P3IfMT00`000000fMWI0=WI
f@3J0=WIf@00dP3IfMT010000000fMWI0=WIf@3IfMT4000000030=WIf@000000fMWI0=/0fMWI003B
0=WIf@030000003IfMT0fMWI0080fMWI0P0000020=WIf@030000003IfMT0fMWI0=X0fMWI003B0=WI
f@030000003IfMT0fMWI00<0fMWI00@000000=WIf@3IfMT00000g03IfMT00=/0fMWI00<000000=WI
f@3IfMT0fP3IfMT00=/0fMWI00<000000=WIf@3IfMT0fP3IfMT00=80fMWI00<000000=WIf@3IfMT0
103IfMT00`000000fMWI0000000V0=WIf@030000003IfMT000000;<0fMWI003K0=WIf@030000003I
fMT0fMWI02@0fMWI0`00002c0=WIf@00f`3IfMT3000002@0fMWI1@00002a0=WIf@00d@3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0000002L0fMWI0`00002b0=WIf@00d03IfMT3000000H0
fMWI00<000000=WIf@0000009P3IfMT2000000030=WIf@00000000000;40fMWI003@0=WIf@<00000
203IfMT00`000000fMWI0=WIf@3J0=WIf@00d03IfMT4000000@0fMWI0P0000000`3IfMT000000=WI
f@0T0=WIf@030000003IfMT0fMWI0;@0fMWI003A0=WIf@030000003IfMT0fMWI00D0fMWI0`00000U
0=WIf@8000000P3IfMT200000;40fMWI003A0=WIf@030000003IfMT0fMWI00@0fMWI1000000T0=WI
f@@000000P3IfMT200000;00fMWI003I0=WIf@030000003IfMT0000002T0fMWI1000002_0=WIf@00
d@3IfMT00`000000fMWI0=WIf@060=WIf@8000009@3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0:l0fMWI003A0=WIf@030000003IfMT0fMWI00H0fMWI0P00000U0=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT0[P3IfMT00=/0fMWI00<000000=WIf@3IfMT0fP3IfMT0
0=/0fMWI00<000000=WIf@3IfMT0fP3IfMT00=00fMWI00<000000=WIf@3IfMT01`3IfMT2000002D0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2^0=WIf@00f`3IfMT00`000000fMWI
0=WIf@0Z0=WIf@030000003IfMT0fMWI0:d0fMWI003K0=WIf@030000003IfMT0fMWI0=X0fMWI003@
0=WIf@030000003IfMT0fMWI00L0fMWI0P00000R0=WIf@<00000]`3IfMT00=00fMWI00<000000=WI
f@3IfMT01`3IfMT400000240fMWI0P0000070=WIf@030000003IfMT0fMWI0:d0fMWI003K0=WIf@03
0000003IfMT0fMWI0240fMWI0`0000050=WIf@030000003IfMT000000:h0fMWI003K0=WIf@030000
003IfMT0fMWI0240fMWI0P0000060=WIf@<00000[P3IfMT00<h0fMWI00<000000=WIf@0000002P3I
fMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0fMWI00@0fMWI1000002]0=WIf@00c`3IfMT2
000000X0fMWI00<000000=WIf@3IfMT0:P3IfMT00`000000fMWI0=WIf@2]0=WIf@00cP3IfMT40000
00T0fMWI00<000000=WIf@3IfMT0fP3IfMT00<l0fMWI00<000000=WIf@3IfMT0203IfMT300000280
fMWI00<000000=WIf@3IfMT0]P3IfMT00<l0fMWI00<000000=WIf@3IfMT0203IfMT300000280fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@2/0=WIf@00fP3IfMT400000=X0fMWI003K
0=WIf@030000003IfMT0fMWI0=X0fMWI003?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT08@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0:`0fMWI003K0=WIf@03
0000003IfMT0fMWI02/0fMWI00<000000=WIf@3IfMT0[03IfMT00=/0fMWI00<000000=WIf@3IfMT0
fP3IfMT00<l0fMWI00<000000=WIf@3IfMT02@3IfMT200000280fMWI00<000000=WIf@3IfMT0]P3I
fMT00<l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT0Z`3IfMT00=/0fMWI00<000000=WIf@3IfMT0fP3IfMT00=/0
fMWI0P00000P0=WIf@030000003IfMT0000000T0fMWI00<000000=WIf@3IfMT0[03IfMT00<h0fMWI
00<000000=WIf@3IfMT02P3IfMT3000001l0fMWI0`0000090=WIf@800000[@3IfMT00=/0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0000000J0=WIf@@00000203IfMT300000:`0fMWI003K
0=WIf@040000003IfMT0fMWI0=WIf@D000006P3IfMT00`000000fMWI0=WIf@080=WIf@800000[@3I
fMT00<h0fMWI00<000000=WIf@3IfMT02P3IfMT200000080fMWI1@00000J0=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT0Z`3IfMT00<h0fMWI00<000000=WIf@3IfMT02P3IfMT00`00
0000fMWI0=WIf@020=WIf@040000003IfMT00000000001X0fMWI00<000000=WIf@3IfMT02@3IfMT0
0`000000fMWI0=WIf@2[0=WIf@00f`3IfMT01@000000fMWI0=WIf@3IfMT0000000<0fMWI0P00003C
0=WIf@00f`3IfMT2000000030=WIf@000000000000<0fMWI0P00003C0=WIf@00cP3IfMT00`000000
fMWI0=WIf@0:0=WIf@80000000<0fMWI0000000000000`3IfMT2000001T0fMWI00<000000=WIf@3I
fMT02P3IfMT00`000000fMWI0=WIf@2Z0=WIf@00c@3IfMT00`000000fMWI0=WIf@0;0=WIf@050000
003IfMT0fMWI0=WIf@000000103IfMT00`000000fMWI0=WIf@0T0=WIf@030000003IfMT0fMWI0:X0
fMWI003<0=WIf@@000002`3IfMT010000000fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI0=40
fMWI003=0=WIf@800000303IfMT010000000fMWI0000000000060=WIf@030000003IfMT0fMWI01D0
fMWI00<000000=WIf@3IfMT0^03IfMT00<h0fMWI00<000000=WIf@3IfMT02P3IfMT2000000030=WI
f@000000fMWI00D0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@0;0=WIf@030000
003IfMT0fMWI0:X0fMWI003K0=WIf@<000001`3IfMT00`000000fMWI0=WIf@3@0=WIf@00f`3IfMT4
000000D0fMWI0`00000F0=WIf@030000003IfMT0fMWI0;P0fMWI00360=WIf@800000103IfMT20000
00<0fMWI100000060=WIf@@00000103IfMT4000001H0fMWI00<000000=WIf@3IfMT02`3IfMT00`00
0000fMWI0=WIf@2Z0=WIf@00a@3IfMT010000000fMWI0=WIf@0000030=WIf@800000103IfMT00`00
0000fMWI0=WIf@060=WIf@@000001@3IfMT300000=40fMWI002c0=WIf@030000003IfMT0000000T0
fMWI1@0000001@3IfMT000000=WIf@3IfMT0000000X0fMWI00<000000=WIf@3IfMT01@3IfMT40000
00H0fMWI00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0000002X0=WIf@00/P3IfMT5000000h0
fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00@0fMWI0`0000080=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0303IfMT50000
0:L0fMWI002b0=WIf@D000003P3IfMT010000000fMWI0=WIf@0000040=WIf@050000003IfMT0fMWI
0=WIf@0000000P3IfMT00`000000fMWI0=WIf@040=WIf@8000002@3IfMT00`000000fMWI0=WIf@0R
0=WIf@H00000Y`3IfMT00;80fMWI0P0000000`3IfMT000000=WIf@0?0=WIf@8000002P3IfMT20000
00L0fMWI0P0000090=WIf@030000003IfMT0fMWI0240fMWI100000000`3IfMT000000000002W0=WI
f@00/@3IfMT2000000<0fMWI00<000000=WIf@3IfMT08P3IfMT3000000P0fMWI00<000000=WIf@3I
fMT04P3IfMT3000000d0fMWI0P0000030=WIf@800000YP3IfMT00;40fMWI0P0000020=WIf@<00000
5@3IfMT00`000000fMWI0=WIf@0;0=WIf@<00000203IfMT00`000000fMWI0=WIf@0C0=WIf@800000
3@3IfMT300000080fMWI0`00002U0=WIf@00/03IfMT300000080fMWI0`00000S0=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT04@3IfMT4000000`0fMWI0`0000000`3IfMT000000000
000200000:D0fMWI002a0=WIf@8000000`3IfMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@0=0=WIf@040000003IfMT0
fMWI0=WIf@<00000Y@3IfMT00:H0fMWI00D000000=WIf@000000fMWI000000060=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@0:0=WIf@<0000000<0
fMWI0000003IfMT01P3IfMT3000001<0fMWI00<000000=WIf@3IfMT0303IfMT2000000@0fMWI00<0
00000=WIf@3IfMT0Y03IfMT00:D0fMWI1P0000060=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@090=WIf@@00000203IfMT400000280fMWI0P000004
0=WIf@030000003IfMT0fMWI0:@0fMWI002U0=WIf@H000001@3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI0200fMWI0`0000090=WIf@<000008P3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI0:<0fMWI002T0=WIf@H000001P3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI0240fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@0B0=WI
f@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2S0=WI
f@00X`3IfMT3000000<0fMWI0P0000050=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT04@3IfMT2000000d0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@0A0=WI
f@030000003IfMT0fMWI00/0fMWI00<000000=WIf@0000001@3IfMT00`000000fMWI0=WIf@2S0=WI
f@00X`3IfMT3000000@0fMWI0P0000030=WIf@<000001@3IfMT300000240fMWI00<000000=WIf@3I
fMT02P3IfMT00`000000fMWI0=WIf@0N0=WIf@<000001@3IfMT300000:@0fMWI002S0=WIf@<00000
0`3IfMT4000000030=WIf@0000000000008000001@3IfMT300000240fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@0N0=WIf@<00000103IfMT400000:@0fMWI002S0=WIf@8000002P3I
fMT3000000H0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0<0=WIf@040000003I
fMT0fMWI000000T0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0;0=WIf@040000
003IfMT0fMWI000000<0fMWI0`00002T0=WIf@00X`3IfMT00`000000fMWI0=WIf@050=WIf@800000
0`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0
2`3IfMT4000000X0fMWI00<000000=WIf@3IfMT07`3IfMT010000000fMWI0=WIf@0000040=WIf@03
0000003IfMT0fMWI0:<0fMWI002_0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0
3`3IfMT00`000000fMWI0000000<0=WIf@800000303IfMT00`000000fMWI0=WIf@0N0=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0XP3IfMT00:40fMWI00<000000=WIf@0000002`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00l0fMWI1000000;0=WIf@8000000P3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0:80fMWI002Q0=WIf@@000001P3IfMT3
000000030=WIf@000000fMWI00P0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0;
0=WIf@8000000P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0100fMWI00<00000
0=WIf@3IfMT02P3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00<000000=WIf@3IfMT0XP3I
fMT00:80fMWI00<000000=WIf@3IfMT01P3IfMT3000000030=WIf@000000fMWI00P0fMWI00<00000
0=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0;0=WIf@8000003@3IfMT00`000000fMWI0=WIf@0M
0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0XP3IfMT00:80fMWI00<000000=WI
f@3IfMT01P3IfMT5000000T0fMWI00<000000=WIf@3IfMT07P3IfMT2000000030=WIf@0000000000
00X0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
0:80fMWI002R0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@0000002`3IfMT00`000000
fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00X0fMWI0`0000020=WIf@800000203IfMT200000140
fMWI00<000000=WIf@3IfMT02P3IfMT010000000fMWI0=WIf@3IfMT3000000D0fMWI00<000000=WI
f@3IfMT0X@3IfMT00:80fMWI00<000000=WIf@3IfMT0203IfMT2000000/0fMWI00<000000=WIf@3I
fMT03`3IfMT00`000000fMWI0=WIf@090=WIf@@0000000<0fMWI0000000000000P0000060=WIf@<0
00007P3IfMT010000000fMWI0=WIf@3IfMT4000000@0fMWI00<000000=WIf@3IfMT0X@3IfMT00:d0
fMWI0`0000090=WIf@<000007@3IfMT300000080fMWI00<000000=WIf@3IfMT01`3IfMT2000001d0
fMWI0`0000030=WIf@030000003IfMT0fMWI00<0fMWI0`00002R0=WIf@00W`3IfMT2000000/0fMWI
100000080=WIf@@000007P3IfMT2000000<0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@0?0=WIf@030000003IfMT0fMWI00P0fMWI100000030=WIf@030000003IfMT0fMWI0080fMWI
1000002R0=WIf@00X03IfMT2000000/0fMWI0`0000090=WIf@<00000403IfMT00`000000fMWI0=WI
f@0;0=WIf@8000000`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00l0fMWI00<0
00000=WIf@3IfMT02@3IfMT3000000@0fMWI00<000000=WIf@3IfMT00P3IfMT300000:80fMWI002O
0=WIf@@000002P3IfMT2000000/0fMWI00<000000=WIf@3IfMT0703IfMT00`000000fMWI0000000=
0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@2Q
0=WIf@00X03IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0703IfMT00`000000fMWI0000000=0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@2P0=WIf@00X03IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0;0=WIf@03
0000003IfMT0000000<0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0>0=WIf@80
0000303IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0X03IfMT00:d0fMWI0`00000:0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0
2`3IfMT00`000000fMWI0000000=0=WIf@030000003IfMT0fMWI00h0fMWI0P00000<0=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2P0=WIf@00[@3I
fMT3000000X0fMWI00<000000=WIf@3IfMT0703IfMT00`000000fMWI0000000>0=WIf@030000003I
fMT0fMWI00d0fMWI0`00000;0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0X03I
fMT00:00fMWI00<000000=WIf@3IfMT02P3IfMT3000000/0fMWI00<000000=WIf@3IfMT06`3IfMT0
0`000000fMWI00000002000000030=WIf@000000fMWI00T0fMWI00<000000=WIf@3IfMT03P3IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0X03IfMT0
0:00fMWI00<000000=WIf@3IfMT02P3IfMT2000000`0fMWI00<000000=WIf@3IfMT03@3IfMT00`00
0000fMWI0=WIf@0;0=WIf@030000003IfMT0000000<0fMWI00<000000=WIf@3IfMT0203IfMT00`00
0000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0:00fMWI002]0=WIf@800000303IfMT00`000000
fMWI0=WIf@0K0=WIf@030000003IfMT0000000h0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI0:00fMWI002N0=WIf@030000003IfMT0000000/0fMWI
00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0J0=WIf@040000003IfMT0fMWI000000h0
fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI09l0
fMWI002N0=WIf@<000002`3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00d0fMWI
00<000000=WIf@3IfMT02P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT03@3IfMT2000000/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI09l0fMWI002N0=WIf@<000002`3IfMT2000000030=WI
f@000000fMWI00X0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0:0=WIf@040000
003IfMT0fMWI000000h0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00@0fMWI0`00002P0=WIf@00W`3IfMT00`000000fMWI0=WIf@090=WIf@<00000
3@3IfMT00`000000fMWI0=WIf@0I0=WIf@<0000000<0fMWI0000003IfMT0303IfMT3000001/0fMWI
00<000000=WIf@3IfMT02P3IfMT400000:00fMWI002N0=WIf@030000003IfMT0fMWI00/0fMWI0P00
000<0=WIf@<000006P3IfMT3000000030=WIf@000000fMWI00<0fMWI00<000000=WIf@3IfMT01P3I
fMT3000000h0fMWI00<000000=WIf@3IfMT02@3IfMT3000000`0fMWI0`00002P0=WIf@00WP3IfMT0
0`000000fMWI0=WIf@0;0=WIf@040000003IfMT0fMWI000000X0fMWI0`00000>0=WIf@030000003I
fMT0fMWI00X0fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT02@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
103IfMT00`000000fMWI0=WIf@2O0=WIf@00[03IfMT010000000fMWI0=WIf@00000;0=WIf@030000
003IfMT0fMWI01X0fMWI00@000000=WIf@3IfMT000003P3IfMT00`000000fMWI0=WIf@0J0=WIf@03
0000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0W`3IfMT00:`0fMWI00<000000=WIf@3IfMT0
303IfMT00`000000fMWI0=WIf@0J0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3I
fMT06P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI09l0fMWI002N0=WIf@030000
003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0=0=WIf@030000
003IfMT0fMWI00T0fMWI00D000000=WIf@3IfMT0fMWI000000040=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00@0
fMWI0P0000060=WIf@030000003IfMT0fMWI09l0fMWI002/0=WIf@040000003IfMT0fMWI000000`0
fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0000000;0=WIf@050000003IfMT0fMWI0=WI
f@0000003`3IfMT00`000000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI00D0fMWI0`0000050=WI
f@030000003IfMT0fMWI09l0fMWI002L0=WIf@030000003IfMT0000000`0fMWI00<000000=WIf@3I
fMT03P3IfMT00`000000fMWI0=WIf@0;0=WIf@8000002`3IfMT01@000000fMWI0=WIf@3IfMT00000
00l0fMWI00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@050=WIf@8000001`3IfMT00`00
0000fMWI0=WIf@2N0=WIf@00W03IfMT3000000`0fMWI00D000000=WIf@3IfMT0fMWI0000000<0=WI
f@030000003IfMT0fMWI00X0fMWI1000000:0=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT0
0`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02@3IfMT0
0`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0WP3IfMT0
09`0fMWI1000000;0=WIf@040000003IfMT0fMWI0=WIf@8000002`3IfMT00`000000fMWI0=WIf@0;
0=WIf@030000003IfMT0fMWI00X0fMWI00D000000=WIf@3IfMT0fMWI000000040=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@2N0=WIf@00W@3IfMT0
0`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@000002P3IfMT00`000000fMWI0=WIf@0H
0=WIf@050000003IfMT0fMWI0=WIf@0000003`3IfMT00`000000fMWI0=WIf@0H0=WIf@030000003I
fMT0fMWI00h0fMWI00<000000=WIf@3IfMT0WP3IfMT00:/0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI01P0fMWI00@000000=WIf@3IfMT0fMWI0`00
0000103IfMT000000=WIf@0000090=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0
3P3IfMT00`000000fMWI0=WIf@2N0=WIf@00W@3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003I
fMT0fMWI00X0fMWI00D000000=WIf@3IfMT0fMWI000000030=WIf@<000002@3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI
0=WIf@050=WIf@030000003IfMT0fMWI09h0fMWI002Z0=WIf@<000003`3IfMT00`000000fMWI0=WI
f@0;0=WIf@030000003IfMT0fMWI00X0fMWI00D000000=WIf@3IfMT0fMWI000000030=WIf@@00000
203IfMT00`000000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0
0`3IfMT3000009l0fMWI000_0=WIf@@000000`3IfMT2000000@0fMWI0P0000150=WIf@<00000103I
fMT2000000@0fMWI0P00000G0=WIf@@000003`3IfMT00`000000fMWI0=WIf@0G0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI01L0fMWI00<000000=WIf@3IfMT0303IfMT4000000h0fMWI0`0000040=WIf@800000103I
fMT2000004@0fMWI100000030=WIf@800000103IfMT2000002l0fMWI000`0=WIf@030000003IfMT0
fMWI0080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000150=WIf@030000
003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000090=WI
f@030000003IfMT0fMWI00/0fMWI0`0000030=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT05P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT03P3IfMT3000000l0fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WIf@000002
0=WIf@040000003IfMT0fMWI000004@0fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WI
f@0000020=WIf@040000003IfMT0fMWI000002h0fMWI000Y0=WIf@D000000`3IfMT01@000000fMWI
0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0l0=WI
f@D000000P3IfMT00`000000fMWI0=WIf@020=WIf@040000003IfMT0fMWI00000080fMWI00@00000
0=WIf@3IfMT000001`3IfMT3000000h0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@0>0=WIf@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI
0=WIf@0000150=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@000002
0=WIf@030000003IfMT0fMWI02`0fMWI000b0=WIf@040000003IfMT0fMWI00000080fMWI00@00000
0=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@130=WIf@030000003IfMT0fMWI0080fMWI00@0
00000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000080=WIf@8000003@3IfMT00`000000
fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI01D0fMWI0`0000030=WIf@030000003IfMT0fMWI00d0
fMWI0`00000G0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT03@3IfMT00`000000
fMWI0=WIf@020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000AP3IfMT0
10000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT0
;03IfMT002l0fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000020=WIf@04
0000003IfMT0fMWI000004D0fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WIf@000002
0=WIf@040000003IfMT0fMWI000000L0fMWI1000000<0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT0203IfMT3000001D0fMWI100000030=WIf@030000003IfMT0fMWI00`0fMWI1000
000:0=WIf@030000003IfMT0000000T0fMWI0`00000A0=WIf@030000003IfMT0fMWI00d0fMWI00<0
00000=WIf@3IfMT00P3IfMT5000000050=WIf@000000fMWI0=WIf@000000@`3IfMT010000000fMWI
0=WIf@0000020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000;P3IfMT0
0300fMWI0P0000040=WIf@800000103IfMT2000004D0fMWI0P0000050=WIf@800000103IfMT20000
00T0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00P0fMWI0`00000;0=WIf@030000003IfMT0fMWI00P0fMWI0`0000030=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT01`3IfMT3000000X0fMWI0`0000090=WIf@<000002@3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00`0fMWI0P0000030=WIf@030000003IfMT00000
00P00000A03IfMT2000000@0fMWI0P0000040=WIf@800000;`3IfMT00:X0fMWI00<000000=WIf@3I
fMT0403IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00T0fMWI100000090=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0?0=WIf@03
0000003IfMT0000000`00000O`3IfMT00:X0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI
0=WIf@0F0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI
0=WIf@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI
0=WIf@0?0=WIf@@000000P3IfMT00`000000fMWI00000007000000040=WIf@000000fMWI000007X0
fMWI002J0=WIf@8000003P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI
00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0?0=WIf@@00000103IfMT01@000000fMWI
0=WIf@000000fMWI00P0000000<0fMWI0000003IfMT0MP3IfMT00:X0fMWI00<000000=WIf@3IfMT0
4@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@0=0=WIf@80000000<0fMWI0000003IfMT0203IfMT00`000000fMWI
0000000<000000040=WIf@000000fMWI00000700fMWI002I0=WIf@030000003IfMT0fMWI00d0fMWI
00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI0180fMWI
00<000000=WIf@3IfMT03@3IfMT3000000h0fMWI00<000000=WIf@000000300000000`3IfMT00000
00000002000000030=WIf@000000fMWI06L0fMWI00260=WIf@060000003IfMT000000000003IfMT0
00003@3IfMT3000000d0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@03
0000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0203IfMT2000000P0fMWI00<000000=WIf@3I
fMT0303IfMT4000000/0fMWI00H000000=WIf@00000000000=WIf@0000020=WIf@030000003IfMT0
000000h0000000@0fMWI000000000000fMWI100000000`3IfMT0000000000008000000030=WIf@00
0000fMWI0580fMWI00090=WIfEH0000000H0fMWI000000000000fMWI0000003IfMT2000000030=WI
f@000000fMWI0080000000<0fMWI0000003IfMT00P0000000`3IfMT000000=WIf@02000000030=WI
f@000000fMWI0080000000<0fMWI0000003IfMT00P0000000`3IfMT000000=WIf@0<000000040=WI
f@000000fMWI000000H0fMWI0P00000=0=WIf@<000001P3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02@3IfMT2000000H0fMWI0`00000>0=WIf@03
0000003IfMT0fMWI00@0fMWI00@000000=WIf@000000fMWI300000000`3IfMT000000=WIf@020000
00030=WIf@000000000006H000002P3IfMT00?l00000^00000010=WIf@000P3IfMT00`000000fMWI
0=WIf@040=WIfHd000000P3IfMT00`000000fMWI0=WIf@0=0=WIf@<000001@3IfMT4000000H0fMWI
00D000000=WIf@3IfMT0fMWI0000000;0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@0>0=WIf@8000003`3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00H0fMWI00@000000=WIf@3IfMT000001`3IfMT3000000<0fMWI00<000000=WI
f@3IfMT01P3IfMT00`000000fMWI000000030=WIfH4000001P3IfMT00`000000fMWI0=WIf@010=WI
f@000P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0000001L0000000<0fMWI00000000
00000P0000000`3IfMT0000000000002000000030=WIf@00000000000080000000<0fMWI00000000
00000P0000000`3IfMT0000000000002000000030=WIf@00000000000080000000<0fMWI00000000
00000P0000000`3IfMT0000000000002000000030=WIf@000000000003<0000000H0fMWI00000000
0000fMWI0000003IfMT2000000030=WIf@000000fMWI00d000003`3IfMT00`000000fMWI0=WIf@05
0=WIf@8000001`3IfMT01@000000fMWI0=WIf@3IfMT0000000/0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0203I
fMT2000000/0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI00H0fMWI
00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI
0`0000020=WIf@X0000000<0fMWI0000003IfMT00P0000000`3IfMT000000=WIf@02000000030=WI
f@000000fMWI0080000000<0fMWI0000003IfMT00P0000000`3IfMT000000=WIf@02000000030=WI
f@000000fMWI0080000000<0fMWI0000003IfMT00P0000001@3IfMT000000=WIf@000000fMWI0080
000000<0fMWI0000003IfMT00P0000000`3IfMT000000=WIf@02000000030=WIf@000000fMWI0080
000000<0fMWI0000003IfMT00P0000000`3IfMT000000=WIf@02000000030=WIf@000000fMWI0080
000000<0fMWI0000003IfMT00P0000000`3IfMT000000=WIf@02000000030=WIf@000000fMWI0080
000000<0fMWI0000003IfMT00P0000000`3IfMT000000=WIf@02000000030=WIf@000000fMWI0080
000000<0fMWI0000003IfMT00P0000000`3IfMT000000=WIf@02000000030=WIf@000000fMWI0080
000000<0fMWI0000003IfMT01P3IfMT00`000000fMWI0=WIf@010=WIf@003`3IfMT00`000000fMWI
000000020=WIf@030000003IfMT000000080fMWI00<000000=WIf@0000000P3IfMT00`000000fMWI
000000020=WIf@030000003IfMT000000080fMWI00<000000=WIf@0000000P3IfMT00`000000fMWI
000000020=WIf@030000003IfMT000000080fMWI00<000000=WIf@0000000P3IfMT00`000000fMWI
000000020=WIf@030000003IfMT000000080fMWI00<000000=WIf@0000000P3IfMT00`000000fMWI
000000040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT2000000030=WI
f@000000fMWI0080000000<0fMWI0000003IfMT03`0000001@3IfMT000000=WIf@3IfMT0000000L0
fMWI00<000000=WIf@0000002000000=0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT02P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3I
fMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@0:0=WIf@<0000000<0fMWI000000000000100000000`3IfMT0
00000=WIf@1>0=WIf@030000003IfMT0fMWI03<0fMWI001`0=WIf@030000003IfMT0fMWI0080fMWI
00D000000=WIf@00000000000=WIf@0>000000/0fMWI1P00000?0=WIf@030000003IfMT0fMWI01<0
fMWI00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0100
fMWI00<000000=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI00X0
fMWI0P0000000`3IfMT0000000000004000008P0fMWI001j0=WIf@030000003IfMT000000080fMWI
2P0000000`3IfMT000000=WIf@090=WIf@@000003`3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@0D0=WIf@030000
003IfMT0fMWI00X0fMWI0P0000000`3IfMT0000000000002000008X0fMWI001o0=WIf@030000003I
fMT000000080fMWI2P0000000`3IfMT000000=WIf@030=WIf@030000003IfMT0000000<000003P3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI00000002000008`0fMWI00240=WIf@050000003IfMT000000000003IfMT02P00
00000`3IfMT0000000000004000000h0fMWI00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WI
f@050=WIf@<000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00H0fMWI00<0
00000=WIf@3IfMT02`3IfMT4000008`0fMWI00290=WIfA800000303IfMT00`000000fMWI0=WIf@0D
0=WIf@<000001`3IfMT2000000X0fMWI0P0000050=WIf@030000003IfMT0fMWI00l0fMWI0P00000C
0=WIf@<000005P3IfMT00`000000fMWI0=WIf@0:0=WIf@@00000S03IfMT008/0fMWI00<000000=WI
f@3IfMT0200000020=WIf@@000002`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI
00P0fMWI100000060=WIf@@00000203IfMT3000000D0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@070=WIf@<000002@3IfMT00`000000fMWI0=WIf@060=WIf@@000005P3IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0000000<00000S@3IfMT008h0fMWI00P000000=WIf@00
000000000=WIf@000000fMWI00000080fMWI1000000;0=WIf@8000005@3IfMT3000000P0fMWI00<0
00000=WIf@3IfMT0203IfMT2000000D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@080=WIf@8000002@3IfMT00`000000fMWI0=WIf@070=WIf@<000003@3IfMT00`000000fMWI0=WI
f@050=WIf@<00000203IfMT5000008h0fMWI002C0=WIf@030000003IfMT0fMWI00<0fMWI0`00000:
0=WIf@<000005P3IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI01<0fMWI10000008
0=WIf@D00000SP3IfMT009X0fMWI0`00000:0=WIf@8000002@3IfMT00`000000fMWI0=WIf@0:0=WI
f@030000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0@0=WI
f@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT0503IfMT3000000T0fMWI0`00002?0=WI
f@00V`3IfMT3000000T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@060=WIf@03
0000003IfMT0fMWI00P0fMWI0P00002@0=WIf@00VP3IfMT4000000T0fMWI00<000000=WIf@3IfMT0
5@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
4P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0
1`3IfMT300000900fMWI002K0=WIf@<00000203IfMT00`000000fMWI0=WIf@0F0=WIf@030000003I
fMT0fMWI0180fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@@000002P3I
fMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT01`3I
fMT200000900fMWI002L0=WIf@800000203IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@040=WIf@<000000`3IfMT2
000000/0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI01H0fMWI00<000000=WIf@3IfMT01P3IfMT200000940fMWI002M0=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
00`0fMWI0`0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0T03IfMT009`0
fMWI0`0000070=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0403IfMT00`000000
fMWI0=WIf@0<0=WIf@<00000203IfMT00`000000fMWI0=WIf@040=WIf@@00000T@3IfMT009`0fMWI
0`0000060=WIf@<000002`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0140fMWI
00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00@0fMWI
0P00000:0=WIf@030000003IfMT0fMWI00`0fMWI100000060=WIf@<000001P3IfMT300000940fMWI
002M0=WIf@8000001P3IfMT3000000X0fMWI0`00000;0=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@050=WIf@8000002@3IfMT00`000000fMWI0=WI
f@0=0=WIf@8000001`3IfMT3000000D0fMWI1000002A0=WIf@00WP3IfMT2000000D0fMWI0P00000;
0=WIf@<000002`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00@0fMWI10000008
0=WIf@030000003IfMT0fMWI00d0fMWI0P0000080=WIf@8000001@3IfMT2000009<0fMWI002N0=WI
f@<00000103IfMT00`000000fMWI0=WIf@0:0=WIf@<000002`3IfMT00`000000fMWI0=WIf@0@0=WI
f@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@020=WI
f@<00000T`3IfMT009h0fMWI0`0000030=WIf@8000003@3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@080=WIf@03
0000003IfMT0fMWI01P0fMWI0P0000030=WIf@<00000T`3IfMT009l0fMWI0`000000103IfMT00000
00000000000=0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00L0fMWI0`000000103IfMT0000000000000002D0=WI
f@00X03IfMT6000001X0fMWI0P00000A0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT04@3IfMT00`000000fMWI0=WIf@0?0=WIf@8000006@3IfMT7000009D0fMWI002O0=WIf@L00000
3@3IfMT00`000000fMWI0=WIf@090=WIf@<00000403IfMT3000000H0fMWI00<000000=WIf@3IfMT0
403IfMT3000000l0fMWI0`00000J0=WIf@P00000T`3IfMT00:00fMWI1@00000>0=WIf@030000003I
fMT0fMWI00X0fMWI0P0000060=WIf@030000003IfMT0fMWI00L0fMWI0`0000060=WIf@030000003I
fMT0fMWI00D0fMWI00<000000=WIf@3IfMT0203IfMT3000000H0fMWI00<000000=WIf@3IfMT01`3I
fMT200000100fMWI00<000000=WIf@3IfMT0203IfMT5000009D0fMWI002Q0=WIf@8000007@3IfMT0
0`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT04@3IfMT0
0`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT02P3IfMT3
000000030=WIf@000000fMWI0980fMWI00300=WIf@030000003IfMT0fMWI0100fMWI00<000000=WI
f@3IfMT01@3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WI
f@3IfMT07@3IfMT3000009<0fMWI002d0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@0N0=WIf@<00000T`3IfMT00<40fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0
TP3IfMT00<40fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@060=WIf@<000004P3I
fMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI0;@0fMWI002d0=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0
fMWI0180fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0
fMWI00`0fMWI00<000000=WIf@3IfMT0T`3IfMT00;@0fMWI00<000000=WIf@3IfMT02P3IfMT00`00
0000fMWI0=WIf@020=WIf@<000002@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
00D0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00L0fMWI00<000000=WIf@3IfMT03`3IfMT200000:<0fMWI00310=WIf@030000003IfMT0fMWI0080
fMWI0`0000090=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000
fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00l0fMWI0`00002R0=WIf@00`@3IfMT00`000000fMWI
0=WIf@020=WIf@@00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0180fMWI
00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00/0fMWI
00<000000=WIf@3IfMT0T`3IfMT00;@0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT0T`3IfMT00<80fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0A0=WIf@8000002P3IfMT00`000000fMWI0000002E
0=WIf@00`P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT04`3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI01d0fMWI1000002D0=WI
f@00]@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@2D0=WIf@00/`3IfMT3000000/0fMWI0`0000030=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@050=WIf@030000
003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@<00000
4`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI09@0fMWI002d0=WIf@8000002P3I
fMT4000000`0fMWI0`0000080=WIf@030000003IfMT0fMWI00@0fMWI0P00000<0=WIf@<000002`3I
fMT4000001<0fMWI00<000000=WIf@3IfMT0X03IfMT00;<0fMWI1000000:0=WIf@<00000303IfMT3
000000P0fMWI00<000000=WIf@3IfMT01@3IfMT2000000/0fMWI0`00000<0=WIf@<000007P3IfMT0
0`000000fMWI0=WIf@2E0=WIf@00]03IfMT2000000`0fMWI00D000000=WIf@3IfMT0fMWI0000000:
0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0103IfMT4000000/0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0140fMWI0`000009
0=WIf@030000003IfMT0fMWI09D0fMWI00330=WIf@040000003IfMT0fMWI000000X0fMWI00<00000
0=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00X0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI01<0fMWI0P000007
0=WIf@800000V03IfMT00<<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@080=WI
f@030000003IfMT0fMWI01@0fMWI00@000000=WIf@00000000002@3IfMT00`000000fMWI0=WIf@0B
0=WIf@@000001`3IfMT2000009L0fMWI002e0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WI
f@3IfMT00P0000080=WIf@030000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT01P3IfMT40000
09H0fMWI002e0=WIf@030000003IfMT0fMWI00/0fMWI00@000000=WIf@3IfMT000002@3IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT02`3IfMT00`00
0000fMWI0=WIf@03000000L0fMWI00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@060=WI
f@030000003IfMT0fMWI09H0fMWI00330=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0203IfMT3000001@0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@2f0=WI
f@00``3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT0503IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3I
fMT0UP3IfMT00;D0fMWI00<000000=WIf@3IfMT02`3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0;0=WIf@05
0000003IfMT0fMWI0=WIf@000000203IfMT00`000000fMWI0=WIf@0D0=WIf@<00000103IfMT00`00
0000fMWI0=WIf@2H0=WIf@00a03IfMT00`000000fMWI000000090=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0;0=WIf@050000003IfMT0fMWI0=WI
f@0000001`3IfMT00`000000fMWI0=WIf@0E0=WIf@<00000103IfMT2000009T0fMWI00340=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0E0=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT05@3IfMT4000000<0fMWI0`00002H0=WIf@00
]P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
5P3IfMT01P000000fMWI0=WIf@3IfMT000000=WIf@800000V@3IfMT00;H0fMWI00<000000=WIf@3I
fMT02P3IfMT4000000P0fMWI0P00000:0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT02`3IfMT2000000030=WIf@000000fMWI00H0fMWI0`00000G0=WIf@L00000VP3IfMT00<<0fMWI
0`0000080=WIf@<000002P3IfMT00`000000fMWI0=WIf@0C0=WIf@<000002@3IfMT3000001P0fMWI
1`00002I0=WIf@00a03IfMT00`000000fMWI0=WIf@080=WIf@8000002P3IfMT00`000000fMWI0=WI
f@0D0=WIf@8000002P3IfMT00`000000fMWI0=WIf@0G0=WIf@D00000V`3IfMT00;H0fMWI00<00000
0=WIf@3IfMT02`3IfMT00`000000fMWI000000080=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0000000P0fMWI00<00000
0=WIf@3IfMT0603IfMT2000000030=WIf@000000fMWI09X0fMWI00340=WIf@030000003IfMT00000
00P0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
00/0fMWI00<000000=WIf@000000203IfMT00`000000fMWI0=WIf@2g0=WIf@00a03IfMT3000000P0
fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT0]`3IfMT00;D0fMWI0`00000<0=WIf@@000001P3IfMT00`000000fMWI
0=WIf@0:0=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI
0=WIf@2h0=WIf@00]P3IfMT2000000d0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0303IfMT2000000L0fMWI00<0
00000=WIf@3IfMT0^03IfMT00;D0fMWI1000000<0=WIf@<00000103IfMT300000080fMWI10000006
0=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@2h
0=WIf@00]P3IfMT00`000000fMWI0=WIf@0<0=WIf@040000003IfMT0fMWI000000<0fMWI0`000003
0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI0;P0fMWI002f0=WIf@8000003@3IfMT010000000fMWI0=WIf@000005
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01@3IfMT4000000H0fMWI00<00000
0=WIf@3IfMT0303IfMT2000000L0fMWI00<000000=WIf@3IfMT0^03IfMT00<@0fMWI0`0000000`3I
fMT000000=WIf@030=WIf@<00000103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00L0fMWI00<000000=WIf@3IfMT02`3IfMT3000000H0fMWI0P00002j0=WIf@00a03IfMT300000003
0=WIf@000000fMWI0080fMWI100000001@3IfMT000000=WIf@3IfMT0000000H0fMWI00<000000=WI
f@3IfMT0503IfMT4000000H0fMWI0P00002j0=WIf@00]`3IfMT00`000000fMWI0=WIf@0;0=WIf@<0
00001@3IfMT300000080fMWI0P0000070=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@00
0000303IfMT3000000L0fMWI00<000000=WIf@3IfMT0^03IfMT00;L0fMWI00<000000=WIf@3IfMT0
2`3IfMT2000000H0fMWI0P00000<0=WIf@030000003IfMT0fMWI00H0fMWI1000000<0=WIf@800000
1P3IfMT00`000000fMWI0=WIf@2i0=WIf@00aP3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00/0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0^@3IfMT00<H0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT02`3IfMT0
0`000000fMWI000000060=WIf@030000003IfMT0fMWI0;T0fMWI002g0=WIf@030000003IfMT0fMWI
00X0fMWI00<000000=WIf@0000001P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI
00L0fMWI00<000000=WIf@3IfMT02`3IfMT3000000H0fMWI00<000000=WIf@3IfMT0^@3IfMT00<@0
fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI
00L0fMWI00<000000=WIf@3IfMT02`3IfMT4000000@0fMWI00<000000=WIf@3IfMT0^P3IfMT00<H0
fMWI0`0000020=WIf@<000003@3IfMT00`000000fMWI0=WIf@0F0=WIf@@000000P3IfMT300000;/0
fMWI002h0=WIf@030000003IfMT0fMWI00/0fMWI0`0000020=WIf@<000003@3IfMT00`000000fMWI
0=WIf@0F0=WIf@@000000P3IfMT300000;/0fMWI002h0=WIf@030000003IfMT0fMWI00T0fMWI00<0
00000=WIf@3IfMT00P0000020=WIf@8000003P3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00/0fMWI00@000000=WIf@00000000000P3IfMT200000;`0fMWI00380=WIf@@000003`3I
fMT00`000000fMWI0=WIf@0I0=WIf@@00000_@3IfMT00<P0fMWI1000000?0=WIf@030000003IfMT0
fMWI01T0fMWI1000002m0=WIf@00^03IfMT00`000000fMWI0=WIf@090=WIf@040000003IfMT0fMWI
0=WIf@@000003`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<00000
0=WIf@3IfMT01000002m0=WIf@00]`3IfMT00`000000fMWI000000080=WIf@<00000103IfMT20000
0100fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@040000003IfMT0fMWI
0=WIf@800000_P3IfMT00;L0fMWI0`0000090=WIf@8000005P3IfMT300000=X0fMWI002h0=WIf@03
0000003IfMT0fMWI00L0fMWI1000000E0=WIf@030000003IfMT0fMWI0=X0fMWI002h0=WIf@030000
003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@080=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0`P3IfMT00=/0fMWI00<000000=WIf@3IfMT0fP3I
fMT00=/0fMWI00<000000=WIf@3IfMT0fP3IfMT00;T0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`00
0000fMWI0=WIf@320=WIf@00``3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI00T0
fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@320=WIf@00f`3IfMT00`000000fMWI
0=WIf@3J0=WIf@00^@3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI0=X0fMWI002i
0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@07
0=WIf@<000002`3IfMT00`000000fMWI0=WIf@320=WIf@00f`3IfMT00`000000fMWI0=WIf@080=WI
f@800000d03IfMT00=/0fMWI00<000000=WIf@3IfMT0203IfMT300000<l0fMWI002i0=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@090=WIf@030000
003IfMT0fMWI00P0fMWI0P0000340=WIf@00`P3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT200000<@0fMWI002h0=WIf@8000008@3IfMT0
0`000000fMWI0=WIf@0C0=WIf@@00000``3IfMT00;T0fMWI0P00000P0=WIf@030000003IfMT0fMWI
0=X0fMWI002h0=WIf@@000001@3IfMT3000001L0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI0<<0fMWI002i0=WIf@030000003IfMT0fMWI00D0fMWI
1000000F0=WIf@<00000fP3IfMT00;X0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WI
f@0F0=WIf@030000003IfMT0fMWI0=X0fMWI002j0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00L0fMWI00<00000
0=WIf@3IfMT0``3IfMT00<80fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@0:0=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0``3IfMT00=/0fMWI00<000000=WIf@3I
fMT0fP3IfMT00;/0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@3J0=WIf@00`@3I
fMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@330=WIf@00f`3IfMT00`000000fMWI0=WIf@3J0=WIf@00^`3IfMT00`00
0000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI0=X0fMWI002k0=WIf@800000103IfMT00`000000
fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000
fMWI0=WIf@340=WIf@00^`3IfMT200000080fMWI00<000000=WIf@0000006@3IfMT00`000000fMWI
0=WIf@090=WIf@800000203IfMT00`000000fMWI0=WIf@340=WIf@00^P3IfMT400000080fMWI0P00
000I0=WIf@030000003IfMT0fMWI00X0fMWI0P00003>0=WIf@00^`3IfMT200000080fMWI1000000H
0=WIf@030000003IfMT0fMWI00T0fMWI100000040=WIf@800000a`3IfMT00<00fMWI00<000000=WI
f@3IfMT0603IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI0P0000360=WI
f@00`03IfMT00`000000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI0180fMWI0`0000350=WIf@00
_03IfMT3000001`0fMWI00<000000=WIf@3IfMT0fP3IfMT00;`0fMWI1000000K0=WIf@<000002`3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0<D0fMWI002l0=WIf@@000006`3IfMT0
0`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0a@3IfMT0
0;d0fMWI1000000J0=WIf@030000003IfMT0fMWI0=X0fMWI002m0=WIf@030000003IfMT0fMWI01/0
fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0<D0
fMWI003K0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@350=WIf@00f`3IfMT00`000000fMWI0=WIf@3J0=WIf@00f`3IfMT00`000000fMWI0=WIf@3J
0=WIf@00f`3IfMT00`000000fMWI0=WIf@0;0=WIf@<000000`3IfMT00`000000fMWI0=WIf@360=WI
f@00f`3IfMT00`000000fMWI0=WIf@0;0=WIf@<000000P3IfMT00`000000fMWI000000370=WIf@00
f`3IfMT00`000000fMWI0=WIf@0;0=WIf@@0000000@0fMWI0000000000000000a`3IfMT00=/0fMWI
00<000000=WIf@3IfMT0303IfMT200000080fMWI100000360=WIf@00f`3IfMT00`000000fMWI0=WI
f@0=0=WIf@050000003IfMT0fMWI0=WIf@000000b03IfMT00=/0fMWI00<000000=WIf@3IfMT0fP3I
fMT00=/0fMWI00<000000=WIf@3IfMT0fP3IfMT00<H0fMWI0P0000040=WIf@800000103IfMT30000
00H0fMWI00<000000=WIf@3IfMT03@3IfMT400000<T0fMWI00350=WIf@040000003IfMT0fMWI0000
00<0fMWI0P0000050=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT03@3IfMT40000
0<T0fMWI00350=WIf@040000003IfMT0fMWI000000P0fMWI100000060=WIf@@00000303IfMT50000
0<P0fMWI00350=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@0000001`3IfMT00`00
0000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI0<P0fMWI00350=WIf@040000003IfMT0fMWI0000
00P0fMWI00<000000=WIf@0000001`3IfMT00`000000fMWI0=WIf@3J0=WIf@00aP3IfMT2000000X0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=X0fMWI003K0=WIf@030000003IfMT0fMWI0=X0fMWI
003K0=WIf@030000003IfMT0fMWI0=X0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 439.375}, {271.062, 0}} -> {-262.972, -0.416632, 
  1.19703, 0.00307405}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Store B field under text tab delimited file", "Subsubsection"],

Cell[BoxData[
    \(tmp = OpenWrite["\<my_B_file.dta\>", FormatType \[Rule] OutputForm]; \n
    Do[Write[tmp, 
        CForm[Tbz0\[LeftDoubleBracket]i, 1\[RightDoubleBracket]\/1000.], 
        "\<\t\>", CForm[Tbx0\[LeftDoubleBracket]i, 2\[RightDoubleBracket]], 
        "\<\t\>", CForm[Tbz0\[LeftDoubleBracket]i, 2\[RightDoubleBracket]]], {
        i, Length[Tbz0]}]; \nClose[tmp]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot of the magnetic structure", "Section"],

Cell[CellGroupData[{

Cell["Mathematica plot", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RadPlot3DOptions[]; \nDwg = radObjDrw[Grp]; \n
    gr = Show[Graphics3D[Dwg], ViewPoint -> {1, 1, \ 1}]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.89732 .20147 0 -11.2625 ]
[.89732 .20147 24.25 2.73747 ]
[.84258 .14967 0 -11.5417 ]
[.84258 .14967 10 2.45832 ]
[.78342 .0937 0 -11.86 ]
[.78342 .0937 16 2.14004 ]
[.89501 .11566 0 -11.5417 ]
[.89501 .11566 15.625 2.45832 ]
[.4412 .77408 -12.4292 0 ]
[.4412 .77408 11.8208 14 ]
[.59541 .70568 -4.79028 0 ]
[.59541 .70568 5.20972 14 ]
[.77962 .62392 -6.97999 0 ]
[.77962 .62392 9.02001 14 ]
[.59803 .76812 -7.48482 0 ]
[.59803 .76812 8.14018 14 ]
[.93704 .2868 0 -10.9186 ]
[.93704 .2868 24.25 3.08143 ]
[.95401 .36051 0 -10.6592 ]
[.95401 .36051 10 3.34077 ]
[.97236 .44028 0 -10.383 ]
[.97236 .44028 16 3.61703 ]
[1.0094 .33156 0 -10.6592 ]
[1.0094 .33156 14.3125 3.34077 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.91222 .23212 m
.74209 .07151 L
s
.25 Mabswid
.88664 .20797 m
.8813 .21122 L
s
gsave
.89732 .20147 -61 -15.2625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.8321 .15648 m
.82685 .15988 L
s
gsave
.84258 .14967 -61 -15.5417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77315 .10083 m
.76801 .10439 L
s
gsave
.78342 .0937 -61 -15.86 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.87339 .19546 m
.8702 .19743 L
s
.85989 .18271 m
.85671 .18471 L
s
.84613 .16972 m
.84297 .17174 L
s
.81779 .14297 m
.81466 .14504 L
s
.80321 .1292 m
.80009 .13129 L
s
.78833 .11516 m
.78523 .11727 L
s
.89965 .22024 m
.89643 .22217 L
s
.75766 .08621 m
.7546 .08837 L
s
gsave
.89501 .11566 -61 -15.5417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.32213 .81482 m
.97858 .52209 L
s
.25 Mabswid
.44152 .76158 m
.44167 .75533 L
s
gsave
.4412 .77408 -73.4292 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.59489 .69319 m
.59463 .68695 L
s
gsave
.59541 .70568 -65.7903 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77804 .61152 m
.77725 .60532 L
s
gsave
.77962 .62392 -67.98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.47016 .74881 m
.47021 .74506 L
s
.49977 .7356 m
.49977 .73185 L
s
.5304 .72195 m
.53035 .7182 L
s
.56208 .70782 m
.56198 .70407 L
s
.62888 .67803 m
.62867 .67429 L
s
.66412 .66232 m
.66384 .65858 L
s
.70067 .64602 m
.70033 .64228 L
s
.73862 .6291 m
.73821 .62537 L
s
.41379 .77395 m
.41393 .7702 L
s
.38693 .78592 m
.38711 .78218 L
s
.36091 .79753 m
.36113 .79379 L
s
.33568 .80878 m
.33593 .80504 L
s
.81902 .59325 m
.81847 .58954 L
s
.86166 .57423 m
.86103 .57053 L
s
.90605 .55444 m
.90534 .55075 L
s
.95231 .53381 m
.95152 .53014 L
s
gsave
.59803 .76812 -68.4848 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.91222 .23212 m
.97858 .52209 L
s
.25 Mabswid
.92614 .29291 m
.92068 .29596 L
s
gsave
.93704 .2868 -61 -14.9186 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.94293 .3663 m
.93739 .3692 L
s
gsave
.95401 .36051 -61 -14.6592 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.96111 .44572 m
.95548 .44844 L
s
gsave
.97236 .44028 -61 -14.383 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.93021 .31073 m
.92693 .31254 L
s
.93437 .3289 m
.93107 .33068 L
s
.93861 .34742 m
.9353 .34918 L
s
.94734 .38556 m
.944 .38728 L
s
.95184 .40521 m
.94849 .4069 L
s
.95642 .42526 m
.95306 .42692 L
s
.92213 .27542 m
.91887 .27728 L
s
.91821 .25826 m
.91496 .26014 L
s
.91435 .24141 m
.91112 .24331 L
s
.96589 .4666 m
.9625 .46821 L
s
.97076 .48792 m
.96736 .4895 L
s
.97575 .5097 m
.97233 .51124 L
s
gsave
1.0094 .33156 -61 -14.6592 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.3404 .57001 m
.32213 .81482 L
s
.32213 .81482 m
.97858 .52209 L
s
.97858 .52209 m
.91222 .23212 L
s
.91222 .23212 m
.3404 .57001 L
s
.16771 .48466 m
.74209 .07151 L
s
.74209 .07151 m
.78676 .37421 L
s
.78676 .37421 m
.12589 .74312 L
s
.12589 .74312 m
.16771 .48466 L
s
.3404 .57001 m
.32213 .81482 L
s
.32213 .81482 m
.12589 .74312 L
s
.12589 .74312 m
.16771 .48466 L
s
.16771 .48466 m
.3404 .57001 L
s
.91222 .23212 m
.74209 .07151 L
s
.74209 .07151 m
.78676 .37421 L
s
.78676 .37421 m
.97858 .52209 L
s
.97858 .52209 m
.91222 .23212 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
[ ] 0 setdash
.31476 .54443 m .30825 .54844 L .34635 .56738 L p 0 .903 1 r
F P
0 g
s
.34635 .56738 m .35288 .56352 L .31476 .54443 L p 0 .903 1 r
F P
0 g
s
.35288 .56352 m .34635 .56738 L .34637 .56742 L p 0 .575 .884 r
F P
0 g
s
.34637 .56742 m .35291 .56356 L .35288 .56352 L p 0 .575 .884 r
F P
0 g
s
.35291 .56356 m .34637 .56742 L .34336 .60926 L p 0 .114 .472 r
F P
0 g
s
.34637 .56742 m .34336 .60926 L .30442 .59076 L p 0 .708 .548 r
F P
0 g
s
.34635 .56738 m .34637 .56742 L p .30442 .59076 L 0 .708 .548 r
F P
0 g
s
.30442 .59076 m .30825 .54844 L .34635 .56738 L p 0 .708 .548 r
F P
0 g
s
.32132 .54039 m .31476 .54443 L .35288 .56352 L p 0 .903 1 r
F P
0 g
s
.35288 .56352 m .35947 .55963 L .32132 .54039 L p 0 .903 1 r
F P
0 g
s
.35947 .55963 m .35288 .56352 L .35291 .56356 L p 0 .575 .884 r
F P
0 g
s
.35291 .56356 m .35949 .55968 L .35947 .55963 L p 0 .575 .884 r
F P
0 g
s
.35949 .55968 m .35291 .56356 L .35001 .6055 L p 0 .114 .472 r
F P
0 g
s
.34336 .60926 m .35001 .6055 L .35291 .56356 L p 0 .114 .472 r
F P
0 g
s
.35291 .56356 m .35001 .6055 L .31104 .58685 L p 0 .707 .545 r
F P
0 g
s
.35288 .56352 m .35291 .56356 L p .31104 .58685 L 0 .707 .545 r
F P
0 g
s
.31104 .58685 m .31476 .54443 L .35288 .56352 L p 0 .707 .545 r
F P
0 g
s
.35291 .56356 m .35001 .6055 L .31104 .58685 L p 0 .707 .545 r
F P
0 g
s
.35288 .56352 m .35291 .56356 L p .31104 .58685 L 0 .707 .545 r
F P
0 g
s
.31104 .58685 m .31476 .54443 L .35288 .56352 L p 0 .707 .545 r
F P
0 g
s
.35001 .6055 m .35672 .6017 L .35949 .55968 L p 0 .114 .472 r
F P
0 g
s
.35949 .55968 m .35672 .6017 L .31771 .5829 L p 0 .707 .542 r
F P
0 g
s
.35947 .55963 m .35949 .55968 L p .31771 .5829 L 0 .707 .542 r
F P
0 g
s
.31771 .5829 m .32132 .54039 L .35947 .55963 L p 0 .707 .542 r
F P
0 g
s
.33264 .53341 m .32474 .53828 L .3629 .55761 L p 0 .903 0 r
F P
0 g
s
.3629 .55761 m .37083 .55292 L .33264 .53341 L p 0 .903 0 r
F P
0 g
s
.37083 .55292 m .3629 .55761 L .36293 .55765 L p 0 .575 0 r
F P
0 g
s
.36293 .55765 m .37086 .55297 L .37083 .55292 L p 0 .575 0 r
F P
0 g
s
.37086 .55297 m .36293 .55765 L .36021 .59972 L p 0 .114 0 r
F P
0 g
s
.36293 .55765 m .36021 .59972 L .3212 .58084 L p 0 .706 0 r
F P
0 g
s
.3629 .55761 m .36293 .55765 L p .3212 .58084 L 0 .706 0 r
F P
0 g
s
.3212 .58084 m .32474 .53828 L .3629 .55761 L p 0 .706 0 r
F P
0 g
s
.34062 .52849 m .33264 .53341 L .37083 .55292 L p 0 .903 0 r
F P
0 g
s
.37083 .55292 m .37884 .5482 L .34062 .52849 L p 0 .903 0 r
F P
0 g
s
.37884 .5482 m .37083 .55292 L .37086 .55297 L p 0 .575 0 r
F P
0 g
s
.37086 .55297 m .37887 .54824 L .37884 .5482 L p 0 .575 0 r
F P
0 g
s
.37887 .54824 m .37086 .55297 L .36829 .59515 L p 0 .114 0 r
F P
0 g
s
.36021 .59972 m .36829 .59515 L .37086 .55297 L p 0 .114 0 r
F P
0 g
s
.37086 .55297 m .36829 .59515 L .32924 .57609 L p 0 .706 0 r
F P
0 g
s
.37083 .55292 m .37086 .55297 L p .32924 .57609 L 0 .706 0 r
F P
0 g
s
.32924 .57609 m .33264 .53341 L .37083 .55292 L p 0 .706 0 r
F P
0 g
s
.37086 .55297 m .36829 .59515 L .32924 .57609 L p 0 .706 0 r
F P
0 g
s
.37083 .55292 m .37086 .55297 L p .32924 .57609 L 0 .706 0 r
F P
0 g
s
.32924 .57609 m .33264 .53341 L .37083 .55292 L p 0 .706 0 r
F P
0 g
s
.27507 .52456 m .2686 .52873 L .30825 .54844 L p 0 .903 1 r
F P
0 g
s
.30825 .54844 m .31476 .54443 L .27507 .52456 L p 0 .903 1 r
F P
0 g
s
.31476 .54443 m .30825 .54844 L .30442 .59076 L p 0 .1 .45 r
F P
0 g
s
.30825 .54844 m .30442 .59076 L .26388 .57152 L p 0 .708 .548 r
F P
0 g
s
.26388 .57152 m .2686 .52873 L .30825 .54844 L p 0 .708 .548 r
F P
0 g
s
.31104 .58685 m .30442 .59076 L .34336 .60926 L p 0 .907 1 r
F P
0 g
s
.34336 .60926 m .35001 .6055 L .31104 .58685 L p 0 .907 1 r
F P
0 g
s
.35001 .6055 m .34336 .60926 L .34024 .65277 L p 0 .114 .472 r
F P
0 g
s
.34336 .60926 m .34024 .65277 L p .30043 .63482 L 0 .708 .548 r
F P
0 g
s
.30043 .63482 m .30442 .59076 L .34336 .60926 L p 0 .708 .548 r
F P
0 g
s
.35001 .6055 m .34336 .60926 L .30442 .59076 L p 0 .907 1 r
F P
0 g
s
.31104 .58685 m .30442 .59076 L .30825 .54844 L p 0 .1 .45 r
F P
0 g
s
.30825 .54844 m .31476 .54443 L .31104 .58685 L p 0 .1 .45 r
F P
0 g
s
.36829 .59515 m .37645 .59054 L .37887 .54824 L p 0 .114 0 r
F P
0 g
s
.37887 .54824 m .37645 .59054 L .33737 .57128 L p 0 .705 0 r
F P
0 g
s
.37884 .5482 m .37887 .54824 L p .33737 .57128 L 0 .705 0 r
F P
0 g
s
.33737 .57128 m .34062 .52849 L .37884 .5482 L p 0 .705 0 r
F P
0 g
s
.31771 .5829 m .31104 .58685 L .31476 .54443 L p 0 .1 .45 r
F P
0 g
s
.31476 .54443 m .32132 .54039 L .31771 .5829 L p 0 .1 .45 r
F P
0 g
s
.2816 .52035 m .27507 .52456 L .31476 .54443 L p 0 .903 1 r
F P
0 g
s
.31476 .54443 m .32132 .54039 L .2816 .52035 L p 0 .903 1 r
F P
0 g
s
.32132 .54039 m .31476 .54443 L .31104 .58685 L p 0 .1 .45 r
F P
0 g
s
.30442 .59076 m .31104 .58685 L .31476 .54443 L p 0 .1 .45 r
F P
0 g
s
.31476 .54443 m .31104 .58685 L .27047 .56744 L p 0 .707 .545 r
F P
0 g
s
.27047 .56744 m .27507 .52456 L .31476 .54443 L p 0 .707 .545 r
F P
0 g
s
.31476 .54443 m .31104 .58685 L .27047 .56744 L p 0 .707 .545 r
F P
0 g
s
.27047 .56744 m .27507 .52456 L .31476 .54443 L p 0 .707 .545 r
F P
0 g
s
.31771 .5829 m .31104 .58685 L .35001 .6055 L p 0 .907 1 r
F P
0 g
s
.35001 .6055 m .35672 .6017 L .31771 .5829 L p 0 .907 1 r
F P
0 g
s
.35672 .6017 m .35001 .6055 L .34701 .64911 L p 0 .114 .472 r
F P
0 g
s
.34024 .65277 m .34701 .64911 L .35001 .6055 L p 0 .114 .472 r
F P
0 g
s
.35001 .6055 m .34701 .64911 L p .30717 .63101 L 0 .707 .545 r
F P
0 g
s
.30442 .59076 m .31104 .58685 L .35001 .6055 L p 0 .907 1 r
F P
0 g
s
.30717 .63101 m .31104 .58685 L .35001 .6055 L p 0 .707 .545 r
F P
0 g
s
.35001 .6055 m .34701 .64911 L p .30717 .63101 L 0 .707 .545 r
F P
0 g
s
.30717 .63101 m .31104 .58685 L .35001 .6055 L p 0 .707 .545 r
F P
0 g
s
.35672 .6017 m .35001 .6055 L .31104 .58685 L p 0 .907 1 r
F P
0 g
s
.35671 .51857 m .35118 .52198 L .38943 .54194 L p 0 .903 1 r
F P
0 g
s
.38943 .54194 m .39498 .53867 L .35671 .51857 L p 0 .903 1 r
F P
0 g
s
.39498 .53867 m .38943 .54194 L .38946 .54198 L p 0 .575 .884 r
F P
0 g
s
.38946 .54198 m .39501 .53871 L .39498 .53867 L p 0 .575 .884 r
F P
0 g
s
.39501 .53871 m .38946 .54198 L .38724 .58443 L p 0 .114 .472 r
F P
0 g
s
.38946 .54198 m .38724 .58443 L .34812 .56492 L p 0 .704 .528 r
F P
0 g
s
.38943 .54194 m .38946 .54198 L p .34812 .56492 L 0 .704 .528 r
F P
0 g
s
.34812 .56492 m .35118 .52198 L .38943 .54194 L p 0 .704 .528 r
F P
0 g
s
.31104 .58685 m .31771 .5829 L .32132 .54039 L p 0 .1 .45 r
F P
0 g
s
.32132 .54039 m .31771 .5829 L .27711 .56333 L p 0 .707 .542 r
F P
0 g
s
.27711 .56333 m .2816 .52035 L .32132 .54039 L p 0 .707 .542 r
F P
0 g
s
.34701 .64911 m .35383 .64542 L .35672 .6017 L p 0 .114 .472 r
F P
0 g
s
.35672 .6017 m .35383 .64542 L p .31397 .62717 L 0 .707 .542 r
F P
0 g
s
.31104 .58685 m .31771 .5829 L .35672 .6017 L p 0 .907 1 r
F P
0 g
s
.31397 .62717 m .31771 .5829 L .35672 .6017 L p 0 .707 .542 r
F P
0 g
s
.36228 .51514 m .35671 .51857 L .39498 .53867 L p 0 .903 1 r
F P
0 g
s
.39498 .53867 m .40056 .53537 L .36228 .51514 L p 0 .903 1 r
F P
0 g
s
.40056 .53537 m .39498 .53867 L .39501 .53871 L p 0 .575 .884 r
F P
0 g
s
.39501 .53871 m .40059 .53542 L .40056 .53537 L p 0 .575 .884 r
F P
0 g
s
.40059 .53542 m .39501 .53871 L .39289 .58124 L p 0 .114 .472 r
F P
0 g
s
.38724 .58443 m .39289 .58124 L .39501 .53871 L p 0 .114 .472 r
F P
0 g
s
.39501 .53871 m .39289 .58124 L .35376 .56159 L p 0 .704 .526 r
F P
0 g
s
.39498 .53867 m .39501 .53871 L p .35376 .56159 L 0 .704 .526 r
F P
0 g
s
.35376 .56159 m .35671 .51857 L .39498 .53867 L p 0 .704 .526 r
F P
0 g
s
.39501 .53871 m .39289 .58124 L .35376 .56159 L p 0 .704 .526 r
F P
0 g
s
.39498 .53867 m .39501 .53871 L p .35376 .56159 L 0 .704 .526 r
F P
0 g
s
.35376 .56159 m .35671 .51857 L .39498 .53867 L p 0 .704 .526 r
F P
0 g
s
.29287 .51309 m .28501 .51815 L .32474 .53828 L p 0 .903 0 r
F P
0 g
s
.32474 .53828 m .33264 .53341 L .29287 .51309 L p 0 .903 0 r
F P
0 g
s
.33264 .53341 m .32474 .53828 L .3212 .58084 L p 0 .1 0 r
F P
0 g
s
.32474 .53828 m .3212 .58084 L .28057 .56118 L p 0 .706 0 r
F P
0 g
s
.28057 .56118 m .28501 .51815 L .32474 .53828 L p 0 .706 0 r
F P
0 g
s
.32924 .57609 m .3212 .58084 L .36021 .59972 L p 0 .907 0 r
F P
0 g
s
.36021 .59972 m .36829 .59515 L .32924 .57609 L p 0 .907 0 r
F P
0 g
s
.36829 .59515 m .36021 .59972 L .35739 .6435 L p 0 .114 0 r
F P
0 g
s
.36021 .59972 m .35739 .6435 L p .31751 .62516 L 0 .706 0 r
F P
0 g
s
.31751 .62516 m .3212 .58084 L .36021 .59972 L p 0 .706 0 r
F P
0 g
s
.36829 .59515 m .36021 .59972 L .3212 .58084 L p 0 .907 0 r
F P
0 g
s
.32924 .57609 m .3212 .58084 L .32474 .53828 L p 0 .1 0 r
F P
0 g
s
.32474 .53828 m .33264 .53341 L .32924 .57609 L p 0 .1 0 r
F P
0 g
s
.40618 .53205 m .40056 .53537 L .40059 .53542 L p 0 .575 .884 r
F P
0 g
s
.40059 .53542 m .40621 .5321 L .40618 .53205 L p 0 .575 .884 r
F P
0 g
s
.40621 .5321 m .40059 .53542 L .39858 .57802 L p 0 .114 .472 r
F P
0 g
s
.39289 .58124 m .39858 .57802 L .40059 .53542 L p 0 .114 .472 r
F P
0 g
s
.40059 .53542 m .39858 .57802 L .35943 .55824 L p 0 .704 .523 r
F P
0 g
s
.40056 .53537 m .40059 .53542 L p .35943 .55824 L 0 .704 .523 r
F P
0 g
s
.40059 .53542 m .39858 .57802 L .35943 .55824 L p 0 .704 .523 r
F P
0 g
s
.40056 .53537 m .40059 .53542 L p .35943 .55824 L 0 .704 .523 r
F P
0 g
s
.36788 .51169 m .36228 .51514 L .40056 .53537 L p 0 .903 1 r
F P
0 g
s
.40056 .53537 m .40618 .53205 L .36788 .51169 L p 0 .903 1 r
F P
0 g
s
.35943 .55824 m .36228 .51514 L .40056 .53537 L p 0 .704 .523 r
F P
0 g
s
.35943 .55824 m .36228 .51514 L .40056 .53537 L p 0 .704 .523 r
F P
0 g
s
.30081 .50796 m .29287 .51309 L .33264 .53341 L p 0 .903 0 r
F P
0 g
s
.33264 .53341 m .34062 .52849 L .30081 .50796 L p 0 .903 0 r
F P
0 g
s
.34062 .52849 m .33264 .53341 L .32924 .57609 L p 0 .1 0 r
F P
0 g
s
.3212 .58084 m .32924 .57609 L .33264 .53341 L p 0 .1 0 r
F P
0 g
s
.33264 .53341 m .32924 .57609 L .28858 .55623 L p 0 .706 0 r
F P
0 g
s
.28858 .55623 m .29287 .51309 L .33264 .53341 L p 0 .706 0 r
F P
0 g
s
.33264 .53341 m .32924 .57609 L .28858 .55623 L p 0 .706 0 r
F P
0 g
s
.28858 .55623 m .29287 .51309 L .33264 .53341 L p 0 .706 0 r
F P
0 g
s
.33737 .57128 m .32924 .57609 L .36829 .59515 L p 0 .907 0 r
F P
0 g
s
.36829 .59515 m .37645 .59054 L .33737 .57128 L p 0 .907 0 r
F P
0 g
s
.37645 .59054 m .36829 .59515 L .36562 .63905 L p 0 .114 0 r
F P
0 g
s
.35739 .6435 m .36562 .63905 L .36829 .59515 L p 0 .114 0 r
F P
0 g
s
.36829 .59515 m .36562 .63905 L p .32571 .62053 L 0 .706 0 r
F P
0 g
s
.3212 .58084 m .32924 .57609 L .36829 .59515 L p 0 .907 0 r
F P
0 g
s
.32571 .62053 m .32924 .57609 L .36829 .59515 L p 0 .706 0 r
F P
0 g
s
.36829 .59515 m .36562 .63905 L p .32571 .62053 L 0 .706 0 r
F P
0 g
s
.32571 .62053 m .32924 .57609 L .36829 .59515 L p 0 .706 0 r
F P
0 g
s
.37645 .59054 m .36829 .59515 L .32924 .57609 L p 0 .907 0 r
F P
0 g
s
.33737 .57128 m .32924 .57609 L .33264 .53341 L p 0 .1 0 r
F P
0 g
s
.33264 .53341 m .34062 .52849 L .33737 .57128 L p 0 .1 0 r
F P
0 g
s
.41184 .52871 m .40618 .53205 L .40621 .5321 L p 0 .575 .884 r
F P
0 g
s
.40621 .5321 m .41186 .52876 L .41184 .52871 L p 0 .575 .884 r
F P
0 g
s
.41186 .52876 m .40621 .5321 L .4043 .57478 L p 0 .114 .472 r
F P
0 g
s
.39858 .57802 m .4043 .57478 L .40621 .5321 L p 0 .114 .472 r
F P
0 g
s
.40621 .5321 m .4043 .57478 L .36514 .55486 L p 0 .703 .52 r
F P
0 g
s
.40618 .53205 m .40621 .5321 L p .36514 .55486 L 0 .703 .52 r
F P
0 g
s
.40621 .5321 m .4043 .57478 L .36514 .55486 L p 0 .703 .52 r
F P
0 g
s
.40618 .53205 m .40621 .5321 L p .36514 .55486 L 0 .703 .52 r
F P
0 g
s
.37352 .50821 m .36788 .51169 L .40618 .53205 L p 0 .903 1 r
F P
0 g
s
.40618 .53205 m .41184 .52871 L .37352 .50821 L p 0 .903 1 r
F P
0 g
s
.36514 .55486 m .36788 .51169 L .40618 .53205 L p 0 .703 .52 r
F P
0 g
s
.36514 .55486 m .36788 .51169 L .40618 .53205 L p 0 .703 .52 r
F P
0 g
s
.34701 .64911 m .34024 .65277 L .34021 .65279 L p 0 .1 .1 r
F P
0 g
s
.34024 .65277 m .34021 .65279 L .30043 .63482 L p 0 .708 .548 r
F P
0 g
s
.27047 .56744 m .26388 .57152 L .30442 .59076 L p 0 .907 1 r
F P
0 g
s
.30442 .59076 m .31104 .58685 L .27047 .56744 L p 0 .907 1 r
F P
0 g
s
.31104 .58685 m .30442 .59076 L .30043 .63482 L p 0 .1 .45 r
F P
0 g
s
.30442 .59076 m .30043 .63482 L .25896 .61608 L p 0 .708 .548 r
F P
0 g
s
.25896 .61608 m .26388 .57152 L .30442 .59076 L p 0 .708 .548 r
F P
0 g
s
.31104 .58685 m .30442 .59076 L .26388 .57152 L p 0 .907 1 r
F P
0 g
s
.27047 .56744 m .26388 .57152 L .2686 .52873 L p 0 .1 .425 r
F P
0 g
s
.2686 .52873 m .27507 .52456 L .27047 .56744 L p 0 .1 .425 r
F P
0 g
s
.30717 .63101 m .30043 .63482 L .30442 .59076 L p 0 .1 .45 r
F P
0 g
s
.30442 .59076 m .31104 .58685 L .30717 .63101 L p 0 .1 .45 r
F P
0 g
s
.382 .50299 m .37352 .50821 L .41184 .52871 L p 0 .903 0 r
F P
0 g
s
.41184 .52871 m .42033 .5237 L .382 .50299 L p 0 .903 0 r
F P
0 g
s
.42033 .5237 m .41184 .52871 L .41186 .52876 L p 0 .575 0 r
F P
0 g
s
.41186 .52876 m .42036 .52374 L .42033 .5237 L p 0 .575 0 r
F P
0 g
s
.42036 .52374 m .41186 .52876 L .41007 .57152 L p 0 .114 0 r
F P
0 g
s
.4043 .57478 m .41007 .57152 L .41186 .52876 L p 0 .114 .472 r
F P
0 g
s
.41186 .52876 m .41007 .57152 L .37089 .55146 L p 0 .703 0 r
F P
0 g
s
.41184 .52871 m .41186 .52876 L p .37089 .55146 L 0 .703 0 r
F P
0 g
s
.37089 .55146 m .37352 .50821 L .41184 .52871 L p 0 .703 0 r
F P
0 g
s
.34021 .65279 m .34698 .64913 L .34701 .64911 L p 0 .1 .1 r
F P
0 g
s
.34698 .64913 m .34021 .65279 L .30043 .63482 L p 0 .911 1 r
F P
0 g
s
.41186 .52876 m .41007 .57152 L .37089 .55146 L p 0 .703 .518 r
F P
0 g
s
.41184 .52871 m .41186 .52876 L p .37089 .55146 L 0 .703 .518 r
F P
0 g
s
.37089 .55146 m .37352 .50821 L .41184 .52871 L p 0 .703 .518 r
F P
0 g
s
.32924 .57609 m .33737 .57128 L .34062 .52849 L p 0 .1 0 r
F P
0 g
s
.34062 .52849 m .33737 .57128 L .29667 .55122 L p 0 .705 0 r
F P
0 g
s
.29667 .55122 m .30081 .50796 L .34062 .52849 L p 0 .705 0 r
F P
0 g
s
.36562 .63905 m .37393 .63457 L .37645 .59054 L p 0 .114 0 r
F P
0 g
s
.37645 .59054 m .37393 .63457 L p .33398 .61586 L 0 .705 0 r
F P
0 g
s
.32924 .57609 m .33737 .57128 L .37645 .59054 L p 0 .907 0 r
F P
0 g
s
.33398 .61586 m .33737 .57128 L .37645 .59054 L p 0 .705 0 r
F P
0 g
s
.2675 .56602 m .27218 .52311 L .26571 .52729 L p 0 .1 .423 r
F P
0 g
s
.26571 .52729 m .26092 .57011 L .2675 .56602 L p 0 .1 .423 r
F P
0 g
s
.22432 .50672 m .26571 .52729 L .27218 .52311 L p 0 .903 1 r
F P
0 g
s
.26571 .52729 m .26092 .57011 L .21857 .55 L p 0 .708 .548 r
F P
0 g
s
.21857 .55 m .22432 .50672 L .26571 .52729 L p 0 .708 .548 r
F P
0 g
s
.35383 .64542 m .34701 .64911 L .34698 .64913 L p 0 .1 .1 r
F P
0 g
s
.34701 .64911 m .34698 .64913 L .30717 .63101 L p 0 .707 .545 r
F P
0 g
s
.34701 .64911 m .34698 .64913 L .30717 .63101 L p 0 .707 .545 r
F P
0 g
s
.31397 .62717 m .30717 .63101 L .31104 .58685 L p 0 .1 .45 r
F P
0 g
s
.31104 .58685 m .31771 .5829 L .31397 .62717 L p 0 .1 .45 r
F P
0 g
s
.27711 .56333 m .27047 .56744 L .31104 .58685 L p 0 .907 1 r
F P
0 g
s
.31104 .58685 m .31771 .5829 L .27711 .56333 L p 0 .907 1 r
F P
0 g
s
.31771 .5829 m .31104 .58685 L .30717 .63101 L p 0 .1 .45 r
F P
0 g
s
.30043 .63482 m .30717 .63101 L .31104 .58685 L p 0 .1 .45 r
F P
0 g
s
.31104 .58685 m .30717 .63101 L .26567 .61211 L p 0 .707 .545 r
F P
0 g
s
.26388 .57152 m .27047 .56744 L .31104 .58685 L p 0 .907 1 r
F P
0 g
s
.26567 .61211 m .27047 .56744 L .31104 .58685 L p 0 .707 .545 r
F P
0 g
s
.31104 .58685 m .30717 .63101 L .26567 .61211 L p 0 .707 .545 r
F P
0 g
s
.26567 .61211 m .27047 .56744 L .31104 .58685 L p 0 .707 .545 r
F P
0 g
s
.31771 .5829 m .31104 .58685 L .27047 .56744 L p 0 .907 1 r
F P
0 g
s
.27711 .56333 m .27047 .56744 L .27507 .52456 L p 0 .1 .425 r
F P
0 g
s
.27507 .52456 m .2816 .52035 L .27711 .56333 L p 0 .1 .425 r
F P
0 g
s
.34698 .64913 m .3538 .64544 L .35383 .64542 L p 0 .1 .1 r
F P
0 g
s
.3538 .64544 m .34698 .64913 L .30717 .63101 L p 0 .911 1 r
F P
0 g
s
.30043 .63482 m .30717 .63101 L .34698 .64913 L p 0 .911 1 r
F P
0 g
s
.39056 .49772 m .382 .50299 L .42033 .5237 L p 0 .903 0 r
F P
0 g
s
.42033 .5237 m .42891 .51863 L .39056 .49772 L p 0 .903 0 r
F P
0 g
s
.42891 .51863 m .42033 .5237 L .42036 .52374 L p 0 .575 0 r
F P
0 g
s
.42036 .52374 m .42894 .51868 L .42891 .51863 L p 0 .575 0 r
F P
0 g
s
.42894 .51868 m .42036 .52374 L .41873 .56662 L p 0 .114 0 r
F P
0 g
s
.41007 .57152 m .41873 .56662 L .42036 .52374 L p 0 .114 0 r
F P
0 g
s
.42036 .52374 m .41873 .56662 L .37953 .54636 L p 0 .702 0 r
F P
0 g
s
.42033 .5237 m .42036 .52374 L p .37953 .54636 L 0 .702 0 r
F P
0 g
s
.37953 .54636 m .382 .50299 L .42033 .5237 L p 0 .702 0 r
F P
0 g
s
.42036 .52374 m .41873 .56662 L .37953 .54636 L p 0 .702 0 r
F P
0 g
s
.42033 .5237 m .42036 .52374 L p .37953 .54636 L 0 .702 0 r
F P
0 g
s
.37953 .54636 m .382 .50299 L .42033 .5237 L p 0 .702 0 r
F P
0 g
s
.27414 .5619 m .2787 .51889 L .27218 .52311 L p 0 .1 .423 r
F P
0 g
s
.27218 .52311 m .2675 .56602 L .27414 .5619 L p 0 .1 .423 r
F P
0 g
s
.23075 .50236 m .27218 .52311 L .2787 .51889 L p 0 .903 1 r
F P
0 g
s
.27218 .52311 m .2675 .56602 L .22511 .54574 L p 0 .707 .545 r
F P
0 g
s
.27218 .52311 m .23075 .50236 L .22432 .50672 L p 0 .903 1 r
F P
0 g
s
.22511 .54574 m .23075 .50236 L .27218 .52311 L p 0 .707 .545 r
F P
0 g
s
.27218 .52311 m .2675 .56602 L .22511 .54574 L p 0 .707 .545 r
F P
0 g
s
.22511 .54574 m .23075 .50236 L .27218 .52311 L p 0 .707 .545 r
F P
0 g
s
.31683 .49764 m .31133 .50119 L .35118 .52198 L p 0 .903 1 r
F P
0 g
s
.35118 .52198 m .35671 .51857 L .31683 .49764 L p 0 .903 1 r
F P
0 g
s
.35671 .51857 m .35118 .52198 L .34812 .56492 L p 0 .1 .45 r
F P
0 g
s
.35118 .52198 m .34812 .56492 L .30737 .54459 L p 0 .704 .528 r
F P
0 g
s
.30737 .54459 m .31133 .50119 L .35118 .52198 L p 0 .704 .528 r
F P
0 g
s
.35376 .56159 m .34812 .56492 L .38724 .58443 L p 0 .907 1 r
F P
0 g
s
.38724 .58443 m .39289 .58124 L .35376 .56159 L p 0 .907 1 r
F P
0 g
s
.39289 .58124 m .38724 .58443 L .38492 .62863 L p 0 .114 .472 r
F P
0 g
s
.38724 .58443 m .38492 .62863 L p .34494 .60966 L 0 .704 .528 r
F P
0 g
s
.34494 .60966 m .34812 .56492 L .38724 .58443 L p 0 .704 .528 r
F P
0 g
s
.39289 .58124 m .38724 .58443 L .34812 .56492 L p 0 .907 1 r
F P
0 g
s
.35376 .56159 m .34812 .56492 L .35118 .52198 L p 0 .1 .45 r
F P
0 g
s
.35118 .52198 m .35671 .51857 L .35376 .56159 L p 0 .1 .45 r
F P
0 g
s
.35383 .64542 m .3538 .64544 L .31397 .62717 L p 0 .707 .542 r
F P
0 g
s
.30717 .63101 m .31397 .62717 L .31771 .5829 L p 0 .1 .45 r
F P
0 g
s
.31771 .5829 m .31397 .62717 L .27243 .60811 L p 0 .707 .542 r
F P
0 g
s
.27047 .56744 m .27711 .56333 L .31771 .5829 L p 0 .907 1 r
F P
0 g
s
.27243 .60811 m .27711 .56333 L .31771 .5829 L p 0 .707 .542 r
F P
0 g
s
.30717 .63101 m .31397 .62717 L .3538 .64544 L p 0 .911 1 r
F P
0 g
s
.2787 .51889 m .23723 .49797 L .23075 .50236 L p 0 .903 1 r
F P
0 g
s
.2787 .51889 m .27414 .5619 L .2317 .54144 L p 0 .707 .542 r
F P
0 g
s
.2317 .54144 m .23723 .49797 L .2787 .51889 L p 0 .707 .542 r
F P
0 g
s
.39921 .49239 m .39056 .49772 L .42891 .51863 L p 0 .903 0 r
F P
0 g
s
.42891 .51863 m .43758 .51352 L .39921 .49239 L p 0 .903 0 r
F P
0 g
s
.43758 .51352 m .42891 .51863 L .42894 .51868 L p 0 .575 0 r
F P
0 g
s
.42894 .51868 m .43761 .51356 L .43758 .51352 L p 0 .575 0 r
F P
0 g
s
.43761 .51356 m .42894 .51868 L .42748 .56166 L p 0 .114 0 r
F P
0 g
s
.41873 .56662 m .42748 .56166 L .42894 .51868 L p 0 .114 0 r
F P
0 g
s
.42894 .51868 m .42748 .56166 L .38825 .5412 L p 0 .701 0 r
F P
0 g
s
.42891 .51863 m .42894 .51868 L p .38825 .5412 L 0 .701 0 r
F P
0 g
s
.38825 .5412 m .39056 .49772 L .42891 .51863 L p 0 .701 0 r
F P
0 g
s
.42894 .51868 m .42748 .56166 L .38825 .5412 L p 0 .701 0 r
F P
0 g
s
.42891 .51863 m .42894 .51868 L p .38825 .5412 L 0 .701 0 r
F P
0 g
s
.38825 .5412 m .39056 .49772 L .42891 .51863 L p 0 .701 0 r
F P
0 g
s
.32238 .49407 m .31683 .49764 L .35671 .51857 L p 0 .903 1 r
F P
0 g
s
.35671 .51857 m .36228 .51514 L .32238 .49407 L p 0 .903 1 r
F P
0 g
s
.36228 .51514 m .35671 .51857 L .35376 .56159 L p 0 .1 .45 r
F P
0 g
s
.34812 .56492 m .35376 .56159 L .35671 .51857 L p 0 .1 .45 r
F P
0 g
s
.35671 .51857 m .35376 .56159 L .31298 .54112 L p 0 .704 .526 r
F P
0 g
s
.31298 .54112 m .31683 .49764 L .35671 .51857 L p 0 .704 .526 r
F P
0 g
s
.35671 .51857 m .35376 .56159 L .31298 .54112 L p 0 .704 .526 r
F P
0 g
s
.31298 .54112 m .31683 .49764 L .35671 .51857 L p 0 .704 .526 r
F P
0 g
s
.35943 .55824 m .35376 .56159 L .39289 .58124 L p 0 .907 1 r
F P
0 g
s
.39289 .58124 m .39858 .57802 L .35943 .55824 L p 0 .907 1 r
F P
0 g
s
.39858 .57802 m .39289 .58124 L .39068 .62551 L p 0 .114 .472 r
F P
0 g
s
.38492 .62863 m .39068 .62551 L .39289 .58124 L p 0 .114 .472 r
F P
0 g
s
.39289 .58124 m .39068 .62551 L p .35068 .60642 L 0 .704 .526 r
F P
0 g
s
.34812 .56492 m .35376 .56159 L .39289 .58124 L p 0 .907 1 r
F P
0 g
s
.35068 .60642 m .35376 .56159 L .39289 .58124 L p 0 .704 .526 r
F P
0 g
s
.39289 .58124 m .39068 .62551 L p .35068 .60642 L 0 .704 .526 r
F P
0 g
s
.35068 .60642 m .35376 .56159 L .39289 .58124 L p 0 .704 .526 r
F P
0 g
s
.39858 .57802 m .39289 .58124 L .35376 .56159 L p 0 .907 1 r
F P
0 g
s
.35943 .55824 m .35376 .56159 L .35671 .51857 L p 0 .1 .45 r
F P
0 g
s
.35671 .51857 m .36228 .51514 L .35943 .55824 L p 0 .1 .45 r
F P
0 g
s
.36562 .63905 m .35739 .6435 L .35736 .64352 L p 0 .1 0 r
F P
0 g
s
.35739 .6435 m .35736 .64352 L .31751 .62516 L p 0 .706 0 r
F P
0 g
s
.28858 .55623 m .28057 .56118 L .3212 .58084 L p 0 .907 0 r
F P
0 g
s
.3212 .58084 m .32924 .57609 L .28858 .55623 L p 0 .907 0 r
F P
0 g
s
.32924 .57609 m .3212 .58084 L .31751 .62516 L p 0 .1 0 r
F P
0 g
s
.3212 .58084 m .31751 .62516 L .27595 .60602 L p 0 .706 0 r
F P
0 g
s
.27595 .60602 m .28057 .56118 L .3212 .58084 L p 0 .706 0 r
F P
0 g
s
.32924 .57609 m .3212 .58084 L .28057 .56118 L p 0 .907 0 r
F P
0 g
s
.28858 .55623 m .28057 .56118 L .28501 .51815 L p 0 .1 0 r
F P
0 g
s
.28501 .51815 m .29287 .51309 L .28858 .55623 L p 0 .1 0 r
F P
0 g
s
.32571 .62053 m .31751 .62516 L .3212 .58084 L p 0 .1 0 r
F P
0 g
s
.3212 .58084 m .32924 .57609 L .32571 .62053 L p 0 .1 0 r
F P
0 g
s
.35736 .64352 m .36559 .63907 L .36562 .63905 L p 0 .1 0 r
F P
0 g
s
.36559 .63907 m .35736 .64352 L .31751 .62516 L p 0 .911 0 r
F P
0 g
s
.28561 .55478 m .28997 .5116 L .28211 .51669 L p 0 .1 0 r
F P
0 g
s
.28211 .51669 m .27761 .55975 L .28561 .55478 L p 0 .1 0 r
F P
0 g
s
.24061 .49567 m .28211 .51669 L .28997 .5116 L p 0 .903 0 r
F P
0 g
s
.28211 .51669 m .27761 .55975 L .23515 .5392 L p 0 .706 0 r
F P
0 g
s
.23515 .5392 m .24061 .49567 L .28211 .51669 L p 0 .706 0 r
F P
0 g
s
.32796 .49047 m .32238 .49407 L .36228 .51514 L p 0 .903 1 r
F P
0 g
s
.36228 .51514 m .36788 .51169 L .32796 .49047 L p 0 .903 1 r
F P
0 g
s
.36788 .51169 m .36228 .51514 L .35943 .55824 L p 0 .1 .45 r
F P
0 g
s
.35376 .56159 m .35943 .55824 L .36228 .51514 L p 0 .1 .45 r
F P
0 g
s
.36228 .51514 m .35943 .55824 L .31863 .53763 L p 0 .704 .523 r
F P
0 g
s
.31863 .53763 m .32238 .49407 L .36228 .51514 L p 0 .704 .523 r
F P
0 g
s
.36228 .51514 m .35943 .55824 L .31863 .53763 L p 0 .704 .523 r
F P
0 g
s
.31863 .53763 m .32238 .49407 L .36228 .51514 L p 0 .704 .523 r
F P
0 g
s
.36514 .55486 m .35943 .55824 L .39858 .57802 L p 0 .907 1 r
F P
0 g
s
.39858 .57802 m .4043 .57478 L .36514 .55486 L p 0 .907 1 r
F P
0 g
s
.4043 .57478 m .39858 .57802 L .39648 .62238 L p 0 .114 .472 r
F P
0 g
s
.39068 .62551 m .39648 .62238 L .39858 .57802 L p 0 .114 .472 r
F P
0 g
s
.39858 .57802 m .39648 .62238 L p .35646 .60316 L 0 .704 .523 r
F P
0 g
s
.35376 .56159 m .35943 .55824 L .39858 .57802 L p 0 .907 1 r
F P
0 g
s
.35646 .60316 m .35943 .55824 L .39858 .57802 L p 0 .704 .523 r
F P
0 g
s
.39858 .57802 m .39648 .62238 L p .35646 .60316 L 0 .704 .523 r
F P
0 g
s
.35646 .60316 m .35943 .55824 L .39858 .57802 L p 0 .704 .523 r
F P
0 g
s
.36514 .55486 m .35943 .55824 L .36228 .51514 L p 0 .1 .45 r
F P
0 g
s
.36228 .51514 m .36788 .51169 L .36514 .55486 L p 0 .1 .45 r
F P
0 g
s
.4043 .57478 m .39858 .57802 L .35943 .55824 L p 0 .907 1 r
F P
0 g
s
.40794 .487 m .39921 .49239 L .43758 .51352 L p 0 .903 0 r
F P
0 g
s
.43758 .51352 m .44634 .50835 L .40794 .487 L p 0 .903 0 r
F P
0 g
s
.44634 .50835 m .43758 .51352 L .43761 .51356 L p 0 .575 0 r
F P
0 g
s
.43761 .51356 m .44636 .50839 L .44634 .50835 L p 0 .575 0 r
F P
0 g
s
.44636 .50839 m .43761 .51356 L .43632 .55666 L p 0 .114 0 r
F P
0 g
s
.42748 .56166 m .43632 .55666 L .43761 .51356 L p 0 .114 0 r
F P
0 g
s
.43761 .51356 m .43632 .55666 L .39707 .53598 L p 0 .7 0 r
F P
0 g
s
.43758 .51352 m .43761 .51356 L p .39707 .53598 L 0 .7 0 r
F P
0 g
s
.39707 .53598 m .39921 .49239 L .43758 .51352 L p 0 .7 0 r
F P
0 g
s
.43761 .51356 m .43632 .55666 L .39707 .53598 L p 0 .7 0 r
F P
0 g
s
.43758 .51352 m .43761 .51356 L p .39707 .53598 L 0 .7 0 r
F P
0 g
s
.39707 .53598 m .39921 .49239 L .43758 .51352 L p 0 .7 0 r
F P
0 g
s
.37393 .63457 m .36562 .63905 L .36559 .63907 L p 0 .1 0 r
F P
0 g
s
.36562 .63905 m .36559 .63907 L .32571 .62053 L p 0 .706 0 r
F P
0 g
s
.36562 .63905 m .36559 .63907 L .32571 .62053 L p 0 .706 0 r
F P
0 g
s
.29667 .55122 m .28858 .55623 L .32924 .57609 L p 0 .907 0 r
F P
0 g
s
.32924 .57609 m .33737 .57128 L .29667 .55122 L p 0 .907 0 r
F P
0 g
s
.33737 .57128 m .32924 .57609 L .32571 .62053 L p 0 .1 0 r
F P
0 g
s
.31751 .62516 m .32571 .62053 L .32924 .57609 L p 0 .1 0 r
F P
0 g
s
.32924 .57609 m .32571 .62053 L .28411 .60119 L p 0 .706 0 r
F P
0 g
s
.28057 .56118 m .28858 .55623 L .32924 .57609 L p 0 .907 0 r
F P
0 g
s
.28411 .60119 m .28858 .55623 L .32924 .57609 L p 0 .706 0 r
F P
0 g
s
.32924 .57609 m .32571 .62053 L .28411 .60119 L p 0 .706 0 r
F P
0 g
s
.28411 .60119 m .28858 .55623 L .32924 .57609 L p 0 .706 0 r
F P
0 g
s
.33737 .57128 m .32924 .57609 L .28858 .55623 L p 0 .907 0 r
F P
0 g
s
.29667 .55122 m .28858 .55623 L .29287 .51309 L p 0 .1 0 r
F P
0 g
s
.29287 .51309 m .30081 .50796 L .29667 .55122 L p 0 .1 0 r
F P
0 g
s
.33398 .61586 m .32571 .62053 L .32924 .57609 L p 0 .1 0 r
F P
0 g
s
.32924 .57609 m .33737 .57128 L .33398 .61586 L p 0 .1 0 r
F P
0 g
s
.36559 .63907 m .3739 .63458 L .37393 .63457 L p 0 .1 0 r
F P
0 g
s
.3739 .63458 m .36559 .63907 L .32571 .62053 L p 0 .911 0 r
F P
0 g
s
.31751 .62516 m .32571 .62053 L .36559 .63907 L p 0 .911 0 r
F P
0 g
s
.33358 .48685 m .32796 .49047 L .36788 .51169 L p 0 .903 1 r
F P
0 g
s
.36788 .51169 m .37352 .50821 L .33358 .48685 L p 0 .903 1 r
F P
0 g
s
.37352 .50821 m .36788 .51169 L .36514 .55486 L p 0 .1 .45 r
F P
0 g
s
.35943 .55824 m .36514 .55486 L .36788 .51169 L p 0 .1 .45 r
F P
0 g
s
.36788 .51169 m .36514 .55486 L .32431 .53411 L p 0 .703 .52 r
F P
0 g
s
.32431 .53411 m .32796 .49047 L .36788 .51169 L p 0 .703 .52 r
F P
0 g
s
.36788 .51169 m .36514 .55486 L .32431 .53411 L p 0 .703 .52 r
F P
0 g
s
.32431 .53411 m .32796 .49047 L .36788 .51169 L p 0 .703 .52 r
F P
0 g
s
.37089 .55146 m .36514 .55486 L .36788 .51169 L p 0 .1 .45 r
F P
0 g
s
.36788 .51169 m .37352 .50821 L .37089 .55146 L p 0 .1 .45 r
F P
0 g
s
.37089 .55146 m .36514 .55486 L .4043 .57478 L p 0 .907 1 r
F P
0 g
s
.4043 .57478 m .41007 .57152 L .37089 .55146 L p 0 .907 1 r
F P
0 g
s
.41007 .57152 m .4043 .57478 L .40232 .61923 L p 0 .114 .472 r
F P
0 g
s
.39648 .62238 m .40232 .61923 L .4043 .57478 L p 0 .114 .472 r
F P
0 g
s
.4043 .57478 m .40232 .61923 L p .36228 .59987 L 0 .703 .52 r
F P
0 g
s
.35943 .55824 m .36514 .55486 L .4043 .57478 L p 0 .907 1 r
F P
0 g
s
.36228 .59987 m .36514 .55486 L .4043 .57478 L p 0 .703 .52 r
F P
0 g
s
.4043 .57478 m .40232 .61923 L p .36228 .59987 L 0 .703 .52 r
F P
0 g
s
.36228 .59987 m .36514 .55486 L .4043 .57478 L p 0 .703 .52 r
F P
0 g
s
.41007 .57152 m .4043 .57478 L .36514 .55486 L p 0 .907 1 r
F P
0 g
s
.29369 .54976 m .29791 .50647 L .28997 .5116 L p 0 .1 0 r
F P
0 g
s
.28997 .5116 m .28561 .55478 L .29369 .54976 L p 0 .1 0 r
F P
0 g
s
.24843 .49038 m .28997 .5116 L .29791 .50647 L p 0 .903 0 r
F P
0 g
s
.28997 .5116 m .28561 .55478 L .2431 .53402 L p 0 .706 0 r
F P
0 g
s
.28997 .5116 m .24843 .49038 L .24061 .49567 L p 0 .903 0 r
F P
0 g
s
.2431 .53402 m .24843 .49038 L .28997 .5116 L p 0 .706 0 r
F P
0 g
s
.28997 .5116 m .28561 .55478 L .2431 .53402 L p 0 .706 0 r
F P
0 g
s
.2431 .53402 m .24843 .49038 L .28997 .5116 L p 0 .706 0 r
F P
0 g
s
.43632 .55666 m .44525 .55161 L .44636 .50839 L p 0 .114 0 r
F P
0 g
s
.44636 .50839 m .44525 .55161 L .40599 .53071 L p 0 .699 0 r
F P
0 g
s
.44634 .50835 m .44636 .50839 L p .40599 .53071 L 0 .699 0 r
F P
0 g
s
.40599 .53071 m .40794 .487 L .44634 .50835 L p 0 .699 0 r
F P
0 g
s
.37953 .54636 m .37089 .55146 L .41007 .57152 L p 0 .907 0 r
F P
0 g
s
.41007 .57152 m .41873 .56662 L .37953 .54636 L p 0 .907 0 r
F P
0 g
s
.41873 .56662 m .41007 .57152 L .4082 .61605 L p 0 .114 0 r
F P
0 g
s
.40232 .61923 m .4082 .61605 L .41007 .57152 L p 0 .114 .472 r
F P
0 g
s
.41007 .57152 m .4082 .61605 L p .36814 .59655 L 0 .703 0 r
F P
0 g
s
.36514 .55486 m .37089 .55146 L .41007 .57152 L p 0 .907 1 r
F P
0 g
s
.36814 .59655 m .37089 .55146 L .41007 .57152 L p 0 .703 0 r
F P
0 g
s
.37953 .54636 m .37089 .55146 L .37352 .50821 L p 0 .1 0 r
F P
0 g
s
.37352 .50821 m .382 .50299 L .37953 .54636 L p 0 .1 0 r
F P
0 g
s
.34202 .4814 m .33358 .48685 L .37352 .50821 L p 0 .903 0 r
F P
0 g
s
.37352 .50821 m .382 .50299 L .34202 .4814 L p 0 .903 0 r
F P
0 g
s
.382 .50299 m .37352 .50821 L .37089 .55146 L p 0 .1 0 r
F P
0 g
s
.36514 .55486 m .37089 .55146 L .37352 .50821 L p 0 .1 .45 r
F P
0 g
s
.37352 .50821 m .37089 .55146 L .33004 .53056 L p 0 .703 0 r
F P
0 g
s
.33004 .53056 m .33358 .48685 L .37352 .50821 L p 0 .703 0 r
F P
0 g
s
.41873 .56662 m .41007 .57152 L .37089 .55146 L p 0 .907 0 r
F P
0 g
s
.30717 .63101 m .30043 .63482 L .25896 .61608 L p 0 .911 1 r
F P
0 g
s
.26567 .61211 m .25896 .61608 L .26388 .57152 L p 0 .1 .425 r
F P
0 g
s
.26388 .57152 m .27047 .56744 L .26567 .61211 L p 0 .1 .425 r
F P
0 g
s
.37352 .50821 m .37089 .55146 L .33004 .53056 L p 0 .703 .518 r
F P
0 g
s
.33004 .53056 m .33358 .48685 L .37352 .50821 L p 0 .703 .518 r
F P
0 g
s
.41007 .57152 m .4082 .61605 L p .36814 .59655 L 0 .703 .518 r
F P
0 g
s
.36814 .59655 m .37089 .55146 L .41007 .57152 L p 0 .703 .518 r
F P
0 g
s
.41703 .4814 m .4082 .48685 L .44659 .5082 L p 0 .903 1 r
F P
0 g
s
.44659 .5082 m .45543 .50298 L .41703 .4814 L p 0 .903 1 r
F P
0 g
s
.45543 .50298 m .44659 .5082 L .44661 .50824 L p 0 .575 .884 r
F P
0 g
s
.44659 .5082 m .44661 .50824 L p .40624 .53056 L 0 .699 .5 r
F P
0 g
s
.40624 .53056 m .4082 .48685 L .44659 .5082 L p 0 .699 .5 r
F P
0 g
s
.44661 .50824 m .45546 .50302 L .45543 .50298 L p 0 .575 .884 r
F P
0 g
s
.45546 .50302 m .44661 .50824 L .4455 .55146 L p 0 .114 .472 r
F P
0 g
s
.44661 .50824 m .4455 .55146 L .40624 .53056 L p 0 .699 .5 r
F P
0 g
s
.37393 .63457 m .3739 .63458 L .33398 .61586 L p 0 .705 0 r
F P
0 g
s
.32571 .62053 m .33398 .61586 L .33737 .57128 L p 0 .1 0 r
F P
0 g
s
.33737 .57128 m .33398 .61586 L .29234 .59632 L p 0 .705 0 r
F P
0 g
s
.28858 .55623 m .29667 .55122 L .33737 .57128 L p 0 .907 0 r
F P
0 g
s
.29234 .59632 m .29667 .55122 L .33737 .57128 L p 0 .705 0 r
F P
0 g
s
.32571 .62053 m .33398 .61586 L .3739 .63458 L p 0 .911 0 r
F P
0 g
s
.26264 .61073 m .2675 .56602 L .26092 .57011 L p 0 .1 .423 r
F P
0 g
s
.26092 .57011 m .25594 .61472 L .26264 .61073 L p 0 .1 .423 r
F P
0 g
s
.21857 .55 m .26092 .57011 L .2675 .56602 L p 0 .907 1 r
F P
0 g
s
.26092 .57011 m .25594 .61472 L .21258 .59513 L p 0 .708 .548 r
F P
0 g
s
.21258 .59513 m .21857 .55 L .26092 .57011 L p 0 .708 .548 r
F P
0 g
s
.22511 .54574 m .2675 .56602 L .26092 .57011 L p 0 .907 1 r
F P
0 g
s
.26092 .57011 m .21857 .55 L .22511 .54574 L p 0 .907 1 r
F P
0 g
s
.21857 .55 m .22432 .50672 L .23075 .50236 L p 0 .1 .396 r
F P
0 g
s
.22511 .54574 m .23075 .50236 L .22432 .50672 L p 0 .1 .396 r
F P
0 g
s
.22432 .50672 m .21857 .55 L .22511 .54574 L p 0 .1 .396 r
F P
0 g
s
.18124 .4853 m .22432 .50672 L .23075 .50236 L p 0 .903 1 r
F P
0 g
s
.22432 .50672 m .21857 .55 L .17442 .52903 L p 0 .708 .548 r
F P
0 g
s
.18124 .4853 m .22432 .50672 L p .17442 .52903 L 0 .708 .548 r
F P
0 g
s
.29791 .50647 m .25632 .48502 L .24843 .49038 L p 0 .903 0 r
F P
0 g
s
.29791 .50647 m .29369 .54976 L .25113 .52878 L p 0 .705 0 r
F P
0 g
s
.25113 .52878 m .25632 .48502 L .29791 .50647 L p 0 .705 0 r
F P
0 g
s
.29566 .68741 m .33647 .70473 L .34338 .70121 L p 0 .914 1 r
F P
0 g
s
.34013 .74884 m .34341 .70125 L .3365 .70478 L p 0 .114 .472 r
F P
0 g
s
.3365 .70478 m .33308 .75223 L .34013 .74884 L p 0 .114 .472 r
F P
0 g
s
.34341 .70125 m .34338 .70121 L .33647 .70473 L p 0 .562 .887 r
F P
0 g
s
.33647 .70473 m .3365 .70478 L .34341 .70125 L p 0 .562 .887 r
F P
0 g
s
.29131 .73554 m .29566 .68741 L .33647 .70473 L p 0 .708 .548 r
F P
0 g
s
.33308 .75223 m .29131 .73554 L p .33647 .70473 L 0 .708 .548 r
F P
0 g
s
.33647 .70473 m .3365 .70478 L .33308 .75223 L p 0 .708 .548 r
F P
0 g
s
.31397 .62717 m .30717 .63101 L .26567 .61211 L p 0 .911 1 r
F P
0 g
s
.27243 .60811 m .26567 .61211 L .27047 .56744 L p 0 .1 .425 r
F P
0 g
s
.27047 .56744 m .27711 .56333 L .27243 .60811 L p 0 .1 .425 r
F P
0 g
s
.25896 .61608 m .26567 .61211 L .30717 .63101 L p 0 .911 1 r
F P
0 g
s
.35056 .4759 m .34202 .4814 L .382 .50299 L p 0 .903 0 r
F P
0 g
s
.382 .50299 m .39056 .49772 L .35056 .4759 L p 0 .903 0 r
F P
0 g
s
.39056 .49772 m .382 .50299 L .37953 .54636 L p 0 .1 0 r
F P
0 g
s
.37089 .55146 m .37953 .54636 L .382 .50299 L p 0 .1 0 r
F P
0 g
s
.382 .50299 m .37953 .54636 L .33865 .52523 L p 0 .702 0 r
F P
0 g
s
.33865 .52523 m .34202 .4814 L .382 .50299 L p 0 .702 0 r
F P
0 g
s
.382 .50299 m .37953 .54636 L .33865 .52523 L p 0 .702 0 r
F P
0 g
s
.33865 .52523 m .34202 .4814 L .382 .50299 L p 0 .702 0 r
F P
0 g
s
.38825 .5412 m .37953 .54636 L .41873 .56662 L p 0 .907 0 r
F P
0 g
s
.41873 .56662 m .42748 .56166 L .38825 .5412 L p 0 .907 0 r
F P
0 g
s
.42748 .56166 m .41873 .56662 L .41703 .61128 L p 0 .114 0 r
F P
0 g
s
.4082 .61605 m .41703 .61128 L .41873 .56662 L p 0 .114 0 r
F P
0 g
s
.41873 .56662 m .41703 .61128 L p .37695 .59158 L 0 .702 0 r
F P
0 g
s
.37089 .55146 m .37953 .54636 L .41873 .56662 L p 0 .907 0 r
F P
0 g
s
.37695 .59158 m .37953 .54636 L .41873 .56662 L p 0 .702 0 r
F P
0 g
s
.41873 .56662 m .41703 .61128 L p .37695 .59158 L 0 .702 0 r
F P
0 g
s
.37695 .59158 m .37953 .54636 L .41873 .56662 L p 0 .702 0 r
F P
0 g
s
.42748 .56166 m .41873 .56662 L .37953 .54636 L p 0 .907 0 r
F P
0 g
s
.38825 .5412 m .37953 .54636 L .382 .50299 L p 0 .1 0 r
F P
0 g
s
.382 .50299 m .39056 .49772 L .38825 .5412 L p 0 .1 0 r
F P
0 g
s
.42595 .4759 m .41703 .4814 L .45543 .50298 L p 0 .903 1 r
F P
0 g
s
.45543 .50298 m .46437 .4977 L .42595 .4759 L p 0 .903 1 r
F P
0 g
s
.46437 .4977 m .45543 .50298 L .45546 .50302 L p 0 .575 .884 r
F P
0 g
s
.45543 .50298 m .45546 .50302 L p .41525 .52523 L 0 .698 .496 r
F P
0 g
s
.41525 .52523 m .41703 .4814 L .45543 .50298 L p 0 .698 .496 r
F P
0 g
s
.45543 .50298 m .45546 .50302 L p .41525 .52523 L 0 .698 .496 r
F P
0 g
s
.41525 .52523 m .41703 .4814 L .45543 .50298 L p 0 .698 .496 r
F P
0 g
s
.45546 .50302 m .4644 .49775 L .46437 .4977 L p 0 .575 .884 r
F P
0 g
s
.4644 .49775 m .45546 .50302 L .45453 .54636 L p 0 .114 .472 r
F P
0 g
s
.4455 .55146 m .45453 .54636 L .45546 .50302 L p 0 .114 .472 r
F P
0 g
s
.45546 .50302 m .45453 .54636 L .41525 .52523 L p 0 .698 .496 r
F P
0 g
s
.45546 .50302 m .45453 .54636 L .41525 .52523 L p 0 .698 .496 r
F P
0 g
s
.26939 .60672 m .27414 .5619 L .2675 .56602 L p 0 .1 .423 r
F P
0 g
s
.2675 .56602 m .26264 .61073 L .26939 .60672 L p 0 .1 .423 r
F P
0 g
s
.22511 .54574 m .2675 .56602 L .27414 .5619 L p 0 .907 1 r
F P
0 g
s
.2675 .56602 m .26264 .61073 L .21923 .59097 L p 0 .707 .545 r
F P
0 g
s
.2675 .56602 m .22511 .54574 L .21857 .55 L p 0 .907 1 r
F P
0 g
s
.21923 .59097 m .22511 .54574 L .2675 .56602 L p 0 .707 .545 r
F P
0 g
s
.2675 .56602 m .26264 .61073 L .21923 .59097 L p 0 .707 .545 r
F P
0 g
s
.21923 .59097 m .22511 .54574 L .2675 .56602 L p 0 .707 .545 r
F P
0 g
s
.2317 .54144 m .27414 .5619 L .2675 .56602 L p 0 .907 1 r
F P
0 g
s
.2675 .56602 m .22511 .54574 L .2317 .54144 L p 0 .907 1 r
F P
0 g
s
.22511 .54574 m .23075 .50236 L .23723 .49797 L p 0 .1 .396 r
F P
0 g
s
.23075 .50236 m .22511 .54574 L .21857 .55 L p 0 .1 .396 r
F P
0 g
s
.2317 .54144 m .23723 .49797 L .23075 .50236 L p 0 .1 .396 r
F P
0 g
s
.23075 .50236 m .22511 .54574 L .2317 .54144 L p 0 .1 .396 r
F P
0 g
s
.18762 .48076 m .23075 .50236 L .23723 .49797 L p 0 .903 1 r
F P
0 g
s
.23075 .50236 m .22511 .54574 L .1809 .52459 L p 0 .707 .545 r
F P
0 g
s
.23075 .50236 m .18762 .48076 L .18124 .4853 L p 0 .903 1 r
F P
0 g
s
.18762 .48076 m .23075 .50236 L p .1809 .52459 L 0 .707 .545 r
F P
0 g
s
.23075 .50236 m .22511 .54574 L .1809 .52459 L p 0 .707 .545 r
F P
0 g
s
.18762 .48076 m .23075 .50236 L p .1809 .52459 L 0 .707 .545 r
F P
0 g
s
.39068 .62551 m .38492 .62863 L .38489 .62864 L p 0 .1 .1 r
F P
0 g
s
.38492 .62863 m .38489 .62864 L .34494 .60966 L p 0 .704 .528 r
F P
0 g
s
.31298 .54112 m .30737 .54459 L .34812 .56492 L p 0 .907 1 r
F P
0 g
s
.34812 .56492 m .35376 .56159 L .31298 .54112 L p 0 .907 1 r
F P
0 g
s
.35376 .56159 m .34812 .56492 L .34494 .60966 L p 0 .1 .45 r
F P
0 g
s
.34812 .56492 m .34494 .60966 L .30325 .58986 L p 0 .704 .528 r
F P
0 g
s
.30325 .58986 m .30737 .54459 L .34812 .56492 L p 0 .704 .528 r
F P
0 g
s
.35376 .56159 m .34812 .56492 L .30737 .54459 L p 0 .907 1 r
F P
0 g
s
.31298 .54112 m .30737 .54459 L .31133 .50119 L p 0 .1 .425 r
F P
0 g
s
.31133 .50119 m .31683 .49764 L .31298 .54112 L p 0 .1 .425 r
F P
0 g
s
.35068 .60642 m .34494 .60966 L .34812 .56492 L p 0 .1 .45 r
F P
0 g
s
.34812 .56492 m .35376 .56159 L .35068 .60642 L p 0 .1 .45 r
F P
0 g
s
.38489 .62864 m .39065 .62553 L .39068 .62551 L p 0 .1 .1 r
F P
0 g
s
.39065 .62553 m .38489 .62864 L .34494 .60966 L p 0 .911 1 r
F P
0 g
s
.34723 .74541 m .35038 .6977 L .34341 .70125 L p 0 .114 .472 r
F P
0 g
s
.34341 .70125 m .34013 .74884 L .34723 .74541 L p 0 .114 .472 r
F P
0 g
s
.34338 .70121 m .34341 .70125 L .35038 .6977 L p 0 .562 .887 r
F P
0 g
s
.34338 .70121 m .34341 .70125 L .34013 .74884 L p 0 .707 .545 r
F P
0 g
s
.34338 .70121 m .34341 .70125 L .34013 .74884 L p 0 .707 .545 r
F P
0 g
s
.30255 .68374 m .34338 .70121 L .35035 .69765 L p 0 .914 1 r
F P
0 g
s
.35038 .6977 m .35035 .69765 L .34338 .70121 L p 0 .562 .887 r
F P
0 g
s
.34338 .70121 m .30255 .68374 L .29566 .68741 L p 0 .914 1 r
F P
0 g
s
.29832 .732 m .30255 .68374 L .34338 .70121 L p 0 .707 .545 r
F P
0 g
s
.34013 .74884 m .29832 .732 L p .34338 .70121 L 0 .707 .545 r
F P
0 g
s
.29832 .732 m .30255 .68374 L .34338 .70121 L p 0 .707 .545 r
F P
0 g
s
.34013 .74884 m .29832 .732 L p .34338 .70121 L 0 .707 .545 r
F P
0 g
s
.31 .53963 m .31392 .49611 L .30842 .49967 L p 0 .1 .423 r
F P
0 g
s
.30842 .49967 m .3044 .54311 L .31 .53963 L p 0 .1 .423 r
F P
0 g
s
.26677 .47794 m .30842 .49967 L .31392 .49611 L p 0 .903 1 r
F P
0 g
s
.30842 .49967 m .3044 .54311 L .26177 .52185 L p 0 .704 .528 r
F P
0 g
s
.26177 .52185 m .26677 .47794 L .30842 .49967 L p 0 .704 .528 r
F P
0 g
s
.26567 .61211 m .27243 .60811 L .31397 .62717 L p 0 .911 1 r
F P
0 g
s
.27414 .5619 m .2317 .54144 L .22511 .54574 L p 0 .907 1 r
F P
0 g
s
.27414 .5619 m .26939 .60672 L .22594 .58678 L p 0 .707 .542 r
F P
0 g
s
.22594 .58678 m .2317 .54144 L .27414 .5619 L p 0 .707 .542 r
F P
0 g
s
.23723 .49797 m .2317 .54144 L .22511 .54574 L p 0 .1 .396 r
F P
0 g
s
.23723 .49797 m .19405 .47618 L .18762 .48076 L p 0 .903 1 r
F P
0 g
s
.23723 .49797 m .2317 .54144 L .18744 .5201 L p 0 .707 .542 r
F P
0 g
s
.19405 .47618 m .23723 .49797 L p .18744 .5201 L 0 .707 .542 r
F P
0 g
s
.35918 .47035 m .35056 .4759 L .39056 .49772 L p 0 .903 0 r
F P
0 g
s
.39056 .49772 m .39921 .49239 L .35918 .47035 L p 0 .903 0 r
F P
0 g
s
.39921 .49239 m .39056 .49772 L .38825 .5412 L p 0 .1 0 r
F P
0 g
s
.37953 .54636 m .38825 .5412 L .39056 .49772 L p 0 .1 0 r
F P
0 g
s
.39056 .49772 m .38825 .5412 L .34735 .51985 L p 0 .701 0 r
F P
0 g
s
.34735 .51985 m .35056 .4759 L .39056 .49772 L p 0 .701 0 r
F P
0 g
s
.39707 .53598 m .38825 .5412 L .39056 .49772 L p 0 .1 0 r
F P
0 g
s
.39056 .49772 m .39921 .49239 L .39707 .53598 L p 0 .1 0 r
F P
0 g
s
.39707 .53598 m .38825 .5412 L .42748 .56166 L p 0 .907 0 r
F P
0 g
s
.42748 .56166 m .43632 .55666 L .39707 .53598 L p 0 .907 0 r
F P
0 g
s
.43632 .55666 m .42748 .56166 L .42595 .60646 L p 0 .114 0 r
F P
0 g
s
.41703 .61128 m .42595 .60646 L .42748 .56166 L p 0 .114 0 r
F P
0 g
s
.42748 .56166 m .42595 .60646 L p .38585 .58655 L 0 .701 0 r
F P
0 g
s
.37953 .54636 m .38825 .5412 L .42748 .56166 L p 0 .907 0 r
F P
0 g
s
.38585 .58655 m .38825 .5412 L .42748 .56166 L p 0 .701 0 r
F P
0 g
s
.43632 .55666 m .42748 .56166 L .38825 .5412 L p 0 .907 0 r
F P
0 g
s
.39056 .49772 m .38825 .5412 L .34735 .51985 L p 0 .701 0 r
F P
0 g
s
.34735 .51985 m .35056 .4759 L .39056 .49772 L p 0 .701 0 r
F P
0 g
s
.42748 .56166 m .42595 .60646 L p .38585 .58655 L 0 .701 0 r
F P
0 g
s
.42595 .60646 m .43497 .60159 L .43632 .55666 L p 0 .114 0 r
F P
0 g
s
.42595 .60646 m .41703 .61128 L .417 .6113 L p 0 .1 0 r
F P
0 g
s
.417 .6113 m .42592 .60648 L .42595 .60646 L p 0 .1 0 r
F P
0 g
s
.43497 .60159 m .42595 .60646 L .42592 .60648 L p 0 .1 0 r
F P
0 g
s
.42595 .60646 m .42592 .60648 L .38585 .58655 L p 0 .701 0 r
F P
0 g
s
.42595 .60646 m .42592 .60648 L .38585 .58655 L p 0 .701 0 r
F P
0 g
s
.42592 .60648 m .43494 .60161 L .43497 .60159 L p 0 .1 0 r
F P
0 g
s
.43494 .60161 m .42592 .60648 L .38585 .58655 L p 0 .911 0 r
F P
0 g
s
.38585 .58655 m .38825 .5412 L .42748 .56166 L p 0 .701 0 r
F P
0 g
s
.35943 .55824 m .35376 .56159 L .35068 .60642 L p 0 .1 .45 r
F P
0 g
s
.34494 .60966 m .35068 .60642 L .35376 .56159 L p 0 .1 .45 r
F P
0 g
s
.35376 .56159 m .35068 .60642 L .30896 .58647 L p 0 .704 .526 r
F P
0 g
s
.30737 .54459 m .31298 .54112 L .35376 .56159 L p 0 .907 1 r
F P
0 g
s
.30896 .58647 m .31298 .54112 L .35376 .56159 L p 0 .704 .526 r
F P
0 g
s
.35376 .56159 m .35068 .60642 L .30896 .58647 L p 0 .704 .526 r
F P
0 g
s
.30896 .58647 m .31298 .54112 L .35376 .56159 L p 0 .704 .526 r
F P
0 g
s
.35646 .60316 m .35068 .60642 L .35376 .56159 L p 0 .1 .45 r
F P
0 g
s
.35376 .56159 m .35943 .55824 L .35646 .60316 L p 0 .1 .45 r
F P
0 g
s
.36514 .55486 m .35943 .55824 L .35646 .60316 L p 0 .1 .45 r
F P
0 g
s
.31863 .53763 m .31298 .54112 L .35376 .56159 L p 0 .907 1 r
F P
0 g
s
.35376 .56159 m .35943 .55824 L .31863 .53763 L p 0 .907 1 r
F P
0 g
s
.35943 .55824 m .35376 .56159 L .31298 .54112 L p 0 .907 1 r
F P
0 g
s
.35068 .60642 m .35646 .60316 L .35943 .55824 L p 0 .1 .45 r
F P
0 g
s
.35943 .55824 m .35646 .60316 L .31472 .58307 L p 0 .704 .523 r
F P
0 g
s
.31298 .54112 m .31863 .53763 L .35943 .55824 L p 0 .907 1 r
F P
0 g
s
.31472 .58307 m .31863 .53763 L .35943 .55824 L p 0 .704 .523 r
F P
0 g
s
.35943 .55824 m .35646 .60316 L .31472 .58307 L p 0 .704 .523 r
F P
0 g
s
.31472 .58307 m .31863 .53763 L .35943 .55824 L p 0 .704 .523 r
F P
0 g
s
.36228 .59987 m .35646 .60316 L .35943 .55824 L p 0 .1 .45 r
F P
0 g
s
.35943 .55824 m .36514 .55486 L .36228 .59987 L p 0 .1 .45 r
F P
0 g
s
.37089 .55146 m .36514 .55486 L .36228 .59987 L p 0 .1 .45 r
F P
0 g
s
.32431 .53411 m .31863 .53763 L .35943 .55824 L p 0 .907 1 r
F P
0 g
s
.35943 .55824 m .36514 .55486 L .32431 .53411 L p 0 .907 1 r
F P
0 g
s
.36514 .55486 m .35943 .55824 L .31863 .53763 L p 0 .907 1 r
F P
0 g
s
.35646 .60316 m .36228 .59987 L .36514 .55486 L p 0 .1 .45 r
F P
0 g
s
.36514 .55486 m .36228 .59987 L .32051 .57963 L p 0 .703 .52 r
F P
0 g
s
.31863 .53763 m .32431 .53411 L .36514 .55486 L p 0 .907 1 r
F P
0 g
s
.32051 .57963 m .32431 .53411 L .36514 .55486 L p 0 .703 .52 r
F P
0 g
s
.36514 .55486 m .36228 .59987 L .32051 .57963 L p 0 .703 .52 r
F P
0 g
s
.32051 .57963 m .32431 .53411 L .36514 .55486 L p 0 .703 .52 r
F P
0 g
s
.36814 .59655 m .36228 .59987 L .36514 .55486 L p 0 .1 .45 r
F P
0 g
s
.36514 .55486 m .37089 .55146 L .36814 .59655 L p 0 .1 .45 r
F P
0 g
s
.37953 .54636 m .37089 .55146 L .36814 .59655 L p 0 .1 0 r
F P
0 g
s
.33004 .53056 m .32431 .53411 L .36514 .55486 L p 0 .907 1 r
F P
0 g
s
.36514 .55486 m .37089 .55146 L .33004 .53056 L p 0 .907 1 r
F P
0 g
s
.37089 .55146 m .36514 .55486 L .32431 .53411 L p 0 .907 1 r
F P
0 g
s
.36228 .59987 m .36814 .59655 L .37089 .55146 L p 0 .1 .45 r
F P
0 g
s
.37089 .55146 m .36814 .59655 L .32635 .57618 L p 0 .703 0 r
F P
0 g
s
.32431 .53411 m .33004 .53056 L .37089 .55146 L p 0 .907 1 r
F P
0 g
s
.32635 .57618 m .33004 .53056 L .37089 .55146 L p 0 .703 0 r
F P
0 g
s
.37695 .59158 m .36814 .59655 L .37089 .55146 L p 0 .1 0 r
F P
0 g
s
.37089 .55146 m .37953 .54636 L .37695 .59158 L p 0 .1 0 r
F P
0 g
s
.37089 .55146 m .36814 .59655 L .32635 .57618 L p 0 .703 .518 r
F P
0 g
s
.32635 .57618 m .33004 .53056 L .37089 .55146 L p 0 .703 .518 r
F P
0 g
s
.38825 .5412 m .37953 .54636 L .37695 .59158 L p 0 .1 0 r
F P
0 g
s
.33865 .52523 m .33004 .53056 L .37089 .55146 L p 0 .907 0 r
F P
0 g
s
.37089 .55146 m .37953 .54636 L .33865 .52523 L p 0 .907 0 r
F P
0 g
s
.37953 .54636 m .37089 .55146 L .33004 .53056 L p 0 .907 0 r
F P
0 g
s
.36814 .59655 m .37695 .59158 L .37953 .54636 L p 0 .1 0 r
F P
0 g
s
.37953 .54636 m .37695 .59158 L .33512 .57098 L p 0 .702 0 r
F P
0 g
s
.33004 .53056 m .33865 .52523 L .37953 .54636 L p 0 .907 0 r
F P
0 g
s
.33512 .57098 m .33865 .52523 L .37953 .54636 L p 0 .702 0 r
F P
0 g
s
.37953 .54636 m .37695 .59158 L .33512 .57098 L p 0 .702 0 r
F P
0 g
s
.33512 .57098 m .33865 .52523 L .37953 .54636 L p 0 .702 0 r
F P
0 g
s
.38585 .58655 m .37695 .59158 L .37953 .54636 L p 0 .1 0 r
F P
0 g
s
.37953 .54636 m .38825 .5412 L .38585 .58655 L p 0 .1 0 r
F P
0 g
s
.38825 .5412 m .39707 .53598 L .43632 .55666 L p 0 .907 0 r
F P
0 g
s
.39707 .53598 m .38825 .5412 L .38585 .58655 L p 0 .1 0 r
F P
0 g
s
.34735 .51985 m .33865 .52523 L .37953 .54636 L p 0 .907 0 r
F P
0 g
s
.37953 .54636 m .38825 .5412 L .34735 .51985 L p 0 .907 0 r
F P
0 g
s
.38825 .5412 m .37953 .54636 L .33865 .52523 L p 0 .907 0 r
F P
0 g
s
.37695 .59158 m .38585 .58655 L .38825 .5412 L p 0 .1 0 r
F P
0 g
s
.38825 .5412 m .38585 .58655 L .34399 .56573 L p 0 .701 0 r
F P
0 g
s
.39485 .58146 m .38585 .58655 L .38825 .5412 L p 0 .1 0 r
F P
0 g
s
.38825 .5412 m .38585 .58655 L .34399 .56573 L p 0 .701 0 r
F P
0 g
s
.33865 .52523 m .34735 .51985 L .38825 .5412 L p 0 .907 0 r
F P
0 g
s
.34399 .56573 m .34735 .51985 L .38825 .5412 L p 0 .701 0 r
F P
0 g
s
.34399 .56573 m .34735 .51985 L .38825 .5412 L p 0 .701 0 r
F P
0 g
s
.38585 .58655 m .39485 .58146 L .39707 .53598 L p 0 .1 0 r
F P
0 g
s
.34399 .56573 m .35296 .56042 L .39485 .58146 L p 0 .911 0 r
F P
0 g
s
.39485 .58146 m .38585 .58655 L .34399 .56573 L p 0 .911 0 r
F P
0 g
s
.43497 .47035 m .42595 .4759 L .46437 .4977 L p 0 .903 1 r
F P
0 g
s
.46437 .4977 m .4734 .49237 L .43497 .47035 L p 0 .903 1 r
F P
0 g
s
.4734 .49237 m .46437 .4977 L .4644 .49775 L p 0 .575 .884 r
F P
0 g
s
.46437 .4977 m .4644 .49775 L p .42436 .51985 L 0 .697 .491 r
F P
0 g
s
.42436 .51985 m .42595 .4759 L .46437 .4977 L p 0 .697 .491 r
F P
0 g
s
.46437 .4977 m .4644 .49775 L p .42436 .51985 L 0 .697 .491 r
F P
0 g
s
.42436 .51985 m .42595 .4759 L .46437 .4977 L p 0 .697 .491 r
F P
0 g
s
.4644 .49775 m .47343 .49242 L .4734 .49237 L p 0 .575 .884 r
F P
0 g
s
.47343 .49242 m .4644 .49775 L .46365 .5412 L p 0 .114 .472 r
F P
0 g
s
.45453 .54636 m .46365 .5412 L .4644 .49775 L p 0 .114 .472 r
F P
0 g
s
.4644 .49775 m .46365 .5412 L .42436 .51985 L p 0 .697 .491 r
F P
0 g
s
.4644 .49775 m .46365 .5412 L .42436 .51985 L p 0 .697 .491 r
F P
0 g
s
.39648 .62238 m .39068 .62551 L .39065 .62553 L p 0 .1 .1 r
F P
0 g
s
.39068 .62551 m .39065 .62553 L .35068 .60642 L p 0 .704 .526 r
F P
0 g
s
.39068 .62551 m .39065 .62553 L .35068 .60642 L p 0 .704 .526 r
F P
0 g
s
.31863 .53763 m .31298 .54112 L .31683 .49764 L p 0 .1 .425 r
F P
0 g
s
.31683 .49764 m .32238 .49407 L .31863 .53763 L p 0 .1 .425 r
F P
0 g
s
.39065 .62553 m .39645 .6224 L .39648 .62238 L p 0 .1 .1 r
F P
0 g
s
.39645 .6224 m .39065 .62553 L .35068 .60642 L p 0 .911 1 r
F P
0 g
s
.34494 .60966 m .35068 .60642 L .39065 .62553 L p 0 .911 1 r
F P
0 g
s
.28411 .60119 m .27595 .60602 L .28057 .56118 L p 0 .1 0 r
F P
0 g
s
.28057 .56118 m .28858 .55623 L .28411 .60119 L p 0 .1 0 r
F P
0 g
s
.32571 .62053 m .31751 .62516 L .27595 .60602 L p 0 .911 0 r
F P
0 g
s
.35035 .69765 m .30949 .68004 L .30255 .68374 L p 0 .914 1 r
F P
0 g
s
.30539 .72843 m .30949 .68004 L .35035 .69765 L p 0 .707 .542 r
F P
0 g
s
.34723 .74541 m .30539 .72843 L p .35035 .69765 L 0 .707 .542 r
F P
0 g
s
.35035 .69765 m .35038 .6977 L .34723 .74541 L p 0 .707 .542 r
F P
0 g
s
.31565 .53612 m .31946 .49253 L .31392 .49611 L p 0 .1 .423 r
F P
0 g
s
.31392 .49611 m .31 .53963 L .31565 .53612 L p 0 .1 .423 r
F P
0 g
s
.27224 .47423 m .31392 .49611 L .31946 .49253 L p 0 .903 1 r
F P
0 g
s
.31392 .49611 m .31 .53963 L .26734 .51821 L p 0 .704 .526 r
F P
0 g
s
.31392 .49611 m .27224 .47423 L .26677 .47794 L p 0 .903 1 r
F P
0 g
s
.26734 .51821 m .27224 .47423 L .31392 .49611 L p 0 .704 .526 r
F P
0 g
s
.31392 .49611 m .31 .53963 L .26734 .51821 L p 0 .704 .526 r
F P
0 g
s
.26734 .51821 m .27224 .47423 L .31392 .49611 L p 0 .704 .526 r
F P
0 g
s
.28107 .59978 m .28561 .55478 L .27761 .55975 L p 0 .1 0 r
F P
0 g
s
.27761 .55975 m .27292 .60462 L .28107 .59978 L p 0 .1 0 r
F P
0 g
s
.23515 .5392 m .27761 .55975 L .28561 .55478 L p 0 .907 0 r
F P
0 g
s
.27761 .55975 m .27292 .60462 L .22944 .5846 L p 0 .706 0 r
F P
0 g
s
.22944 .5846 m .23515 .5392 L .27761 .55975 L p 0 .706 0 r
F P
0 g
s
.2431 .53402 m .28561 .55478 L .27761 .55975 L p 0 .907 0 r
F P
0 g
s
.27761 .55975 m .23515 .5392 L .2431 .53402 L p 0 .907 0 r
F P
0 g
s
.23515 .5392 m .24061 .49567 L .24843 .49038 L p 0 .1 0 r
F P
0 g
s
.2431 .53402 m .24843 .49038 L .24061 .49567 L p 0 .1 0 r
F P
0 g
s
.24061 .49567 m .23515 .5392 L .2431 .53402 L p 0 .1 0 r
F P
0 g
s
.1974 .47379 m .24061 .49567 L .24843 .49038 L p 0 .903 0 r
F P
0 g
s
.24061 .49567 m .23515 .5392 L .19086 .51776 L p 0 .706 0 r
F P
0 g
s
.1974 .47379 m .24061 .49567 L p .19086 .51776 L 0 .706 0 r
F P
0 g
s
.31311 .67811 m .35399 .6958 L .3624 .69152 L p 0 .914 0 r
F P
0 g
s
.35951 .73951 m .36242 .69156 L .35402 .69585 L p 0 .114 0 r
F P
0 g
s
.35402 .69585 m .35094 .74363 L .35951 .73951 L p 0 .114 0 r
F P
0 g
s
.36242 .69156 m .3624 .69152 L .35399 .6958 L p 0 .562 0 r
F P
0 g
s
.35399 .6958 m .35402 .69585 L .36242 .69156 L p 0 .562 0 r
F P
0 g
s
.30908 .72657 m .31311 .67811 L .35399 .6958 L p 0 .706 0 r
F P
0 g
s
.35094 .74363 m .30908 .72657 L p .35399 .6958 L 0 .706 0 r
F P
0 g
s
.35399 .6958 m .35402 .69585 L .35094 .74363 L p 0 .706 0 r
F P
0 g
s
.40232 .61923 m .39648 .62238 L .39645 .6224 L p 0 .1 .1 r
F P
0 g
s
.39648 .62238 m .39645 .6224 L .35646 .60316 L p 0 .704 .523 r
F P
0 g
s
.39648 .62238 m .39645 .6224 L .35646 .60316 L p 0 .704 .523 r
F P
0 g
s
.32431 .53411 m .31863 .53763 L .32238 .49407 L p 0 .1 .425 r
F P
0 g
s
.32238 .49407 m .32796 .49047 L .32431 .53411 L p 0 .1 .425 r
F P
0 g
s
.39645 .6224 m .40229 .61925 L .40232 .61923 L p 0 .1 .1 r
F P
0 g
s
.40229 .61925 m .39645 .6224 L .35646 .60316 L p 0 .911 1 r
F P
0 g
s
.35068 .60642 m .35646 .60316 L .39645 .6224 L p 0 .911 1 r
F P
0 g
s
.32133 .53259 m .32504 .48892 L .31946 .49253 L p 0 .1 .423 r
F P
0 g
s
.31946 .49253 m .31565 .53612 L .32133 .53259 L p 0 .1 .423 r
F P
0 g
s
.27776 .47049 m .31946 .49253 L .32504 .48892 L p 0 .903 1 r
F P
0 g
s
.31946 .49253 m .31565 .53612 L .27296 .51455 L p 0 .704 .523 r
F P
0 g
s
.31946 .49253 m .27776 .47049 L .27224 .47423 L p 0 .903 1 r
F P
0 g
s
.27296 .51455 m .27776 .47049 L .31946 .49253 L p 0 .704 .523 r
F P
0 g
s
.31946 .49253 m .31565 .53612 L .27296 .51455 L p 0 .704 .523 r
F P
0 g
s
.27296 .51455 m .27776 .47049 L .31946 .49253 L p 0 .704 .523 r
F P
0 g
s
.36789 .46473 m .35918 .47035 L .39921 .49239 L p 0 .903 0 r
F P
0 g
s
.39921 .49239 m .40794 .487 L .36789 .46473 L p 0 .903 0 r
F P
0 g
s
.40794 .487 m .39921 .49239 L .39707 .53598 L p 0 .1 0 r
F P
0 g
s
.38825 .5412 m .39707 .53598 L .39921 .49239 L p 0 .1 0 r
F P
0 g
s
.39921 .49239 m .39707 .53598 L .35614 .51441 L p 0 .7 0 r
F P
0 g
s
.35614 .51441 m .35918 .47035 L .39921 .49239 L p 0 .7 0 r
F P
0 g
s
.39921 .49239 m .39707 .53598 L .35614 .51441 L p 0 .7 0 r
F P
0 g
s
.35614 .51441 m .35918 .47035 L .39921 .49239 L p 0 .7 0 r
F P
0 g
s
.40599 .53071 m .39707 .53598 L .43632 .55666 L p 0 .907 0 r
F P
0 g
s
.43632 .55666 m .44525 .55161 L .40599 .53071 L p 0 .907 0 r
F P
0 g
s
.44525 .55161 m .43632 .55666 L .43497 .60159 L p 0 .114 0 r
F P
0 g
s
.43632 .55666 m .43497 .60159 L p .39485 .58146 L 0 .7 0 r
F P
0 g
s
.39485 .58146 m .39707 .53598 L .43632 .55666 L p 0 .7 0 r
F P
0 g
s
.43632 .55666 m .43497 .60159 L p .39485 .58146 L 0 .7 0 r
F P
0 g
s
.39485 .58146 m .39707 .53598 L .43632 .55666 L p 0 .7 0 r
F P
0 g
s
.44525 .55161 m .43632 .55666 L .39707 .53598 L p 0 .907 0 r
F P
0 g
s
.40599 .53071 m .39707 .53598 L .39921 .49239 L p 0 .1 0 r
F P
0 g
s
.39921 .49239 m .40794 .487 L .40599 .53071 L p 0 .1 0 r
F P
0 g
s
.44408 .46473 m .43497 .47035 L .4734 .49237 L p 0 .903 1 r
F P
0 g
s
.4734 .49237 m .48252 .48699 L .44408 .46473 L p 0 .903 1 r
F P
0 g
s
.48252 .48699 m .4734 .49237 L .47343 .49242 L p 0 .575 .884 r
F P
0 g
s
.4734 .49237 m .47343 .49242 L p .43356 .51441 L 0 .696 .486 r
F P
0 g
s
.43356 .51441 m .43497 .47035 L .4734 .49237 L p 0 .696 .486 r
F P
0 g
s
.4734 .49237 m .47343 .49242 L p .43356 .51441 L 0 .696 .486 r
F P
0 g
s
.43356 .51441 m .43497 .47035 L .4734 .49237 L p 0 .696 .486 r
F P
0 g
s
.47343 .49242 m .48255 .48703 L .48252 .48699 L p 0 .575 .884 r
F P
0 g
s
.48255 .48703 m .47343 .49242 L .47286 .53598 L p 0 .114 .472 r
F P
0 g
s
.46365 .5412 m .47286 .53598 L .47343 .49242 L p 0 .114 .472 r
F P
0 g
s
.47343 .49242 m .47286 .53598 L .43356 .51441 L p 0 .696 .486 r
F P
0 g
s
.47343 .49242 m .47286 .53598 L .43356 .51441 L p 0 .696 .486 r
F P
0 g
s
.33398 .61586 m .32571 .62053 L .28411 .60119 L p 0 .911 0 r
F P
0 g
s
.27595 .60602 m .28411 .60119 L .32571 .62053 L p 0 .911 0 r
F P
0 g
s
.29234 .59632 m .28411 .60119 L .28858 .55623 L p 0 .1 0 r
F P
0 g
s
.28858 .55623 m .29667 .55122 L .29234 .59632 L p 0 .1 0 r
F P
0 g
s
.4082 .61605 m .40232 .61923 L .40229 .61925 L p 0 .1 .1 r
F P
0 g
s
.40232 .61923 m .40229 .61925 L .36228 .59987 L p 0 .703 .52 r
F P
0 g
s
.40232 .61923 m .40229 .61925 L .36228 .59987 L p 0 .703 .52 r
F P
0 g
s
.33004 .53056 m .32431 .53411 L .32796 .49047 L p 0 .1 .425 r
F P
0 g
s
.32796 .49047 m .33358 .48685 L .33004 .53056 L p 0 .1 .425 r
F P
0 g
s
.40229 .61925 m .40817 .61607 L .4082 .61605 L p 0 .1 .1 r
F P
0 g
s
.40817 .61607 m .40229 .61925 L .36228 .59987 L p 0 .911 1 r
F P
0 g
s
.35646 .60316 m .36228 .59987 L .40229 .61925 L p 0 .911 1 r
F P
0 g
s
.25113 .52878 m .29369 .54976 L .28561 .55478 L p 0 .907 0 r
F P
0 g
s
.28561 .55478 m .2431 .53402 L .25113 .52878 L p 0 .907 0 r
F P
0 g
s
.2431 .53402 m .24843 .49038 L .25632 .48502 L p 0 .1 0 r
F P
0 g
s
.24843 .49038 m .2431 .53402 L .23515 .5392 L p 0 .1 0 r
F P
0 g
s
.25113 .52878 m .25632 .48502 L .24843 .49038 L p 0 .1 0 r
F P
0 g
s
.24843 .49038 m .2431 .53402 L .25113 .52878 L p 0 .1 0 r
F P
0 g
s
.20516 .46827 m .24843 .49038 L .25632 .48502 L p 0 .903 0 r
F P
0 g
s
.24843 .49038 m .2431 .53402 L .19874 .51236 L p 0 .706 0 r
F P
0 g
s
.24843 .49038 m .20516 .46827 L .1974 .47379 L p 0 .903 0 r
F P
0 g
s
.20516 .46827 m .24843 .49038 L p .19874 .51236 L 0 .706 0 r
F P
0 g
s
.24843 .49038 m .2431 .53402 L .19874 .51236 L p 0 .706 0 r
F P
0 g
s
.20516 .46827 m .24843 .49038 L p .19874 .51236 L 0 .706 0 r
F P
0 g
s
.2893 .59489 m .29369 .54976 L .28561 .55478 L p 0 .1 0 r
F P
0 g
s
.28561 .55478 m .28107 .59978 L .2893 .59489 L p 0 .1 0 r
F P
0 g
s
.2431 .53402 m .28561 .55478 L .29369 .54976 L p 0 .907 0 r
F P
0 g
s
.28561 .55478 m .28107 .59978 L .23754 .57955 L p 0 .706 0 r
F P
0 g
s
.28561 .55478 m .2431 .53402 L .23515 .5392 L p 0 .907 0 r
F P
0 g
s
.23754 .57955 m .2431 .53402 L .28561 .55478 L p 0 .706 0 r
F P
0 g
s
.28561 .55478 m .28107 .59978 L .23754 .57955 L p 0 .706 0 r
F P
0 g
s
.23754 .57955 m .2431 .53402 L .28561 .55478 L p 0 .706 0 r
F P
0 g
s
.32706 .52903 m .33066 .48528 L .32504 .48892 L p 0 .1 .423 r
F P
0 g
s
.32504 .48892 m .32133 .53259 L .32706 .52903 L p 0 .1 .423 r
F P
0 g
s
.32504 .48892 m .32133 .53259 L .27861 .51087 L p 0 .703 .52 r
F P
0 g
s
.32504 .48892 m .28331 .46673 L .27776 .47049 L p 0 .903 1 r
F P
0 g
s
.27861 .51087 m .28331 .46673 L .32504 .48892 L p 0 .703 .52 r
F P
0 g
s
.32504 .48892 m .32133 .53259 L .27861 .51087 L p 0 .703 .52 r
F P
0 g
s
.27861 .51087 m .28331 .46673 L .32504 .48892 L p 0 .703 .52 r
F P
0 g
s
.33865 .52523 m .33004 .53056 L .33358 .48685 L p 0 .1 0 r
F P
0 g
s
.33066 .48528 m .32706 .52903 L .33566 .52369 L p 0 .1 0 r
F P
0 g
s
.28331 .46673 m .32504 .48892 L .33066 .48528 L p 0 .903 1 r
F P
0 g
s
.33066 .48528 m .32706 .52903 L .28431 .50716 L p 0 .703 0 r
F P
0 g
s
.33066 .48528 m .2889 .46294 L .28331 .46673 L p 0 .903 1 r
F P
0 g
s
.28431 .50716 m .29497 .46619 L .33066 .48528 L p 0 .703 0 r
F P
0 g
s
.2889 .46294 m .33066 .48528 L .33911 .47983 L p 0 .903 0 r
F P
0 g
s
.28431 .50716 m .2889 .46294 L .33066 .48528 L p 0 .703 .518 r
F P
0 g
s
.33911 .47983 m .2973 .45725 L .2889 .46294 L p 0 .903 0 r
F P
0 g
s
.28431 .50716 m .2889 .46294 L .2973 .45725 L p 0 .1 0 r
F P
0 g
s
.33066 .48528 m .32706 .52903 L .28431 .50716 L p 0 .703 .518 r
F P
0 g
s
.29286 .50158 m .33566 .52369 L .32706 .52903 L p 0 .907 0 r
F P
0 g
s
.28431 .50716 m .32706 .52903 L .33566 .52369 L p 0 .907 0 r
F P
0 g
s
.32148 .67364 m .3624 .69152 L .37089 .68719 L p 0 .914 0 r
F P
0 g
s
.36816 .73534 m .37091 .68724 L .36242 .69156 L p 0 .114 0 r
F P
0 g
s
.36242 .69156 m .35951 .73951 L .36816 .73534 L p 0 .114 0 r
F P
0 g
s
.37091 .68724 m .37089 .68719 L .3624 .69152 L p 0 .562 0 r
F P
0 g
s
.3624 .69152 m .36242 .69156 L .37091 .68724 L p 0 .562 0 r
F P
0 g
s
.3624 .69152 m .32148 .67364 L .31311 .67811 L p 0 .914 0 r
F P
0 g
s
.31761 .72227 m .32148 .67364 L .3624 .69152 L p 0 .706 0 r
F P
0 g
s
.35951 .73951 m .31761 .72227 L p .3624 .69152 L 0 .706 0 r
F P
0 g
s
.3624 .69152 m .36242 .69156 L .35951 .73951 L p 0 .706 0 r
F P
0 g
s
.31761 .72227 m .32148 .67364 L .3624 .69152 L p 0 .706 0 r
F P
0 g
s
.35951 .73951 m .31761 .72227 L p .3624 .69152 L 0 .706 0 r
F P
0 g
s
.3624 .69152 m .36242 .69156 L .35951 .73951 L p 0 .706 0 r
F P
0 g
s
.39707 .53598 m .40599 .53071 L .40794 .487 L p 0 .1 0 r
F P
0 g
s
.40794 .487 m .40599 .53071 L .36502 .50891 L p 0 .699 0 r
F P
0 g
s
.36502 .50891 m .36789 .46473 L .40794 .487 L p 0 .699 0 r
F P
0 g
s
.43497 .60159 m .44408 .59666 L .44525 .55161 L p 0 .114 0 r
F P
0 g
s
.44525 .55161 m .44408 .59666 L p .40394 .57632 L 0 .699 0 r
F P
0 g
s
.39707 .53598 m .40599 .53071 L .44525 .55161 L p 0 .907 0 r
F P
0 g
s
.40394 .57632 m .40599 .53071 L .44525 .55161 L p 0 .699 0 r
F P
0 g
s
.47286 .53598 m .48218 .53071 L .48255 .48703 L p 0 .114 .472 r
F P
0 g
s
.48255 .48703 m .48218 .53071 L .44287 .50891 L p 0 .695 .481 r
F P
0 g
s
.48252 .48699 m .48255 .48703 L p .44287 .50891 L 0 .695 .481 r
F P
0 g
s
.44287 .50891 m .44408 .46473 L .48252 .48699 L p 0 .695 .481 r
F P
0 g
s
.41703 .61128 m .4082 .61605 L .40817 .61607 L p 0 .1 0 r
F P
0 g
s
.4082 .61605 m .40817 .61607 L .36814 .59655 L p 0 .703 0 r
F P
0 g
s
.4082 .61605 m .40817 .61607 L .36814 .59655 L p 0 .703 .518 r
F P
0 g
s
.33358 .48685 m .34202 .4814 L .33865 .52523 L p 0 .1 0 r
F P
0 g
s
.37695 .45889 m .36814 .46457 L .4082 .48685 L p 0 .903 1 r
F P
0 g
s
.4082 .48685 m .41703 .4814 L .37695 .45889 L p 0 .903 1 r
F P
0 g
s
.41703 .4814 m .4082 .48685 L .40624 .53056 L p 0 .1 .45 r
F P
0 g
s
.4082 .48685 m .40624 .53056 L .36528 .50875 L p 0 .699 .5 r
F P
0 g
s
.36528 .50875 m .36814 .46457 L .4082 .48685 L p 0 .699 .5 r
F P
0 g
s
.41525 .52523 m .40624 .53056 L .4455 .55146 L p 0 .907 1 r
F P
0 g
s
.4455 .55146 m .45453 .54636 L .41525 .52523 L p 0 .907 1 r
F P
0 g
s
.45453 .54636 m .4455 .55146 L .44435 .59652 L p 0 .114 .472 r
F P
0 g
s
.4455 .55146 m .44435 .59652 L p .40421 .57618 L 0 .699 .5 r
F P
0 g
s
.40421 .57618 m .40624 .53056 L .4455 .55146 L p 0 .699 .5 r
F P
0 g
s
.45453 .54636 m .4455 .55146 L .40624 .53056 L p 0 .907 1 r
F P
0 g
s
.41525 .52523 m .40624 .53056 L .4082 .48685 L p 0 .1 .45 r
F P
0 g
s
.4082 .48685 m .41703 .4814 L .41525 .52523 L p 0 .1 .45 r
F P
0 g
s
.45356 .45889 m .44435 .46457 L .48278 .48683 L p 0 .903 0 r
F P
0 g
s
.48278 .48683 m .492 .48139 L .45356 .45889 L p 0 .903 0 r
F P
0 g
s
.492 .48139 m .48278 .48683 L .48281 .48688 L p 0 .575 0 r
F P
0 g
s
.48281 .48688 m .49203 .48143 L .492 .48139 L p 0 .575 0 r
F P
0 g
s
.49203 .48143 m .48281 .48688 L .48245 .53056 L p 0 .114 0 r
F P
0 g
s
.48281 .48688 m .48245 .53056 L .44314 .50875 L p 0 .695 0 r
F P
0 g
s
.48278 .48683 m .48281 .48688 L p .44314 .50875 L 0 .695 0 r
F P
0 g
s
.44314 .50875 m .44435 .46457 L .48278 .48683 L p 0 .695 0 r
F P
0 g
s
.40817 .61607 m .417 .6113 L .41703 .61128 L p 0 .1 0 r
F P
0 g
s
.417 .6113 m .40817 .61607 L .36814 .59655 L p 0 .911 0 r
F P
0 g
s
.36228 .59987 m .36814 .59655 L .40817 .61607 L p 0 .911 1 r
F P
0 g
s
.28411 .60119 m .29234 .59632 L .33398 .61586 L p 0 .911 0 r
F P
0 g
s
.18121 .48532 m .18124 .4853 L .18762 .48076 L p 0 1 .86 r
F P
0 g
s
.17442 .52903 m .18121 .48532 L .18124 .4853 L p 0 .708 .548 r
F P
0 g
s
.33566 .52369 m .33911 .47983 L .33066 .48528 L p 0 .1 0 r
F P
0 g
s
.21923 .59097 m .26264 .61073 L .25594 .61472 L p 0 .911 1 r
F P
0 g
s
.25594 .61472 m .21258 .59513 L .21923 .59097 L p 0 .911 1 r
F P
0 g
s
.21258 .59513 m .21857 .55 L .22511 .54574 L p 0 .1 .396 r
F P
0 g
s
.21923 .59097 m .22511 .54574 L .21857 .55 L p 0 .1 .396 r
F P
0 g
s
.21857 .55 m .21258 .59513 L .21923 .59097 L p 0 .1 .396 r
F P
0 g
s
.17442 .52903 m .21857 .55 L .22511 .54574 L p 0 .907 1 r
F P
0 g
s
.21857 .55 m .21258 .59513 L .16737 .5747 L p 0 .708 .548 r
F P
0 g
s
.17442 .52903 m .21857 .55 L p .16737 .5747 L 0 .708 .548 r
F P
0 g
s
.1809 .52459 m .22511 .54574 L .21857 .55 L p 0 .907 1 r
F P
0 g
s
.21857 .55 m .17442 .52903 L .1809 .52459 L p 0 .907 1 r
F P
0 g
s
.18762 .48076 m .18758 .48077 L .18121 .48532 L p 0 1 .86 r
F P
0 g
s
.17442 .52903 m .18121 .48532 L .18758 .48077 L p 0 .1 .365 r
F P
0 g
s
.25632 .48502 m .25113 .52878 L .2431 .53402 L p 0 .1 0 r
F P
0 g
s
.25632 .48502 m .21299 .46269 L .20516 .46827 L p 0 .903 0 r
F P
0 g
s
.25632 .48502 m .25113 .52878 L .20672 .50689 L p 0 .705 0 r
F P
0 g
s
.21299 .46269 m .25632 .48502 L p .20672 .50689 L 0 .705 0 r
F P
0 g
s
.29369 .54976 m .25113 .52878 L .2431 .53402 L p 0 .907 0 r
F P
0 g
s
.29369 .54976 m .2893 .59489 L .24571 .57444 L p 0 .705 0 r
F P
0 g
s
.24571 .57444 m .25113 .52878 L .29369 .54976 L p 0 .705 0 r
F P
0 g
s
.29832 .732 m .34013 .74884 L .33308 .75223 L p 0 .916 1 r
F P
0 g
s
.33308 .75223 m .29131 .73554 L .29832 .732 L p 0 .916 1 r
F P
0 g
s
.29131 .73554 m .33308 .75223 L .34013 .74884 L p 0 .916 1 r
F P
0 g
s
.33671 .79845 m .34013 .74884 L .33308 .75223 L p 0 .114 .472 r
F P
0 g
s
.33308 .75223 m .32953 .8017 L .33671 .79845 L p 0 .114 .472 r
F P
0 g
s
.28676 .78576 m .29131 .73554 L .33308 .75223 L p 0 .708 .548 r
F P
0 g
s
.32949 .80172 m .28676 .78576 L p .33308 .75223 L 0 .708 .548 r
F P
0 g
s
.33308 .75223 m .32953 .8017 L .32949 .80172 L p 0 .708 .548 r
F P
0 g
s
.25309 .66935 m .29566 .68741 L .30255 .68374 L p 0 .914 1 r
F P
0 g
s
.29832 .732 m .30255 .68374 L .29566 .68741 L p 0 .1 .45 r
F P
0 g
s
.29566 .68741 m .29131 .73554 L .29832 .732 L p 0 .1 .45 r
F P
0 g
s
.24771 .71813 m .25309 .66935 L .29566 .68741 L p 0 .708 .548 r
F P
0 g
s
.29566 .68741 m .29131 .73554 L .24771 .71813 L p 0 .708 .548 r
F P
0 g
s
.29131 .73554 m .29566 .68741 L .30255 .68374 L p 0 .1 .45 r
F P
0 g
s
.37089 .68719 m .32994 .66913 L .32148 .67364 L p 0 .914 0 r
F P
0 g
s
.32623 .71792 m .32994 .66913 L .37089 .68719 L p 0 .705 0 r
F P
0 g
s
.36816 .73534 m .32623 .71792 L p .37089 .68719 L 0 .705 0 r
F P
0 g
s
.37089 .68719 m .37091 .68724 L .36816 .73534 L p 0 .705 0 r
F P
0 g
s
.41703 .61128 m .417 .6113 L .37695 .59158 L p 0 .702 0 r
F P
0 g
s
.41703 .61128 m .417 .6113 L .37695 .59158 L p 0 .702 0 r
F P
0 g
s
.34735 .51985 m .33865 .52523 L .34202 .4814 L p 0 .1 0 r
F P
0 g
s
.34202 .4814 m .35056 .4759 L .34735 .51985 L p 0 .1 0 r
F P
0 g
s
.42436 .51985 m .41525 .52523 L .45453 .54636 L p 0 .907 1 r
F P
0 g
s
.45453 .54636 m .46365 .5412 L .42436 .51985 L p 0 .907 1 r
F P
0 g
s
.46365 .5412 m .45453 .54636 L .45356 .59154 L p 0 .114 .472 r
F P
0 g
s
.44435 .59652 m .45356 .59154 L .45453 .54636 L p 0 .114 .472 r
F P
0 g
s
.45453 .54636 m .45356 .59154 L p .4134 .57098 L 0 .698 .496 r
F P
0 g
s
.40624 .53056 m .41525 .52523 L .45453 .54636 L p 0 .907 1 r
F P
0 g
s
.4134 .57098 m .41525 .52523 L .45453 .54636 L p 0 .698 .496 r
F P
0 g
s
.45453 .54636 m .45356 .59154 L p .4134 .57098 L 0 .698 .496 r
F P
0 g
s
.4134 .57098 m .41525 .52523 L .45453 .54636 L p 0 .698 .496 r
F P
0 g
s
.46365 .5412 m .45453 .54636 L .41525 .52523 L p 0 .907 1 r
F P
0 g
s
.42436 .51985 m .41525 .52523 L .41703 .4814 L p 0 .1 .45 r
F P
0 g
s
.41703 .4814 m .42595 .4759 L .42436 .51985 L p 0 .1 .45 r
F P
0 g
s
.38585 .45315 m .37695 .45889 L .41703 .4814 L p 0 .903 1 r
F P
0 g
s
.41703 .4814 m .42595 .4759 L .38585 .45315 L p 0 .903 1 r
F P
0 g
s
.42595 .4759 m .41703 .4814 L .41525 .52523 L p 0 .1 .45 r
F P
0 g
s
.40624 .53056 m .41525 .52523 L .41703 .4814 L p 0 .1 .45 r
F P
0 g
s
.41703 .4814 m .41525 .52523 L .37426 .50319 L p 0 .698 .496 r
F P
0 g
s
.37426 .50319 m .37695 .45889 L .41703 .4814 L p 0 .698 .496 r
F P
0 g
s
.41703 .4814 m .41525 .52523 L .37426 .50319 L p 0 .698 .496 r
F P
0 g
s
.37426 .50319 m .37695 .45889 L .41703 .4814 L p 0 .698 .496 r
F P
0 g
s
.46287 .45315 m .45356 .45889 L .492 .48139 L p 0 .903 0 r
F P
0 g
s
.492 .48139 m .50132 .47589 L .46287 .45315 L p 0 .903 0 r
F P
0 g
s
.50132 .47589 m .492 .48139 L .49203 .48143 L p 0 .575 0 r
F P
0 g
s
.49203 .48143 m .50135 .47593 L .50132 .47589 L p 0 .575 0 r
F P
0 g
s
.50135 .47593 m .49203 .48143 L .49186 .52523 L p 0 .114 0 r
F P
0 g
s
.48245 .53056 m .49186 .52523 L .49203 .48143 L p 0 .114 0 r
F P
0 g
s
.49203 .48143 m .49186 .52523 L .45254 .50319 L p 0 .694 0 r
F P
0 g
s
.492 .48139 m .49203 .48143 L p .45254 .50319 L 0 .694 0 r
F P
0 g
s
.45254 .50319 m .45356 .45889 L .492 .48139 L p 0 .694 0 r
F P
0 g
s
.49203 .48143 m .49186 .52523 L .45254 .50319 L p 0 .694 0 r
F P
0 g
s
.492 .48139 m .49203 .48143 L p .45254 .50319 L 0 .694 0 r
F P
0 g
s
.45254 .50319 m .45356 .45889 L .492 .48139 L p 0 .694 0 r
F P
0 g
s
.42592 .60648 m .417 .6113 L .37695 .59158 L p 0 .911 0 r
F P
0 g
s
.36814 .59655 m .37695 .59158 L .417 .6113 L p 0 .911 0 r
F P
0 g
s
.18758 .48077 m .18762 .48076 L .19405 .47618 L p 0 1 .86 r
F P
0 g
s
.1809 .52459 m .18758 .48077 L .18762 .48076 L p 0 .707 .545 r
F P
0 g
s
.1809 .52459 m .18758 .48077 L .18762 .48076 L p 0 .707 .545 r
F P
0 g
s
.22594 .58678 m .26939 .60672 L .26264 .61073 L p 0 .911 1 r
F P
0 g
s
.26264 .61073 m .21923 .59097 L .22594 .58678 L p 0 .911 1 r
F P
0 g
s
.21923 .59097 m .22511 .54574 L .2317 .54144 L p 0 .1 .396 r
F P
0 g
s
.22511 .54574 m .21923 .59097 L .21258 .59513 L p 0 .1 .396 r
F P
0 g
s
.22594 .58678 m .2317 .54144 L .22511 .54574 L p 0 .1 .396 r
F P
0 g
s
.22511 .54574 m .21923 .59097 L .22594 .58678 L p 0 .1 .396 r
F P
0 g
s
.1809 .52459 m .22511 .54574 L .2317 .54144 L p 0 .907 1 r
F P
0 g
s
.22511 .54574 m .21923 .59097 L .17396 .57037 L p 0 .707 .545 r
F P
0 g
s
.22511 .54574 m .1809 .52459 L .17442 .52903 L p 0 .907 1 r
F P
0 g
s
.1809 .52459 m .22511 .54574 L p .17396 .57037 L 0 .707 .545 r
F P
0 g
s
.22511 .54574 m .21923 .59097 L .17396 .57037 L p 0 .707 .545 r
F P
0 g
s
.1809 .52459 m .22511 .54574 L p .17396 .57037 L 0 .707 .545 r
F P
0 g
s
.18744 .5201 m .2317 .54144 L .22511 .54574 L p 0 .907 1 r
F P
0 g
s
.22511 .54574 m .1809 .52459 L .18744 .5201 L p 0 .907 1 r
F P
0 g
s
.19405 .47618 m .19401 .47619 L .18758 .48077 L p 0 1 .86 r
F P
0 g
s
.1809 .52459 m .18758 .48077 L .19401 .47619 L p 0 .1 .365 r
F P
0 g
s
.18758 .48077 m .1809 .52459 L .17442 .52903 L p 0 .1 .365 r
F P
0 g
s
.34436 .51829 m .34763 .47431 L .33911 .47983 L p 0 .1 0 r
F P
0 g
s
.33911 .47983 m .33566 .52369 L .34436 .51829 L p 0 .1 0 r
F P
0 g
s
.2973 .45725 m .33911 .47983 L .34763 .47431 L p 0 .903 0 r
F P
0 g
s
.33911 .47983 m .33566 .52369 L .29286 .50158 L p 0 .702 0 r
F P
0 g
s
.29286 .50158 m .2973 .45725 L .33911 .47983 L p 0 .702 0 r
F P
0 g
s
.33911 .47983 m .33566 .52369 L .29286 .50158 L p 0 .702 0 r
F P
0 g
s
.29286 .50158 m .2973 .45725 L .33911 .47983 L p 0 .702 0 r
F P
0 g
s
.35068 .60642 m .34494 .60966 L .30325 .58986 L p 0 .911 1 r
F P
0 g
s
.30896 .58647 m .30325 .58986 L .30737 .54459 L p 0 .1 .425 r
F P
0 g
s
.30737 .54459 m .31298 .54112 L .30896 .58647 L p 0 .1 .425 r
F P
0 g
s
.29832 .732 m .30255 .68374 L .30949 .68004 L p 0 .1 .45 r
F P
0 g
s
.30255 .68374 m .29832 .732 L .29131 .73554 L p 0 .1 .45 r
F P
0 g
s
.30539 .72843 m .34723 .74541 L .34013 .74884 L p 0 .916 1 r
F P
0 g
s
.34013 .74884 m .29832 .732 L .30539 .72843 L p 0 .916 1 r
F P
0 g
s
.29832 .732 m .34013 .74884 L .34723 .74541 L p 0 .916 1 r
F P
0 g
s
.34395 .79518 m .34723 .74541 L .34013 .74884 L p 0 .114 .472 r
F P
0 g
s
.34013 .74884 m .33671 .79845 L .34395 .79518 L p 0 .114 .472 r
F P
0 g
s
.34013 .74884 m .29832 .732 L .29131 .73554 L p 0 .916 1 r
F P
0 g
s
.2939 .78238 m .29832 .732 L .34013 .74884 L p 0 .707 .545 r
F P
0 g
s
.33667 .79848 m .33671 .79845 L .32953 .8017 L p 0 .1 .1 r
F P
0 g
s
.33667 .79848 m .2939 .78238 L p .34013 .74884 L 0 .707 .545 r
F P
0 g
s
.34013 .74884 m .33671 .79845 L .33667 .79848 L p 0 .707 .545 r
F P
0 g
s
.2939 .78238 m .29832 .732 L .34013 .74884 L p 0 .707 .545 r
F P
0 g
s
.33667 .79848 m .2939 .78238 L p .34013 .74884 L 0 .707 .545 r
F P
0 g
s
.34013 .74884 m .33671 .79845 L .33667 .79848 L p 0 .707 .545 r
F P
0 g
s
.25993 .66552 m .30255 .68374 L .30949 .68004 L p 0 .914 1 r
F P
0 g
s
.30539 .72843 m .30949 .68004 L .30255 .68374 L p 0 .1 .45 r
F P
0 g
s
.30255 .68374 m .29832 .732 L .30539 .72843 L p 0 .1 .45 r
F P
0 g
s
.30255 .68374 m .25993 .66552 L .25309 .66935 L p 0 .914 1 r
F P
0 g
s
.25467 .71443 m .25993 .66552 L .30255 .68374 L p 0 .707 .545 r
F P
0 g
s
.30255 .68374 m .29832 .732 L .25467 .71443 L p 0 .707 .545 r
F P
0 g
s
.25467 .71443 m .25993 .66552 L .30255 .68374 L p 0 .707 .545 r
F P
0 g
s
.30255 .68374 m .29832 .732 L .25467 .71443 L p 0 .707 .545 r
F P
0 g
s
.30591 .58502 m .31 .53963 L .3044 .54311 L p 0 .1 .423 r
F P
0 g
s
.3044 .54311 m .3002 .58841 L .30591 .58502 L p 0 .1 .423 r
F P
0 g
s
.26177 .52185 m .3044 .54311 L .31 .53963 L p 0 .907 1 r
F P
0 g
s
.3044 .54311 m .3002 .58841 L .25655 .56767 L p 0 .704 .528 r
F P
0 g
s
.25655 .56767 m .26177 .52185 L .3044 .54311 L p 0 .704 .528 r
F P
0 g
s
.26734 .51821 m .31 .53963 L .3044 .54311 L p 0 .907 1 r
F P
0 g
s
.3044 .54311 m .26177 .52185 L .26734 .51821 L p 0 .907 1 r
F P
0 g
s
.26177 .52185 m .26677 .47794 L .27224 .47423 L p 0 .1 .396 r
F P
0 g
s
.26734 .51821 m .27224 .47423 L .26677 .47794 L p 0 .1 .396 r
F P
0 g
s
.26677 .47794 m .26177 .52185 L .26734 .51821 L p 0 .1 .396 r
F P
0 g
s
.22337 .4553 m .26677 .47794 L .27224 .47423 L p 0 .903 1 r
F P
0 g
s
.26677 .47794 m .26177 .52185 L .21727 .49965 L p 0 .704 .528 r
F P
0 g
s
.22337 .4553 m .26677 .47794 L p .21727 .49965 L 0 .704 .528 r
F P
0 g
s
.34113 .66315 m .38213 .68146 L .38802 .67846 L p 0 .914 1 r
F P
0 g
s
.38563 .72693 m .38804 .67851 L .38215 .68151 L p 0 .114 .472 r
F P
0 g
s
.38215 .68151 m .37962 .72982 L .38563 .72693 L p 0 .114 .472 r
F P
0 g
s
.38804 .67851 m .38802 .67846 L .38213 .68146 L p 0 .562 .887 r
F P
0 g
s
.38213 .68146 m .38215 .68151 L .38804 .67851 L p 0 .562 .887 r
F P
0 g
s
.33765 .71215 m .34113 .66315 L .38213 .68146 L p 0 .704 .528 r
F P
0 g
s
.37962 .72982 m .33765 .71215 L p .38213 .68146 L 0 .704 .528 r
F P
0 g
s
.38213 .68146 m .38215 .68151 L .37962 .72982 L p 0 .704 .528 r
F P
0 g
s
.18744 .5201 m .19401 .47619 L .19405 .47618 L p 0 .707 .542 r
F P
0 g
s
.2317 .54144 m .22594 .58678 L .21923 .59097 L p 0 .1 .396 r
F P
0 g
s
.2317 .54144 m .18744 .5201 L .1809 .52459 L p 0 .907 1 r
F P
0 g
s
.2317 .54144 m .22594 .58678 L .18061 .56599 L p 0 .707 .542 r
F P
0 g
s
.18744 .5201 m .2317 .54144 L p .18061 .56599 L 0 .707 .542 r
F P
0 g
s
.19401 .47619 m .18744 .5201 L .1809 .52459 L p 0 .1 .365 r
F P
0 g
s
.35614 .51441 m .34735 .51985 L .38825 .5412 L p 0 .907 0 r
F P
0 g
s
.38825 .5412 m .39707 .53598 L .35614 .51441 L p 0 .907 0 r
F P
0 g
s
.39707 .53598 m .38825 .5412 L .34735 .51985 L p 0 .907 0 r
F P
0 g
s
.35614 .51441 m .34735 .51985 L .35056 .4759 L p 0 .1 0 r
F P
0 g
s
.35056 .4759 m .35918 .47035 L .35614 .51441 L p 0 .1 0 r
F P
0 g
s
.38825 .5412 m .39707 .53598 L .39485 .58146 L p 0 .1 0 r
F P
0 g
s
.43356 .51441 m .42436 .51985 L .46365 .5412 L p 0 .907 1 r
F P
0 g
s
.46365 .5412 m .47286 .53598 L .43356 .51441 L p 0 .907 1 r
F P
0 g
s
.47286 .53598 m .46365 .5412 L .46287 .58651 L p 0 .114 .472 r
F P
0 g
s
.45356 .59154 m .46287 .58651 L .46365 .5412 L p 0 .114 .472 r
F P
0 g
s
.46365 .5412 m .46287 .58651 L p .4227 .56573 L 0 .697 .491 r
F P
0 g
s
.41525 .52523 m .42436 .51985 L .46365 .5412 L p 0 .907 1 r
F P
0 g
s
.4227 .56573 m .42436 .51985 L .46365 .5412 L p 0 .697 .491 r
F P
0 g
s
.46365 .5412 m .46287 .58651 L p .4227 .56573 L 0 .697 .491 r
F P
0 g
s
.4227 .56573 m .42436 .51985 L .46365 .5412 L p 0 .697 .491 r
F P
0 g
s
.47286 .53598 m .46365 .5412 L .42436 .51985 L p 0 .907 1 r
F P
0 g
s
.43356 .51441 m .42436 .51985 L .42595 .4759 L p 0 .1 .45 r
F P
0 g
s
.42595 .4759 m .43497 .47035 L .43356 .51441 L p 0 .1 .45 r
F P
0 g
s
.39485 .44735 m .38585 .45315 L .42595 .4759 L p 0 .903 1 r
F P
0 g
s
.42595 .4759 m .43497 .47035 L .39485 .44735 L p 0 .903 1 r
F P
0 g
s
.43497 .47035 m .42595 .4759 L .42436 .51985 L p 0 .1 .45 r
F P
0 g
s
.41525 .52523 m .42436 .51985 L .42595 .4759 L p 0 .1 .45 r
F P
0 g
s
.42595 .4759 m .42436 .51985 L .38335 .49757 L p 0 .697 .491 r
F P
0 g
s
.38335 .49757 m .38585 .45315 L .42595 .4759 L p 0 .697 .491 r
F P
0 g
s
.42595 .4759 m .42436 .51985 L .38335 .49757 L p 0 .697 .491 r
F P
0 g
s
.38335 .49757 m .38585 .45315 L .42595 .4759 L p 0 .697 .491 r
F P
0 g
s
.47228 .44735 m .46287 .45315 L .50132 .47589 L p 0 .903 0 r
F P
0 g
s
.50132 .47589 m .51073 .47033 L .47228 .44735 L p 0 .903 0 r
F P
0 g
s
.51073 .47033 m .50132 .47589 L .50135 .47593 L p 0 .575 0 r
F P
0 g
s
.50135 .47593 m .51076 .47038 L .51073 .47033 L p 0 .575 0 r
F P
0 g
s
.51076 .47038 m .50135 .47593 L .50138 .51985 L p 0 .114 0 r
F P
0 g
s
.49186 .52523 m .50138 .51985 L .50135 .47593 L p 0 .114 0 r
F P
0 g
s
.50135 .47593 m .50138 .51985 L .46205 .49757 L p 0 .693 0 r
F P
0 g
s
.50132 .47589 m .50135 .47593 L p .46205 .49757 L 0 .693 0 r
F P
0 g
s
.46205 .49757 m .46287 .45315 L .50132 .47589 L p 0 .693 0 r
F P
0 g
s
.50135 .47593 m .50138 .51985 L .46205 .49757 L p 0 .693 0 r
F P
0 g
s
.50132 .47589 m .50135 .47593 L p .46205 .49757 L 0 .693 0 r
F P
0 g
s
.46205 .49757 m .46287 .45315 L .50132 .47589 L p 0 .693 0 r
F P
0 g
s
.37695 .59158 m .38585 .58655 L .42592 .60648 L p 0 .911 0 r
F P
0 g
s
.35646 .60316 m .35068 .60642 L .30896 .58647 L p 0 .911 1 r
F P
0 g
s
.30325 .58986 m .30896 .58647 L .35068 .60642 L p 0 .911 1 r
F P
0 g
s
.31472 .58307 m .30896 .58647 L .31298 .54112 L p 0 .1 .425 r
F P
0 g
s
.31298 .54112 m .31863 .53763 L .31472 .58307 L p 0 .1 .425 r
F P
0 g
s
.30949 .68004 m .26683 .66165 L .25993 .66552 L p 0 .914 1 r
F P
0 g
s
.2617 .71071 m .26683 .66165 L .30949 .68004 L p 0 .707 .542 r
F P
0 g
s
.30949 .68004 m .30539 .72843 L .29832 .732 L p 0 .1 .45 r
F P
0 g
s
.30949 .68004 m .30539 .72843 L .2617 .71071 L p 0 .707 .542 r
F P
0 g
s
.34723 .74541 m .30539 .72843 L .29832 .732 L p 0 .916 1 r
F P
0 g
s
.30111 .77896 m .30539 .72843 L .34723 .74541 L p 0 .707 .542 r
F P
0 g
s
.34391 .79521 m .34395 .79518 L .33671 .79845 L p 0 .1 .1 r
F P
0 g
s
.34391 .79521 m .30111 .77896 L p .34723 .74541 L 0 .707 .542 r
F P
0 g
s
.34723 .74541 m .34395 .79518 L .34391 .79521 L p 0 .707 .542 r
F P
0 g
s
.35314 .51283 m .35625 .46874 L .34763 .47431 L p 0 .1 0 r
F P
0 g
s
.34763 .47431 m .34436 .51829 L .35314 .51283 L p 0 .1 0 r
F P
0 g
s
.30579 .45149 m .34763 .47431 L .35625 .46874 L p 0 .903 0 r
F P
0 g
s
.34763 .47431 m .34436 .51829 L .30152 .49594 L p 0 .701 0 r
F P
0 g
s
.34763 .47431 m .30579 .45149 L .2973 .45725 L p 0 .903 0 r
F P
0 g
s
.30152 .49594 m .30579 .45149 L .34763 .47431 L p 0 .701 0 r
F P
0 g
s
.34763 .47431 m .34436 .51829 L .30152 .49594 L p 0 .701 0 r
F P
0 g
s
.30152 .49594 m .30579 .45149 L .34763 .47431 L p 0 .701 0 r
F P
0 g
s
.31166 .5816 m .31565 .53612 L .31 .53963 L p 0 .1 .423 r
F P
0 g
s
.31 .53963 m .30591 .58502 L .31166 .5816 L p 0 .1 .423 r
F P
0 g
s
.26734 .51821 m .31 .53963 L .31565 .53612 L p 0 .907 1 r
F P
0 g
s
.31 .53963 m .30591 .58502 L .26222 .56413 L p 0 .704 .526 r
F P
0 g
s
.31 .53963 m .26734 .51821 L .26177 .52185 L p 0 .907 1 r
F P
0 g
s
.26222 .56413 m .26734 .51821 L .31 .53963 L p 0 .704 .526 r
F P
0 g
s
.31 .53963 m .30591 .58502 L .26222 .56413 L p 0 .704 .526 r
F P
0 g
s
.26222 .56413 m .26734 .51821 L .31 .53963 L p 0 .704 .526 r
F P
0 g
s
.27296 .51455 m .31565 .53612 L .31 .53963 L p 0 .907 1 r
F P
0 g
s
.31 .53963 m .26734 .51821 L .27296 .51455 L p 0 .907 1 r
F P
0 g
s
.26734 .51821 m .27224 .47423 L .27776 .47049 L p 0 .1 .396 r
F P
0 g
s
.27224 .47423 m .26734 .51821 L .26177 .52185 L p 0 .1 .396 r
F P
0 g
s
.27296 .51455 m .27776 .47049 L .27224 .47423 L p 0 .1 .396 r
F P
0 g
s
.27224 .47423 m .26734 .51821 L .27296 .51455 L p 0 .1 .396 r
F P
0 g
s
.2288 .45142 m .27224 .47423 L .27776 .47049 L p 0 .903 1 r
F P
0 g
s
.27224 .47423 m .26734 .51821 L .22281 .49585 L p 0 .704 .526 r
F P
0 g
s
.27224 .47423 m .2288 .45142 L .22337 .4553 L p 0 .903 1 r
F P
0 g
s
.2288 .45142 m .27224 .47423 L p .22281 .49585 L 0 .704 .526 r
F P
0 g
s
.27224 .47423 m .26734 .51821 L .22281 .49585 L p 0 .704 .526 r
F P
0 g
s
.2288 .45142 m .27224 .47423 L p .22281 .49585 L 0 .704 .526 r
F P
0 g
s
.19737 .4738 m .1974 .47379 L .20516 .46827 L p 0 1 0 r
F P
0 g
s
.19086 .51776 m .19737 .4738 L .1974 .47379 L p 0 .706 0 r
F P
0 g
s
.22944 .5846 m .23515 .5392 L .2431 .53402 L p 0 .1 0 r
F P
0 g
s
.23754 .57955 m .2431 .53402 L .23515 .5392 L p 0 .1 0 r
F P
0 g
s
.23515 .5392 m .22944 .5846 L .23754 .57955 L p 0 .1 0 r
F P
0 g
s
.19086 .51776 m .23515 .5392 L .2431 .53402 L p 0 .907 0 r
F P
0 g
s
.23515 .5392 m .22944 .5846 L .18409 .56371 L p 0 .706 0 r
F P
0 g
s
.19086 .51776 m .23515 .5392 L p .18409 .56371 L 0 .706 0 r
F P
0 g
s
.19874 .51236 m .2431 .53402 L .23515 .5392 L p 0 .907 0 r
F P
0 g
s
.23515 .5392 m .19086 .51776 L .19874 .51236 L p 0 .907 0 r
F P
0 g
s
.23754 .57955 m .28107 .59978 L .27292 .60462 L p 0 .911 0 r
F P
0 g
s
.27292 .60462 m .22944 .5846 L .23754 .57955 L p 0 .911 0 r
F P
0 g
s
.20516 .46827 m .20512 .46828 L .19737 .4738 L p 0 1 0 r
F P
0 g
s
.19086 .51776 m .19737 .4738 L .20512 .46828 L p 0 .1 0 r
F P
0 g
s
.347 .66002 m .38802 .67846 L .39394 .67544 L p 0 .914 1 r
F P
0 g
s
.39168 .72402 m .39397 .67549 L .38804 .67851 L p 0 .114 .472 r
F P
0 g
s
.38804 .67851 m .38563 .72693 L .39168 .72402 L p 0 .114 .472 r
F P
0 g
s
.39397 .67549 m .39394 .67544 L .38802 .67846 L p 0 .562 .887 r
F P
0 g
s
.38802 .67846 m .38804 .67851 L .39397 .67549 L p 0 .562 .887 r
F P
0 g
s
.38802 .67846 m .347 .66002 L .34113 .66315 L p 0 .914 1 r
F P
0 g
s
.34363 .70913 m .347 .66002 L .38802 .67846 L p 0 .704 .526 r
F P
0 g
s
.38563 .72693 m .34363 .70913 L p .38802 .67846 L 0 .704 .526 r
F P
0 g
s
.38802 .67846 m .38804 .67851 L .38563 .72693 L p 0 .704 .526 r
F P
0 g
s
.34363 .70913 m .347 .66002 L .38802 .67846 L p 0 .704 .526 r
F P
0 g
s
.38563 .72693 m .34363 .70913 L p .38802 .67846 L 0 .704 .526 r
F P
0 g
s
.38802 .67846 m .38804 .67851 L .38563 .72693 L p 0 .704 .526 r
F P
0 g
s
.27043 .65963 m .31311 .67811 L .32148 .67364 L p 0 .914 0 r
F P
0 g
s
.31761 .72227 m .32148 .67364 L .31311 .67811 L p 0 .1 0 r
F P
0 g
s
.31311 .67811 m .30908 .72657 L .31761 .72227 L p 0 .1 0 r
F P
0 g
s
.26537 .70876 m .27043 .65963 L .31311 .67811 L p 0 .706 0 r
F P
0 g
s
.31311 .67811 m .30908 .72657 L .26537 .70876 L p 0 .706 0 r
F P
0 g
s
.31761 .72227 m .35951 .73951 L .35094 .74363 L p 0 .916 0 r
F P
0 g
s
.35094 .74363 m .30908 .72657 L .31761 .72227 L p 0 .916 0 r
F P
0 g
s
.30908 .72657 m .35094 .74363 L .35951 .73951 L p 0 .916 0 r
F P
0 g
s
.35646 .78952 m .35951 .73951 L .35094 .74363 L p 0 .114 0 r
F P
0 g
s
.35094 .74363 m .34773 .79347 L .35646 .78952 L p 0 .114 0 r
F P
0 g
s
.30487 .77717 m .30908 .72657 L .35094 .74363 L p 0 .706 0 r
F P
0 g
s
.34769 .7935 m .30487 .77717 L p .35094 .74363 L 0 .706 0 r
F P
0 g
s
.35094 .74363 m .34773 .79347 L .34769 .7935 L p 0 .706 0 r
F P
0 g
s
.30908 .72657 m .31311 .67811 L .32148 .67364 L p 0 .1 0 r
F P
0 g
s
.36228 .59987 m .35646 .60316 L .31472 .58307 L p 0 .911 1 r
F P
0 g
s
.30896 .58647 m .31472 .58307 L .35646 .60316 L p 0 .911 1 r
F P
0 g
s
.32051 .57963 m .31472 .58307 L .31863 .53763 L p 0 .1 .425 r
F P
0 g
s
.31863 .53763 m .32431 .53411 L .32051 .57963 L p 0 .1 .425 r
F P
0 g
s
.31746 .57815 m .32133 .53259 L .31565 .53612 L p 0 .1 .423 r
F P
0 g
s
.31565 .53612 m .31166 .5816 L .31746 .57815 L p 0 .1 .423 r
F P
0 g
s
.27296 .51455 m .31565 .53612 L .32133 .53259 L p 0 .907 1 r
F P
0 g
s
.31565 .53612 m .31166 .5816 L .26794 .56056 L p 0 .704 .523 r
F P
0 g
s
.31565 .53612 m .27296 .51455 L .26734 .51821 L p 0 .907 1 r
F P
0 g
s
.26794 .56056 m .27296 .51455 L .31565 .53612 L p 0 .704 .523 r
F P
0 g
s
.31565 .53612 m .31166 .5816 L .26794 .56056 L p 0 .704 .523 r
F P
0 g
s
.26794 .56056 m .27296 .51455 L .31565 .53612 L p 0 .704 .523 r
F P
0 g
s
.27861 .51087 m .32133 .53259 L .31565 .53612 L p 0 .907 1 r
F P
0 g
s
.31565 .53612 m .27296 .51455 L .27861 .51087 L p 0 .907 1 r
F P
0 g
s
.27296 .51455 m .27776 .47049 L .28331 .46673 L p 0 .1 .396 r
F P
0 g
s
.27776 .47049 m .27296 .51455 L .26734 .51821 L p 0 .1 .396 r
F P
0 g
s
.27861 .51087 m .28331 .46673 L .27776 .47049 L p 0 .1 .396 r
F P
0 g
s
.27776 .47049 m .27296 .51455 L .27861 .51087 L p 0 .1 .396 r
F P
0 g
s
.23428 .44752 m .27776 .47049 L .28331 .46673 L p 0 .903 1 r
F P
0 g
s
.27776 .47049 m .27296 .51455 L .22838 .49203 L p 0 .704 .523 r
F P
0 g
s
.27776 .47049 m .23428 .44752 L .2288 .45142 L p 0 .903 1 r
F P
0 g
s
.23428 .44752 m .27776 .47049 L p .22838 .49203 L 0 .704 .523 r
F P
0 g
s
.27776 .47049 m .27296 .51455 L .22838 .49203 L p 0 .704 .523 r
F P
0 g
s
.23428 .44752 m .27776 .47049 L p .22838 .49203 L 0 .704 .523 r
F P
0 g
s
.44408 .59666 m .43497 .60159 L .43494 .60161 L p 0 .1 0 r
F P
0 g
s
.43497 .60159 m .43494 .60161 L .39485 .58146 L p 0 .7 0 r
F P
0 g
s
.43497 .60159 m .43494 .60161 L .39485 .58146 L p 0 .7 0 r
F P
0 g
s
.36502 .50891 m .35614 .51441 L .39707 .53598 L p 0 .907 0 r
F P
0 g
s
.39707 .53598 m .40599 .53071 L .36502 .50891 L p 0 .907 0 r
F P
0 g
s
.40599 .53071 m .39707 .53598 L .39485 .58146 L p 0 .1 0 r
F P
0 g
s
.39707 .53598 m .39485 .58146 L .35296 .56042 L p 0 .7 0 r
F P
0 g
s
.34735 .51985 m .35614 .51441 L .39707 .53598 L p 0 .907 0 r
F P
0 g
s
.35296 .56042 m .35614 .51441 L .39707 .53598 L p 0 .7 0 r
F P
0 g
s
.39707 .53598 m .39485 .58146 L .35296 .56042 L p 0 .7 0 r
F P
0 g
s
.35296 .56042 m .35614 .51441 L .39707 .53598 L p 0 .7 0 r
F P
0 g
s
.40599 .53071 m .39707 .53598 L .35614 .51441 L p 0 .907 0 r
F P
0 g
s
.36502 .50891 m .35614 .51441 L .35918 .47035 L p 0 .1 0 r
F P
0 g
s
.35918 .47035 m .36789 .46473 L .36502 .50891 L p 0 .1 0 r
F P
0 g
s
.40394 .57632 m .39485 .58146 L .39707 .53598 L p 0 .1 0 r
F P
0 g
s
.39707 .53598 m .40599 .53071 L .40394 .57632 L p 0 .1 0 r
F P
0 g
s
.48218 .53071 m .47286 .53598 L .43356 .51441 L p 0 .907 1 r
F P
0 g
s
.42436 .51985 m .43356 .51441 L .47286 .53598 L p 0 .907 1 r
F P
0 g
s
.44287 .50891 m .43356 .51441 L .47286 .53598 L p 0 .907 1 r
F P
0 g
s
.47286 .53598 m .48218 .53071 L .44287 .50891 L p 0 .907 1 r
F P
0 g
s
.48218 .53071 m .47286 .53598 L .47228 .58143 L p 0 .114 .472 r
F P
0 g
s
.46287 .58651 m .47228 .58143 L .47286 .53598 L p 0 .114 .472 r
F P
0 g
s
.47286 .53598 m .47228 .58143 L p .4321 .56042 L 0 .696 .486 r
F P
0 g
s
.4321 .56042 m .43356 .51441 L .47286 .53598 L p 0 .696 .486 r
F P
0 g
s
.47286 .53598 m .47228 .58143 L p .4321 .56042 L 0 .696 .486 r
F P
0 g
s
.4321 .56042 m .43356 .51441 L .47286 .53598 L p 0 .696 .486 r
F P
0 g
s
.44287 .50891 m .43356 .51441 L .43497 .47035 L p 0 .1 .45 r
F P
0 g
s
.43497 .47035 m .44408 .46473 L .44287 .50891 L p 0 .1 .45 r
F P
0 g
s
.40394 .44149 m .39485 .44735 L .43497 .47035 L p 0 .903 1 r
F P
0 g
s
.43497 .47035 m .44408 .46473 L .40394 .44149 L p 0 .903 1 r
F P
0 g
s
.44408 .46473 m .43497 .47035 L .43356 .51441 L p 0 .1 .45 r
F P
0 g
s
.42436 .51985 m .43356 .51441 L .43497 .47035 L p 0 .1 .45 r
F P
0 g
s
.43497 .47035 m .43356 .51441 L .39253 .49188 L p 0 .696 .486 r
F P
0 g
s
.39253 .49188 m .39485 .44735 L .43497 .47035 L p 0 .696 .486 r
F P
0 g
s
.43497 .47035 m .43356 .51441 L .39253 .49188 L p 0 .696 .486 r
F P
0 g
s
.39253 .49188 m .39485 .44735 L .43497 .47035 L p 0 .696 .486 r
F P
0 g
s
.43494 .60161 m .44405 .59668 L .44408 .59666 L p 0 .1 0 r
F P
0 g
s
.44405 .59668 m .43494 .60161 L .39485 .58146 L p 0 .911 0 r
F P
0 g
s
.38585 .58655 m .39485 .58146 L .43494 .60161 L p 0 .911 0 r
F P
0 g
s
.48179 .44149 m .47228 .44735 L .51073 .47033 L p 0 .903 0 r
F P
0 g
s
.51073 .47033 m .52025 .46471 L .48179 .44149 L p 0 .903 0 r
F P
0 g
s
.52025 .46471 m .51073 .47033 L .51076 .47038 L p 0 .575 0 r
F P
0 g
s
.51076 .47038 m .52027 .46476 L .52025 .46471 L p 0 .575 0 r
F P
0 g
s
.52027 .46476 m .51076 .47038 L .51099 .51441 L p 0 .114 0 r
F P
0 g
s
.50138 .51985 m .51099 .51441 L .51076 .47038 L p 0 .114 0 r
F P
0 g
s
.51076 .47038 m .51099 .51441 L .47167 .49188 L p 0 .692 0 r
F P
0 g
s
.51073 .47033 m .51076 .47038 L p .47167 .49188 L 0 .692 0 r
F P
0 g
s
.47167 .49188 m .47228 .44735 L .51073 .47033 L p 0 .692 0 r
F P
0 g
s
.51076 .47038 m .51099 .51441 L .47167 .49188 L p 0 .692 0 r
F P
0 g
s
.51073 .47033 m .51076 .47038 L p .47167 .49188 L 0 .692 0 r
F P
0 g
s
.47167 .49188 m .47228 .44735 L .51073 .47033 L p 0 .692 0 r
F P
0 g
s
.35291 .65687 m .39394 .67544 L .39992 .6724 L p 0 .914 1 r
F P
0 g
s
.39777 .72108 m .39994 .67245 L .39397 .67549 L p 0 .114 .472 r
F P
0 g
s
.39397 .67549 m .39168 .72402 L .39777 .72108 L p 0 .114 .472 r
F P
0 g
s
.39994 .67245 m .39992 .6724 L .39394 .67544 L p 0 .562 .887 r
F P
0 g
s
.39394 .67544 m .39397 .67549 L .39994 .67245 L p 0 .562 .887 r
F P
0 g
s
.39394 .67544 m .35291 .65687 L .347 .66002 L p 0 .914 1 r
F P
0 g
s
.34966 .70609 m .35291 .65687 L .39394 .67544 L p 0 .704 .523 r
F P
0 g
s
.39168 .72402 m .34966 .70609 L p .39394 .67544 L 0 .704 .523 r
F P
0 g
s
.39394 .67544 m .39397 .67549 L .39168 .72402 L p 0 .704 .523 r
F P
0 g
s
.34966 .70609 m .35291 .65687 L .39394 .67544 L p 0 .704 .523 r
F P
0 g
s
.39168 .72402 m .34966 .70609 L p .39394 .67544 L 0 .704 .523 r
F P
0 g
s
.39394 .67544 m .39397 .67549 L .39168 .72402 L p 0 .704 .523 r
F P
0 g
s
.36203 .50731 m .36496 .4631 L .35625 .46874 L p 0 .1 0 r
F P
0 g
s
.35625 .46874 m .35314 .51283 L .36203 .50731 L p 0 .1 0 r
F P
0 g
s
.31437 .44567 m .35625 .46874 L .36496 .4631 L p 0 .903 0 r
F P
0 g
s
.35625 .46874 m .35314 .51283 L .31026 .49023 L p 0 .7 0 r
F P
0 g
s
.35625 .46874 m .31437 .44567 L .30579 .45149 L p 0 .903 0 r
F P
0 g
s
.31026 .49023 m .31437 .44567 L .35625 .46874 L p 0 .7 0 r
F P
0 g
s
.35625 .46874 m .35314 .51283 L .31026 .49023 L p 0 .7 0 r
F P
0 g
s
.31026 .49023 m .31437 .44567 L .35625 .46874 L p 0 .7 0 r
F P
0 g
s
.36814 .59655 m .36228 .59987 L .32051 .57963 L p 0 .911 1 r
F P
0 g
s
.31472 .58307 m .32051 .57963 L .36228 .59987 L p 0 .911 1 r
F P
0 g
s
.32635 .57618 m .32051 .57963 L .32431 .53411 L p 0 .1 .425 r
F P
0 g
s
.32431 .53411 m .33004 .53056 L .32635 .57618 L p 0 .1 .425 r
F P
0 g
s
.20512 .46828 m .20516 .46827 L .21299 .46269 L p 0 1 0 r
F P
0 g
s
.19874 .51236 m .20512 .46828 L .20516 .46827 L p 0 .706 0 r
F P
0 g
s
.19874 .51236 m .20512 .46828 L .20516 .46827 L p 0 .706 0 r
F P
0 g
s
.24571 .57444 m .2893 .59489 L .28107 .59978 L p 0 .911 0 r
F P
0 g
s
.28107 .59978 m .23754 .57955 L .24571 .57444 L p 0 .911 0 r
F P
0 g
s
.23754 .57955 m .2431 .53402 L .25113 .52878 L p 0 .1 0 r
F P
0 g
s
.2431 .53402 m .23754 .57955 L .22944 .5846 L p 0 .1 0 r
F P
0 g
s
.24571 .57444 m .25113 .52878 L .2431 .53402 L p 0 .1 0 r
F P
0 g
s
.2431 .53402 m .23754 .57955 L .24571 .57444 L p 0 .1 0 r
F P
0 g
s
.19874 .51236 m .2431 .53402 L .25113 .52878 L p 0 .907 0 r
F P
0 g
s
.2431 .53402 m .23754 .57955 L .19211 .55843 L p 0 .706 0 r
F P
0 g
s
.2431 .53402 m .19874 .51236 L .19086 .51776 L p 0 .907 0 r
F P
0 g
s
.19874 .51236 m .2431 .53402 L p .19211 .55843 L 0 .706 0 r
F P
0 g
s
.2431 .53402 m .23754 .57955 L .19211 .55843 L p 0 .706 0 r
F P
0 g
s
.19874 .51236 m .2431 .53402 L p .19211 .55843 L 0 .706 0 r
F P
0 g
s
.20672 .50689 m .25113 .52878 L .2431 .53402 L p 0 .907 0 r
F P
0 g
s
.2431 .53402 m .19874 .51236 L .20672 .50689 L p 0 .907 0 r
F P
0 g
s
.21299 .46269 m .21296 .4627 L .20512 .46828 L p 0 1 0 r
F P
0 g
s
.19874 .51236 m .20512 .46828 L .21296 .4627 L p 0 .1 0 r
F P
0 g
s
.20512 .46828 m .19874 .51236 L .19086 .51776 L p 0 .1 0 r
F P
0 g
s
.32329 .57469 m .32706 .52903 L .32133 .53259 L p 0 .1 .423 r
F P
0 g
s
.32133 .53259 m .31746 .57815 L .32329 .57469 L p 0 .1 .423 r
F P
0 g
s
.32133 .53259 m .31746 .57815 L .2737 .55696 L p 0 .703 .52 r
F P
0 g
s
.32133 .53259 m .27861 .51087 L .27296 .51455 L p 0 .907 1 r
F P
0 g
s
.2737 .55696 m .27861 .51087 L .32133 .53259 L p 0 .703 .52 r
F P
0 g
s
.32133 .53259 m .31746 .57815 L .2737 .55696 L p 0 .703 .52 r
F P
0 g
s
.2737 .55696 m .27861 .51087 L .32133 .53259 L p 0 .703 .52 r
F P
0 g
s
.27861 .51087 m .32133 .53259 L .32706 .52903 L p 0 .907 1 r
F P
0 g
s
.28431 .50716 m .32706 .52903 L .32133 .53259 L p 0 .907 1 r
F P
0 g
s
.32133 .53259 m .27861 .51087 L .28431 .50716 L p 0 .907 1 r
F P
0 g
s
.32706 .52903 m .28431 .50716 L .27861 .51087 L p 0 .907 1 r
F P
0 g
s
.27951 .55334 m .28431 .50716 L .32706 .52903 L p 0 .703 0 r
F P
0 g
s
.27951 .55334 m .28431 .50716 L .32706 .52903 L p 0 .703 .518 r
F P
0 g
s
.28431 .50716 m .27951 .55334 L .28823 .54789 L p 0 .1 0 r
F P
0 g
s
.32706 .52903 m .28431 .50716 L .29286 .50158 L p 0 .907 0 r
F P
0 g
s
.33566 .52369 m .29286 .50158 L .28431 .50716 L p 0 .907 0 r
F P
0 g
s
.28823 .54789 m .29286 .50158 L .28431 .50716 L p 0 .1 0 r
F P
0 g
s
.27951 .55334 m .28431 .50716 L .29286 .50158 L p 0 .1 0 r
F P
0 g
s
.32706 .52903 m .32329 .57469 L .27951 .55334 L p 0 .703 0 r
F P
0 g
s
.32706 .52903 m .32329 .57469 L .27951 .55334 L p 0 .703 .518 r
F P
0 g
s
.32329 .57469 m .27951 .55334 L .28823 .54789 L p 0 .911 0 r
F P
0 g
s
.33512 .57098 m .32635 .57618 L .33004 .53056 L p 0 .1 0 r
F P
0 g
s
.32706 .52903 m .32329 .57469 L .33207 .56947 L p 0 .1 0 r
F P
0 g
s
.28823 .54789 m .33207 .56947 L .32329 .57469 L p 0 .911 0 r
F P
0 g
s
.27861 .51087 m .28331 .46673 L .2889 .46294 L p 0 .1 .396 r
F P
0 g
s
.28331 .46673 m .27861 .51087 L .27296 .51455 L p 0 .1 .396 r
F P
0 g
s
.28431 .50716 m .2889 .46294 L .28331 .46673 L p 0 .1 .396 r
F P
0 g
s
.28331 .46673 m .27861 .51087 L .28431 .50716 L p 0 .1 .396 r
F P
0 g
s
.28331 .46673 m .27861 .51087 L .23399 .48818 L p 0 .703 .52 r
F P
0 g
s
.28331 .46673 m .23979 .4436 L .23428 .44752 L p 0 .903 1 r
F P
0 g
s
.23979 .4436 m .28331 .46673 L p .23399 .48818 L 0 .703 .52 r
F P
0 g
s
.28331 .46673 m .27861 .51087 L .23399 .48818 L p 0 .703 .52 r
F P
0 g
s
.23979 .4436 m .28331 .46673 L p .23399 .48818 L 0 .703 .52 r
F P
0 g
s
.2889 .46294 m .28431 .50716 L .29286 .50158 L p 0 .1 0 r
F P
0 g
s
.23979 .4436 m .28331 .46673 L .2889 .46294 L p 0 .903 1 r
F P
0 g
s
.2889 .46294 m .28431 .50716 L .27861 .51087 L p 0 .1 .396 r
F P
0 g
s
.2889 .46294 m .28431 .50716 L .23965 .4843 L p 0 .703 0 r
F P
0 g
s
.2889 .46294 m .24535 .43964 L .23979 .4436 L p 0 .903 1 r
F P
0 g
s
.24535 .43964 m .2889 .46294 L p .23965 .4843 L 0 .703 0 r
F P
0 g
s
.2889 .46294 m .28431 .50716 L .23965 .4843 L p 0 .703 .518 r
F P
0 g
s
.24535 .43964 m .2889 .46294 L p .23965 .4843 L 0 .703 .518 r
F P
0 g
s
.28431 .50716 m .23965 .4843 L .24815 .47847 L p 0 .907 0 r
F P
0 g
s
.2973 .45725 m .29286 .50158 L .28431 .50716 L p 0 .1 0 r
F P
0 g
s
.24815 .47847 m .29286 .50158 L .28431 .50716 L p 0 .907 0 r
F P
0 g
s
.23965 .4843 m .28431 .50716 L .29286 .50158 L p 0 .907 0 r
F P
0 g
s
.27876 .65497 m .32148 .67364 L .32994 .66913 L p 0 .914 0 r
F P
0 g
s
.32623 .71792 m .32994 .66913 L .32148 .67364 L p 0 .1 0 r
F P
0 g
s
.32148 .67364 m .31761 .72227 L .32623 .71792 L p 0 .1 0 r
F P
0 g
s
.32148 .67364 m .27876 .65497 L .27043 .65963 L p 0 .914 0 r
F P
0 g
s
.27385 .70426 m .27876 .65497 L .32148 .67364 L p 0 .706 0 r
F P
0 g
s
.32148 .67364 m .31761 .72227 L .30908 .72657 L p 0 .1 0 r
F P
0 g
s
.32148 .67364 m .31761 .72227 L .27385 .70426 L p 0 .706 0 r
F P
0 g
s
.27385 .70426 m .27876 .65497 L .32148 .67364 L p 0 .706 0 r
F P
0 g
s
.32148 .67364 m .31761 .72227 L .27385 .70426 L p 0 .706 0 r
F P
0 g
s
.31761 .72227 m .32148 .67364 L .32994 .66913 L p 0 .1 0 r
F P
0 g
s
.32623 .71792 m .36816 .73534 L .35951 .73951 L p 0 .916 0 r
F P
0 g
s
.35951 .73951 m .31761 .72227 L .32623 .71792 L p 0 .916 0 r
F P
0 g
s
.31761 .72227 m .35951 .73951 L .36816 .73534 L p 0 .916 0 r
F P
0 g
s
.36529 .78553 m .36816 .73534 L .35951 .73951 L p 0 .114 0 r
F P
0 g
s
.35951 .73951 m .35646 .78952 L .36529 .78553 L p 0 .114 0 r
F P
0 g
s
.35951 .73951 m .31761 .72227 L .30908 .72657 L p 0 .916 0 r
F P
0 g
s
.31357 .77305 m .31761 .72227 L .35951 .73951 L p 0 .706 0 r
F P
0 g
s
.35643 .78955 m .35646 .78952 L .34773 .79347 L p 0 .1 0 r
F P
0 g
s
.35643 .78955 m .31357 .77305 L p .35951 .73951 L 0 .706 0 r
F P
0 g
s
.35951 .73951 m .35646 .78952 L .35643 .78955 L p 0 .706 0 r
F P
0 g
s
.31357 .77305 m .31761 .72227 L .35951 .73951 L p 0 .706 0 r
F P
0 g
s
.35643 .78955 m .31357 .77305 L p .35951 .73951 L 0 .706 0 r
F P
0 g
s
.35951 .73951 m .35646 .78952 L .35643 .78955 L p 0 .706 0 r
F P
0 g
s
.35886 .65369 m .39992 .6724 L .40593 .66933 L p 0 .914 1 r
F P
0 g
s
.40391 .71813 m .40596 .66938 L .39994 .67245 L p 0 .114 .472 r
F P
0 g
s
.39994 .67245 m .39777 .72108 L .40391 .71813 L p 0 .114 .472 r
F P
0 g
s
.40596 .66938 m .40593 .66933 L .39992 .6724 L p 0 .562 .887 r
F P
0 g
s
.39992 .6724 m .39994 .67245 L .40596 .66938 L p 0 .562 .887 r
F P
0 g
s
.39992 .6724 m .35886 .65369 L .35291 .65687 L p 0 .914 1 r
F P
0 g
s
.35573 .70303 m .35886 .65369 L .39992 .6724 L p 0 .703 .52 r
F P
0 g
s
.39777 .72108 m .35573 .70303 L p .39992 .6724 L 0 .703 .52 r
F P
0 g
s
.39992 .6724 m .39994 .67245 L .39777 .72108 L p 0 .703 .52 r
F P
0 g
s
.35573 .70303 m .35886 .65369 L .39992 .6724 L p 0 .703 .52 r
F P
0 g
s
.39777 .72108 m .35573 .70303 L p .39992 .6724 L 0 .703 .52 r
F P
0 g
s
.39992 .6724 m .39994 .67245 L .39777 .72108 L p 0 .703 .52 r
F P
0 g
s
.44408 .59666 m .44405 .59668 L .40394 .57632 L p 0 .699 0 r
F P
0 g
s
.39485 .58146 m .40394 .57632 L .40599 .53071 L p 0 .1 0 r
F P
0 g
s
.40599 .53071 m .40394 .57632 L .36202 .55505 L p 0 .699 0 r
F P
0 g
s
.35614 .51441 m .36502 .50891 L .40599 .53071 L p 0 .907 0 r
F P
0 g
s
.36202 .55505 m .36502 .50891 L .40599 .53071 L p 0 .699 0 r
F P
0 g
s
.43356 .51441 m .44287 .50891 L .48218 .53071 L p 0 .907 1 r
F P
0 g
s
.43356 .51441 m .44287 .50891 L .44408 .46473 L p 0 .1 .45 r
F P
0 g
s
.44408 .46473 m .44287 .50891 L .40181 .48614 L p 0 .695 .481 r
F P
0 g
s
.40181 .48614 m .40394 .44149 L .44408 .46473 L p 0 .695 .481 r
F P
0 g
s
.47228 .58143 m .48179 .57629 L .48218 .53071 L p 0 .114 .472 r
F P
0 g
s
.48218 .53071 m .48179 .57629 L p .4416 .55505 L 0 .695 .481 r
F P
0 g
s
.4416 .55505 m .44287 .50891 L .48218 .53071 L p 0 .695 .481 r
F P
0 g
s
.39485 .58146 m .40394 .57632 L .44405 .59668 L p 0 .911 0 r
F P
0 g
s
.51099 .51441 m .52071 .50891 L .52027 .46476 L p 0 .114 0 r
F P
0 g
s
.52027 .46476 m .52071 .50891 L .48139 .48614 L p 0 .69 0 r
F P
0 g
s
.52025 .46471 m .52027 .46476 L p .48139 .48614 L 0 .69 0 r
F P
0 g
s
.48139 .48614 m .48179 .44149 L .52025 .46471 L p 0 .69 0 r
F P
0 g
s
.45356 .59154 m .44435 .59652 L .44432 .59654 L p 0 .1 .1 r
F P
0 g
s
.44435 .59652 m .44432 .59654 L .40421 .57618 L p 0 .699 .5 r
F P
0 g
s
.4134 .4354 m .40421 .44132 L .44435 .46457 L p 0 .903 0 r
F P
0 g
s
.44435 .46457 m .45356 .45889 L .4134 .4354 L p 0 .903 0 r
F P
0 g
s
.45356 .45889 m .44435 .46457 L .44314 .50875 L p 0 .1 0 r
F P
0 g
s
.44435 .46457 m .44314 .50875 L .40208 .48597 L p 0 .695 0 r
F P
0 g
s
.40208 .48597 m .40421 .44132 L .44435 .46457 L p 0 .695 0 r
F P
0 g
s
.45254 .50319 m .44314 .50875 L .48245 .53056 L p 0 .907 0 r
F P
0 g
s
.48245 .53056 m .49186 .52523 L .45254 .50319 L p 0 .907 0 r
F P
0 g
s
.49186 .52523 m .48245 .53056 L .48207 .57614 L p 0 .114 0 r
F P
0 g
s
.48245 .53056 m .48207 .57614 L p .44187 .55489 L 0 .695 0 r
F P
0 g
s
.44187 .55489 m .44314 .50875 L .48245 .53056 L p 0 .695 0 r
F P
0 g
s
.49186 .52523 m .48245 .53056 L .44314 .50875 L p 0 .907 0 r
F P
0 g
s
.45254 .50319 m .44314 .50875 L .44435 .46457 L p 0 .1 0 r
F P
0 g
s
.44435 .46457 m .45356 .45889 L .45254 .50319 L p 0 .1 0 r
F P
0 g
s
.33004 .53056 m .33865 .52523 L .33512 .57098 L p 0 .1 0 r
F P
0 g
s
.37695 .59158 m .36814 .59655 L .32635 .57618 L p 0 .911 0 r
F P
0 g
s
.37426 .50319 m .36528 .50875 L .40624 .53056 L p 0 .907 1 r
F P
0 g
s
.40624 .53056 m .41525 .52523 L .37426 .50319 L p 0 .907 1 r
F P
0 g
s
.41525 .52523 m .40624 .53056 L .40421 .57618 L p 0 .1 .45 r
F P
0 g
s
.40624 .53056 m .40421 .57618 L .36229 .55489 L p 0 .699 .5 r
F P
0 g
s
.36229 .55489 m .36528 .50875 L .40624 .53056 L p 0 .699 .5 r
F P
0 g
s
.4134 .57098 m .40421 .57618 L .40624 .53056 L p 0 .1 .45 r
F P
0 g
s
.40624 .53056 m .41525 .52523 L .4134 .57098 L p 0 .1 .45 r
F P
0 g
s
.41525 .52523 m .40624 .53056 L .36528 .50875 L p 0 .907 1 r
F P
0 g
s
.37426 .50319 m .36528 .50875 L .36814 .46457 L p 0 .1 .425 r
F P
0 g
s
.36814 .46457 m .37695 .45889 L .37426 .50319 L p 0 .1 .425 r
F P
0 g
s
.32051 .57963 m .32635 .57618 L .36814 .59655 L p 0 .911 1 r
F P
0 g
s
.44432 .59654 m .45353 .59156 L .45356 .59154 L p 0 .1 .1 r
F P
0 g
s
.45353 .59156 m .44432 .59654 L .40421 .57618 L p 0 .911 1 r
F P
0 g
s
.49168 .4354 m .48206 .44132 L .52052 .46455 L p 0 .903 1 r
F P
0 g
s
.52052 .46455 m .53014 .45887 L .49168 .4354 L p 0 .903 1 r
F P
0 g
s
.53014 .45887 m .52052 .46455 L .52055 .4646 L p 0 .575 .884 r
F P
0 g
s
.52052 .46455 m .52055 .4646 L p .48167 .48597 L 0 .69 .46 r
F P
0 g
s
.48167 .48597 m .48206 .44132 L .52052 .46455 L p 0 .69 .46 r
F P
0 g
s
.52055 .4646 m .53016 .45892 L .53014 .45887 L p 0 .575 .884 r
F P
0 g
s
.53016 .45892 m .52055 .4646 L .52099 .50875 L p 0 .114 .472 r
F P
0 g
s
.52055 .4646 m .52099 .50875 L .48167 .48597 L p 0 .69 .46 r
F P
0 g
s
.36496 .4631 m .32304 .43979 L .31437 .44567 L p 0 .903 0 r
F P
0 g
s
.36496 .4631 m .36203 .50731 L .31911 .48447 L p 0 .699 0 r
F P
0 g
s
.31911 .48447 m .32304 .43979 L .36496 .4631 L p 0 .699 0 r
F P
0 g
s
.33207 .56947 m .33566 .52369 L .32706 .52903 L p 0 .1 0 r
F P
0 g
s
.29286 .50158 m .2973 .45725 L .2889 .46294 L p 0 .1 0 r
F P
0 g
s
.24535 .43964 m .2889 .46294 L .2973 .45725 L p 0 .903 0 r
F P
0 g
s
.16737 .5747 m .16734 .57465 L .17442 .52903 L p 0 .708 .548 r
F P
0 g
s
.16734 .57465 m .17442 .52903 L .1809 .52459 L p 0 .1 .365 r
F P
0 g
s
.17396 .57037 m .21923 .59097 L .21258 .59513 L p 0 .911 1 r
F P
0 g
s
.21258 .59513 m .16737 .5747 L .17396 .57037 L p 0 .911 1 r
F P
0 g
s
.37127 .50158 m .37402 .45725 L .36522 .46294 L p 0 .1 .423 r
F P
0 g
s
.36522 .46294 m .36228 .50716 L .37127 .50158 L p 0 .1 .423 r
F P
0 g
s
.32329 .43962 m .36522 .46294 L .37402 .45725 L p 0 .903 1 r
F P
0 g
s
.36522 .46294 m .36228 .50716 L .31936 .4843 L p 0 .699 .5 r
F P
0 g
s
.31936 .4843 m .32329 .43962 L .36522 .46294 L p 0 .699 .5 r
F P
0 g
s
.20672 .50689 m .21296 .4627 L .21299 .46269 L p 0 .705 0 r
F P
0 g
s
.25113 .52878 m .24571 .57444 L .23754 .57955 L p 0 .1 0 r
F P
0 g
s
.25113 .52878 m .20672 .50689 L .19874 .51236 L p 0 .907 0 r
F P
0 g
s
.25113 .52878 m .24571 .57444 L .20022 .55309 L p 0 .705 0 r
F P
0 g
s
.20672 .50689 m .25113 .52878 L p .20022 .55309 L 0 .705 0 r
F P
0 g
s
.21296 .4627 m .20672 .50689 L .19874 .51236 L p 0 .1 0 r
F P
0 g
s
.32953 .8017 m .32949 .80172 L .33667 .79848 L p 0 .1 .1 r
F P
0 g
s
.24771 .71813 m .25309 .66935 L .25993 .66552 L p 0 .1 .425 r
F P
0 g
s
.25467 .71443 m .29832 .732 L .29131 .73554 L p 0 .916 1 r
F P
0 g
s
.29131 .73554 m .24771 .71813 L .25467 .71443 L p 0 .916 1 r
F P
0 g
s
.24771 .71813 m .29131 .73554 L .29832 .732 L p 0 .916 1 r
F P
0 g
s
.2939 .78238 m .29832 .732 L .29131 .73554 L p 0 .1 .45 r
F P
0 g
s
.29131 .73554 m .28676 .78576 L .2939 .78238 L p 0 .1 .45 r
F P
0 g
s
.24209 .76908 m .24771 .71813 L .29131 .73554 L p 0 .708 .548 r
F P
0 g
s
.29131 .73554 m .28676 .78576 L .24209 .76908 L p 0 .708 .548 r
F P
0 g
s
.28676 .78576 m .29131 .73554 L .29832 .732 L p 0 .1 .45 r
F P
0 g
s
.40593 .66933 m .36486 .65049 L .35886 .65369 L p 0 .914 1 r
F P
0 g
s
.36185 .69994 m .36486 .65049 L .40593 .66933 L p 0 .703 .518 r
F P
0 g
s
.40391 .71813 m .36185 .69994 L p .40593 .66933 L 0 .703 .518 r
F P
0 g
s
.40593 .66933 m .40596 .66938 L .40391 .71813 L p 0 .703 .518 r
F P
0 g
s
.2939 .78238 m .33667 .79848 L .32949 .80172 L p 0 .916 1 r
F P
0 g
s
.32949 .80172 m .28676 .78576 L .2939 .78238 L p 0 .916 1 r
F P
0 g
s
.36486 .65049 m .40593 .66933 L .41497 .66473 L p 0 .914 0 r
F P
0 g
s
.41313 .71369 m .41499 .66478 L .40596 .66938 L p 0 .114 0 r
F P
0 g
s
.40596 .66938 m .40391 .71813 L .41313 .71369 L p 0 .114 0 r
F P
0 g
s
.41499 .66478 m .41497 .66473 L .40593 .66933 L p 0 .562 0 r
F P
0 g
s
.40593 .66933 m .40596 .66938 L .41499 .66478 L p 0 .562 0 r
F P
0 g
s
.36185 .69994 m .36486 .65049 L .40593 .66933 L p 0 .703 0 r
F P
0 g
s
.40391 .71813 m .36185 .69994 L p .40593 .66933 L 0 .703 0 r
F P
0 g
s
.40593 .66933 m .40596 .66938 L .40391 .71813 L p 0 .703 0 r
F P
0 g
s
.32994 .66913 m .28717 .65026 L .27876 .65497 L p 0 .914 0 r
F P
0 g
s
.28243 .69972 m .28717 .65026 L .32994 .66913 L p 0 .705 0 r
F P
0 g
s
.32994 .66913 m .32623 .71792 L .31761 .72227 L p 0 .1 0 r
F P
0 g
s
.32994 .66913 m .32623 .71792 L .28243 .69972 L p 0 .705 0 r
F P
0 g
s
.36816 .73534 m .32623 .71792 L .31761 .72227 L p 0 .916 0 r
F P
0 g
s
.32236 .76888 m .32623 .71792 L .36816 .73534 L p 0 .705 0 r
F P
0 g
s
.36526 .78556 m .36529 .78553 L .35646 .78952 L p 0 .1 0 r
F P
0 g
s
.36526 .78556 m .32236 .76888 L p .36816 .73534 L 0 .705 0 r
F P
0 g
s
.36816 .73534 m .36529 .78553 L .36526 .78556 L p 0 .705 0 r
F P
0 g
s
.2122 .6451 m .20541 .64911 L .24998 .66803 L p 0 .914 1 r
F P
0 g
s
.24998 .66803 m .25682 .66418 L .2122 .6451 L p 0 .914 1 r
F P
0 g
s
.25682 .66418 m .24998 .66803 L .24452 .71686 L p 0 .1 .423 r
F P
0 g
s
.19884 .69861 m .20541 .64911 L .24998 .66803 L p 0 .708 .548 r
F P
0 g
s
.24998 .66803 m .24452 .71686 L .19884 .69861 L p 0 .708 .548 r
F P
0 g
s
.46287 .58651 m .45356 .59154 L .45353 .59156 L p 0 .1 .1 r
F P
0 g
s
.45356 .59154 m .45353 .59156 L .4134 .57098 L p 0 .698 .496 r
F P
0 g
s
.45356 .59154 m .45353 .59156 L .4134 .57098 L p 0 .698 .496 r
F P
0 g
s
.44314 .50875 m .45254 .50319 L .45356 .45889 L p 0 .1 0 r
F P
0 g
s
.48207 .57614 m .49168 .57095 L .49186 .52523 L p 0 .114 0 r
F P
0 g
s
.44314 .50875 m .45254 .50319 L .49186 .52523 L p 0 .907 0 r
F P
0 g
s
.4227 .4294 m .4134 .4354 L .45356 .45889 L p 0 .903 0 r
F P
0 g
s
.45356 .45889 m .46287 .45315 L .4227 .4294 L p 0 .903 0 r
F P
0 g
s
.46287 .45315 m .45356 .45889 L .45254 .50319 L p 0 .1 0 r
F P
0 g
s
.45356 .45889 m .45254 .50319 L .41147 .48016 L p 0 .694 0 r
F P
0 g
s
.41147 .48016 m .4134 .4354 L .45356 .45889 L p 0 .694 0 r
F P
0 g
s
.45356 .45889 m .45254 .50319 L .41147 .48016 L p 0 .694 0 r
F P
0 g
s
.41147 .48016 m .4134 .4354 L .45356 .45889 L p 0 .694 0 r
F P
0 g
s
.46205 .49757 m .45254 .50319 L .49186 .52523 L p 0 .907 0 r
F P
0 g
s
.49186 .52523 m .50138 .51985 L .46205 .49757 L p 0 .907 0 r
F P
0 g
s
.50138 .51985 m .49186 .52523 L .49168 .57095 L p 0 .114 0 r
F P
0 g
s
.49186 .52523 m .49168 .57095 L p .45148 .54946 L 0 .694 0 r
F P
0 g
s
.45148 .54946 m .45254 .50319 L .49186 .52523 L p 0 .694 0 r
F P
0 g
s
.49186 .52523 m .49168 .57095 L p .45148 .54946 L 0 .694 0 r
F P
0 g
s
.45148 .54946 m .45254 .50319 L .49186 .52523 L p 0 .694 0 r
F P
0 g
s
.50138 .51985 m .49186 .52523 L .45254 .50319 L p 0 .907 0 r
F P
0 g
s
.46205 .49757 m .45254 .50319 L .45356 .45889 L p 0 .1 0 r
F P
0 g
s
.45356 .45889 m .46287 .45315 L .46205 .49757 L p 0 .1 0 r
F P
0 g
s
.34399 .56573 m .33512 .57098 L .33865 .52523 L p 0 .1 0 r
F P
0 g
s
.33865 .52523 m .34735 .51985 L .34399 .56573 L p 0 .1 0 r
F P
0 g
s
.38585 .58655 m .37695 .59158 L .33512 .57098 L p 0 .911 0 r
F P
0 g
s
.32635 .57618 m .33512 .57098 L .37695 .59158 L p 0 .911 0 r
F P
0 g
s
.38335 .49757 m .37426 .50319 L .41525 .52523 L p 0 .907 1 r
F P
0 g
s
.41525 .52523 m .42436 .51985 L .38335 .49757 L p 0 .907 1 r
F P
0 g
s
.42436 .51985 m .41525 .52523 L .4134 .57098 L p 0 .1 .45 r
F P
0 g
s
.40421 .57618 m .4134 .57098 L .41525 .52523 L p 0 .1 .45 r
F P
0 g
s
.41525 .52523 m .4134 .57098 L .37146 .54946 L p 0 .698 .496 r
F P
0 g
s
.36528 .50875 m .37426 .50319 L .41525 .52523 L p 0 .907 1 r
F P
0 g
s
.37146 .54946 m .37426 .50319 L .41525 .52523 L p 0 .698 .496 r
F P
0 g
s
.41525 .52523 m .4134 .57098 L .37146 .54946 L p 0 .698 .496 r
F P
0 g
s
.37146 .54946 m .37426 .50319 L .41525 .52523 L p 0 .698 .496 r
F P
0 g
s
.4227 .56573 m .4134 .57098 L .41525 .52523 L p 0 .1 .45 r
F P
0 g
s
.41525 .52523 m .42436 .51985 L .4227 .56573 L p 0 .1 .45 r
F P
0 g
s
.42436 .51985 m .41525 .52523 L .37426 .50319 L p 0 .907 1 r
F P
0 g
s
.38335 .49757 m .37426 .50319 L .37695 .45889 L p 0 .1 .425 r
F P
0 g
s
.37695 .45889 m .38585 .45315 L .38335 .49757 L p 0 .1 .425 r
F P
0 g
s
.45353 .59156 m .46284 .58653 L .46287 .58651 L p 0 .1 .1 r
F P
0 g
s
.46284 .58653 m .45353 .59156 L .4134 .57098 L p 0 .911 1 r
F P
0 g
s
.40421 .57618 m .4134 .57098 L .45353 .59156 L p 0 .911 1 r
F P
0 g
s
.50141 .4294 m .49168 .4354 L .53014 .45887 L p 0 .903 1 r
F P
0 g
s
.53014 .45887 m .53986 .45314 L .50141 .4294 L p 0 .903 1 r
F P
0 g
s
.53986 .45314 m .53014 .45887 L .53016 .45892 L p 0 .575 .884 r
F P
0 g
s
.53016 .45892 m .53988 .45318 L .53986 .45314 L p 0 .575 .884 r
F P
0 g
s
.53988 .45318 m .53016 .45892 L .53082 .50319 L p 0 .114 .472 r
F P
0 g
s
.52099 .50875 m .53082 .50319 L .53016 .45892 L p 0 .114 .472 r
F P
0 g
s
.53016 .45892 m .53082 .50319 L .4915 .48016 L p 0 .689 .454 r
F P
0 g
s
.53014 .45887 m .53016 .45892 L p .4915 .48016 L 0 .689 .454 r
F P
0 g
s
.4915 .48016 m .49168 .4354 L .53014 .45887 L p 0 .689 .454 r
F P
0 g
s
.53016 .45892 m .53082 .50319 L .4915 .48016 L p 0 .689 .454 r
F P
0 g
s
.53014 .45887 m .53016 .45892 L p .4915 .48016 L 0 .689 .454 r
F P
0 g
s
.4915 .48016 m .49168 .4354 L .53014 .45887 L p 0 .689 .454 r
F P
0 g
s
.17396 .57037 m .17393 .57032 L .1809 .52459 L p 0 .707 .545 r
F P
0 g
s
.17396 .57037 m .17393 .57032 L .1809 .52459 L p 0 .707 .545 r
F P
0 g
s
.17393 .57032 m .1809 .52459 L .18744 .5201 L p 0 .1 .365 r
F P
0 g
s
.1809 .52459 m .17393 .57032 L .16734 .57465 L p 0 .1 .365 r
F P
0 g
s
.18061 .56599 m .22594 .58678 L .21923 .59097 L p 0 .911 1 r
F P
0 g
s
.21923 .59097 m .17396 .57037 L .18061 .56599 L p 0 .911 1 r
F P
0 g
s
.34093 .56421 m .34436 .51829 L .33566 .52369 L p 0 .1 0 r
F P
0 g
s
.33566 .52369 m .33207 .56947 L .34093 .56421 L p 0 .1 0 r
F P
0 g
s
.29286 .50158 m .33566 .52369 L .34436 .51829 L p 0 .907 0 r
F P
0 g
s
.33566 .52369 m .33207 .56947 L .28823 .54789 L p 0 .702 0 r
F P
0 g
s
.28823 .54789 m .29286 .50158 L .33566 .52369 L p 0 .702 0 r
F P
0 g
s
.33566 .52369 m .33207 .56947 L .28823 .54789 L p 0 .702 0 r
F P
0 g
s
.28823 .54789 m .29286 .50158 L .33566 .52369 L p 0 .702 0 r
F P
0 g
s
.30152 .49594 m .34436 .51829 L .33566 .52369 L p 0 .907 0 r
F P
0 g
s
.33566 .52369 m .29286 .50158 L .30152 .49594 L p 0 .907 0 r
F P
0 g
s
.29286 .50158 m .2973 .45725 L .30579 .45149 L p 0 .1 0 r
F P
0 g
s
.30152 .49594 m .30579 .45149 L .2973 .45725 L p 0 .1 0 r
F P
0 g
s
.2973 .45725 m .29286 .50158 L .30152 .49594 L p 0 .1 0 r
F P
0 g
s
.2537 .4337 m .2973 .45725 L .30579 .45149 L p 0 .903 0 r
F P
0 g
s
.2973 .45725 m .29286 .50158 L .24815 .47847 L p 0 .702 0 r
F P
0 g
s
.2973 .45725 m .2537 .4337 L .24535 .43964 L p 0 .903 0 r
F P
0 g
s
.2537 .4337 m .2973 .45725 L p .24815 .47847 L 0 .702 0 r
F P
0 g
s
.2973 .45725 m .29286 .50158 L .24815 .47847 L p 0 .702 0 r
F P
0 g
s
.2537 .4337 m .2973 .45725 L p .24815 .47847 L 0 .702 0 r
F P
0 g
s
.38035 .49594 m .38292 .45149 L .37402 .45725 L p 0 .1 .423 r
F P
0 g
s
.37402 .45725 m .37127 .50158 L .38035 .49594 L p 0 .1 .423 r
F P
0 g
s
.33207 .43368 m .37402 .45725 L .38292 .45149 L p 0 .903 1 r
F P
0 g
s
.37402 .45725 m .37127 .50158 L .32831 .47847 L p 0 .698 .496 r
F P
0 g
s
.37402 .45725 m .33207 .43368 L .32329 .43962 L p 0 .903 1 r
F P
0 g
s
.32831 .47847 m .33207 .43368 L .37402 .45725 L p 0 .698 .496 r
F P
0 g
s
.37402 .45725 m .37127 .50158 L .32831 .47847 L p 0 .698 .496 r
F P
0 g
s
.32831 .47847 m .33207 .43368 L .37402 .45725 L p 0 .698 .496 r
F P
0 g
s
.33671 .79845 m .33667 .79848 L .34391 .79521 L p 0 .1 .1 r
F P
0 g
s
.2617 .71071 m .30539 .72843 L .29832 .732 L p 0 .916 1 r
F P
0 g
s
.29832 .732 m .25467 .71443 L .2617 .71071 L p 0 .916 1 r
F P
0 g
s
.2939 .78238 m .29832 .732 L .30539 .72843 L p 0 .1 .45 r
F P
0 g
s
.29832 .732 m .2939 .78238 L .28676 .78576 L p 0 .1 .45 r
F P
0 g
s
.25467 .71443 m .25993 .66552 L .26683 .66165 L p 0 .1 .425 r
F P
0 g
s
.25993 .66552 m .25467 .71443 L .24771 .71813 L p 0 .1 .425 r
F P
0 g
s
.25467 .71443 m .29832 .732 L .30539 .72843 L p 0 .916 1 r
F P
0 g
s
.30111 .77896 m .30539 .72843 L .29832 .732 L p 0 .1 .45 r
F P
0 g
s
.29832 .732 m .2939 .78238 L .30111 .77896 L p 0 .1 .45 r
F P
0 g
s
.29832 .732 m .25467 .71443 L .24771 .71813 L p 0 .916 1 r
F P
0 g
s
.24918 .76554 m .25467 .71443 L .29832 .732 L p 0 .707 .545 r
F P
0 g
s
.29832 .732 m .2939 .78238 L .24918 .76554 L p 0 .707 .545 r
F P
0 g
s
.24918 .76554 m .25467 .71443 L .29832 .732 L p 0 .707 .545 r
F P
0 g
s
.29832 .732 m .2939 .78238 L .24918 .76554 L p 0 .707 .545 r
F P
0 g
s
.30111 .77896 m .34391 .79521 L .33667 .79848 L p 0 .916 1 r
F P
0 g
s
.33667 .79848 m .2939 .78238 L .30111 .77896 L p 0 .916 1 r
F P
0 g
s
.37387 .64568 m .41497 .66473 L .4241 .66007 L p 0 .914 0 r
F P
0 g
s
.42246 .7092 m .42413 .66012 L .41499 .66478 L p 0 .114 0 r
F P
0 g
s
.41499 .66478 m .41313 .71369 L .42246 .7092 L p 0 .114 0 r
F P
0 g
s
.42413 .66012 m .4241 .66007 L .41497 .66473 L p 0 .562 0 r
F P
0 g
s
.41497 .66473 m .41499 .66478 L .42413 .66012 L p 0 .562 0 r
F P
0 g
s
.41497 .66473 m .37387 .64568 L .36486 .65049 L p 0 .914 0 r
F P
0 g
s
.37104 .6953 m .37387 .64568 L .41497 .66473 L p 0 .702 0 r
F P
0 g
s
.41313 .71369 m .37104 .6953 L p .41497 .66473 L 0 .702 0 r
F P
0 g
s
.41497 .66473 m .41499 .66478 L .41313 .71369 L p 0 .702 0 r
F P
0 g
s
.37104 .6953 m .37387 .64568 L .41497 .66473 L p 0 .702 0 r
F P
0 g
s
.41313 .71369 m .37104 .6953 L p .41497 .66473 L 0 .702 0 r
F P
0 g
s
.41497 .66473 m .41499 .66478 L .41313 .71369 L p 0 .702 0 r
F P
0 g
s
.22333 .45531 m .22337 .4553 L .2288 .45142 L p 0 1 .86 r
F P
0 g
s
.21727 .49965 m .22333 .45531 L .22337 .4553 L p 0 .704 .528 r
F P
0 g
s
.26222 .56413 m .30591 .58502 L .3002 .58841 L p 0 .911 1 r
F P
0 g
s
.3002 .58841 m .25655 .56767 L .26222 .56413 L p 0 .911 1 r
F P
0 g
s
.25655 .56767 m .26177 .52185 L .26734 .51821 L p 0 .1 .396 r
F P
0 g
s
.26222 .56413 m .26734 .51821 L .26177 .52185 L p 0 .1 .396 r
F P
0 g
s
.26177 .52185 m .25655 .56767 L .26222 .56413 L p 0 .1 .396 r
F P
0 g
s
.21727 .49965 m .26177 .52185 L .26734 .51821 L p 0 .907 1 r
F P
0 g
s
.26177 .52185 m .25655 .56767 L .21097 .54602 L p 0 .704 .528 r
F P
0 g
s
.21727 .49965 m .26177 .52185 L p .21097 .54602 L 0 .704 .528 r
F P
0 g
s
.22281 .49585 m .26734 .51821 L .26177 .52185 L p 0 .907 1 r
F P
0 g
s
.26177 .52185 m .21727 .49965 L .22281 .49585 L p 0 .907 1 r
F P
0 g
s
.2288 .45142 m .22877 .45144 L .22333 .45531 L p 0 1 .86 r
F P
0 g
s
.21727 .49965 m .22333 .45531 L .22877 .45144 L p 0 .1 .365 r
F P
0 g
s
.21904 .64105 m .2122 .6451 L .25682 .66418 L p 0 .914 1 r
F P
0 g
s
.25682 .66418 m .26371 .66031 L .21904 .64105 L p 0 .914 1 r
F P
0 g
s
.26371 .66031 m .25682 .66418 L .25148 .71315 L p 0 .1 .423 r
F P
0 g
s
.20574 .69474 m .2122 .6451 L .25682 .66418 L p 0 .707 .545 r
F P
0 g
s
.24452 .71686 m .25148 .71315 L .25682 .66418 L p 0 .1 .423 r
F P
0 g
s
.25682 .66418 m .25148 .71315 L .20574 .69474 L p 0 .707 .545 r
F P
0 g
s
.20574 .69474 m .2122 .6451 L .25682 .66418 L p 0 .707 .545 r
F P
0 g
s
.25682 .66418 m .25148 .71315 L .20574 .69474 L p 0 .707 .545 r
F P
0 g
s
.34363 .70913 m .38563 .72693 L .37962 .72982 L p 0 .916 1 r
F P
0 g
s
.37962 .72982 m .33765 .71215 L .34363 .70913 L p 0 .916 1 r
F P
0 g
s
.33765 .71215 m .37962 .72982 L .38563 .72693 L p 0 .916 1 r
F P
0 g
s
.38311 .77748 m .38563 .72693 L .37962 .72982 L p 0 .114 .472 r
F P
0 g
s
.37962 .72982 m .37698 .78025 L .38311 .77748 L p 0 .114 .472 r
F P
0 g
s
.334 .76336 m .33765 .71215 L .37962 .72982 L p 0 .704 .528 r
F P
0 g
s
.37695 .78027 m .334 .76336 L p .37962 .72982 L 0 .704 .528 r
F P
0 g
s
.37962 .72982 m .37698 .78025 L .37695 .78027 L p 0 .704 .528 r
F P
0 g
s
.29831 .64402 m .34113 .66315 L .347 .66002 L p 0 .914 1 r
F P
0 g
s
.34363 .70913 m .347 .66002 L .34113 .66315 L p 0 .1 .45 r
F P
0 g
s
.34113 .66315 m .33765 .71215 L .34363 .70913 L p 0 .1 .45 r
F P
0 g
s
.29378 .6937 m .29831 .64402 L .34113 .66315 L p 0 .704 .528 r
F P
0 g
s
.34113 .66315 m .33765 .71215 L .29378 .6937 L p 0 .704 .528 r
F P
0 g
s
.33765 .71215 m .34113 .66315 L .347 .66002 L p 0 .1 .45 r
F P
0 g
s
.18744 .5201 m .18059 .56594 L .17393 .57032 L p 0 .1 .365 r
F P
0 g
s
.18061 .56599 m .18059 .56594 L .18744 .5201 L p 0 .707 .542 r
F P
0 g
s
.47228 .58143 m .46287 .58651 L .46284 .58653 L p 0 .1 .1 r
F P
0 g
s
.46287 .58651 m .46284 .58653 L .4227 .56573 L p 0 .697 .491 r
F P
0 g
s
.46287 .58651 m .46284 .58653 L .4227 .56573 L p 0 .697 .491 r
F P
0 g
s
.35296 .56042 m .34399 .56573 L .34735 .51985 L p 0 .1 0 r
F P
0 g
s
.34735 .51985 m .35614 .51441 L .35296 .56042 L p 0 .1 0 r
F P
0 g
s
.4321 .42335 m .4227 .4294 L .46287 .45315 L p 0 .903 0 r
F P
0 g
s
.46287 .45315 m .47228 .44735 L .4321 .42335 L p 0 .903 0 r
F P
0 g
s
.47228 .44735 m .46287 .45315 L .46205 .49757 L p 0 .1 0 r
F P
0 g
s
.45254 .50319 m .46205 .49757 L .46287 .45315 L p 0 .1 0 r
F P
0 g
s
.46287 .45315 m .46205 .49757 L .42096 .47428 L p 0 .693 0 r
F P
0 g
s
.42096 .47428 m .4227 .4294 L .46287 .45315 L p 0 .693 0 r
F P
0 g
s
.46287 .45315 m .46205 .49757 L .42096 .47428 L p 0 .693 0 r
F P
0 g
s
.42096 .47428 m .4227 .4294 L .46287 .45315 L p 0 .693 0 r
F P
0 g
s
.51099 .51441 m .50138 .51985 L .46205 .49757 L p 0 .907 0 r
F P
0 g
s
.47167 .49188 m .46205 .49757 L .46287 .45315 L p 0 .1 0 r
F P
0 g
s
.46287 .45315 m .47228 .44735 L .47167 .49188 L p 0 .1 0 r
F P
0 g
s
.47167 .49188 m .46205 .49757 L .50138 .51985 L p 0 .907 0 r
F P
0 g
s
.50138 .51985 m .51099 .51441 L .47167 .49188 L p 0 .907 0 r
F P
0 g
s
.51099 .51441 m .50138 .51985 L .50141 .56569 L p 0 .114 0 r
F P
0 g
s
.49168 .57095 m .50141 .56569 L .50138 .51985 L p 0 .114 0 r
F P
0 g
s
.50138 .51985 m .50141 .56569 L p .4612 .54397 L 0 .693 0 r
F P
0 g
s
.45254 .50319 m .46205 .49757 L .50138 .51985 L p 0 .907 0 r
F P
0 g
s
.4612 .54397 m .46205 .49757 L .50138 .51985 L p 0 .693 0 r
F P
0 g
s
.50138 .51985 m .50141 .56569 L p .4612 .54397 L 0 .693 0 r
F P
0 g
s
.4612 .54397 m .46205 .49757 L .50138 .51985 L p 0 .693 0 r
F P
0 g
s
.33512 .57098 m .34399 .56573 L .38585 .58655 L p 0 .911 0 r
F P
0 g
s
.39253 .49188 m .38335 .49757 L .42436 .51985 L p 0 .907 1 r
F P
0 g
s
.42436 .51985 m .43356 .51441 L .39253 .49188 L p 0 .907 1 r
F P
0 g
s
.43356 .51441 m .42436 .51985 L .4227 .56573 L p 0 .1 .45 r
F P
0 g
s
.4134 .57098 m .4227 .56573 L .42436 .51985 L p 0 .1 .45 r
F P
0 g
s
.42436 .51985 m .4227 .56573 L .38073 .54397 L p 0 .697 .491 r
F P
0 g
s
.37426 .50319 m .38335 .49757 L .42436 .51985 L p 0 .907 1 r
F P
0 g
s
.38073 .54397 m .38335 .49757 L .42436 .51985 L p 0 .697 .491 r
F P
0 g
s
.42436 .51985 m .4227 .56573 L .38073 .54397 L p 0 .697 .491 r
F P
0 g
s
.38073 .54397 m .38335 .49757 L .42436 .51985 L p 0 .697 .491 r
F P
0 g
s
.4321 .56042 m .4227 .56573 L .42436 .51985 L p 0 .1 .45 r
F P
0 g
s
.42436 .51985 m .43356 .51441 L .4321 .56042 L p 0 .1 .45 r
F P
0 g
s
.43356 .51441 m .42436 .51985 L .38335 .49757 L p 0 .907 1 r
F P
0 g
s
.39253 .49188 m .38335 .49757 L .38585 .45315 L p 0 .1 .425 r
F P
0 g
s
.38585 .45315 m .39485 .44735 L .39253 .49188 L p 0 .1 .425 r
F P
0 g
s
.46284 .58653 m .47225 .58145 L .47228 .58143 L p 0 .1 .1 r
F P
0 g
s
.47225 .58145 m .46284 .58653 L .4227 .56573 L p 0 .911 1 r
F P
0 g
s
.4134 .57098 m .4227 .56573 L .46284 .58653 L p 0 .911 1 r
F P
0 g
s
.51123 .42335 m .50141 .4294 L .53986 .45314 L p 0 .903 1 r
F P
0 g
s
.53986 .45314 m .54968 .44734 L .51123 .42335 L p 0 .903 1 r
F P
0 g
s
.54968 .44734 m .53986 .45314 L .53988 .45318 L p 0 .575 .884 r
F P
0 g
s
.53988 .45318 m .54971 .44739 L .54968 .44734 L p 0 .575 .884 r
F P
0 g
s
.54971 .44739 m .53988 .45318 L .54076 .49757 L p 0 .114 .472 r
F P
0 g
s
.53082 .50319 m .54076 .49757 L .53988 .45318 L p 0 .114 .472 r
F P
0 g
s
.53988 .45318 m .54076 .49757 L .50144 .47428 L p 0 .687 .449 r
F P
0 g
s
.53986 .45314 m .53988 .45318 L p .50144 .47428 L 0 .687 .449 r
F P
0 g
s
.50144 .47428 m .50141 .4294 L .53986 .45314 L p 0 .687 .449 r
F P
0 g
s
.53988 .45318 m .54076 .49757 L .50144 .47428 L p 0 .687 .449 r
F P
0 g
s
.53986 .45314 m .53988 .45318 L p .50144 .47428 L 0 .687 .449 r
F P
0 g
s
.50144 .47428 m .50141 .4294 L .53986 .45314 L p 0 .687 .449 r
F P
0 g
s
.30539 .72843 m .2617 .71071 L .25467 .71443 L p 0 .916 1 r
F P
0 g
s
.25635 .76197 m .2617 .71071 L .30539 .72843 L p 0 .707 .542 r
F P
0 g
s
.30539 .72843 m .30111 .77896 L .2939 .78238 L p 0 .1 .45 r
F P
0 g
s
.30539 .72843 m .30111 .77896 L .25635 .76197 L p 0 .707 .542 r
F P
0 g
s
.26683 .66165 m .2617 .71071 L .25467 .71443 L p 0 .1 .425 r
F P
0 g
s
.3499 .55888 m .35314 .51283 L .34436 .51829 L p 0 .1 0 r
F P
0 g
s
.34436 .51829 m .34093 .56421 L .3499 .55888 L p 0 .1 0 r
F P
0 g
s
.30152 .49594 m .34436 .51829 L .35314 .51283 L p 0 .907 0 r
F P
0 g
s
.34436 .51829 m .34093 .56421 L .29705 .54238 L p 0 .701 0 r
F P
0 g
s
.34436 .51829 m .30152 .49594 L .29286 .50158 L p 0 .907 0 r
F P
0 g
s
.29705 .54238 m .30152 .49594 L .34436 .51829 L p 0 .701 0 r
F P
0 g
s
.31026 .49023 m .35314 .51283 L .34436 .51829 L p 0 .907 0 r
F P
0 g
s
.34436 .51829 m .30152 .49594 L .31026 .49023 L p 0 .907 0 r
F P
0 g
s
.30152 .49594 m .30579 .45149 L .31437 .44567 L p 0 .1 0 r
F P
0 g
s
.31026 .49023 m .31437 .44567 L .30579 .45149 L p 0 .1 0 r
F P
0 g
s
.30579 .45149 m .30152 .49594 L .31026 .49023 L p 0 .1 0 r
F P
0 g
s
.26213 .42768 m .30579 .45149 L .31437 .44567 L p 0 .903 0 r
F P
0 g
s
.30579 .45149 m .30152 .49594 L .29286 .50158 L p 0 .1 0 r
F P
0 g
s
.30579 .45149 m .30152 .49594 L .25675 .47258 L p 0 .701 0 r
F P
0 g
s
.30579 .45149 m .26213 .42768 L .2537 .4337 L p 0 .903 0 r
F P
0 g
s
.26213 .42768 m .30579 .45149 L p .25675 .47258 L 0 .701 0 r
F P
0 g
s
.34436 .51829 m .34093 .56421 L .29705 .54238 L p 0 .701 0 r
F P
0 g
s
.29705 .54238 m .30152 .49594 L .34436 .51829 L p 0 .701 0 r
F P
0 g
s
.34093 .56421 m .29705 .54238 L .30597 .53681 L p 0 .911 0 r
F P
0 g
s
.30597 .53681 m .3499 .55888 L .34093 .56421 L p 0 .911 0 r
F P
0 g
s
.30579 .45149 m .30152 .49594 L .25675 .47258 L p 0 .701 0 r
F P
0 g
s
.26213 .42768 m .30579 .45149 L p .25675 .47258 L 0 .701 0 r
F P
0 g
s
.31437 .44567 m .31026 .49023 L .30152 .49594 L p 0 .1 0 r
F P
0 g
s
.31026 .49023 m .26545 .46662 L .25675 .47258 L p 0 .907 0 r
F P
0 g
s
.30152 .49594 m .25675 .47258 L .26545 .46662 L p 0 .907 0 r
F P
0 g
s
.26545 .46662 m .31026 .49023 L .30152 .49594 L p 0 .907 0 r
F P
0 g
s
.25675 .47258 m .30152 .49594 L .31026 .49023 L p 0 .907 0 r
F P
0 g
s
.38953 .49023 m .39192 .44567 L .38292 .45149 L p 0 .1 .423 r
F P
0 g
s
.38292 .45149 m .38035 .49594 L .38953 .49023 L p 0 .1 .423 r
F P
0 g
s
.34093 .42767 m .38292 .45149 L .39192 .44567 L p 0 .903 1 r
F P
0 g
s
.38292 .45149 m .38035 .49594 L .33735 .47258 L p 0 .697 .491 r
F P
0 g
s
.38292 .45149 m .34093 .42767 L .33207 .43368 L p 0 .903 1 r
F P
0 g
s
.33735 .47258 m .34093 .42767 L .38292 .45149 L p 0 .697 .491 r
F P
0 g
s
.38292 .45149 m .38035 .49594 L .33735 .47258 L p 0 .697 .491 r
F P
0 g
s
.33735 .47258 m .34093 .42767 L .38292 .45149 L p 0 .697 .491 r
F P
0 g
s
.22877 .45144 m .2288 .45142 L .23428 .44752 L p 0 1 .86 r
F P
0 g
s
.22281 .49585 m .22877 .45144 L .2288 .45142 L p 0 .704 .526 r
F P
0 g
s
.22281 .49585 m .22877 .45144 L .2288 .45142 L p 0 .704 .526 r
F P
0 g
s
.26794 .56056 m .31166 .5816 L .30591 .58502 L p 0 .911 1 r
F P
0 g
s
.30591 .58502 m .26222 .56413 L .26794 .56056 L p 0 .911 1 r
F P
0 g
s
.26222 .56413 m .26734 .51821 L .27296 .51455 L p 0 .1 .396 r
F P
0 g
s
.26734 .51821 m .26222 .56413 L .25655 .56767 L p 0 .1 .396 r
F P
0 g
s
.26794 .56056 m .27296 .51455 L .26734 .51821 L p 0 .1 .396 r
F P
0 g
s
.26734 .51821 m .26222 .56413 L .26794 .56056 L p 0 .1 .396 r
F P
0 g
s
.22281 .49585 m .26734 .51821 L .27296 .51455 L p 0 .907 1 r
F P
0 g
s
.26734 .51821 m .26222 .56413 L .2166 .54232 L p 0 .704 .526 r
F P
0 g
s
.26734 .51821 m .22281 .49585 L .21727 .49965 L p 0 .907 1 r
F P
0 g
s
.22281 .49585 m .26734 .51821 L p .2166 .54232 L 0 .704 .526 r
F P
0 g
s
.26734 .51821 m .26222 .56413 L .2166 .54232 L p 0 .704 .526 r
F P
0 g
s
.22281 .49585 m .26734 .51821 L p .2166 .54232 L 0 .704 .526 r
F P
0 g
s
.22838 .49203 m .27296 .51455 L .26734 .51821 L p 0 .907 1 r
F P
0 g
s
.26734 .51821 m .22281 .49585 L .22838 .49203 L p 0 .907 1 r
F P
0 g
s
.23428 .44752 m .23424 .44754 L .22877 .45144 L p 0 1 .86 r
F P
0 g
s
.22281 .49585 m .22877 .45144 L .23424 .44754 L p 0 .1 .365 r
F P
0 g
s
.22877 .45144 m .22281 .49585 L .21727 .49965 L p 0 .1 .365 r
F P
0 g
s
.19211 .55843 m .23754 .57955 L .22944 .5846 L p 0 .911 0 r
F P
0 g
s
.22944 .5846 m .18409 .56371 L .19211 .55843 L p 0 .911 0 r
F P
0 g
s
.18409 .56371 m .18406 .56366 L .19086 .51776 L p 0 .706 0 r
F P
0 g
s
.18406 .56366 m .19086 .51776 L .19874 .51236 L p 0 .1 0 r
F P
0 g
s
.25148 .71315 m .25851 .70941 L .26371 .66031 L p 0 .1 .423 r
F P
0 g
s
.21271 .69083 m .21904 .64105 L .26371 .66031 L p 0 .707 .542 r
F P
0 g
s
.26371 .66031 m .25851 .70941 L .21271 .69083 L p 0 .707 .542 r
F P
0 g
s
.38298 .64082 m .4241 .66007 L .43333 .65537 L p 0 .914 0 r
F P
0 g
s
.43188 .70466 m .43336 .65542 L .42413 .66012 L p 0 .114 0 r
F P
0 g
s
.42413 .66012 m .42246 .7092 L .43188 .70466 L p 0 .114 0 r
F P
0 g
s
.43336 .65542 m .43333 .65537 L .4241 .66007 L p 0 .562 0 r
F P
0 g
s
.4241 .66007 m .42413 .66012 L .43336 .65542 L p 0 .562 0 r
F P
0 g
s
.4241 .66007 m .38298 .64082 L .37387 .64568 L p 0 .914 0 r
F P
0 g
s
.38034 .69061 m .38298 .64082 L .4241 .66007 L p 0 .701 0 r
F P
0 g
s
.42246 .7092 m .38034 .69061 L p .4241 .66007 L 0 .701 0 r
F P
0 g
s
.4241 .66007 m .42413 .66012 L .42246 .7092 L p 0 .701 0 r
F P
0 g
s
.38034 .69061 m .38298 .64082 L .4241 .66007 L p 0 .701 0 r
F P
0 g
s
.42246 .7092 m .38034 .69061 L p .4241 .66007 L 0 .701 0 r
F P
0 g
s
.4241 .66007 m .42413 .66012 L .42246 .7092 L p 0 .701 0 r
F P
0 g
s
.30415 .64075 m .347 .66002 L .35291 .65687 L p 0 .914 1 r
F P
0 g
s
.34966 .70609 m .35291 .65687 L .347 .66002 L p 0 .1 .45 r
F P
0 g
s
.347 .66002 m .34363 .70913 L .34966 .70609 L p 0 .1 .45 r
F P
0 g
s
.347 .66002 m .30415 .64075 L .29831 .64402 L p 0 .914 1 r
F P
0 g
s
.29974 .69054 m .30415 .64075 L .347 .66002 L p 0 .704 .526 r
F P
0 g
s
.347 .66002 m .34363 .70913 L .33765 .71215 L p 0 .1 .45 r
F P
0 g
s
.347 .66002 m .34363 .70913 L .29974 .69054 L p 0 .704 .526 r
F P
0 g
s
.29974 .69054 m .30415 .64075 L .347 .66002 L p 0 .704 .526 r
F P
0 g
s
.347 .66002 m .34363 .70913 L .29974 .69054 L p 0 .704 .526 r
F P
0 g
s
.34363 .70913 m .347 .66002 L .35291 .65687 L p 0 .1 .45 r
F P
0 g
s
.34966 .70609 m .39168 .72402 L .38563 .72693 L p 0 .916 1 r
F P
0 g
s
.38563 .72693 m .34363 .70913 L .34966 .70609 L p 0 .916 1 r
F P
0 g
s
.34363 .70913 m .38563 .72693 L .39168 .72402 L p 0 .916 1 r
F P
0 g
s
.38929 .77469 m .39168 .72402 L .38563 .72693 L p 0 .114 .472 r
F P
0 g
s
.38563 .72693 m .38311 .77748 L .38929 .77469 L p 0 .114 .472 r
F P
0 g
s
.38563 .72693 m .34363 .70913 L .33765 .71215 L p 0 .916 1 r
F P
0 g
s
.34011 .76046 m .34363 .70913 L .38563 .72693 L p 0 .704 .526 r
F P
0 g
s
.38308 .7775 m .38311 .77748 L .37698 .78025 L p 0 .1 .1 r
F P
0 g
s
.38308 .7775 m .34011 .76046 L p .38563 .72693 L 0 .704 .526 r
F P
0 g
s
.38563 .72693 m .38311 .77748 L .38308 .7775 L p 0 .704 .526 r
F P
0 g
s
.34011 .76046 m .34363 .70913 L .38563 .72693 L p 0 .704 .526 r
F P
0 g
s
.38308 .7775 m .34011 .76046 L p .38563 .72693 L 0 .704 .526 r
F P
0 g
s
.38563 .72693 m .38311 .77748 L .38308 .7775 L p 0 .704 .526 r
F P
0 g
s
.34773 .79347 m .34769 .7935 L .35643 .78955 L p 0 .1 0 r
F P
0 g
s
.27385 .70426 m .31761 .72227 L .30908 .72657 L p 0 .916 0 r
F P
0 g
s
.30908 .72657 m .26537 .70876 L .27385 .70426 L p 0 .916 0 r
F P
0 g
s
.30487 .77717 m .30908 .72657 L .31761 .72227 L p 0 .1 0 r
F P
0 g
s
.26537 .70876 m .27043 .65963 L .27876 .65497 L p 0 .1 0 r
F P
0 g
s
.26537 .70876 m .30908 .72657 L .31761 .72227 L p 0 .916 0 r
F P
0 g
s
.31357 .77305 m .31761 .72227 L .30908 .72657 L p 0 .1 0 r
F P
0 g
s
.30908 .72657 m .30487 .77717 L .31357 .77305 L p 0 .1 0 r
F P
0 g
s
.26008 .7601 m .26537 .70876 L .30908 .72657 L p 0 .706 0 r
F P
0 g
s
.30908 .72657 m .30487 .77717 L .26008 .7601 L p 0 .706 0 r
F P
0 g
s
.31357 .77305 m .35643 .78955 L .34769 .7935 L p 0 .916 0 r
F P
0 g
s
.34769 .7935 m .30487 .77717 L .31357 .77305 L p 0 .916 0 r
F P
0 g
s
.23088 .63405 m .22262 .63894 L .26731 .65828 L p 0 .914 0 r
F P
0 g
s
.26731 .65828 m .27563 .65361 L .23088 .63405 L p 0 .914 0 r
F P
0 g
s
.27563 .65361 m .26731 .65828 L .26218 .70746 L p 0 .1 0 r
F P
0 g
s
.21635 .68879 m .22262 .63894 L .26731 .65828 L p 0 .706 0 r
F P
0 g
s
.26731 .65828 m .26218 .70746 L .21635 .68879 L p 0 .706 0 r
F P
0 g
s
.23424 .44754 m .23428 .44752 L .23979 .4436 L p 0 1 .86 r
F P
0 g
s
.22838 .49203 m .23424 .44754 L .23428 .44752 L p 0 .704 .523 r
F P
0 g
s
.22838 .49203 m .23424 .44754 L .23428 .44752 L p 0 .704 .523 r
F P
0 g
s
.2737 .55696 m .31746 .57815 L .31166 .5816 L p 0 .911 1 r
F P
0 g
s
.31166 .5816 m .26794 .56056 L .2737 .55696 L p 0 .911 1 r
F P
0 g
s
.26794 .56056 m .27296 .51455 L .27861 .51087 L p 0 .1 .396 r
F P
0 g
s
.27296 .51455 m .26794 .56056 L .26222 .56413 L p 0 .1 .396 r
F P
0 g
s
.2737 .55696 m .27861 .51087 L .27296 .51455 L p 0 .1 .396 r
F P
0 g
s
.27296 .51455 m .26794 .56056 L .2737 .55696 L p 0 .1 .396 r
F P
0 g
s
.22838 .49203 m .27296 .51455 L .27861 .51087 L p 0 .907 1 r
F P
0 g
s
.27296 .51455 m .26794 .56056 L .22228 .53858 L p 0 .704 .523 r
F P
0 g
s
.27296 .51455 m .22838 .49203 L .22281 .49585 L p 0 .907 1 r
F P
0 g
s
.22838 .49203 m .27296 .51455 L p .22228 .53858 L 0 .704 .523 r
F P
0 g
s
.27296 .51455 m .26794 .56056 L .22228 .53858 L p 0 .704 .523 r
F P
0 g
s
.22838 .49203 m .27296 .51455 L p .22228 .53858 L 0 .704 .523 r
F P
0 g
s
.23399 .48818 m .27861 .51087 L .27296 .51455 L p 0 .907 1 r
F P
0 g
s
.27296 .51455 m .22838 .49203 L .23399 .48818 L p 0 .907 1 r
F P
0 g
s
.23979 .4436 m .23976 .44361 L .23424 .44754 L p 0 1 .86 r
F P
0 g
s
.22838 .49203 m .23424 .44754 L .23976 .44361 L p 0 .1 .365 r
F P
0 g
s
.23424 .44754 m .22838 .49203 L .22281 .49585 L p 0 .1 .365 r
F P
0 g
s
.48179 .57629 m .47228 .58143 L .47225 .58145 L p 0 .1 .1 r
F P
0 g
s
.47228 .58143 m .47225 .58145 L .4321 .56042 L p 0 .696 .486 r
F P
0 g
s
.47228 .58143 m .47225 .58145 L .4321 .56042 L p 0 .696 .486 r
F P
0 g
s
.36202 .55505 m .35296 .56042 L .35614 .51441 L p 0 .1 0 r
F P
0 g
s
.35614 .51441 m .36502 .50891 L .36202 .55505 L p 0 .1 0 r
F P
0 g
s
.40394 .57632 m .39485 .58146 L .35296 .56042 L p 0 .911 0 r
F P
0 g
s
.4416 .41722 m .4321 .42335 L .47228 .44735 L p 0 .903 0 r
F P
0 g
s
.47228 .44735 m .48179 .44149 L .4416 .41722 L p 0 .903 0 r
F P
0 g
s
.48179 .44149 m .47228 .44735 L .47167 .49188 L p 0 .1 0 r
F P
0 g
s
.46205 .49757 m .47167 .49188 L .47228 .44735 L p 0 .1 0 r
F P
0 g
s
.47228 .44735 m .47167 .49188 L .43056 .46834 L p 0 .692 0 r
F P
0 g
s
.43056 .46834 m .4321 .42335 L .47228 .44735 L p 0 .692 0 r
F P
0 g
s
.47228 .44735 m .47167 .49188 L .43056 .46834 L p 0 .692 0 r
F P
0 g
s
.43056 .46834 m .4321 .42335 L .47228 .44735 L p 0 .692 0 r
F P
0 g
s
.48139 .48614 m .47167 .49188 L .51099 .51441 L p 0 .907 0 r
F P
0 g
s
.51099 .51441 m .52071 .50891 L .48139 .48614 L p 0 .907 0 r
F P
0 g
s
.52071 .50891 m .51099 .51441 L .51123 .56038 L p 0 .114 0 r
F P
0 g
s
.50141 .56569 m .51123 .56038 L .51099 .51441 L p 0 .114 0 r
F P
0 g
s
.51099 .51441 m .51123 .56038 L p .47103 .53842 L 0 .692 0 r
F P
0 g
s
.46205 .49757 m .47167 .49188 L .51099 .51441 L p 0 .907 0 r
F P
0 g
s
.47103 .53842 m .47167 .49188 L .51099 .51441 L p 0 .692 0 r
F P
0 g
s
.51099 .51441 m .51123 .56038 L p .47103 .53842 L 0 .692 0 r
F P
0 g
s
.47103 .53842 m .47167 .49188 L .51099 .51441 L p 0 .692 0 r
F P
0 g
s
.52071 .50891 m .51099 .51441 L .47167 .49188 L p 0 .907 0 r
F P
0 g
s
.48139 .48614 m .47167 .49188 L .47228 .44735 L p 0 .1 0 r
F P
0 g
s
.47228 .44735 m .48179 .44149 L .48139 .48614 L p 0 .1 0 r
F P
0 g
s
.4227 .56573 m .4321 .56042 L .43356 .51441 L p 0 .1 .45 r
F P
0 g
s
.40181 .48614 m .39253 .49188 L .43356 .51441 L p 0 .907 1 r
F P
0 g
s
.43356 .51441 m .44287 .50891 L .40181 .48614 L p 0 .907 1 r
F P
0 g
s
.44287 .50891 m .43356 .51441 L .4321 .56042 L p 0 .1 .45 r
F P
0 g
s
.43356 .51441 m .4321 .56042 L .3901 .53842 L p 0 .696 .486 r
F P
0 g
s
.38335 .49757 m .39253 .49188 L .43356 .51441 L p 0 .907 1 r
F P
0 g
s
.3901 .53842 m .39253 .49188 L .43356 .51441 L p 0 .696 .486 r
F P
0 g
s
.43356 .51441 m .4321 .56042 L .3901 .53842 L p 0 .696 .486 r
F P
0 g
s
.3901 .53842 m .39253 .49188 L .43356 .51441 L p 0 .696 .486 r
F P
0 g
s
.44287 .50891 m .43356 .51441 L .39253 .49188 L p 0 .907 1 r
F P
0 g
s
.4416 .55505 m .4321 .56042 L .43356 .51441 L p 0 .1 .45 r
F P
0 g
s
.43356 .51441 m .44287 .50891 L .4416 .55505 L p 0 .1 .45 r
F P
0 g
s
.40181 .48614 m .39253 .49188 L .39485 .44735 L p 0 .1 .425 r
F P
0 g
s
.39485 .44735 m .40394 .44149 L .40181 .48614 L p 0 .1 .425 r
F P
0 g
s
.47225 .58145 m .48176 .57631 L .48179 .57629 L p 0 .1 .1 r
F P
0 g
s
.48176 .57631 m .47225 .58145 L .4321 .56042 L p 0 .911 1 r
F P
0 g
s
.4227 .56573 m .4321 .56042 L .47225 .58145 L p 0 .911 1 r
F P
0 g
s
.52117 .41722 m .51123 .42335 L .54968 .44734 L p 0 .903 1 r
F P
0 g
s
.54968 .44734 m .55961 .44148 L .52117 .41722 L p 0 .903 1 r
F P
0 g
s
.55961 .44148 m .54968 .44734 L .54971 .44739 L p 0 .575 .884 r
F P
0 g
s
.54971 .44739 m .55964 .44152 L .55961 .44148 L p 0 .575 .884 r
F P
0 g
s
.55964 .44152 m .54971 .44739 L .5508 .49188 L p 0 .114 .472 r
F P
0 g
s
.54076 .49757 m .5508 .49188 L .54971 .44739 L p 0 .114 .472 r
F P
0 g
s
.54971 .44739 m .5508 .49188 L .51149 .46834 L p 0 .686 .443 r
F P
0 g
s
.54968 .44734 m .54971 .44739 L p .51149 .46834 L 0 .686 .443 r
F P
0 g
s
.51149 .46834 m .51123 .42335 L .54968 .44734 L p 0 .686 .443 r
F P
0 g
s
.54971 .44739 m .5508 .49188 L .51149 .46834 L p 0 .686 .443 r
F P
0 g
s
.54968 .44734 m .54971 .44739 L p .51149 .46834 L 0 .686 .443 r
F P
0 g
s
.51149 .46834 m .51123 .42335 L .54968 .44734 L p 0 .686 .443 r
F P
0 g
s
.31003 .63746 m .35291 .65687 L .35886 .65369 L p 0 .914 1 r
F P
0 g
s
.35573 .70303 m .35886 .65369 L .35291 .65687 L p 0 .1 .45 r
F P
0 g
s
.35291 .65687 m .34966 .70609 L .35573 .70303 L p 0 .1 .45 r
F P
0 g
s
.35291 .65687 m .31003 .63746 L .30415 .64075 L p 0 .914 1 r
F P
0 g
s
.30574 .68736 m .31003 .63746 L .35291 .65687 L p 0 .704 .523 r
F P
0 g
s
.35291 .65687 m .34966 .70609 L .34363 .70913 L p 0 .1 .45 r
F P
0 g
s
.35291 .65687 m .34966 .70609 L .30574 .68736 L p 0 .704 .523 r
F P
0 g
s
.30574 .68736 m .31003 .63746 L .35291 .65687 L p 0 .704 .523 r
F P
0 g
s
.35291 .65687 m .34966 .70609 L .30574 .68736 L p 0 .704 .523 r
F P
0 g
s
.34966 .70609 m .35291 .65687 L .35886 .65369 L p 0 .1 .45 r
F P
0 g
s
.35573 .70303 m .39777 .72108 L .39168 .72402 L p 0 .916 1 r
F P
0 g
s
.39168 .72402 m .34966 .70609 L .35573 .70303 L p 0 .916 1 r
F P
0 g
s
.34966 .70609 m .39168 .72402 L .39777 .72108 L p 0 .916 1 r
F P
0 g
s
.3955 .77188 m .39777 .72108 L .39168 .72402 L p 0 .114 .472 r
F P
0 g
s
.39168 .72402 m .38929 .77469 L .3955 .77188 L p 0 .114 .472 r
F P
0 g
s
.39168 .72402 m .34966 .70609 L .34363 .70913 L p 0 .916 1 r
F P
0 g
s
.34626 .75754 m .34966 .70609 L .39168 .72402 L p 0 .704 .523 r
F P
0 g
s
.38925 .77471 m .38929 .77469 L .38311 .77748 L p 0 .1 .1 r
F P
0 g
s
.38925 .77471 m .34626 .75754 L p .39168 .72402 L 0 .704 .523 r
F P
0 g
s
.39168 .72402 m .38929 .77469 L .38925 .77471 L p 0 .704 .523 r
F P
0 g
s
.34626 .75754 m .34966 .70609 L .39168 .72402 L p 0 .704 .523 r
F P
0 g
s
.38925 .77471 m .34626 .75754 L p .39168 .72402 L 0 .704 .523 r
F P
0 g
s
.39168 .72402 m .38929 .77469 L .38925 .77471 L p 0 .704 .523 r
F P
0 g
s
.35896 .55349 m .36203 .50731 L .35314 .51283 L p 0 .1 0 r
F P
0 g
s
.35314 .51283 m .3499 .55888 L .35896 .55349 L p 0 .1 0 r
F P
0 g
s
.31026 .49023 m .35314 .51283 L .36203 .50731 L p 0 .907 0 r
F P
0 g
s
.35314 .51283 m .3499 .55888 L .30597 .53681 L p 0 .7 0 r
F P
0 g
s
.35314 .51283 m .31026 .49023 L .30152 .49594 L p 0 .907 0 r
F P
0 g
s
.30597 .53681 m .31026 .49023 L .35314 .51283 L p 0 .7 0 r
F P
0 g
s
.35314 .51283 m .3499 .55888 L .30597 .53681 L p 0 .7 0 r
F P
0 g
s
.30597 .53681 m .31026 .49023 L .35314 .51283 L p 0 .7 0 r
F P
0 g
s
.31911 .48447 m .36203 .50731 L .35314 .51283 L p 0 .907 0 r
F P
0 g
s
.35314 .51283 m .31026 .49023 L .31911 .48447 L p 0 .907 0 r
F P
0 g
s
.31026 .49023 m .31437 .44567 L .32304 .43979 L p 0 .1 0 r
F P
0 g
s
.31911 .48447 m .32304 .43979 L .31437 .44567 L p 0 .1 0 r
F P
0 g
s
.31437 .44567 m .31026 .49023 L .31911 .48447 L p 0 .1 0 r
F P
0 g
s
.27067 .42161 m .31437 .44567 L .32304 .43979 L p 0 .903 0 r
F P
0 g
s
.31437 .44567 m .31026 .49023 L .26545 .46662 L p 0 .7 0 r
F P
0 g
s
.31437 .44567 m .27067 .42161 L .26213 .42768 L p 0 .903 0 r
F P
0 g
s
.27067 .42161 m .31437 .44567 L p .26545 .46662 L 0 .7 0 r
F P
0 g
s
.31437 .44567 m .31026 .49023 L .26545 .46662 L p 0 .7 0 r
F P
0 g
s
.27067 .42161 m .31437 .44567 L p .26545 .46662 L 0 .7 0 r
F P
0 g
s
.39881 .48447 m .40101 .43979 L .39192 .44567 L p 0 .1 .423 r
F P
0 g
s
.39192 .44567 m .38953 .49023 L .39881 .48447 L p 0 .1 .423 r
F P
0 g
s
.3499 .42159 m .39192 .44567 L .40101 .43979 L p 0 .903 1 r
F P
0 g
s
.39192 .44567 m .38953 .49023 L .3465 .46662 L p 0 .696 .486 r
F P
0 g
s
.39192 .44567 m .3499 .42159 L .34093 .42767 L p 0 .903 1 r
F P
0 g
s
.3465 .46662 m .3499 .42159 L .39192 .44567 L p 0 .696 .486 r
F P
0 g
s
.39192 .44567 m .38953 .49023 L .3465 .46662 L p 0 .696 .486 r
F P
0 g
s
.3465 .46662 m .3499 .42159 L .39192 .44567 L p 0 .696 .486 r
F P
0 g
s
.20022 .55309 m .24571 .57444 L .23754 .57955 L p 0 .911 0 r
F P
0 g
s
.23754 .57955 m .19211 .55843 L .20022 .55309 L p 0 .911 0 r
F P
0 g
s
.19211 .55843 m .19208 .55838 L .19874 .51236 L p 0 .706 0 r
F P
0 g
s
.19211 .55843 m .19208 .55838 L .19874 .51236 L p 0 .706 0 r
F P
0 g
s
.19208 .55838 m .19874 .51236 L .20672 .50689 L p 0 .1 0 r
F P
0 g
s
.19874 .51236 m .19208 .55838 L .18406 .56366 L p 0 .1 0 r
F P
0 g
s
.44141 .70007 m .44269 .65066 L .43336 .65542 L p 0 .114 0 r
F P
0 g
s
.43336 .65542 m .43188 .70466 L .44141 .70007 L p 0 .114 0 r
F P
0 g
s
.43333 .65537 m .43336 .65542 L .44269 .65066 L p 0 .562 0 r
F P
0 g
s
.43333 .65537 m .43336 .65542 L .43188 .70466 L p 0 .7 0 r
F P
0 g
s
.43333 .65537 m .43336 .65542 L .43188 .70466 L p 0 .7 0 r
F P
0 g
s
.39219 .63591 m .43333 .65537 L .44266 .65062 L p 0 .914 0 r
F P
0 g
s
.44269 .65066 m .44266 .65062 L .43333 .65537 L p 0 .562 0 r
F P
0 g
s
.43333 .65537 m .39219 .63591 L .38298 .64082 L p 0 .914 0 r
F P
0 g
s
.38975 .68586 m .39219 .63591 L .43333 .65537 L p 0 .7 0 r
F P
0 g
s
.43188 .70466 m .38975 .68586 L p .43333 .65537 L 0 .7 0 r
F P
0 g
s
.38975 .68586 m .39219 .63591 L .43333 .65537 L p 0 .7 0 r
F P
0 g
s
.43188 .70466 m .38975 .68586 L p .43333 .65537 L 0 .7 0 r
F P
0 g
s
.23976 .44361 m .23979 .4436 L .24535 .43964 L p 0 1 .86 r
F P
0 g
s
.23399 .48818 m .23976 .44361 L .23979 .4436 L p 0 .703 .52 r
F P
0 g
s
.23399 .48818 m .23976 .44361 L .23979 .4436 L p 0 .703 .52 r
F P
0 g
s
.23965 .4843 m .28431 .50716 L .27861 .51087 L p 0 .907 1 r
F P
0 g
s
.27861 .51087 m .23399 .48818 L .23965 .4843 L p 0 .907 1 r
F P
0 g
s
.23399 .48818 m .27861 .51087 L .28431 .50716 L p 0 .907 1 r
F P
0 g
s
.27861 .51087 m .23399 .48818 L .22838 .49203 L p 0 .907 1 r
F P
0 g
s
.23399 .48818 m .27861 .51087 L p .228 .53482 L 0 .703 .52 r
F P
0 g
s
.23399 .48818 m .27861 .51087 L p .228 .53482 L 0 .703 .52 r
F P
0 g
s
.28431 .50716 m .23965 .4843 L .23399 .48818 L p 0 .907 1 r
F P
0 g
s
.23965 .4843 m .28431 .50716 L p .23376 .53103 L 0 .703 0 r
F P
0 g
s
.23965 .4843 m .28431 .50716 L p .23376 .53103 L 0 .703 .518 r
F P
0 g
s
.29286 .50158 m .24815 .47847 L .23965 .4843 L p 0 .907 0 r
F P
0 g
s
.23376 .53103 m .23373 .53098 L .23965 .4843 L p 0 .703 0 r
F P
0 g
s
.23376 .53103 m .23373 .53098 L .23965 .4843 L p 0 .703 .518 r
F P
0 g
s
.23373 .53098 m .23965 .4843 L .24815 .47847 L p 0 .1 0 r
F P
0 g
s
.27951 .55334 m .32329 .57469 L .31746 .57815 L p 0 .911 1 r
F P
0 g
s
.31746 .57815 m .2737 .55696 L .27951 .55334 L p 0 .911 1 r
F P
0 g
s
.2737 .55696 m .27861 .51087 L .28431 .50716 L p 0 .1 .396 r
F P
0 g
s
.27861 .51087 m .2737 .55696 L .26794 .56056 L p 0 .1 .396 r
F P
0 g
s
.27951 .55334 m .28431 .50716 L .27861 .51087 L p 0 .1 .396 r
F P
0 g
s
.27861 .51087 m .2737 .55696 L .27951 .55334 L p 0 .1 .396 r
F P
0 g
s
.27861 .51087 m .2737 .55696 L .228 .53482 L p 0 .703 .52 r
F P
0 g
s
.27861 .51087 m .2737 .55696 L .228 .53482 L p 0 .703 .52 r
F P
0 g
s
.28431 .50716 m .27951 .55334 L .2737 .55696 L p 0 .1 .396 r
F P
0 g
s
.28431 .50716 m .27951 .55334 L .23376 .53103 L p 0 .703 0 r
F P
0 g
s
.28431 .50716 m .27951 .55334 L .23376 .53103 L p 0 .703 .518 r
F P
0 g
s
.27951 .55334 m .23376 .53103 L .24243 .52533 L p 0 .911 0 r
F P
0 g
s
.29286 .50158 m .28823 .54789 L .27951 .55334 L p 0 .1 0 r
F P
0 g
s
.24243 .52533 m .28823 .54789 L .27951 .55334 L p 0 .911 0 r
F P
0 g
s
.24535 .43964 m .24531 .43965 L .23976 .44361 L p 0 1 .86 r
F P
0 g
s
.24531 .43965 m .24535 .43964 L .2537 .4337 L p 0 1 0 r
F P
0 g
s
.23965 .4843 m .24531 .43965 L .24535 .43964 L p 0 .703 0 r
F P
0 g
s
.23965 .4843 m .24531 .43965 L .24535 .43964 L p 0 .703 .518 r
F P
0 g
s
.2537 .4337 m .25366 .43371 L .24531 .43965 L p 0 1 0 r
F P
0 g
s
.23965 .4843 m .24531 .43965 L .25366 .43371 L p 0 .1 0 r
F P
0 g
s
.23399 .48818 m .23976 .44361 L .24531 .43965 L p 0 .1 .365 r
F P
0 g
s
.23976 .44361 m .23399 .48818 L .22838 .49203 L p 0 .1 .365 r
F P
0 g
s
.35646 .78952 m .35643 .78955 L .36526 .78556 L p 0 .1 0 r
F P
0 g
s
.27385 .70426 m .27876 .65497 L .28717 .65026 L p 0 .1 0 r
F P
0 g
s
.28243 .69972 m .32623 .71792 L .31761 .72227 L p 0 .916 0 r
F P
0 g
s
.31761 .72227 m .27385 .70426 L .28243 .69972 L p 0 .916 0 r
F P
0 g
s
.27876 .65497 m .27385 .70426 L .26537 .70876 L p 0 .1 0 r
F P
0 g
s
.27385 .70426 m .31761 .72227 L .32623 .71792 L p 0 .916 0 r
F P
0 g
s
.32236 .76888 m .32623 .71792 L .31761 .72227 L p 0 .1 0 r
F P
0 g
s
.31761 .72227 m .31357 .77305 L .32236 .76888 L p 0 .1 0 r
F P
0 g
s
.31761 .72227 m .27385 .70426 L .26537 .70876 L p 0 .916 0 r
F P
0 g
s
.26873 .75579 m .27385 .70426 L .31761 .72227 L p 0 .706 0 r
F P
0 g
s
.31761 .72227 m .31357 .77305 L .30487 .77717 L p 0 .1 0 r
F P
0 g
s
.31761 .72227 m .31357 .77305 L .26873 .75579 L p 0 .706 0 r
F P
0 g
s
.26873 .75579 m .27385 .70426 L .31761 .72227 L p 0 .706 0 r
F P
0 g
s
.31761 .72227 m .31357 .77305 L .26873 .75579 L p 0 .706 0 r
F P
0 g
s
.31357 .77305 m .31761 .72227 L .32623 .71792 L p 0 .1 0 r
F P
0 g
s
.32236 .76888 m .36526 .78556 L .35643 .78955 L p 0 .916 0 r
F P
0 g
s
.35643 .78955 m .31357 .77305 L .32236 .76888 L p 0 .916 0 r
F P
0 g
s
.35573 .70303 m .39777 .72108 L .40391 .71813 L p 0 .916 1 r
F P
0 g
s
.40177 .76905 m .40391 .71813 L .39777 .72108 L p 0 .114 .472 r
F P
0 g
s
.39777 .72108 m .3955 .77188 L .40177 .76905 L p 0 .114 .472 r
F P
0 g
s
.39777 .72108 m .35573 .70303 L .34966 .70609 L p 0 .916 1 r
F P
0 g
s
.35246 .7546 m .35573 .70303 L .39777 .72108 L p 0 .703 .52 r
F P
0 g
s
.39547 .7719 m .3955 .77188 L .38929 .77469 L p 0 .1 .1 r
F P
0 g
s
.39547 .7719 m .35246 .7546 L p .39777 .72108 L 0 .703 .52 r
F P
0 g
s
.39777 .72108 m .3955 .77188 L .39547 .7719 L p 0 .703 .52 r
F P
0 g
s
.35246 .7546 m .35573 .70303 L .39777 .72108 L p 0 .703 .52 r
F P
0 g
s
.39547 .7719 m .35246 .7546 L p .39777 .72108 L 0 .703 .52 r
F P
0 g
s
.39777 .72108 m .3955 .77188 L .39547 .7719 L p 0 .703 .52 r
F P
0 g
s
.31596 .63414 m .35886 .65369 L .36486 .65049 L p 0 .914 1 r
F P
0 g
s
.36185 .69994 m .36486 .65049 L .35886 .65369 L p 0 .1 .45 r
F P
0 g
s
.35886 .65369 m .35573 .70303 L .36185 .69994 L p 0 .1 .45 r
F P
0 g
s
.35886 .65369 m .31596 .63414 L .31003 .63746 L p 0 .914 1 r
F P
0 g
s
.31178 .68415 m .31596 .63414 L .35886 .65369 L p 0 .703 .52 r
F P
0 g
s
.35886 .65369 m .35573 .70303 L .34966 .70609 L p 0 .1 .45 r
F P
0 g
s
.35886 .65369 m .35573 .70303 L .31178 .68415 L p 0 .703 .52 r
F P
0 g
s
.31178 .68415 m .31596 .63414 L .35886 .65369 L p 0 .703 .52 r
F P
0 g
s
.35886 .65369 m .35573 .70303 L .31178 .68415 L p 0 .703 .52 r
F P
0 g
s
.35573 .70303 m .35886 .65369 L .36486 .65049 L p 0 .1 .45 r
F P
0 g
s
.36185 .69994 m .40391 .71813 L .39777 .72108 L p 0 .916 1 r
F P
0 g
s
.39777 .72108 m .35573 .70303 L .36185 .69994 L p 0 .916 1 r
F P
0 g
s
.23923 .62912 m .23088 .63405 L .27563 .65361 L p 0 .914 0 r
F P
0 g
s
.27563 .65361 m .28404 .64888 L .23923 .62912 L p 0 .914 0 r
F P
0 g
s
.28404 .64888 m .27563 .65361 L .27065 .70295 L p 0 .1 0 r
F P
0 g
s
.22477 .68407 m .23088 .63405 L .27563 .65361 L p 0 .706 0 r
F P
0 g
s
.26218 .70746 m .27065 .70295 L .27563 .65361 L p 0 .1 0 r
F P
0 g
s
.27563 .65361 m .27065 .70295 L .22477 .68407 L p 0 .706 0 r
F P
0 g
s
.22477 .68407 m .23088 .63405 L .27563 .65361 L p 0 .706 0 r
F P
0 g
s
.27563 .65361 m .27065 .70295 L .22477 .68407 L p 0 .706 0 r
F P
0 g
s
.48179 .57629 m .48176 .57631 L .4416 .55505 L p 0 .695 .481 r
F P
0 g
s
.35296 .56042 m .36202 .55505 L .40394 .57632 L p 0 .911 0 r
F P
0 g
s
.47167 .49188 m .48139 .48614 L .48179 .44149 L p 0 .1 0 r
F P
0 g
s
.48179 .44149 m .48139 .48614 L .44027 .46233 L p 0 .69 0 r
F P
0 g
s
.44027 .46233 m .4416 .41722 L .48179 .44149 L p 0 .69 0 r
F P
0 g
s
.51123 .56038 m .52117 .55501 L .52071 .50891 L p 0 .114 0 r
F P
0 g
s
.52071 .50891 m .52117 .55501 L p .48096 .53281 L 0 .69 0 r
F P
0 g
s
.47167 .49188 m .48139 .48614 L .52071 .50891 L p 0 .907 0 r
F P
0 g
s
.48096 .53281 m .48139 .48614 L .52071 .50891 L p 0 .69 0 r
F P
0 g
s
.4321 .56042 m .4416 .55505 L .44287 .50891 L p 0 .1 .45 r
F P
0 g
s
.44287 .50891 m .4416 .55505 L .39958 .53281 L p 0 .695 .481 r
F P
0 g
s
.39253 .49188 m .40181 .48614 L .44287 .50891 L p 0 .907 1 r
F P
0 g
s
.39958 .53281 m .40181 .48614 L .44287 .50891 L p 0 .695 .481 r
F P
0 g
s
.4321 .56042 m .4416 .55505 L .48176 .57631 L p 0 .911 1 r
F P
0 g
s
.5508 .49188 m .56096 .48614 L .55964 .44152 L p 0 .114 .472 r
F P
0 g
s
.55964 .44152 m .56096 .48614 L .52165 .46233 L p 0 .684 .437 r
F P
0 g
s
.55961 .44148 m .55964 .44152 L p .52165 .46233 L 0 .684 .437 r
F P
0 g
s
.52165 .46233 m .52117 .41722 L .55961 .44148 L p 0 .684 .437 r
F P
0 g
s
.49168 .57095 m .48207 .57614 L .48204 .57616 L p 0 .1 0 r
F P
0 g
s
.48207 .57614 m .48204 .57616 L .44187 .55489 L p 0 .695 0 r
F P
0 g
s
.41147 .48016 m .40208 .48597 L .44314 .50875 L p 0 .907 0 r
F P
0 g
s
.44314 .50875 m .45254 .50319 L .41147 .48016 L p 0 .907 0 r
F P
0 g
s
.45254 .50319 m .44314 .50875 L .44187 .55489 L p 0 .1 0 r
F P
0 g
s
.44314 .50875 m .44187 .55489 L .39986 .53264 L p 0 .695 0 r
F P
0 g
s
.39986 .53264 m .40208 .48597 L .44314 .50875 L p 0 .695 0 r
F P
0 g
s
.45254 .50319 m .44314 .50875 L .40208 .48597 L p 0 .907 0 r
F P
0 g
s
.41147 .48016 m .40208 .48597 L .40421 .44132 L p 0 .1 0 r
F P
0 g
s
.40421 .44132 m .4134 .4354 L .41147 .48016 L p 0 .1 0 r
F P
0 g
s
.45148 .54946 m .44187 .55489 L .44314 .50875 L p 0 .1 0 r
F P
0 g
s
.44314 .50875 m .45254 .50319 L .45148 .54946 L p 0 .1 0 r
F P
0 g
s
.4134 .57098 m .40421 .57618 L .36229 .55489 L p 0 .911 1 r
F P
0 g
s
.37146 .54946 m .36229 .55489 L .36528 .50875 L p 0 .1 .425 r
F P
0 g
s
.36528 .50875 m .37426 .50319 L .37146 .54946 L p 0 .1 .425 r
F P
0 g
s
.45148 .41085 m .44187 .41705 L .48206 .44132 L p 0 .903 1 r
F P
0 g
s
.48206 .44132 m .49168 .4354 L .45148 .41085 L p 0 .903 1 r
F P
0 g
s
.49168 .4354 m .48206 .44132 L .48167 .48597 L p 0 .1 .45 r
F P
0 g
s
.48206 .44132 m .48167 .48597 L .44055 .46215 L p 0 .69 .46 r
F P
0 g
s
.44055 .46215 m .44187 .41705 L .48206 .44132 L p 0 .69 .46 r
F P
0 g
s
.4915 .48016 m .48167 .48597 L .48206 .44132 L p 0 .1 .45 r
F P
0 g
s
.48206 .44132 m .49168 .4354 L .4915 .48016 L p 0 .1 .45 r
F P
0 g
s
.4915 .48016 m .48167 .48597 L .52099 .50875 L p 0 .907 1 r
F P
0 g
s
.52099 .50875 m .53082 .50319 L .4915 .48016 L p 0 .907 1 r
F P
0 g
s
.53082 .50319 m .52099 .50875 L .52146 .55486 L p 0 .114 .472 r
F P
0 g
s
.52099 .50875 m .52146 .55486 L p .48125 .53264 L 0 .69 .46 r
F P
0 g
s
.48125 .53264 m .48167 .48597 L .52099 .50875 L p 0 .69 .46 r
F P
0 g
s
.53082 .50319 m .52099 .50875 L .48167 .48597 L p 0 .907 1 r
F P
0 g
s
.48204 .57616 m .49165 .57097 L .49168 .57095 L p 0 .1 0 r
F P
0 g
s
.49165 .57097 m .48204 .57616 L .44187 .55489 L p 0 .911 0 r
F P
0 g
s
.53151 .41085 m .52146 .41705 L .5599 .44131 L p 0 .903 0 r
F P
0 g
s
.5599 .44131 m .56994 .43538 L .53151 .41085 L p 0 .903 0 r
F P
0 g
s
.56994 .43538 m .5599 .44131 L .55992 .44135 L p 0 .575 0 r
F P
0 g
s
.55992 .44135 m .56996 .43543 L .56994 .43538 L p 0 .575 0 r
F P
0 g
s
.56996 .43543 m .55992 .44135 L .56125 .48597 L p 0 .114 0 r
F P
0 g
s
.55992 .44135 m .56125 .48597 L .52195 .46215 L p 0 .684 0 r
F P
0 g
s
.5599 .44131 m .55992 .44135 L p .52195 .46215 L 0 .684 0 r
F P
0 g
s
.52195 .46215 m .52146 .41705 L .5599 .44131 L p 0 .684 0 r
F P
0 g
s
.36203 .50731 m .31911 .48447 L .31026 .49023 L p 0 .907 0 r
F P
0 g
s
.36203 .50731 m .35896 .55349 L .31499 .53118 L p 0 .699 0 r
F P
0 g
s
.31499 .53118 m .31911 .48447 L .36203 .50731 L p 0 .699 0 r
F P
0 g
s
.32304 .43979 m .31911 .48447 L .31026 .49023 L p 0 .1 0 r
F P
0 g
s
.32304 .43979 m .27929 .41547 L .27067 .42161 L p 0 .903 0 r
F P
0 g
s
.32304 .43979 m .31911 .48447 L .27424 .46059 L p 0 .699 0 r
F P
0 g
s
.27929 .41547 m .32304 .43979 L p .27424 .46059 L 0 .699 0 r
F P
0 g
s
.40101 .43979 m .35896 .41545 L .3499 .42159 L p 0 .903 1 r
F P
0 g
s
.40101 .43979 m .39881 .48447 L .35575 .46059 L p 0 .695 .481 r
F P
0 g
s
.35575 .46059 m .35896 .41545 L .40101 .43979 L p 0 .695 .481 r
F P
0 g
s
.17393 .57032 m .17396 .57037 L .16737 .5747 L p 0 .546 .889 r
F P
0 g
s
.16737 .5747 m .16734 .57465 L .17393 .57032 L p 0 .546 .889 r
F P
0 g
s
.40847 .47847 m .41047 .43368 L .40127 .43962 L p 0 .1 0 r
F P
0 g
s
.40127 .43962 m .39908 .4843 L .40847 .47847 L p 0 .1 0 r
F P
0 g
s
.35922 .41527 m .40127 .43962 L .41047 .43368 L p 0 .903 0 r
F P
0 g
s
.40127 .43962 m .39908 .4843 L .35602 .46041 L p 0 .695 0 r
F P
0 g
s
.35602 .46041 m .35922 .41527 L .40127 .43962 L p 0 .695 0 r
F P
0 g
s
.36839 .54789 m .37127 .50158 L .36228 .50716 L p 0 .1 .423 r
F P
0 g
s
.36228 .50716 m .35922 .55334 L .36839 .54789 L p 0 .1 .423 r
F P
0 g
s
.31936 .4843 m .36228 .50716 L .37127 .50158 L p 0 .907 1 r
F P
0 g
s
.36228 .50716 m .35922 .55334 L .31526 .53102 L p 0 .699 .5 r
F P
0 g
s
.31526 .53102 m .31936 .4843 L .36228 .50716 L p 0 .699 .5 r
F P
0 g
s
.32831 .47847 m .37127 .50158 L .36228 .50716 L p 0 .907 1 r
F P
0 g
s
.36228 .50716 m .31936 .4843 L .32831 .47847 L p 0 .907 1 r
F P
0 g
s
.31936 .4843 m .32329 .43962 L .33207 .43368 L p 0 .1 .396 r
F P
0 g
s
.32831 .47847 m .33207 .43368 L .32329 .43962 L p 0 .1 .396 r
F P
0 g
s
.32329 .43962 m .31936 .4843 L .32831 .47847 L p 0 .1 .396 r
F P
0 g
s
.27954 .41529 m .32329 .43962 L .33207 .43368 L p 0 .903 1 r
F P
0 g
s
.32329 .43962 m .31936 .4843 L .27449 .46041 L p 0 .699 .5 r
F P
0 g
s
.27954 .41529 m .32329 .43962 L p .27449 .46041 L 0 .699 .5 r
F P
0 g
s
.24531 .43965 m .23965 .4843 L .23399 .48818 L p 0 .1 .365 r
F P
0 g
s
.20672 .50689 m .20019 .55304 L .19208 .55838 L p 0 .1 0 r
F P
0 g
s
.20022 .55309 m .20019 .55304 L .20672 .50689 L p 0 .705 0 r
F P
0 g
s
.44266 .65062 m .4015 .63094 L .39219 .63591 L p 0 .914 0 r
F P
0 g
s
.39925 .68106 m .4015 .63094 L .44266 .65062 L p 0 .699 0 r
F P
0 g
s
.44141 .70007 m .39925 .68106 L p .44266 .65062 L 0 .699 0 r
F P
0 g
s
.44266 .65062 m .44269 .65066 L .44141 .70007 L p 0 .699 0 r
F P
0 g
s
.40391 .71813 m .36185 .69994 L .35573 .70303 L p 0 .916 1 r
F P
0 g
s
.3587 .75164 m .36185 .69994 L .40391 .71813 L p 0 .703 .518 r
F P
0 g
s
.40174 .76907 m .40177 .76905 L .3955 .77188 L p 0 .1 .1 r
F P
0 g
s
.40174 .76907 m .3587 .75164 L p .40391 .71813 L 0 .703 .518 r
F P
0 g
s
.40391 .71813 m .40177 .76905 L .40174 .76907 L p 0 .703 .518 r
F P
0 g
s
.36486 .65049 m .32193 .6308 L .31596 .63414 L p 0 .914 1 r
F P
0 g
s
.31787 .68092 m .32193 .6308 L .36486 .65049 L p 0 .703 .518 r
F P
0 g
s
.36486 .65049 m .36185 .69994 L .35573 .70303 L p 0 .1 .45 r
F P
0 g
s
.36486 .65049 m .36185 .69994 L .31787 .68092 L p 0 .703 .518 r
F P
0 g
s
.24209 .76908 m .24771 .71813 L .25467 .71443 L p 0 .1 .425 r
F P
0 g
s
.24918 .76554 m .2939 .78238 L .28676 .78576 L p 0 .916 1 r
F P
0 g
s
.28676 .78576 m .24209 .76908 L .24918 .76554 L p 0 .916 1 r
F P
0 g
s
.32193 .6308 m .36486 .65049 L .37387 .64568 L p 0 .914 0 r
F P
0 g
s
.37104 .6953 m .37387 .64568 L .36486 .65049 L p 0 .1 0 r
F P
0 g
s
.36486 .65049 m .36185 .69994 L .37104 .6953 L p 0 .1 0 r
F P
0 g
s
.31787 .68092 m .32193 .6308 L .36486 .65049 L p 0 .703 0 r
F P
0 g
s
.36486 .65049 m .36185 .69994 L .31787 .68092 L p 0 .703 0 r
F P
0 g
s
.36185 .69994 m .36486 .65049 L .37387 .64568 L p 0 .1 0 r
F P
0 g
s
.36185 .69994 m .40391 .71813 L .41313 .71369 L p 0 .916 0 r
F P
0 g
s
.41119 .76479 m .41313 .71369 L .40391 .71813 L p 0 .114 0 r
F P
0 g
s
.40391 .71813 m .40177 .76905 L .41119 .76479 L p 0 .114 0 r
F P
0 g
s
.3587 .75164 m .36185 .69994 L .40391 .71813 L p 0 .703 0 r
F P
0 g
s
.40174 .76907 m .3587 .75164 L p .40391 .71813 L 0 .703 0 r
F P
0 g
s
.40391 .71813 m .40177 .76905 L .40174 .76907 L p 0 .703 0 r
F P
0 g
s
.37104 .6953 m .41313 .71369 L .40391 .71813 L p 0 .916 0 r
F P
0 g
s
.40391 .71813 m .36185 .69994 L .37104 .6953 L p 0 .916 0 r
F P
0 g
s
.40177 .6308 m .44293 .65048 L .45237 .64567 L p 0 .914 1 r
F P
0 g
s
.45133 .6953 m .45239 .64572 L .44296 .65053 L p 0 .114 .472 r
F P
0 g
s
.44296 .65053 m .44169 .69994 L .45133 .6953 L p 0 .114 .472 r
F P
0 g
s
.45239 .64572 m .45237 .64567 L .44293 .65048 L p 0 .562 .887 r
F P
0 g
s
.44293 .65048 m .44296 .65053 L .45239 .64572 L p 0 .562 .887 r
F P
0 g
s
.39953 .68092 m .40177 .6308 L .44293 .65048 L p 0 .699 .5 r
F P
0 g
s
.44169 .69994 m .39953 .68092 L p .44293 .65048 L 0 .699 .5 r
F P
0 g
s
.44293 .65048 m .44296 .65053 L .44169 .69994 L p 0 .699 .5 r
F P
0 g
s
.28717 .65026 m .28243 .69972 L .27385 .70426 L p 0 .1 0 r
F P
0 g
s
.32623 .71792 m .28243 .69972 L .27385 .70426 L p 0 .916 0 r
F P
0 g
s
.27747 .75143 m .28243 .69972 L .32623 .71792 L p 0 .705 0 r
F P
0 g
s
.32623 .71792 m .32236 .76888 L .31357 .77305 L p 0 .1 0 r
F P
0 g
s
.32623 .71792 m .32236 .76888 L .27747 .75143 L p 0 .705 0 r
F P
0 g
s
.25148 .71315 m .24452 .71686 L .19884 .69861 L p 0 .916 1 r
F P
0 g
s
.20574 .69474 m .19884 .69861 L .20541 .64911 L p 0 .1 .396 r
F P
0 g
s
.20541 .64911 m .2122 .6451 L .20574 .69474 L p 0 .1 .396 r
F P
0 g
s
.20574 .69474 m .19884 .69861 L .24452 .71686 L p 0 .916 1 r
F P
0 g
s
.24452 .71686 m .25148 .71315 L .20574 .69474 L p 0 .916 1 r
F P
0 g
s
.25148 .71315 m .24452 .71686 L .23882 .76786 L p 0 .1 .423 r
F P
0 g
s
.19196 .75036 m .19884 .69861 L .24452 .71686 L p 0 .708 .548 r
F P
0 g
s
.24452 .71686 m .23882 .76786 L .19196 .75036 L p 0 .708 .548 r
F P
0 g
s
.16561 .62518 m .15889 .62937 L .20541 .64911 L p 0 .914 1 r
F P
0 g
s
.20541 .64911 m .2122 .6451 L .16561 .62518 L p 0 .914 1 r
F P
0 g
s
.2122 .6451 m .20541 .64911 L .19884 .69861 L p 0 .1 .396 r
F P
0 g
s
.15885 .62939 m .15889 .62937 L .20541 .64911 L p 0 .708 .548 r
F P
0 g
s
.15107 .67953 m .15885 .62939 L p .20541 .64911 L 0 .708 .548 r
F P
0 g
s
.20541 .64911 m .19884 .69861 L .15107 .67953 L p 0 .708 .548 r
F P
0 g
s
.27065 .70295 m .27922 .69839 L .28404 .64888 L p 0 .1 0 r
F P
0 g
s
.23328 .6793 m .23923 .62912 L .28404 .64888 L p 0 .705 0 r
F P
0 g
s
.28404 .64888 m .27922 .69839 L .23328 .6793 L p 0 .705 0 r
F P
0 g
s
.50141 .56569 m .49168 .57095 L .49165 .57097 L p 0 .1 0 r
F P
0 g
s
.49168 .57095 m .49165 .57097 L .45148 .54946 L p 0 .694 0 r
F P
0 g
s
.49168 .57095 m .49165 .57097 L .45148 .54946 L p 0 .694 0 r
F P
0 g
s
.42096 .47428 m .41147 .48016 L .45254 .50319 L p 0 .907 0 r
F P
0 g
s
.45254 .50319 m .46205 .49757 L .42096 .47428 L p 0 .907 0 r
F P
0 g
s
.46205 .49757 m .45254 .50319 L .45148 .54946 L p 0 .1 0 r
F P
0 g
s
.44187 .55489 m .45148 .54946 L .45254 .50319 L p 0 .1 0 r
F P
0 g
s
.45254 .50319 m .45148 .54946 L .40945 .52696 L p 0 .694 0 r
F P
0 g
s
.40208 .48597 m .41147 .48016 L .45254 .50319 L p 0 .907 0 r
F P
0 g
s
.40945 .52696 m .41147 .48016 L .45254 .50319 L p 0 .694 0 r
F P
0 g
s
.45254 .50319 m .45148 .54946 L .40945 .52696 L p 0 .694 0 r
F P
0 g
s
.40945 .52696 m .41147 .48016 L .45254 .50319 L p 0 .694 0 r
F P
0 g
s
.46205 .49757 m .45254 .50319 L .41147 .48016 L p 0 .907 0 r
F P
0 g
s
.42096 .47428 m .41147 .48016 L .4134 .4354 L p 0 .1 0 r
F P
0 g
s
.4134 .4354 m .4227 .4294 L .42096 .47428 L p 0 .1 0 r
F P
0 g
s
.4612 .54397 m .45148 .54946 L .45254 .50319 L p 0 .1 0 r
F P
0 g
s
.45254 .50319 m .46205 .49757 L .4612 .54397 L p 0 .1 0 r
F P
0 g
s
.38073 .54397 m .37146 .54946 L .37426 .50319 L p 0 .1 .425 r
F P
0 g
s
.37426 .50319 m .38335 .49757 L .38073 .54397 L p 0 .1 .425 r
F P
0 g
s
.4227 .56573 m .4134 .57098 L .37146 .54946 L p 0 .911 1 r
F P
0 g
s
.36229 .55489 m .37146 .54946 L .4134 .57098 L p 0 .911 1 r
F P
0 g
s
.4612 .40459 m .45148 .41085 L .49168 .4354 L p 0 .903 1 r
F P
0 g
s
.49168 .4354 m .50141 .4294 L .4612 .40459 L p 0 .903 1 r
F P
0 g
s
.50141 .4294 m .49168 .4354 L .4915 .48016 L p 0 .1 .45 r
F P
0 g
s
.48167 .48597 m .4915 .48016 L .49168 .4354 L p 0 .1 .45 r
F P
0 g
s
.49168 .4354 m .4915 .48016 L .45038 .45607 L p 0 .689 .454 r
F P
0 g
s
.45038 .45607 m .45148 .41085 L .49168 .4354 L p 0 .689 .454 r
F P
0 g
s
.49168 .4354 m .4915 .48016 L .45038 .45607 L p 0 .689 .454 r
F P
0 g
s
.45038 .45607 m .45148 .41085 L .49168 .4354 L p 0 .689 .454 r
F P
0 g
s
.50144 .47428 m .4915 .48016 L .49168 .4354 L p 0 .1 .45 r
F P
0 g
s
.49168 .4354 m .50141 .4294 L .50144 .47428 L p 0 .1 .45 r
F P
0 g
s
.50144 .47428 m .4915 .48016 L .53082 .50319 L p 0 .907 1 r
F P
0 g
s
.53082 .50319 m .54076 .49757 L .50144 .47428 L p 0 .907 1 r
F P
0 g
s
.54076 .49757 m .53082 .50319 L .53151 .54943 L p 0 .114 .472 r
F P
0 g
s
.52146 .55486 m .53151 .54943 L .53082 .50319 L p 0 .114 .472 r
F P
0 g
s
.53082 .50319 m .53151 .54943 L p .4913 .52696 L 0 .689 .454 r
F P
0 g
s
.48167 .48597 m .4915 .48016 L .53082 .50319 L p 0 .907 1 r
F P
0 g
s
.4913 .52696 m .4915 .48016 L .53082 .50319 L p 0 .689 .454 r
F P
0 g
s
.53082 .50319 m .53151 .54943 L p .4913 .52696 L 0 .689 .454 r
F P
0 g
s
.4913 .52696 m .4915 .48016 L .53082 .50319 L p 0 .689 .454 r
F P
0 g
s
.54076 .49757 m .53082 .50319 L .4915 .48016 L p 0 .907 1 r
F P
0 g
s
.58009 .42939 m .56994 .43538 L .56996 .43543 L p 0 .575 0 r
F P
0 g
s
.56996 .43543 m .58011 .42944 L .58009 .42939 L p 0 .575 0 r
F P
0 g
s
.58011 .42944 m .56996 .43543 L .57152 .48016 L p 0 .114 0 r
F P
0 g
s
.56125 .48597 m .57152 .48016 L .56996 .43543 L p 0 .114 0 r
F P
0 g
s
.56996 .43543 m .57152 .48016 L .53223 .45607 L p 0 .683 0 r
F P
0 g
s
.56994 .43538 m .56996 .43543 L p .53223 .45607 L 0 .683 0 r
F P
0 g
s
.56996 .43543 m .57152 .48016 L .53223 .45607 L p 0 .683 0 r
F P
0 g
s
.56994 .43538 m .56996 .43543 L p .53223 .45607 L 0 .683 0 r
F P
0 g
s
.54167 .40459 m .53151 .41085 L .56994 .43538 L p 0 .903 0 r
F P
0 g
s
.56994 .43538 m .58009 .42939 L .54167 .40459 L p 0 .903 0 r
F P
0 g
s
.53223 .45607 m .53151 .41085 L .56994 .43538 L p 0 .683 0 r
F P
0 g
s
.53223 .45607 m .53151 .41085 L .56994 .43538 L p 0 .683 0 r
F P
0 g
s
.49165 .57097 m .50138 .56571 L .50141 .56569 L p 0 .1 0 r
F P
0 g
s
.50138 .56571 m .49165 .57097 L .45148 .54946 L p 0 .911 0 r
F P
0 g
s
.44187 .55489 m .45148 .54946 L .49165 .57097 L p 0 .911 0 r
F P
0 g
s
.18059 .56594 m .18061 .56599 L .17396 .57037 L p 0 .546 .889 r
F P
0 g
s
.17396 .57037 m .17393 .57032 L .18059 .56594 L p 0 .546 .889 r
F P
0 g
s
.25366 .43371 m .2537 .4337 L .26213 .42768 L p 0 1 0 r
F P
0 g
s
.26213 .42768 m .2621 .4277 L .25366 .43371 L p 0 1 0 r
F P
0 g
s
.25675 .47258 m .2621 .4277 L .26213 .42768 L p 0 .701 0 r
F P
0 g
s
.24815 .47847 m .25366 .43371 L .2537 .4337 L p 0 .702 0 r
F P
0 g
s
.24815 .47847 m .25366 .43371 L .2537 .4337 L p 0 .702 0 r
F P
0 g
s
.41796 .47258 m .41976 .42767 L .41047 .43368 L p 0 .1 0 r
F P
0 g
s
.41047 .43368 m .40847 .47847 L .41796 .47258 L p 0 .1 0 r
F P
0 g
s
.36839 .40906 m .41047 .43368 L .41976 .42767 L p 0 .903 0 r
F P
0 g
s
.41047 .43368 m .40847 .47847 L .36538 .45431 L p 0 .694 0 r
F P
0 g
s
.41047 .43368 m .36839 .40906 L .35922 .41527 L p 0 .903 0 r
F P
0 g
s
.36538 .45431 m .36839 .40906 L .41047 .43368 L p 0 .694 0 r
F P
0 g
s
.41047 .43368 m .40847 .47847 L .36538 .45431 L p 0 .694 0 r
F P
0 g
s
.36538 .45431 m .36839 .40906 L .41047 .43368 L p 0 .694 0 r
F P
0 g
s
.29705 .54238 m .34093 .56421 L .33207 .56947 L p 0 .911 0 r
F P
0 g
s
.33207 .56947 m .28823 .54789 L .29705 .54238 L p 0 .911 0 r
F P
0 g
s
.28823 .54789 m .29286 .50158 L .30152 .49594 L p 0 .1 0 r
F P
0 g
s
.29705 .54238 m .30152 .49594 L .29286 .50158 L p 0 .1 0 r
F P
0 g
s
.29286 .50158 m .28823 .54789 L .29705 .54238 L p 0 .1 0 r
F P
0 g
s
.24815 .47847 m .29286 .50158 L .30152 .49594 L p 0 .907 0 r
F P
0 g
s
.24815 .47847 m .29286 .50158 L p .24243 .52533 L 0 .702 0 r
F P
0 g
s
.24815 .47847 m .29286 .50158 L p .24243 .52533 L 0 .702 0 r
F P
0 g
s
.25675 .47258 m .30152 .49594 L .29286 .50158 L p 0 .907 0 r
F P
0 g
s
.29286 .50158 m .24815 .47847 L .25675 .47258 L p 0 .907 0 r
F P
0 g
s
.30152 .49594 m .25675 .47258 L .24815 .47847 L p 0 .907 0 r
F P
0 g
s
.25119 .51957 m .25116 .51952 L .25675 .47258 L p 0 .701 0 r
F P
0 g
s
.25675 .47258 m .30152 .49594 L p .25119 .51957 L 0 .701 0 r
F P
0 g
s
.29286 .50158 m .28823 .54789 L .24243 .52533 L p 0 .702 0 r
F P
0 g
s
.29286 .50158 m .28823 .54789 L .24243 .52533 L p 0 .702 0 r
F P
0 g
s
.37766 .54238 m .38035 .49594 L .37127 .50158 L p 0 .1 .423 r
F P
0 g
s
.37127 .50158 m .36839 .54789 L .37766 .54238 L p 0 .1 .423 r
F P
0 g
s
.32831 .47847 m .37127 .50158 L .38035 .49594 L p 0 .907 1 r
F P
0 g
s
.37127 .50158 m .36839 .54789 L .32438 .52532 L p 0 .698 .496 r
F P
0 g
s
.37127 .50158 m .32831 .47847 L .31936 .4843 L p 0 .907 1 r
F P
0 g
s
.32438 .52532 m .32831 .47847 L .37127 .50158 L p 0 .698 .496 r
F P
0 g
s
.37127 .50158 m .36839 .54789 L .32438 .52532 L p 0 .698 .496 r
F P
0 g
s
.32438 .52532 m .32831 .47847 L .37127 .50158 L p 0 .698 .496 r
F P
0 g
s
.33735 .47258 m .38035 .49594 L .37127 .50158 L p 0 .907 1 r
F P
0 g
s
.37127 .50158 m .32831 .47847 L .33735 .47258 L p 0 .907 1 r
F P
0 g
s
.32831 .47847 m .33207 .43368 L .34093 .42767 L p 0 .1 .396 r
F P
0 g
s
.33207 .43368 m .32831 .47847 L .31936 .4843 L p 0 .1 .396 r
F P
0 g
s
.33735 .47258 m .34093 .42767 L .33207 .43368 L p 0 .1 .396 r
F P
0 g
s
.33207 .43368 m .32831 .47847 L .33735 .47258 L p 0 .1 .396 r
F P
0 g
s
.28826 .40907 m .33207 .43368 L .34093 .42767 L p 0 .903 1 r
F P
0 g
s
.33207 .43368 m .32831 .47847 L .28339 .45431 L p 0 .698 .496 r
F P
0 g
s
.33207 .43368 m .28826 .40907 L .27954 .41529 L p 0 .903 1 r
F P
0 g
s
.28826 .40907 m .33207 .43368 L p .28339 .45431 L 0 .698 .496 r
F P
0 g
s
.33207 .43368 m .32831 .47847 L .28339 .45431 L p 0 .698 .496 r
F P
0 g
s
.28826 .40907 m .33207 .43368 L p .28339 .45431 L 0 .698 .496 r
F P
0 g
s
.24815 .47847 m .25366 .43371 L .2621 .4277 L p 0 .1 0 r
F P
0 g
s
.25366 .43371 m .24815 .47847 L .23965 .4843 L p 0 .1 0 r
F P
0 g
s
.25635 .76197 m .30111 .77896 L .2939 .78238 L p 0 .916 1 r
F P
0 g
s
.2939 .78238 m .24918 .76554 L .25635 .76197 L p 0 .916 1 r
F P
0 g
s
.24918 .76554 m .25467 .71443 L .2617 .71071 L p 0 .1 .425 r
F P
0 g
s
.25467 .71443 m .24918 .76554 L .24209 .76908 L p 0 .1 .425 r
F P
0 g
s
.37104 .6953 m .41313 .71369 L .42246 .7092 L p 0 .916 0 r
F P
0 g
s
.42071 .76049 m .42246 .7092 L .41313 .71369 L p 0 .114 0 r
F P
0 g
s
.41313 .71369 m .41119 .76479 L .42071 .76049 L p 0 .114 0 r
F P
0 g
s
.41313 .71369 m .37104 .6953 L .36185 .69994 L p 0 .916 0 r
F P
0 g
s
.36809 .74719 m .37104 .6953 L .41313 .71369 L p 0 .702 0 r
F P
0 g
s
.41116 .76481 m .41119 .76479 L .40177 .76905 L p 0 .1 0 r
F P
0 g
s
.41116 .76481 m .36809 .74719 L p .41313 .71369 L 0 .702 0 r
F P
0 g
s
.41313 .71369 m .41119 .76479 L .41116 .76481 L p 0 .702 0 r
F P
0 g
s
.36809 .74719 m .37104 .6953 L .41313 .71369 L p 0 .702 0 r
F P
0 g
s
.41116 .76481 m .36809 .74719 L p .41313 .71369 L 0 .702 0 r
F P
0 g
s
.41313 .71369 m .41119 .76479 L .41116 .76481 L p 0 .702 0 r
F P
0 g
s
.3309 .62577 m .37387 .64568 L .38298 .64082 L p 0 .914 0 r
F P
0 g
s
.38034 .69061 m .38298 .64082 L .37387 .64568 L p 0 .1 0 r
F P
0 g
s
.37387 .64568 m .37104 .6953 L .38034 .69061 L p 0 .1 0 r
F P
0 g
s
.37387 .64568 m .3309 .62577 L .32193 .6308 L p 0 .914 0 r
F P
0 g
s
.32703 .67607 m .3309 .62577 L .37387 .64568 L p 0 .702 0 r
F P
0 g
s
.37387 .64568 m .37104 .6953 L .36185 .69994 L p 0 .1 0 r
F P
0 g
s
.37387 .64568 m .37104 .6953 L .32703 .67607 L p 0 .702 0 r
F P
0 g
s
.32703 .67607 m .3309 .62577 L .37387 .64568 L p 0 .702 0 r
F P
0 g
s
.37387 .64568 m .37104 .6953 L .32703 .67607 L p 0 .702 0 r
F P
0 g
s
.37104 .6953 m .37387 .64568 L .38298 .64082 L p 0 .1 0 r
F P
0 g
s
.38034 .69061 m .42246 .7092 L .41313 .71369 L p 0 .916 0 r
F P
0 g
s
.41313 .71369 m .37104 .6953 L .38034 .69061 L p 0 .916 0 r
F P
0 g
s
.41119 .62577 m .45237 .64567 L .4619 .64081 L p 0 .914 1 r
F P
0 g
s
.46108 .69061 m .46193 .64086 L .45239 .64572 L p 0 .114 .472 r
F P
0 g
s
.45239 .64572 m .45133 .6953 L .46108 .69061 L p 0 .114 .472 r
F P
0 g
s
.46193 .64086 m .4619 .64081 L .45237 .64567 L p 0 .562 .887 r
F P
0 g
s
.45237 .64567 m .45239 .64572 L .46193 .64086 L p 0 .562 .887 r
F P
0 g
s
.45237 .64567 m .41119 .62577 L .40177 .6308 L p 0 .914 1 r
F P
0 g
s
.40915 .67607 m .41119 .62577 L .45237 .64567 L p 0 .698 .496 r
F P
0 g
s
.45133 .6953 m .40915 .67607 L p .45237 .64567 L 0 .698 .496 r
F P
0 g
s
.45237 .64567 m .45239 .64572 L .45133 .6953 L p 0 .698 .496 r
F P
0 g
s
.40915 .67607 m .41119 .62577 L .45237 .64567 L p 0 .698 .496 r
F P
0 g
s
.45133 .6953 m .40915 .67607 L p .45237 .64567 L 0 .698 .496 r
F P
0 g
s
.45237 .64567 m .45239 .64572 L .45133 .6953 L p 0 .698 .496 r
F P
0 g
s
.2166 .54232 m .26222 .56413 L .25655 .56767 L p 0 .911 1 r
F P
0 g
s
.25655 .56767 m .21097 .54602 L .2166 .54232 L p 0 .911 1 r
F P
0 g
s
.21097 .54602 m .21094 .54597 L .21727 .49965 L p 0 .704 .528 r
F P
0 g
s
.21094 .54597 m .21727 .49965 L .22281 .49585 L p 0 .1 .365 r
F P
0 g
s
.25851 .70941 m .25148 .71315 L .20574 .69474 L p 0 .916 1 r
F P
0 g
s
.21271 .69083 m .20574 .69474 L .2122 .6451 L p 0 .1 .396 r
F P
0 g
s
.2122 .6451 m .21904 .64105 L .21271 .69083 L p 0 .1 .396 r
F P
0 g
s
.19884 .69861 m .20574 .69474 L .25148 .71315 L p 0 .916 1 r
F P
0 g
s
.21271 .69083 m .20574 .69474 L .25148 .71315 L p 0 .916 1 r
F P
0 g
s
.25148 .71315 m .25851 .70941 L .21271 .69083 L p 0 .916 1 r
F P
0 g
s
.25851 .70941 m .25148 .71315 L .24591 .76431 L p 0 .1 .423 r
F P
0 g
s
.199 .74665 m .20574 .69474 L .25148 .71315 L p 0 .707 .545 r
F P
0 g
s
.23882 .76786 m .24591 .76431 L .25148 .71315 L p 0 .1 .423 r
F P
0 g
s
.25148 .71315 m .24591 .76431 L .199 .74665 L p 0 .707 .545 r
F P
0 g
s
.199 .74665 m .20574 .69474 L .25148 .71315 L p 0 .707 .545 r
F P
0 g
s
.25148 .71315 m .24591 .76431 L .199 .74665 L p 0 .707 .545 r
F P
0 g
s
.17239 .62094 m .16561 .62518 L .2122 .6451 L p 0 .914 1 r
F P
0 g
s
.2122 .6451 m .21904 .64105 L .17239 .62094 L p 0 .914 1 r
F P
0 g
s
.21904 .64105 m .2122 .6451 L .20574 .69474 L p 0 .1 .396 r
F P
0 g
s
.15889 .62937 m .16561 .62518 L .16557 .6252 L p 0 .93 .764 r
F P
0 g
s
.16557 .6252 m .16561 .62518 L .2122 .6451 L p 0 .707 .545 r
F P
0 g
s
.15791 .67548 m .16557 .6252 L p .2122 .6451 L 0 .707 .545 r
F P
0 g
s
.19884 .69861 m .20574 .69474 L .2122 .6451 L p 0 .1 .396 r
F P
0 g
s
.2122 .6451 m .20574 .69474 L .15791 .67548 L p 0 .707 .545 r
F P
0 g
s
.16557 .6252 m .16561 .62518 L .2122 .6451 L p 0 .707 .545 r
F P
0 g
s
.15791 .67548 m .16557 .6252 L p .2122 .6451 L 0 .707 .545 r
F P
0 g
s
.2122 .6451 m .20574 .69474 L .15791 .67548 L p 0 .707 .545 r
F P
0 g
s
.37698 .78025 m .37695 .78027 L .38308 .7775 L p 0 .1 .1 r
F P
0 g
s
.29974 .69054 m .34363 .70913 L .33765 .71215 L p 0 .916 1 r
F P
0 g
s
.33765 .71215 m .29378 .6937 L .29974 .69054 L p 0 .916 1 r
F P
0 g
s
.334 .76336 m .33765 .71215 L .34363 .70913 L p 0 .1 .45 r
F P
0 g
s
.29378 .6937 m .29831 .64402 L .30415 .64075 L p 0 .1 .425 r
F P
0 g
s
.29378 .6937 m .33765 .71215 L .34363 .70913 L p 0 .916 1 r
F P
0 g
s
.34011 .76046 m .34363 .70913 L .33765 .71215 L p 0 .1 .45 r
F P
0 g
s
.33765 .71215 m .334 .76336 L .34011 .76046 L p 0 .1 .45 r
F P
0 g
s
.28905 .74565 m .29378 .6937 L .33765 .71215 L p 0 .704 .528 r
F P
0 g
s
.33765 .71215 m .334 .76336 L .28905 .74565 L p 0 .704 .528 r
F P
0 g
s
.34011 .76046 m .38308 .7775 L .37695 .78027 L p 0 .916 1 r
F P
0 g
s
.37695 .78027 m .334 .76336 L .34011 .76046 L p 0 .916 1 r
F P
0 g
s
.51123 .56038 m .50141 .56569 L .50138 .56571 L p 0 .1 0 r
F P
0 g
s
.50141 .56569 m .50138 .56571 L .4612 .54397 L p 0 .693 0 r
F P
0 g
s
.50141 .56569 m .50138 .56571 L .4612 .54397 L p 0 .693 0 r
F P
0 g
s
.43056 .46834 m .42096 .47428 L .4227 .4294 L p 0 .1 0 r
F P
0 g
s
.4227 .4294 m .4321 .42335 L .43056 .46834 L p 0 .1 0 r
F P
0 g
s
.41147 .48016 m .42096 .47428 L .46205 .49757 L p 0 .907 0 r
F P
0 g
s
.43056 .46834 m .42096 .47428 L .46205 .49757 L p 0 .907 0 r
F P
0 g
s
.46205 .49757 m .47167 .49188 L .43056 .46834 L p 0 .907 0 r
F P
0 g
s
.47167 .49188 m .46205 .49757 L .4612 .54397 L p 0 .1 0 r
F P
0 g
s
.45148 .54946 m .4612 .54397 L .46205 .49757 L p 0 .1 0 r
F P
0 g
s
.46205 .49757 m .4612 .54397 L .41915 .52122 L p 0 .693 0 r
F P
0 g
s
.41915 .52122 m .42096 .47428 L .46205 .49757 L p 0 .693 0 r
F P
0 g
s
.46205 .49757 m .4612 .54397 L .41915 .52122 L p 0 .693 0 r
F P
0 g
s
.41915 .52122 m .42096 .47428 L .46205 .49757 L p 0 .693 0 r
F P
0 g
s
.47167 .49188 m .46205 .49757 L .42096 .47428 L p 0 .907 0 r
F P
0 g
s
.47103 .53842 m .4612 .54397 L .46205 .49757 L p 0 .1 0 r
F P
0 g
s
.46205 .49757 m .47167 .49188 L .47103 .53842 L p 0 .1 0 r
F P
0 g
s
.3901 .53842 m .38073 .54397 L .38335 .49757 L p 0 .1 .425 r
F P
0 g
s
.38335 .49757 m .39253 .49188 L .3901 .53842 L p 0 .1 .425 r
F P
0 g
s
.4321 .56042 m .4227 .56573 L .38073 .54397 L p 0 .911 1 r
F P
0 g
s
.37146 .54946 m .38073 .54397 L .4227 .56573 L p 0 .911 1 r
F P
0 g
s
.47103 .39825 m .4612 .40459 L .50141 .4294 L p 0 .903 1 r
F P
0 g
s
.50141 .4294 m .51123 .42335 L .47103 .39825 L p 0 .903 1 r
F P
0 g
s
.51123 .42335 m .50141 .4294 L .50144 .47428 L p 0 .1 .45 r
F P
0 g
s
.4915 .48016 m .50144 .47428 L .50141 .4294 L p 0 .1 .45 r
F P
0 g
s
.50141 .4294 m .50144 .47428 L .46031 .44993 L p 0 .687 .449 r
F P
0 g
s
.46031 .44993 m .4612 .40459 L .50141 .4294 L p 0 .687 .449 r
F P
0 g
s
.50141 .4294 m .50144 .47428 L .46031 .44993 L p 0 .687 .449 r
F P
0 g
s
.46031 .44993 m .4612 .40459 L .50141 .4294 L p 0 .687 .449 r
F P
0 g
s
.51149 .46834 m .50144 .47428 L .50141 .4294 L p 0 .1 .45 r
F P
0 g
s
.50141 .4294 m .51123 .42335 L .51149 .46834 L p 0 .1 .45 r
F P
0 g
s
.51149 .46834 m .50144 .47428 L .54076 .49757 L p 0 .907 1 r
F P
0 g
s
.54076 .49757 m .5508 .49188 L .51149 .46834 L p 0 .907 1 r
F P
0 g
s
.5508 .49188 m .54076 .49757 L .54167 .54394 L p 0 .114 .472 r
F P
0 g
s
.53151 .54943 m .54167 .54394 L .54076 .49757 L p 0 .114 .472 r
F P
0 g
s
.54076 .49757 m .54167 .54394 L p .50147 .52122 L 0 .687 .449 r
F P
0 g
s
.4915 .48016 m .50144 .47428 L .54076 .49757 L p 0 .907 1 r
F P
0 g
s
.50147 .52122 m .50144 .47428 L .54076 .49757 L p 0 .687 .449 r
F P
0 g
s
.54076 .49757 m .54167 .54394 L p .50147 .52122 L 0 .687 .449 r
F P
0 g
s
.50147 .52122 m .50144 .47428 L .54076 .49757 L p 0 .687 .449 r
F P
0 g
s
.5508 .49188 m .54076 .49757 L .50144 .47428 L p 0 .907 1 r
F P
0 g
s
.57152 .48016 m .58191 .47428 L .58011 .42944 L p 0 .114 0 r
F P
0 g
s
.58011 .42944 m .58191 .47428 L .54263 .44993 L p 0 .681 0 r
F P
0 g
s
.58009 .42939 m .58011 .42944 L p .54263 .44993 L 0 .681 0 r
F P
0 g
s
.54263 .44993 m .54167 .40459 L .58009 .42939 L p 0 .681 0 r
F P
0 g
s
.58009 .42939 m .58011 .42944 L .59037 .42338 L p 0 .575 0 r
F P
0 g
s
.58011 .42944 m .58191 .47428 L .59241 .46834 L p 0 .114 0 r
F P
0 g
s
.59241 .46834 m .59037 .42338 L .58011 .42944 L p 0 .114 0 r
F P
0 g
s
.58191 .47428 m .58011 .42944 L .58009 .42939 L p 0 .681 0 r
F P
0 g
s
.54167 .40459 m .58009 .42939 L .59035 .42333 L p 0 .903 0 r
F P
0 g
s
.59037 .42338 m .59035 .42333 L .58009 .42939 L p 0 .575 0 r
F P
0 g
s
.58009 .42939 m .54167 .40459 L p .58191 .47428 L 0 .681 0 r
F P
0 g
s
.50138 .56571 m .51121 .5604 L .51123 .56038 L p 0 .1 0 r
F P
0 g
s
.51121 .5604 m .50138 .56571 L .4612 .54397 L p 0 .911 0 r
F P
0 g
s
.45148 .54946 m .4612 .54397 L .50138 .56571 L p 0 .911 0 r
F P
0 g
s
.25609 .61914 m .25029 .62257 L .29518 .64262 L p 0 .914 1 r
F P
0 g
s
.29518 .64262 m .30102 .63934 L .25609 .61914 L p 0 .914 1 r
F P
0 g
s
.30102 .63934 m .29518 .64262 L .29058 .69235 L p 0 .1 .423 r
F P
0 g
s
.24455 .67298 m .25029 .62257 L .29518 .64262 L p 0 .704 .528 r
F P
0 g
s
.29518 .64262 m .29058 .69235 L .24455 .67298 L p 0 .704 .528 r
F P
0 g
s
.2617 .71071 m .25635 .76197 L .24918 .76554 L p 0 .1 .425 r
F P
0 g
s
.2621 .4277 m .26213 .42768 L .27067 .42161 L p 0 1 0 r
F P
0 g
s
.25675 .47258 m .2621 .4277 L .26213 .42768 L p 0 .701 0 r
F P
0 g
s
.30597 .53681 m .31026 .49023 L .30152 .49594 L p 0 .1 0 r
F P
0 g
s
.30152 .49594 m .29705 .54238 L .30597 .53681 L p 0 .1 0 r
F P
0 g
s
.30152 .49594 m .29705 .54238 L .28823 .54789 L p 0 .1 0 r
F P
0 g
s
.30152 .49594 m .29705 .54238 L .25119 .51957 L p 0 .701 0 r
F P
0 g
s
.29705 .54238 m .30152 .49594 L .31026 .49023 L p 0 .1 0 r
F P
0 g
s
.42756 .46662 m .42916 .42159 L .41976 .42767 L p 0 .1 0 r
F P
0 g
s
.41976 .42767 m .41796 .47258 L .42756 .46662 L p 0 .1 0 r
F P
0 g
s
.37766 .40277 m .41976 .42767 L .42916 .42159 L p 0 .903 0 r
F P
0 g
s
.41976 .42767 m .41796 .47258 L .37484 .44814 L p 0 .693 0 r
F P
0 g
s
.41976 .42767 m .37766 .40277 L .36839 .40906 L p 0 .903 0 r
F P
0 g
s
.37484 .44814 m .37766 .40277 L .41976 .42767 L p 0 .693 0 r
F P
0 g
s
.41976 .42767 m .41796 .47258 L .37484 .44814 L p 0 .693 0 r
F P
0 g
s
.37484 .44814 m .37766 .40277 L .41976 .42767 L p 0 .693 0 r
F P
0 g
s
.30152 .49594 m .29705 .54238 L .25119 .51957 L p 0 .701 0 r
F P
0 g
s
.25675 .47258 m .30152 .49594 L p .25119 .51957 L 0 .701 0 r
F P
0 g
s
.29705 .54238 m .25119 .51957 L .26005 .51374 L p 0 .911 0 r
F P
0 g
s
.31026 .49023 m .30597 .53681 L .29705 .54238 L p 0 .1 0 r
F P
0 g
s
.26005 .51374 m .30597 .53681 L .29705 .54238 L p 0 .911 0 r
F P
0 g
s
.38703 .53681 m .38953 .49023 L .38035 .49594 L p 0 .1 .423 r
F P
0 g
s
.38035 .49594 m .37766 .54238 L .38703 .53681 L p 0 .1 .423 r
F P
0 g
s
.33735 .47258 m .38035 .49594 L .38953 .49023 L p 0 .907 1 r
F P
0 g
s
.38035 .49594 m .37766 .54238 L .33361 .51955 L p 0 .697 .491 r
F P
0 g
s
.38035 .49594 m .33735 .47258 L .32831 .47847 L p 0 .907 1 r
F P
0 g
s
.33361 .51955 m .33735 .47258 L .38035 .49594 L p 0 .697 .491 r
F P
0 g
s
.38035 .49594 m .37766 .54238 L .33361 .51955 L p 0 .697 .491 r
F P
0 g
s
.33361 .51955 m .33735 .47258 L .38035 .49594 L p 0 .697 .491 r
F P
0 g
s
.3465 .46662 m .38953 .49023 L .38035 .49594 L p 0 .907 1 r
F P
0 g
s
.38035 .49594 m .33735 .47258 L .3465 .46662 L p 0 .907 1 r
F P
0 g
s
.33735 .47258 m .34093 .42767 L .3499 .42159 L p 0 .1 .396 r
F P
0 g
s
.34093 .42767 m .33735 .47258 L .32831 .47847 L p 0 .1 .396 r
F P
0 g
s
.3465 .46662 m .3499 .42159 L .34093 .42767 L p 0 .1 .396 r
F P
0 g
s
.34093 .42767 m .33735 .47258 L .3465 .46662 L p 0 .1 .396 r
F P
0 g
s
.29709 .40279 m .34093 .42767 L .3499 .42159 L p 0 .903 1 r
F P
0 g
s
.34093 .42767 m .33735 .47258 L .29238 .44814 L p 0 .697 .491 r
F P
0 g
s
.34093 .42767 m .29709 .40279 L .28826 .40907 L p 0 .903 1 r
F P
0 g
s
.29709 .40279 m .34093 .42767 L p .29238 .44814 L 0 .697 .491 r
F P
0 g
s
.34093 .42767 m .33735 .47258 L .29238 .44814 L p 0 .697 .491 r
F P
0 g
s
.29709 .40279 m .34093 .42767 L p .29238 .44814 L 0 .697 .491 r
F P
0 g
s
.27067 .42161 m .27063 .42162 L .2621 .4277 L p 0 1 0 r
F P
0 g
s
.25675 .47258 m .2621 .4277 L .27063 .42162 L p 0 .1 0 r
F P
0 g
s
.2621 .4277 m .25675 .47258 L .24815 .47847 L p 0 .1 0 r
F P
0 g
s
.22228 .53858 m .26794 .56056 L .26222 .56413 L p 0 .911 1 r
F P
0 g
s
.26222 .56413 m .2166 .54232 L .22228 .53858 L p 0 .911 1 r
F P
0 g
s
.2166 .54232 m .21658 .54227 L .22281 .49585 L p 0 .704 .526 r
F P
0 g
s
.2166 .54232 m .21658 .54227 L .22281 .49585 L p 0 .704 .526 r
F P
0 g
s
.21658 .54227 m .22281 .49585 L .22838 .49203 L p 0 .1 .365 r
F P
0 g
s
.22281 .49585 m .21658 .54227 L .21094 .54597 L p 0 .1 .365 r
F P
0 g
s
.19208 .55838 m .19211 .55843 L .18409 .56371 L p 0 .546 0 r
F P
0 g
s
.18409 .56371 m .18406 .56366 L .19208 .55838 L p 0 .546 0 r
F P
0 g
s
.20574 .69474 m .21271 .69083 L .25851 .70941 L p 0 .916 1 r
F P
0 g
s
.24591 .76431 m .25307 .76073 L .25851 .70941 L p 0 .1 .423 r
F P
0 g
s
.2061 .7429 m .21271 .69083 L .25851 .70941 L p 0 .707 .542 r
F P
0 g
s
.25851 .70941 m .25307 .76073 L .2061 .7429 L p 0 .707 .542 r
F P
0 g
s
.20574 .69474 m .21271 .69083 L .21904 .64105 L p 0 .1 .396 r
F P
0 g
s
.16561 .62518 m .17239 .62094 L .17235 .62096 L p 0 .93 .764 r
F P
0 g
s
.17235 .62096 m .17239 .62094 L .21904 .64105 L p 0 .707 .542 r
F P
0 g
s
.16481 .67139 m .17235 .62096 L p .21904 .64105 L 0 .707 .542 r
F P
0 g
s
.21904 .64105 m .21271 .69083 L .16481 .67139 L p 0 .707 .542 r
F P
0 g
s
.33998 .62069 m .38298 .64082 L .39219 .63591 L p 0 .914 0 r
F P
0 g
s
.38975 .68586 m .39219 .63591 L .38298 .64082 L p 0 .1 0 r
F P
0 g
s
.38298 .64082 m .38034 .69061 L .38975 .68586 L p 0 .1 0 r
F P
0 g
s
.38298 .64082 m .33998 .62069 L .3309 .62577 L p 0 .914 0 r
F P
0 g
s
.33629 .67116 m .33998 .62069 L .38298 .64082 L p 0 .701 0 r
F P
0 g
s
.38298 .64082 m .38034 .69061 L .37104 .6953 L p 0 .1 0 r
F P
0 g
s
.38298 .64082 m .38034 .69061 L .33629 .67116 L p 0 .701 0 r
F P
0 g
s
.38034 .69061 m .38298 .64082 L .39219 .63591 L p 0 .1 0 r
F P
0 g
s
.38975 .68586 m .43188 .70466 L .42246 .7092 L p 0 .916 0 r
F P
0 g
s
.42246 .7092 m .38034 .69061 L .38975 .68586 L p 0 .916 0 r
F P
0 g
s
.38034 .69061 m .42246 .7092 L .43188 .70466 L p 0 .916 0 r
F P
0 g
s
.43034 .75613 m .43188 .70466 L .42246 .7092 L p 0 .114 0 r
F P
0 g
s
.42246 .7092 m .42071 .76049 L .43034 .75613 L p 0 .114 0 r
F P
0 g
s
.42246 .7092 m .38034 .69061 L .37104 .6953 L p 0 .916 0 r
F P
0 g
s
.37758 .74268 m .38034 .69061 L .42246 .7092 L p 0 .701 0 r
F P
0 g
s
.42068 .76051 m .42071 .76049 L .41119 .76479 L p 0 .1 0 r
F P
0 g
s
.42068 .76051 m .37758 .74268 L p .42246 .7092 L 0 .701 0 r
F P
0 g
s
.42246 .7092 m .42071 .76049 L .42068 .76051 L p 0 .701 0 r
F P
0 g
s
.33629 .67116 m .33998 .62069 L .38298 .64082 L p 0 .701 0 r
F P
0 g
s
.38298 .64082 m .38034 .69061 L .33629 .67116 L p 0 .701 0 r
F P
0 g
s
.37758 .74268 m .38034 .69061 L .42246 .7092 L p 0 .701 0 r
F P
0 g
s
.42068 .76051 m .37758 .74268 L p .42246 .7092 L 0 .701 0 r
F P
0 g
s
.42246 .7092 m .42071 .76049 L .42068 .76051 L p 0 .701 0 r
F P
0 g
s
.47093 .68586 m .47158 .63594 L .46193 .64086 L p 0 .114 .472 r
F P
0 g
s
.46193 .64086 m .46108 .69061 L .47093 .68586 L p 0 .114 .472 r
F P
0 g
s
.4619 .64081 m .46193 .64086 L .47158 .63594 L p 0 .562 .887 r
F P
0 g
s
.4619 .64081 m .46193 .64086 L .46108 .69061 L p 0 .697 .491 r
F P
0 g
s
.4619 .64081 m .46193 .64086 L .46108 .69061 L p 0 .697 .491 r
F P
0 g
s
.42071 .62069 m .4619 .64081 L .47155 .63589 L p 0 .914 1 r
F P
0 g
s
.47158 .63594 m .47155 .63589 L .4619 .64081 L p 0 .562 .887 r
F P
0 g
s
.4619 .64081 m .42071 .62069 L .41119 .62577 L p 0 .914 1 r
F P
0 g
s
.41888 .67116 m .42071 .62069 L .4619 .64081 L p 0 .697 .491 r
F P
0 g
s
.46108 .69061 m .41888 .67116 L p .4619 .64081 L 0 .697 .491 r
F P
0 g
s
.41888 .67116 m .42071 .62069 L .4619 .64081 L p 0 .697 .491 r
F P
0 g
s
.46108 .69061 m .41888 .67116 L p .4619 .64081 L 0 .697 .491 r
F P
0 g
s
.38311 .77748 m .38308 .7775 L .38925 .77471 L p 0 .1 .1 r
F P
0 g
s
.29974 .69054 m .30415 .64075 L .31003 .63746 L p 0 .1 .425 r
F P
0 g
s
.30574 .68736 m .34966 .70609 L .34363 .70913 L p 0 .916 1 r
F P
0 g
s
.34363 .70913 m .29974 .69054 L .30574 .68736 L p 0 .916 1 r
F P
0 g
s
.30415 .64075 m .29974 .69054 L .29378 .6937 L p 0 .1 .425 r
F P
0 g
s
.29974 .69054 m .34363 .70913 L .34966 .70609 L p 0 .916 1 r
F P
0 g
s
.34626 .75754 m .34966 .70609 L .34363 .70913 L p 0 .1 .45 r
F P
0 g
s
.34363 .70913 m .34011 .76046 L .34626 .75754 L p 0 .1 .45 r
F P
0 g
s
.34363 .70913 m .29974 .69054 L .29378 .6937 L p 0 .916 1 r
F P
0 g
s
.29512 .74262 m .29974 .69054 L .34363 .70913 L p 0 .704 .526 r
F P
0 g
s
.34363 .70913 m .34011 .76046 L .334 .76336 L p 0 .1 .45 r
F P
0 g
s
.34363 .70913 m .34011 .76046 L .29512 .74262 L p 0 .704 .526 r
F P
0 g
s
.29512 .74262 m .29974 .69054 L .34363 .70913 L p 0 .704 .526 r
F P
0 g
s
.34363 .70913 m .34011 .76046 L .29512 .74262 L p 0 .704 .526 r
F P
0 g
s
.34011 .76046 m .34363 .70913 L .34966 .70609 L p 0 .1 .45 r
F P
0 g
s
.34626 .75754 m .38925 .77471 L .38308 .7775 L p 0 .916 1 r
F P
0 g
s
.38308 .7775 m .34011 .76046 L .34626 .75754 L p 0 .916 1 r
F P
0 g
s
.26873 .75579 m .31357 .77305 L .30487 .77717 L p 0 .916 0 r
F P
0 g
s
.30487 .77717 m .26008 .7601 L .26873 .75579 L p 0 .916 0 r
F P
0 g
s
.26008 .7601 m .26537 .70876 L .27385 .70426 L p 0 .1 0 r
F P
0 g
s
.26194 .61569 m .25609 .61914 L .30102 .63934 L p 0 .914 1 r
F P
0 g
s
.30102 .63934 m .3069 .63604 L .26194 .61569 L p 0 .914 1 r
F P
0 g
s
.3069 .63604 m .30102 .63934 L .29653 .68918 L p 0 .1 .423 r
F P
0 g
s
.25046 .66966 m .25609 .61914 L .30102 .63934 L p 0 .704 .526 r
F P
0 g
s
.29058 .69235 m .29653 .68918 L .30102 .63934 L p 0 .1 .423 r
F P
0 g
s
.30102 .63934 m .29653 .68918 L .25046 .66966 L p 0 .704 .526 r
F P
0 g
s
.25046 .66966 m .25609 .61914 L .30102 .63934 L p 0 .704 .526 r
F P
0 g
s
.30102 .63934 m .29653 .68918 L .25046 .66966 L p 0 .704 .526 r
F P
0 g
s
.27065 .70295 m .26218 .70746 L .21635 .68879 L p 0 .916 0 r
F P
0 g
s
.22477 .68407 m .21635 .68879 L .26218 .70746 L p 0 .916 0 r
F P
0 g
s
.26218 .70746 m .27065 .70295 L .22477 .68407 L p 0 .916 0 r
F P
0 g
s
.27065 .70295 m .26218 .70746 L .25681 .75885 L p 0 .1 0 r
F P
0 g
s
.2098 .74094 m .21635 .68879 L .26218 .70746 L p 0 .706 0 r
F P
0 g
s
.26218 .70746 m .25681 .75885 L .2098 .74094 L p 0 .706 0 r
F P
0 g
s
.22477 .68407 m .21635 .68879 L .22262 .63894 L p 0 .1 0 r
F P
0 g
s
.22262 .63894 m .23088 .63405 L .22477 .68407 L p 0 .1 0 r
F P
0 g
s
.18412 .61363 m .17594 .61873 L .22262 .63894 L p 0 .914 0 r
F P
0 g
s
.22262 .63894 m .23088 .63405 L .18412 .61363 L p 0 .914 0 r
F P
0 g
s
.23088 .63405 m .22262 .63894 L .21635 .68879 L p 0 .1 0 r
F P
0 g
s
.1759 .61875 m .17594 .61873 L .22262 .63894 L p 0 .706 0 r
F P
0 g
s
.16842 .66925 m .1759 .61875 L p .22262 .63894 L 0 .706 0 r
F P
0 g
s
.22262 .63894 m .21635 .68879 L .16842 .66925 L p 0 .706 0 r
F P
0 g
s
.228 .53482 m .2737 .55696 L .26794 .56056 L p 0 .911 1 r
F P
0 g
s
.26794 .56056 m .22228 .53858 L .228 .53482 L p 0 .911 1 r
F P
0 g
s
.22228 .53858 m .22225 .53853 L .22838 .49203 L p 0 .704 .523 r
F P
0 g
s
.22228 .53858 m .22225 .53853 L .22838 .49203 L p 0 .704 .523 r
F P
0 g
s
.22225 .53853 m .22838 .49203 L .23399 .48818 L p 0 .1 .365 r
F P
0 g
s
.22838 .49203 m .22225 .53853 L .21658 .54227 L p 0 .1 .365 r
F P
0 g
s
.52117 .55501 m .51123 .56038 L .51121 .5604 L p 0 .1 0 r
F P
0 g
s
.51123 .56038 m .51121 .5604 L .47103 .53842 L p 0 .692 0 r
F P
0 g
s
.51123 .56038 m .51121 .5604 L .47103 .53842 L p 0 .692 0 r
F P
0 g
s
.44027 .46233 m .43056 .46834 L .47167 .49188 L p 0 .907 0 r
F P
0 g
s
.47167 .49188 m .48139 .48614 L .44027 .46233 L p 0 .907 0 r
F P
0 g
s
.48139 .48614 m .47167 .49188 L .47103 .53842 L p 0 .1 0 r
F P
0 g
s
.4612 .54397 m .47103 .53842 L .47167 .49188 L p 0 .1 0 r
F P
0 g
s
.47167 .49188 m .47103 .53842 L .42896 .51541 L p 0 .692 0 r
F P
0 g
s
.42096 .47428 m .43056 .46834 L .47167 .49188 L p 0 .907 0 r
F P
0 g
s
.42896 .51541 m .43056 .46834 L .47167 .49188 L p 0 .692 0 r
F P
0 g
s
.47167 .49188 m .47103 .53842 L .42896 .51541 L p 0 .692 0 r
F P
0 g
s
.42896 .51541 m .43056 .46834 L .47167 .49188 L p 0 .692 0 r
F P
0 g
s
.48139 .48614 m .47167 .49188 L .43056 .46834 L p 0 .907 0 r
F P
0 g
s
.44027 .46233 m .43056 .46834 L .4321 .42335 L p 0 .1 0 r
F P
0 g
s
.4321 .42335 m .4416 .41722 L .44027 .46233 L p 0 .1 0 r
F P
0 g
s
.48096 .53281 m .47103 .53842 L .47167 .49188 L p 0 .1 0 r
F P
0 g
s
.47167 .49188 m .48139 .48614 L .48096 .53281 L p 0 .1 0 r
F P
0 g
s
.4416 .55505 m .4321 .56042 L .3901 .53842 L p 0 .911 1 r
F P
0 g
s
.39958 .53281 m .3901 .53842 L .39253 .49188 L p 0 .1 .425 r
F P
0 g
s
.39253 .49188 m .40181 .48614 L .39958 .53281 L p 0 .1 .425 r
F P
0 g
s
.38073 .54397 m .3901 .53842 L .4321 .56042 L p 0 .911 1 r
F P
0 g
s
.48096 .39185 m .47103 .39825 L .51123 .42335 L p 0 .903 1 r
F P
0 g
s
.51123 .42335 m .52117 .41722 L .48096 .39185 L p 0 .903 1 r
F P
0 g
s
.52117 .41722 m .51123 .42335 L .51149 .46834 L p 0 .1 .45 r
F P
0 g
s
.50144 .47428 m .51149 .46834 L .51123 .42335 L p 0 .1 .45 r
F P
0 g
s
.51123 .42335 m .51149 .46834 L .47036 .44371 L p 0 .686 .443 r
F P
0 g
s
.47036 .44371 m .47103 .39825 L .51123 .42335 L p 0 .686 .443 r
F P
0 g
s
.51123 .42335 m .51149 .46834 L .47036 .44371 L p 0 .686 .443 r
F P
0 g
s
.47036 .44371 m .47103 .39825 L .51123 .42335 L p 0 .686 .443 r
F P
0 g
s
.52165 .46233 m .51149 .46834 L .51123 .42335 L p 0 .1 .45 r
F P
0 g
s
.51123 .42335 m .52117 .41722 L .52165 .46233 L p 0 .1 .45 r
F P
0 g
s
.52165 .46233 m .51149 .46834 L .5508 .49188 L p 0 .907 1 r
F P
0 g
s
.5508 .49188 m .56096 .48614 L .52165 .46233 L p 0 .907 1 r
F P
0 g
s
.56096 .48614 m .5508 .49188 L .55195 .53839 L p 0 .114 .472 r
F P
0 g
s
.54167 .54394 m .55195 .53839 L .5508 .49188 L p 0 .114 .472 r
F P
0 g
s
.5508 .49188 m .55195 .53839 L p .51175 .51541 L 0 .686 .443 r
F P
0 g
s
.50144 .47428 m .51149 .46834 L .5508 .49188 L p 0 .907 1 r
F P
0 g
s
.51175 .51541 m .51149 .46834 L .5508 .49188 L p 0 .686 .443 r
F P
0 g
s
.5508 .49188 m .55195 .53839 L p .51175 .51541 L 0 .686 .443 r
F P
0 g
s
.51175 .51541 m .51149 .46834 L .5508 .49188 L p 0 .686 .443 r
F P
0 g
s
.56096 .48614 m .5508 .49188 L .51149 .46834 L p 0 .907 1 r
F P
0 g
s
.59241 .46834 m .59037 .42338 L .59035 .42333 L p 0 .679 0 r
F P
0 g
s
.59035 .42333 m .59037 .42338 L .60075 .41725 L p 0 .575 0 r
F P
0 g
s
.59037 .42338 m .59241 .46834 L .60303 .46233 L p 0 .114 0 r
F P
0 g
s
.60303 .46233 m .60075 .41725 L .59037 .42338 L p 0 .114 0 r
F P
0 g
s
.59241 .46834 m .59037 .42338 L .59035 .42333 L p 0 .679 0 r
F P
0 g
s
.59035 .42333 m .55195 .39825 L .54167 .40459 L p 0 .903 0 r
F P
0 g
s
.59035 .42333 m .55195 .39825 L p .59241 .46834 L 0 .679 0 r
F P
0 g
s
.55195 .39825 m .59035 .42333 L .60072 .4172 L p 0 .903 0 r
F P
0 g
s
.60075 .41725 m .60072 .4172 L .59035 .42333 L p 0 .575 0 r
F P
0 g
s
.59035 .42333 m .55195 .39825 L p .59241 .46834 L 0 .679 0 r
F P
0 g
s
.51121 .5604 m .52114 .55503 L .52117 .55501 L p 0 .1 0 r
F P
0 g
s
.52114 .55503 m .51121 .5604 L .47103 .53842 L p 0 .911 0 r
F P
0 g
s
.4612 .54397 m .47103 .53842 L .51121 .5604 L p 0 .911 0 r
F P
0 g
s
.38929 .77469 m .38925 .77471 L .39547 .7719 L p 0 .1 .1 r
F P
0 g
s
.30574 .68736 m .31003 .63746 L .31596 .63414 L p 0 .1 .425 r
F P
0 g
s
.31178 .68415 m .35573 .70303 L .34966 .70609 L p 0 .916 1 r
F P
0 g
s
.34966 .70609 m .30574 .68736 L .31178 .68415 L p 0 .916 1 r
F P
0 g
s
.31003 .63746 m .30574 .68736 L .29974 .69054 L p 0 .1 .425 r
F P
0 g
s
.30574 .68736 m .34966 .70609 L .35573 .70303 L p 0 .916 1 r
F P
0 g
s
.35246 .7546 m .35573 .70303 L .34966 .70609 L p 0 .1 .45 r
F P
0 g
s
.34966 .70609 m .34626 .75754 L .35246 .7546 L p 0 .1 .45 r
F P
0 g
s
.34966 .70609 m .30574 .68736 L .29974 .69054 L p 0 .916 1 r
F P
0 g
s
.30124 .73956 m .30574 .68736 L .34966 .70609 L p 0 .704 .523 r
F P
0 g
s
.34966 .70609 m .34626 .75754 L .34011 .76046 L p 0 .1 .45 r
F P
0 g
s
.34966 .70609 m .34626 .75754 L .30124 .73956 L p 0 .704 .523 r
F P
0 g
s
.30124 .73956 m .30574 .68736 L .34966 .70609 L p 0 .704 .523 r
F P
0 g
s
.34966 .70609 m .34626 .75754 L .30124 .73956 L p 0 .704 .523 r
F P
0 g
s
.34626 .75754 m .34966 .70609 L .35573 .70303 L p 0 .1 .45 r
F P
0 g
s
.35246 .7546 m .39547 .7719 L .38925 .77471 L p 0 .916 1 r
F P
0 g
s
.38925 .77471 m .34626 .75754 L .35246 .7546 L p 0 .916 1 r
F P
0 g
s
.27063 .42162 m .27067 .42161 L .27929 .41547 L p 0 1 0 r
F P
0 g
s
.26545 .46662 m .27063 .42162 L .27067 .42161 L p 0 .7 0 r
F P
0 g
s
.26545 .46662 m .27063 .42162 L .27067 .42161 L p 0 .7 0 r
F P
0 g
s
.31499 .53118 m .35896 .55349 L .3499 .55888 L p 0 .911 0 r
F P
0 g
s
.3499 .55888 m .30597 .53681 L .31499 .53118 L p 0 .911 0 r
F P
0 g
s
.30597 .53681 m .31026 .49023 L .31911 .48447 L p 0 .1 0 r
F P
0 g
s
.31499 .53118 m .31911 .48447 L .31026 .49023 L p 0 .1 0 r
F P
0 g
s
.31026 .49023 m .30597 .53681 L .31499 .53118 L p 0 .1 0 r
F P
0 g
s
.26545 .46662 m .31026 .49023 L .31911 .48447 L p 0 .907 0 r
F P
0 g
s
.31026 .49023 m .30597 .53681 L .26005 .51374 L p 0 .7 0 r
F P
0 g
s
.26545 .46662 m .31026 .49023 L p .26005 .51374 L 0 .7 0 r
F P
0 g
s
.31026 .49023 m .30597 .53681 L .26005 .51374 L p 0 .7 0 r
F P
0 g
s
.26545 .46662 m .31026 .49023 L p .26005 .51374 L 0 .7 0 r
F P
0 g
s
.27424 .46059 m .31911 .48447 L .31026 .49023 L p 0 .907 0 r
F P
0 g
s
.31026 .49023 m .26545 .46662 L .27424 .46059 L p 0 .907 0 r
F P
0 g
s
.43726 .46059 m .43866 .41545 L .42916 .42159 L p 0 .1 0 r
F P
0 g
s
.42916 .42159 m .42756 .46662 L .43726 .46059 L p 0 .1 0 r
F P
0 g
s
.38703 .39642 m .42916 .42159 L .43866 .41545 L p 0 .903 0 r
F P
0 g
s
.42916 .42159 m .42756 .46662 L .38441 .4419 L p 0 .692 0 r
F P
0 g
s
.42916 .42159 m .38703 .39642 L .37766 .40277 L p 0 .903 0 r
F P
0 g
s
.38441 .4419 m .38703 .39642 L .42916 .42159 L p 0 .692 0 r
F P
0 g
s
.42916 .42159 m .42756 .46662 L .38441 .4419 L p 0 .692 0 r
F P
0 g
s
.38441 .4419 m .38703 .39642 L .42916 .42159 L p 0 .692 0 r
F P
0 g
s
.38953 .49023 m .3465 .46662 L .33735 .47258 L p 0 .907 1 r
F P
0 g
s
.39651 .53118 m .39881 .48447 L .38953 .49023 L p 0 .1 .423 r
F P
0 g
s
.38953 .49023 m .38703 .53681 L .39651 .53118 L p 0 .1 .423 r
F P
0 g
s
.3465 .46662 m .38953 .49023 L .39881 .48447 L p 0 .907 1 r
F P
0 g
s
.38953 .49023 m .38703 .53681 L .34295 .51372 L p 0 .696 .486 r
F P
0 g
s
.34295 .51372 m .3465 .46662 L .38953 .49023 L p 0 .696 .486 r
F P
0 g
s
.38953 .49023 m .38703 .53681 L .34295 .51372 L p 0 .696 .486 r
F P
0 g
s
.34295 .51372 m .3465 .46662 L .38953 .49023 L p 0 .696 .486 r
F P
0 g
s
.35575 .46059 m .39881 .48447 L .38953 .49023 L p 0 .907 1 r
F P
0 g
s
.38953 .49023 m .3465 .46662 L .35575 .46059 L p 0 .907 1 r
F P
0 g
s
.3465 .46662 m .3499 .42159 L .35896 .41545 L p 0 .1 .396 r
F P
0 g
s
.3499 .42159 m .3465 .46662 L .33735 .47258 L p 0 .1 .396 r
F P
0 g
s
.35575 .46059 m .35896 .41545 L .3499 .42159 L p 0 .1 .396 r
F P
0 g
s
.3499 .42159 m .3465 .46662 L .35575 .46059 L p 0 .1 .396 r
F P
0 g
s
.30601 .39644 m .3499 .42159 L .35896 .41545 L p 0 .903 1 r
F P
0 g
s
.3499 .42159 m .3465 .46662 L .30148 .4419 L p 0 .696 .486 r
F P
0 g
s
.3499 .42159 m .30601 .39644 L .29709 .40279 L p 0 .903 1 r
F P
0 g
s
.30601 .39644 m .3499 .42159 L p .30148 .4419 L 0 .696 .486 r
F P
0 g
s
.3499 .42159 m .3465 .46662 L .30148 .4419 L p 0 .696 .486 r
F P
0 g
s
.30601 .39644 m .3499 .42159 L p .30148 .4419 L 0 .696 .486 r
F P
0 g
s
.27929 .41547 m .27925 .41548 L .27063 .42162 L p 0 1 0 r
F P
0 g
s
.26545 .46662 m .27063 .42162 L .27925 .41548 L p 0 .1 0 r
F P
0 g
s
.27063 .42162 m .26545 .46662 L .25675 .47258 L p 0 .1 0 r
F P
0 g
s
.20019 .55304 m .20022 .55309 L .19211 .55843 L p 0 .546 0 r
F P
0 g
s
.19211 .55843 m .19208 .55838 L .20019 .55304 L p 0 .546 0 r
F P
0 g
s
.26782 .61221 m .26194 .61569 L .3069 .63604 L p 0 .914 1 r
F P
0 g
s
.3069 .63604 m .31282 .63271 L .26782 .61221 L p 0 .914 1 r
F P
0 g
s
.31282 .63271 m .3069 .63604 L .30252 .68599 L p 0 .1 .423 r
F P
0 g
s
.25642 .66632 m .26194 .61569 L .3069 .63604 L p 0 .704 .523 r
F P
0 g
s
.29653 .68918 m .30252 .68599 L .3069 .63604 L p 0 .1 .423 r
F P
0 g
s
.3069 .63604 m .30252 .68599 L .25642 .66632 L p 0 .704 .523 r
F P
0 g
s
.25642 .66632 m .26194 .61569 L .3069 .63604 L p 0 .704 .523 r
F P
0 g
s
.3069 .63604 m .30252 .68599 L .25642 .66632 L p 0 .704 .523 r
F P
0 g
s
.34915 .61555 m .39219 .63591 L .4015 .63094 L p 0 .914 0 r
F P
0 g
s
.39925 .68106 m .4015 .63094 L .39219 .63591 L p 0 .1 0 r
F P
0 g
s
.39219 .63591 m .38975 .68586 L .39925 .68106 L p 0 .1 0 r
F P
0 g
s
.39219 .63591 m .34915 .61555 L .33998 .62069 L p 0 .914 0 r
F P
0 g
s
.34566 .66619 m .34915 .61555 L .39219 .63591 L p 0 .7 0 r
F P
0 g
s
.39219 .63591 m .38975 .68586 L .38034 .69061 L p 0 .1 0 r
F P
0 g
s
.39219 .63591 m .38975 .68586 L .34566 .66619 L p 0 .7 0 r
F P
0 g
s
.34566 .66619 m .34915 .61555 L .39219 .63591 L p 0 .7 0 r
F P
0 g
s
.39219 .63591 m .38975 .68586 L .34566 .66619 L p 0 .7 0 r
F P
0 g
s
.38975 .68586 m .39219 .63591 L .4015 .63094 L p 0 .1 0 r
F P
0 g
s
.39925 .68106 m .44141 .70007 L .43188 .70466 L p 0 .916 0 r
F P
0 g
s
.43188 .70466 m .38975 .68586 L .39925 .68106 L p 0 .916 0 r
F P
0 g
s
.38975 .68586 m .43188 .70466 L .44141 .70007 L p 0 .916 0 r
F P
0 g
s
.44008 .75173 m .44141 .70007 L .43188 .70466 L p 0 .114 0 r
F P
0 g
s
.43188 .70466 m .43034 .75613 L .44008 .75173 L p 0 .114 0 r
F P
0 g
s
.43188 .70466 m .38975 .68586 L .38034 .69061 L p 0 .916 0 r
F P
0 g
s
.38719 .73813 m .38975 .68586 L .43188 .70466 L p 0 .7 0 r
F P
0 g
s
.43031 .75616 m .43034 .75613 L .42071 .76049 L p 0 .1 0 r
F P
0 g
s
.43031 .75616 m .38719 .73813 L p .43188 .70466 L 0 .7 0 r
F P
0 g
s
.43188 .70466 m .43034 .75613 L .43031 .75616 L p 0 .7 0 r
F P
0 g
s
.38719 .73813 m .38975 .68586 L .43188 .70466 L p 0 .7 0 r
F P
0 g
s
.43031 .75616 m .38719 .73813 L p .43188 .70466 L 0 .7 0 r
F P
0 g
s
.43188 .70466 m .43034 .75613 L .43031 .75616 L p 0 .7 0 r
F P
0 g
s
.43034 .61555 m .47155 .63589 L .4813 .63093 L p 0 .914 1 r
F P
0 g
s
.4809 .68106 m .48133 .63098 L .47158 .63594 L p 0 .114 .472 r
F P
0 g
s
.47158 .63594 m .47093 .68586 L .4809 .68106 L p 0 .114 .472 r
F P
0 g
s
.48133 .63098 m .4813 .63093 L .47155 .63589 L p 0 .562 .887 r
F P
0 g
s
.47155 .63589 m .47158 .63594 L .48133 .63098 L p 0 .562 .887 r
F P
0 g
s
.47155 .63589 m .43034 .61555 L .42071 .62069 L p 0 .914 1 r
F P
0 g
s
.42872 .66619 m .43034 .61555 L .47155 .63589 L p 0 .696 .486 r
F P
0 g
s
.47093 .68586 m .42872 .66619 L p .47155 .63589 L 0 .696 .486 r
F P
0 g
s
.47155 .63589 m .47158 .63594 L .47093 .68586 L p 0 .696 .486 r
F P
0 g
s
.42872 .66619 m .43034 .61555 L .47155 .63589 L p 0 .696 .486 r
F P
0 g
s
.47093 .68586 m .42872 .66619 L p .47155 .63589 L 0 .696 .486 r
F P
0 g
s
.47155 .63589 m .47158 .63594 L .47093 .68586 L p 0 .696 .486 r
F P
0 g
s
.23376 .53103 m .27951 .55334 L .2737 .55696 L p 0 .911 1 r
F P
0 g
s
.2737 .55696 m .228 .53482 L .23376 .53103 L p 0 .911 1 r
F P
0 g
s
.228 .53482 m .22797 .53477 L .23399 .48818 L p 0 .703 .52 r
F P
0 g
s
.228 .53482 m .22797 .53477 L .23399 .48818 L p 0 .703 .52 r
F P
0 g
s
.22797 .53477 m .23399 .48818 L .23965 .4843 L p 0 .1 .365 r
F P
0 g
s
.23399 .48818 m .22797 .53477 L .22225 .53853 L p 0 .1 .365 r
F P
0 g
s
.27747 .75143 m .32236 .76888 L .31357 .77305 L p 0 .916 0 r
F P
0 g
s
.31357 .77305 m .26873 .75579 L .27747 .75143 L p 0 .916 0 r
F P
0 g
s
.26873 .75579 m .27385 .70426 L .28243 .69972 L p 0 .1 0 r
F P
0 g
s
.27385 .70426 m .26873 .75579 L .26008 .7601 L p 0 .1 0 r
F P
0 g
s
.3955 .77188 m .39547 .7719 L .40174 .76907 L p 0 .1 .1 r
F P
0 g
s
.31178 .68415 m .35573 .70303 L .36185 .69994 L p 0 .916 1 r
F P
0 g
s
.3587 .75164 m .36185 .69994 L .35573 .70303 L p 0 .1 .45 r
F P
0 g
s
.35573 .70303 m .35246 .7546 L .3587 .75164 L p 0 .1 .45 r
F P
0 g
s
.35573 .70303 m .31178 .68415 L .30574 .68736 L p 0 .916 1 r
F P
0 g
s
.30741 .73649 m .31178 .68415 L .35573 .70303 L p 0 .703 .52 r
F P
0 g
s
.35573 .70303 m .35246 .7546 L .34626 .75754 L p 0 .1 .45 r
F P
0 g
s
.35573 .70303 m .35246 .7546 L .30741 .73649 L p 0 .703 .52 r
F P
0 g
s
.30741 .73649 m .31178 .68415 L .35573 .70303 L p 0 .703 .52 r
F P
0 g
s
.35573 .70303 m .35246 .7546 L .30741 .73649 L p 0 .703 .52 r
F P
0 g
s
.31787 .68092 m .36185 .69994 L .35573 .70303 L p 0 .916 1 r
F P
0 g
s
.35573 .70303 m .31178 .68415 L .31787 .68092 L p 0 .916 1 r
F P
0 g
s
.35246 .7546 m .35573 .70303 L .36185 .69994 L p 0 .1 .45 r
F P
0 g
s
.31178 .68415 m .31596 .63414 L .32193 .6308 L p 0 .1 .425 r
F P
0 g
s
.31596 .63414 m .31178 .68415 L .30574 .68736 L p 0 .1 .425 r
F P
0 g
s
.3587 .75164 m .40174 .76907 L .39547 .7719 L p 0 .916 1 r
F P
0 g
s
.39547 .7719 m .35246 .7546 L .3587 .75164 L p 0 .916 1 r
F P
0 g
s
.27922 .69839 m .27065 .70295 L .22477 .68407 L p 0 .916 0 r
F P
0 g
s
.21635 .68879 m .22477 .68407 L .27065 .70295 L p 0 .916 0 r
F P
0 g
s
.23328 .6793 m .22477 .68407 L .27065 .70295 L p 0 .916 0 r
F P
0 g
s
.27065 .70295 m .27922 .69839 L .23328 .6793 L p 0 .916 0 r
F P
0 g
s
.27922 .69839 m .27065 .70295 L .26545 .75453 L p 0 .1 0 r
F P
0 g
s
.21837 .73641 m .22477 .68407 L .27065 .70295 L p 0 .706 0 r
F P
0 g
s
.25681 .75885 m .26545 .75453 L .27065 .70295 L p 0 .1 0 r
F P
0 g
s
.27065 .70295 m .26545 .75453 L .21837 .73641 L p 0 .706 0 r
F P
0 g
s
.21837 .73641 m .22477 .68407 L .27065 .70295 L p 0 .706 0 r
F P
0 g
s
.27065 .70295 m .26545 .75453 L .21837 .73641 L p 0 .706 0 r
F P
0 g
s
.23328 .6793 m .22477 .68407 L .23088 .63405 L p 0 .1 0 r
F P
0 g
s
.23088 .63405 m .23923 .62912 L .23328 .6793 L p 0 .1 0 r
F P
0 g
s
.1924 .60846 m .18412 .61363 L .23088 .63405 L p 0 .914 0 r
F P
0 g
s
.23088 .63405 m .23923 .62912 L .1924 .60846 L p 0 .914 0 r
F P
0 g
s
.23923 .62912 m .23088 .63405 L .22477 .68407 L p 0 .1 0 r
F P
0 g
s
.17594 .61873 m .18412 .61363 L .18408 .61365 L p 0 .93 0 r
F P
0 g
s
.18408 .61365 m .18412 .61363 L .23088 .63405 L p 0 .706 0 r
F P
0 g
s
.17675 .66431 m .18408 .61365 L p .23088 .63405 L 0 .706 0 r
F P
0 g
s
.21635 .68879 m .22477 .68407 L .23088 .63405 L p 0 .1 0 r
F P
0 g
s
.23088 .63405 m .22477 .68407 L .17675 .66431 L p 0 .706 0 r
F P
0 g
s
.18408 .61365 m .18412 .61363 L .23088 .63405 L p 0 .706 0 r
F P
0 g
s
.17675 .66431 m .18408 .61365 L p .23088 .63405 L 0 .706 0 r
F P
0 g
s
.23088 .63405 m .22477 .68407 L .17675 .66431 L p 0 .706 0 r
F P
0 g
s
.52117 .55501 m .52114 .55503 L .48096 .53281 L p 0 .69 0 r
F P
0 g
s
.47103 .53842 m .48096 .53281 L .48139 .48614 L p 0 .1 0 r
F P
0 g
s
.48139 .48614 m .48096 .53281 L .43888 .50953 L p 0 .69 0 r
F P
0 g
s
.43056 .46834 m .44027 .46233 L .48139 .48614 L p 0 .907 0 r
F P
0 g
s
.43888 .50953 m .44027 .46233 L .48139 .48614 L p 0 .69 0 r
F P
0 g
s
.3901 .53842 m .39958 .53281 L .4416 .55505 L p 0 .911 1 r
F P
0 g
s
.51149 .46834 m .52165 .46233 L .52117 .41722 L p 0 .1 .45 r
F P
0 g
s
.52117 .41722 m .52165 .46233 L .48052 .43741 L p 0 .684 .437 r
F P
0 g
s
.48052 .43741 m .48096 .39185 L .52117 .41722 L p 0 .684 .437 r
F P
0 g
s
.55195 .53839 m .56234 .53277 L .56096 .48614 L p 0 .114 .472 r
F P
0 g
s
.56096 .48614 m .56234 .53277 L p .52216 .50953 L 0 .684 .437 r
F P
0 g
s
.51149 .46834 m .52165 .46233 L .56096 .48614 L p 0 .907 1 r
F P
0 g
s
.52216 .50953 m .52165 .46233 L .56096 .48614 L p 0 .684 .437 r
F P
0 g
s
.60072 .4172 m .56234 .39185 L .55195 .39825 L p 0 .903 0 r
F P
0 g
s
.60072 .4172 m .56234 .39185 L p .60303 .46233 L 0 .677 0 r
F P
0 g
s
.60303 .46233 m .60075 .41725 L .60072 .4172 L p 0 .677 0 r
F P
0 g
s
.47103 .53842 m .48096 .53281 L .52114 .55503 L p 0 .911 0 r
F P
0 g
s
.53151 .54943 m .52146 .55486 L .52143 .55488 L p 0 .1 .1 r
F P
0 g
s
.52146 .55486 m .52143 .55488 L .48125 .53264 L p 0 .69 .46 r
F P
0 g
s
.40945 .52696 m .39986 .53264 L .40208 .48597 L p 0 .1 0 r
F P
0 g
s
.40208 .48597 m .41147 .48016 L .40945 .52696 L p 0 .1 0 r
F P
0 g
s
.45148 .54946 m .44187 .55489 L .39986 .53264 L p 0 .911 0 r
F P
0 g
s
.53223 .45607 m .52195 .46215 L .56125 .48597 L p 0 .907 0 r
F P
0 g
s
.56125 .48597 m .57152 .48016 L .53223 .45607 L p 0 .907 0 r
F P
0 g
s
.57152 .48016 m .56125 .48597 L .56264 .53261 L p 0 .114 0 r
F P
0 g
s
.56125 .48597 m .56264 .53261 L p .52246 .50936 L 0 .684 0 r
F P
0 g
s
.52246 .50936 m .52195 .46215 L .56125 .48597 L p 0 .684 0 r
F P
0 g
s
.57152 .48016 m .56125 .48597 L .52195 .46215 L p 0 .907 0 r
F P
0 g
s
.4913 .38519 m .48125 .39166 L .52146 .41705 L p 0 .903 0 r
F P
0 g
s
.52146 .41705 m .53151 .41085 L .4913 .38519 L p 0 .903 0 r
F P
0 g
s
.53151 .41085 m .52146 .41705 L .52195 .46215 L p 0 .1 0 r
F P
0 g
s
.52146 .41705 m .52195 .46215 L .48081 .43723 L p 0 .684 0 r
F P
0 g
s
.48081 .43723 m .48125 .39166 L .52146 .41705 L p 0 .684 0 r
F P
0 g
s
.53223 .45607 m .52195 .46215 L .52146 .41705 L p 0 .1 0 r
F P
0 g
s
.52146 .41705 m .53151 .41085 L .53223 .45607 L p 0 .1 0 r
F P
0 g
s
.45038 .45607 m .44055 .46215 L .48167 .48597 L p 0 .907 1 r
F P
0 g
s
.48167 .48597 m .4915 .48016 L .45038 .45607 L p 0 .907 1 r
F P
0 g
s
.4915 .48016 m .48167 .48597 L .48125 .53264 L p 0 .1 .45 r
F P
0 g
s
.48167 .48597 m .48125 .53264 L .43917 .50936 L p 0 .69 .46 r
F P
0 g
s
.43917 .50936 m .44055 .46215 L .48167 .48597 L p 0 .69 .46 r
F P
0 g
s
.4915 .48016 m .48167 .48597 L .44055 .46215 L p 0 .907 1 r
F P
0 g
s
.45038 .45607 m .44055 .46215 L .44187 .41705 L p 0 .1 .425 r
F P
0 g
s
.44187 .41705 m .45148 .41085 L .45038 .45607 L p 0 .1 .425 r
F P
0 g
s
.4913 .52696 m .48125 .53264 L .48167 .48597 L p 0 .1 .45 r
F P
0 g
s
.48167 .48597 m .4915 .48016 L .4913 .52696 L p 0 .1 .45 r
F P
0 g
s
.56264 .39166 m .60102 .41703 L .61151 .41083 L p 0 .903 1 r
F P
0 g
s
.60102 .41703 m .60105 .41708 L .61154 .41088 L p 0 .575 .884 r
F P
0 g
s
.61154 .41088 m .61151 .41083 L .60102 .41703 L p 0 .575 .884 r
F P
0 g
s
.60105 .41708 m .60334 .46215 L .61409 .45607 L p 0 .114 .472 r
F P
0 g
s
.61409 .45607 m .61154 .41088 L .60105 .41708 L p 0 .114 .472 r
F P
0 g
s
.60102 .41703 m .56264 .39166 L p .60334 .46215 L 0 .677 .411 r
F P
0 g
s
.60334 .46215 m .60105 .41708 L .60102 .41703 L p 0 .677 .411 r
F P
0 g
s
.52143 .55488 m .53148 .54945 L .53151 .54943 L p 0 .1 .1 r
F P
0 g
s
.53148 .54945 m .52143 .55488 L .48125 .53264 L p 0 .911 1 r
F P
0 g
s
.27376 .6087 m .26782 .61221 L .31282 .63271 L p 0 .914 1 r
F P
0 g
s
.31282 .63271 m .31879 .62936 L .27376 .6087 L p 0 .914 1 r
F P
0 g
s
.31879 .62936 m .31282 .63271 L .30857 .68277 L p 0 .1 .423 r
F P
0 g
s
.26242 .66295 m .26782 .61221 L .31282 .63271 L p 0 .703 .52 r
F P
0 g
s
.30252 .68599 m .30857 .68277 L .31282 .63271 L p 0 .1 .423 r
F P
0 g
s
.31282 .63271 m .30857 .68277 L .26242 .66295 L p 0 .703 .52 r
F P
0 g
s
.26242 .66295 m .26782 .61221 L .31282 .63271 L p 0 .703 .52 r
F P
0 g
s
.31282 .63271 m .30857 .68277 L .26242 .66295 L p 0 .703 .52 r
F P
0 g
s
.27424 .46059 m .27925 .41548 L .27929 .41547 L p 0 .699 0 r
F P
0 g
s
.31911 .48447 m .31499 .53118 L .30597 .53681 L p 0 .1 0 r
F P
0 g
s
.31911 .48447 m .27424 .46059 L .26545 .46662 L p 0 .907 0 r
F P
0 g
s
.31911 .48447 m .31499 .53118 L .26902 .50784 L p 0 .699 0 r
F P
0 g
s
.27424 .46059 m .31911 .48447 L p .26902 .50784 L 0 .699 0 r
F P
0 g
s
.43866 .41545 m .39651 .38999 L .38703 .39642 L p 0 .903 0 r
F P
0 g
s
.43866 .41545 m .43726 .46059 L .3941 .43559 L p 0 .69 0 r
F P
0 g
s
.3941 .43559 m .39651 .38999 L .43866 .41545 L p 0 .69 0 r
F P
0 g
s
.35896 .41545 m .35575 .46059 L .3465 .46662 L p 0 .1 .396 r
F P
0 g
s
.35896 .41545 m .31503 .39001 L .30601 .39644 L p 0 .903 1 r
F P
0 g
s
.39881 .48447 m .35575 .46059 L .3465 .46662 L p 0 .907 1 r
F P
0 g
s
.39881 .48447 m .39651 .53118 L .35239 .50783 L p 0 .695 .481 r
F P
0 g
s
.35239 .50783 m .35575 .46059 L .39881 .48447 L p 0 .695 .481 r
F P
0 g
s
.35896 .41545 m .35575 .46059 L .31069 .43559 L p 0 .695 .481 r
F P
0 g
s
.31503 .39001 m .35896 .41545 L p .31069 .43559 L 0 .695 .481 r
F P
0 g
s
.27925 .41548 m .27424 .46059 L .26545 .46662 L p 0 .1 0 r
F P
0 g
s
.2795 .4153 m .27954 .41529 L .28826 .40907 L p 0 1 .86 r
F P
0 g
s
.27449 .46041 m .2795 .4153 L .27954 .41529 L p 0 .699 .5 r
F P
0 g
s
.40637 .52532 m .40847 .47847 L .39908 .4843 L p 0 .1 0 r
F P
0 g
s
.39908 .4843 m .39678 .53102 L .40637 .52532 L p 0 .1 0 r
F P
0 g
s
.35602 .46041 m .39908 .4843 L .40847 .47847 L p 0 .907 0 r
F P
0 g
s
.39908 .4843 m .39678 .53102 L .35267 .50765 L p 0 .695 0 r
F P
0 g
s
.35267 .50765 m .35602 .46041 L .39908 .4843 L p 0 .695 0 r
F P
0 g
s
.36538 .45431 m .40847 .47847 L .39908 .4843 L p 0 .907 0 r
F P
0 g
s
.39908 .4843 m .35602 .46041 L .36538 .45431 L p 0 .907 0 r
F P
0 g
s
.35602 .46041 m .35922 .41527 L .36839 .40906 L p 0 .1 0 r
F P
0 g
s
.36538 .45431 m .36839 .40906 L .35922 .41527 L p 0 .1 0 r
F P
0 g
s
.35922 .41527 m .35602 .46041 L .36538 .45431 L p 0 .1 0 r
F P
0 g
s
.31529 .38983 m .35922 .41527 L .36839 .40906 L p 0 .903 0 r
F P
0 g
s
.35922 .41527 m .35602 .46041 L .31095 .43541 L p 0 .695 0 r
F P
0 g
s
.31529 .38983 m .35922 .41527 L p .31095 .43541 L 0 .695 0 r
F P
0 g
s
.32438 .52532 m .36839 .54789 L .35922 .55334 L p 0 .911 1 r
F P
0 g
s
.35922 .55334 m .31526 .53102 L .32438 .52532 L p 0 .911 1 r
F P
0 g
s
.31526 .53102 m .31936 .4843 L .32831 .47847 L p 0 .1 .396 r
F P
0 g
s
.32438 .52532 m .32831 .47847 L .31936 .4843 L p 0 .1 .396 r
F P
0 g
s
.31936 .4843 m .31526 .53102 L .32438 .52532 L p 0 .1 .396 r
F P
0 g
s
.27449 .46041 m .31936 .4843 L .32831 .47847 L p 0 .907 1 r
F P
0 g
s
.31936 .4843 m .31526 .53102 L .26928 .50767 L p 0 .699 .5 r
F P
0 g
s
.27449 .46041 m .31936 .4843 L p .26928 .50767 L 0 .699 .5 r
F P
0 g
s
.28339 .45431 m .32831 .47847 L .31936 .4843 L p 0 .907 1 r
F P
0 g
s
.31936 .4843 m .27449 .46041 L .28339 .45431 L p 0 .907 1 r
F P
0 g
s
.44737 .45431 m .44854 .40906 L .43893 .41527 L p 0 .1 .423 r
F P
0 g
s
.43893 .41527 m .43754 .46041 L .44737 .45431 L p 0 .1 .423 r
F P
0 g
s
.39678 .38981 m .43893 .41527 L .44854 .40906 L p 0 .903 1 r
F P
0 g
s
.43893 .41527 m .43754 .46041 L .39438 .43541 L p 0 .69 .46 r
F P
0 g
s
.39438 .43541 m .39678 .38981 L .43893 .41527 L p 0 .69 .46 r
F P
0 g
s
.23965 .4843 m .23373 .53098 L .22797 .53477 L p 0 .1 .365 r
F P
0 g
s
.28826 .40907 m .28823 .40909 L .2795 .4153 L p 0 1 .86 r
F P
0 g
s
.27449 .46041 m .2795 .4153 L .28823 .40909 L p 0 .1 .365 r
F P
0 g
s
.4015 .63094 m .35843 .61035 L .34915 .61555 L p 0 .914 0 r
F P
0 g
s
.35513 .66116 m .35843 .61035 L .4015 .63094 L p 0 .699 0 r
F P
0 g
s
.4015 .63094 m .39925 .68106 L .38975 .68586 L p 0 .1 0 r
F P
0 g
s
.4015 .63094 m .39925 .68106 L .35513 .66116 L p 0 .699 0 r
F P
0 g
s
.44141 .70007 m .39925 .68106 L .38975 .68586 L p 0 .916 0 r
F P
0 g
s
.39691 .73352 m .39925 .68106 L .44141 .70007 L p 0 .699 0 r
F P
0 g
s
.44005 .75176 m .44008 .75173 L .43034 .75613 L p 0 .1 0 r
F P
0 g
s
.44005 .75176 m .39691 .73352 L p .44141 .70007 L 0 .699 0 r
F P
0 g
s
.44141 .70007 m .44008 .75173 L .44005 .75176 L p 0 .699 0 r
F P
0 g
s
.4813 .63093 m .44008 .61035 L .43034 .61555 L p 0 .914 1 r
F P
0 g
s
.43868 .66116 m .44008 .61035 L .4813 .63093 L p 0 .695 .481 r
F P
0 g
s
.4809 .68106 m .43868 .66116 L p .4813 .63093 L 0 .695 .481 r
F P
0 g
s
.4813 .63093 m .48133 .63098 L .4809 .68106 L p 0 .695 .481 r
F P
0 g
s
.40177 .76905 m .40174 .76907 L .41116 .76481 L p 0 .1 0 r
F P
0 g
s
.3587 .6102 m .40177 .6308 L .41119 .62577 L p 0 .914 1 r
F P
0 g
s
.40915 .67607 m .41119 .62577 L .40177 .6308 L p 0 .1 .45 r
F P
0 g
s
.40177 .6308 m .39953 .68092 L .40915 .67607 L p 0 .1 .45 r
F P
0 g
s
.35541 .66102 m .3587 .6102 L .40177 .6308 L p 0 .699 .5 r
F P
0 g
s
.40177 .6308 m .39953 .68092 L .35541 .66102 L p 0 .699 .5 r
F P
0 g
s
.39953 .68092 m .40177 .6308 L .41119 .62577 L p 0 .1 .45 r
F P
0 g
s
.40915 .67607 m .45133 .6953 L .44169 .69994 L p 0 .916 1 r
F P
0 g
s
.44169 .69994 m .39953 .68092 L .40915 .67607 L p 0 .916 1 r
F P
0 g
s
.39953 .68092 m .44169 .69994 L .45133 .6953 L p 0 .916 1 r
F P
0 g
s
.45021 .74715 m .45133 .6953 L .44169 .69994 L p 0 .114 .472 r
F P
0 g
s
.44169 .69994 m .44036 .7516 L .45021 .74715 L p 0 .114 .472 r
F P
0 g
s
.39719 .73339 m .39953 .68092 L .44169 .69994 L p 0 .699 .5 r
F P
0 g
s
.44033 .75163 m .39719 .73339 L p .44169 .69994 L 0 .699 .5 r
F P
0 g
s
.44169 .69994 m .44036 .7516 L .44033 .75163 L p 0 .699 .5 r
F P
0 g
s
.36185 .69994 m .31787 .68092 L .31178 .68415 L p 0 .916 1 r
F P
0 g
s
.31362 .73339 m .31787 .68092 L .36185 .69994 L p 0 .703 .518 r
F P
0 g
s
.36185 .69994 m .3587 .75164 L .35246 .7546 L p 0 .1 .45 r
F P
0 g
s
.36185 .69994 m .3587 .75164 L .31362 .73339 L p 0 .703 .518 r
F P
0 g
s
.32193 .6308 m .31787 .68092 L .31178 .68415 L p 0 .1 .425 r
F P
0 g
s
.31787 .68092 m .36185 .69994 L .37104 .6953 L p 0 .916 0 r
F P
0 g
s
.36809 .74719 m .37104 .6953 L .36185 .69994 L p 0 .1 0 r
F P
0 g
s
.36185 .69994 m .3587 .75164 L .36809 .74719 L p 0 .1 0 r
F P
0 g
s
.31362 .73339 m .31787 .68092 L .36185 .69994 L p 0 .703 0 r
F P
0 g
s
.36185 .69994 m .3587 .75164 L .31362 .73339 L p 0 .703 0 r
F P
0 g
s
.3587 .75164 m .36185 .69994 L .37104 .6953 L p 0 .1 0 r
F P
0 g
s
.32703 .67607 m .37104 .6953 L .36185 .69994 L p 0 .916 0 r
F P
0 g
s
.36185 .69994 m .31787 .68092 L .32703 .67607 L p 0 .916 0 r
F P
0 g
s
.31787 .68092 m .32193 .6308 L .3309 .62577 L p 0 .1 0 r
F P
0 g
s
.44036 .6102 m .48158 .63078 L .49144 .62576 L p 0 .914 0 r
F P
0 g
s
.49127 .67607 m .49147 .62581 L .48161 .63083 L p 0 .114 0 r
F P
0 g
s
.48161 .63083 m .48119 .68092 L .49127 .67607 L p 0 .114 0 r
F P
0 g
s
.49147 .62581 m .49144 .62576 L .48158 .63078 L p 0 .562 0 r
F P
0 g
s
.48158 .63078 m .48161 .63083 L .49147 .62581 L p 0 .562 0 r
F P
0 g
s
.43897 .66102 m .44036 .6102 L .48158 .63078 L p 0 .695 0 r
F P
0 g
s
.48119 .68092 m .43897 .66102 L p .48158 .63078 L 0 .695 0 r
F P
0 g
s
.48158 .63078 m .48161 .63083 L .48119 .68092 L p 0 .695 0 r
F P
0 g
s
.36809 .74719 m .41116 .76481 L .40174 .76907 L p 0 .916 0 r
F P
0 g
s
.40174 .76907 m .3587 .75164 L .36809 .74719 L p 0 .916 0 r
F P
0 g
s
.28243 .69972 m .27747 .75143 L .26873 .75579 L p 0 .1 0 r
F P
0 g
s
.16557 .6252 m .15885 .62939 L .15889 .62937 L p 0 .93 .764 r
F P
0 g
s
.30857 .68277 m .31465 .67953 L .31879 .62936 L p 0 .1 .423 r
F P
0 g
s
.26847 .65956 m .27376 .6087 L .31879 .62936 L p 0 .703 .518 r
F P
0 g
s
.31879 .62936 m .31465 .67953 L .26847 .65956 L p 0 .703 .518 r
F P
0 g
s
.24591 .76431 m .23882 .76786 L .19196 .75036 L p 0 .916 1 r
F P
0 g
s
.199 .74665 m .19196 .75036 L .19884 .69861 L p 0 .1 .396 r
F P
0 g
s
.19884 .69861 m .20574 .69474 L .199 .74665 L p 0 .1 .396 r
F P
0 g
s
.20574 .69474 m .19884 .69861 L .15107 .67953 L p 0 .916 1 r
F P
0 g
s
.15791 .67548 m .15107 .67953 L .19884 .69861 L p 0 .916 1 r
F P
0 g
s
.19884 .69861 m .20574 .69474 L .15791 .67548 L p 0 .916 1 r
F P
0 g
s
.20574 .69474 m .19884 .69861 L .19196 .75036 L p 0 .1 .396 r
F P
0 g
s
.14293 .73201 m .15107 .67953 L .19884 .69861 L p 0 .708 .548 r
F P
0 g
s
.14296 .73206 m .14293 .73201 L p .19884 .69861 L 0 .708 .548 r
F P
0 g
s
.19884 .69861 m .19196 .75036 L .14296 .73206 L p 0 .708 .548 r
F P
0 g
s
.28268 .60342 m .27376 .6087 L .31879 .62936 L p 0 .914 0 r
F P
0 g
s
.31879 .62936 m .32776 .62431 L .28268 .60342 L p 0 .914 0 r
F P
0 g
s
.32776 .62431 m .31879 .62936 L .31465 .67953 L p 0 .1 0 r
F P
0 g
s
.26847 .65956 m .27376 .6087 L .31879 .62936 L p 0 .703 0 r
F P
0 g
s
.31879 .62936 m .31465 .67953 L .26847 .65956 L p 0 .703 0 r
F P
0 g
s
.15791 .67548 m .15107 .67953 L .15885 .62939 L p 0 .1 .365 r
F P
0 g
s
.15885 .62939 m .16557 .6252 L .15791 .67548 L p 0 .1 .365 r
F P
0 g
s
.26545 .75453 m .27418 .75015 L .27922 .69839 L p 0 .1 0 r
F P
0 g
s
.22477 .68407 m .23328 .6793 L .27922 .69839 L p 0 .916 0 r
F P
0 g
s
.22704 .73183 m .23328 .6793 L .27922 .69839 L p 0 .705 0 r
F P
0 g
s
.27922 .69839 m .27418 .75015 L .22704 .73183 L p 0 .705 0 r
F P
0 g
s
.22477 .68407 m .23328 .6793 L .23923 .62912 L p 0 .1 0 r
F P
0 g
s
.18412 .61363 m .1924 .60846 L .19236 .60848 L p 0 .93 0 r
F P
0 g
s
.19236 .60848 m .1924 .60846 L .23923 .62912 L p 0 .705 0 r
F P
0 g
s
.18518 .65932 m .19236 .60848 L p .23923 .62912 L 0 .705 0 r
F P
0 g
s
.23923 .62912 m .23328 .6793 L .18518 .65932 L p 0 .705 0 r
F P
0 g
s
.54167 .54394 m .53151 .54943 L .53148 .54945 L p 0 .1 .1 r
F P
0 g
s
.53151 .54943 m .53148 .54945 L .4913 .52696 L p 0 .689 .454 r
F P
0 g
s
.53151 .54943 m .53148 .54945 L .4913 .52696 L p 0 .689 .454 r
F P
0 g
s
.50147 .37863 m .4913 .38519 L .53151 .41085 L p 0 .903 0 r
F P
0 g
s
.53151 .41085 m .54167 .40459 L .50147 .37863 L p 0 .903 0 r
F P
0 g
s
.54167 .40459 m .53151 .41085 L .53223 .45607 L p 0 .1 0 r
F P
0 g
s
.52195 .46215 m .53223 .45607 L .53151 .41085 L p 0 .1 0 r
F P
0 g
s
.53151 .41085 m .53223 .45607 L .4911 .43087 L p 0 .683 0 r
F P
0 g
s
.4911 .43087 m .4913 .38519 L .53151 .41085 L p 0 .683 0 r
F P
0 g
s
.53151 .41085 m .53223 .45607 L .4911 .43087 L p 0 .683 0 r
F P
0 g
s
.4911 .43087 m .4913 .38519 L .53151 .41085 L p 0 .683 0 r
F P
0 g
s
.54263 .44993 m .53223 .45607 L .53151 .41085 L p 0 .1 0 r
F P
0 g
s
.53151 .41085 m .54167 .40459 L .54263 .44993 L p 0 .1 0 r
F P
0 g
s
.52195 .46215 m .53223 .45607 L .57152 .48016 L p 0 .907 0 r
F P
0 g
s
.54263 .44993 m .53223 .45607 L .57152 .48016 L p 0 .907 0 r
F P
0 g
s
.57152 .48016 m .58191 .47428 L .54263 .44993 L p 0 .907 0 r
F P
0 g
s
.58191 .47428 m .57152 .48016 L .57316 .52693 L p 0 .114 0 r
F P
0 g
s
.56264 .53261 m .57316 .52693 L .57152 .48016 L p 0 .114 0 r
F P
0 g
s
.57152 .48016 m .57316 .52693 L p .53298 .50341 L 0 .683 0 r
F P
0 g
s
.53298 .50341 m .53223 .45607 L .57152 .48016 L p 0 .683 0 r
F P
0 g
s
.57152 .48016 m .57316 .52693 L p .53298 .50341 L 0 .683 0 r
F P
0 g
s
.53298 .50341 m .53223 .45607 L .57152 .48016 L p 0 .683 0 r
F P
0 g
s
.58191 .47428 m .57152 .48016 L .53223 .45607 L p 0 .907 0 r
F P
0 g
s
.4612 .54397 m .45148 .54946 L .40945 .52696 L p 0 .911 0 r
F P
0 g
s
.41915 .52122 m .40945 .52696 L .41147 .48016 L p 0 .1 0 r
F P
0 g
s
.41147 .48016 m .42096 .47428 L .41915 .52122 L p 0 .1 0 r
F P
0 g
s
.39986 .53264 m .40945 .52696 L .45148 .54946 L p 0 .911 0 r
F P
0 g
s
.46031 .44993 m .45038 .45607 L .4915 .48016 L p 0 .907 1 r
F P
0 g
s
.4915 .48016 m .50144 .47428 L .46031 .44993 L p 0 .907 1 r
F P
0 g
s
.50144 .47428 m .4915 .48016 L .4913 .52696 L p 0 .1 .45 r
F P
0 g
s
.48125 .53264 m .4913 .52696 L .4915 .48016 L p 0 .1 .45 r
F P
0 g
s
.4915 .48016 m .4913 .52696 L .44922 .50341 L p 0 .689 .454 r
F P
0 g
s
.44055 .46215 m .45038 .45607 L .4915 .48016 L p 0 .907 1 r
F P
0 g
s
.44922 .50341 m .45038 .45607 L .4915 .48016 L p 0 .689 .454 r
F P
0 g
s
.4915 .48016 m .4913 .52696 L .44922 .50341 L p 0 .689 .454 r
F P
0 g
s
.44922 .50341 m .45038 .45607 L .4915 .48016 L p 0 .689 .454 r
F P
0 g
s
.50144 .47428 m .4915 .48016 L .45038 .45607 L p 0 .907 1 r
F P
0 g
s
.46031 .44993 m .45038 .45607 L .45148 .41085 L p 0 .1 .425 r
F P
0 g
s
.45148 .41085 m .4612 .40459 L .46031 .44993 L p 0 .1 .425 r
F P
0 g
s
.50147 .52122 m .4913 .52696 L .4915 .48016 L p 0 .1 .45 r
F P
0 g
s
.4915 .48016 m .50144 .47428 L .50147 .52122 L p 0 .1 .45 r
F P
0 g
s
.61151 .41083 m .57316 .38519 L .56264 .39166 L p 0 .903 1 r
F P
0 g
s
.61151 .41083 m .57316 .38519 L p .61409 .45607 L 0 .675 .404 r
F P
0 g
s
.61409 .45607 m .61154 .41088 L .61151 .41083 L p 0 .675 .404 r
F P
0 g
s
.57316 .38519 m .61151 .41083 L .62212 .40457 L p 0 .903 1 r
F P
0 g
s
.61151 .41083 m .61154 .41088 L .62215 .40462 L p 0 .575 .884 r
F P
0 g
s
.62215 .40462 m .62212 .40457 L .61151 .41083 L p 0 .575 .884 r
F P
0 g
s
.61154 .41088 m .61409 .45607 L .62495 .44993 L p 0 .114 .472 r
F P
0 g
s
.62495 .44993 m .62215 .40462 L .61154 .41088 L p 0 .114 .472 r
F P
0 g
s
.61151 .41083 m .57316 .38519 L p .61409 .45607 L 0 .675 .404 r
F P
0 g
s
.61409 .45607 m .61154 .41088 L .61151 .41083 L p 0 .675 .404 r
F P
0 g
s
.53148 .54945 m .54165 .54396 L .54167 .54394 L p 0 .1 .1 r
F P
0 g
s
.54165 .54396 m .53148 .54945 L .4913 .52696 L p 0 .911 1 r
F P
0 g
s
.48125 .53264 m .4913 .52696 L .53148 .54945 L p 0 .911 1 r
F P
0 g
s
.28823 .40909 m .28826 .40907 L .29709 .40279 L p 0 1 .86 r
F P
0 g
s
.28339 .45431 m .28823 .40909 L .28826 .40907 L p 0 .698 .496 r
F P
0 g
s
.28339 .45431 m .28823 .40909 L .28826 .40907 L p 0 .698 .496 r
F P
0 g
s
.41607 .51955 m .41796 .47258 L .40847 .47847 L p 0 .1 0 r
F P
0 g
s
.40847 .47847 m .40637 .52532 L .41607 .51955 L p 0 .1 0 r
F P
0 g
s
.36538 .45431 m .40847 .47847 L .41796 .47258 L p 0 .907 0 r
F P
0 g
s
.40847 .47847 m .40637 .52532 L .36222 .50169 L p 0 .694 0 r
F P
0 g
s
.40847 .47847 m .36538 .45431 L .35602 .46041 L p 0 .907 0 r
F P
0 g
s
.36222 .50169 m .36538 .45431 L .40847 .47847 L p 0 .694 0 r
F P
0 g
s
.40847 .47847 m .40637 .52532 L .36222 .50169 L p 0 .694 0 r
F P
0 g
s
.36222 .50169 m .36538 .45431 L .40847 .47847 L p 0 .694 0 r
F P
0 g
s
.37484 .44814 m .41796 .47258 L .40847 .47847 L p 0 .907 0 r
F P
0 g
s
.40847 .47847 m .36538 .45431 L .37484 .44814 L p 0 .907 0 r
F P
0 g
s
.36839 .40906 m .36538 .45431 L .35602 .46041 L p 0 .1 0 r
F P
0 g
s
.36839 .40906 m .32441 .38333 L .31529 .38983 L p 0 .903 0 r
F P
0 g
s
.36538 .45431 m .36839 .40906 L .37766 .40277 L p 0 .1 0 r
F P
0 g
s
.37484 .44814 m .37766 .40277 L .36839 .40906 L p 0 .1 0 r
F P
0 g
s
.36839 .40906 m .36538 .45431 L .37484 .44814 L p 0 .1 0 r
F P
0 g
s
.32441 .38333 m .36839 .40906 L .37766 .40277 L p 0 .903 0 r
F P
0 g
s
.36839 .40906 m .36538 .45431 L .32027 .42902 L p 0 .694 0 r
F P
0 g
s
.32441 .38333 m .36839 .40906 L p .32027 .42902 L 0 .694 0 r
F P
0 g
s
.36839 .40906 m .36538 .45431 L .32027 .42902 L p 0 .694 0 r
F P
0 g
s
.32441 .38333 m .36839 .40906 L p .32027 .42902 L 0 .694 0 r
F P
0 g
s
.25119 .51957 m .29705 .54238 L .28823 .54789 L p 0 .911 0 r
F P
0 g
s
.28823 .54789 m .24243 .52533 L .25119 .51957 L p 0 .911 0 r
F P
0 g
s
.24243 .52533 m .2424 .52528 L .24815 .47847 L p 0 .702 0 r
F P
0 g
s
.24243 .52533 m .2424 .52528 L .24815 .47847 L p 0 .702 0 r
F P
0 g
s
.2424 .52528 m .24815 .47847 L .25675 .47258 L p 0 .1 0 r
F P
0 g
s
.24815 .47847 m .2424 .52528 L .23373 .53098 L p 0 .1 0 r
F P
0 g
s
.33361 .51955 m .37766 .54238 L .36839 .54789 L p 0 .911 1 r
F P
0 g
s
.36839 .54789 m .32438 .52532 L .33361 .51955 L p 0 .911 1 r
F P
0 g
s
.32438 .52532 m .32831 .47847 L .33735 .47258 L p 0 .1 .396 r
F P
0 g
s
.32831 .47847 m .32438 .52532 L .31526 .53102 L p 0 .1 .396 r
F P
0 g
s
.33361 .51955 m .33735 .47258 L .32831 .47847 L p 0 .1 .396 r
F P
0 g
s
.32831 .47847 m .32438 .52532 L .33361 .51955 L p 0 .1 .396 r
F P
0 g
s
.28339 .45431 m .32831 .47847 L .33735 .47258 L p 0 .907 1 r
F P
0 g
s
.32831 .47847 m .32438 .52532 L .27835 .5017 L p 0 .698 .496 r
F P
0 g
s
.32831 .47847 m .28339 .45431 L .27449 .46041 L p 0 .907 1 r
F P
0 g
s
.28339 .45431 m .32831 .47847 L p .27835 .5017 L 0 .698 .496 r
F P
0 g
s
.32831 .47847 m .32438 .52532 L .27835 .5017 L p 0 .698 .496 r
F P
0 g
s
.28339 .45431 m .32831 .47847 L p .27835 .5017 L 0 .698 .496 r
F P
0 g
s
.29238 .44814 m .33735 .47258 L .32831 .47847 L p 0 .907 1 r
F P
0 g
s
.32831 .47847 m .28339 .45431 L .29238 .44814 L p 0 .907 1 r
F P
0 g
s
.4573 .44814 m .45826 .40277 L .44854 .40906 L p 0 .1 .423 r
F P
0 g
s
.44854 .40906 m .44737 .45431 L .4573 .44814 L p 0 .1 .423 r
F P
0 g
s
.40637 .38331 m .44854 .40906 L .45826 .40277 L p 0 .903 1 r
F P
0 g
s
.44854 .40906 m .44737 .45431 L .40418 .42902 L p 0 .689 .454 r
F P
0 g
s
.44854 .40906 m .40637 .38331 L .39678 .38981 L p 0 .903 1 r
F P
0 g
s
.40418 .42902 m .40637 .38331 L .44854 .40906 L p 0 .689 .454 r
F P
0 g
s
.44854 .40906 m .44737 .45431 L .40418 .42902 L p 0 .689 .454 r
F P
0 g
s
.40418 .42902 m .40637 .38331 L .44854 .40906 L p 0 .689 .454 r
F P
0 g
s
.29709 .40279 m .29705 .4028 L .28823 .40909 L p 0 1 .86 r
F P
0 g
s
.28339 .45431 m .28823 .40909 L .29705 .4028 L p 0 .1 .365 r
F P
0 g
s
.28823 .40909 m .28339 .45431 L .27449 .46041 L p 0 .1 .365 r
F P
0 g
s
.41119 .76479 m .41116 .76481 L .42068 .76051 L p 0 .1 0 r
F P
0 g
s
.36809 .60495 m .41119 .62577 L .42071 .62069 L p 0 .914 1 r
F P
0 g
s
.41888 .67116 m .42071 .62069 L .41119 .62577 L p 0 .1 .45 r
F P
0 g
s
.41119 .62577 m .40915 .67607 L .41888 .67116 L p 0 .1 .45 r
F P
0 g
s
.41119 .62577 m .36809 .60495 L .3587 .6102 L p 0 .914 1 r
F P
0 g
s
.365 .65593 m .36809 .60495 L .41119 .62577 L p 0 .698 .496 r
F P
0 g
s
.41119 .62577 m .40915 .67607 L .39953 .68092 L p 0 .1 .45 r
F P
0 g
s
.41119 .62577 m .40915 .67607 L .365 .65593 L p 0 .698 .496 r
F P
0 g
s
.365 .65593 m .36809 .60495 L .41119 .62577 L p 0 .698 .496 r
F P
0 g
s
.41119 .62577 m .40915 .67607 L .365 .65593 L p 0 .698 .496 r
F P
0 g
s
.40915 .67607 m .41119 .62577 L .42071 .62069 L p 0 .1 .45 r
F P
0 g
s
.41888 .67116 m .46108 .69061 L .45133 .6953 L p 0 .916 1 r
F P
0 g
s
.45133 .6953 m .40915 .67607 L .41888 .67116 L p 0 .916 1 r
F P
0 g
s
.40915 .67607 m .45133 .6953 L .46108 .69061 L p 0 .916 1 r
F P
0 g
s
.46018 .74265 m .46108 .69061 L .45133 .6953 L p 0 .114 .472 r
F P
0 g
s
.45133 .6953 m .45021 .74715 L .46018 .74265 L p 0 .114 .472 r
F P
0 g
s
.45133 .6953 m .40915 .67607 L .39953 .68092 L p 0 .916 1 r
F P
0 g
s
.40702 .72872 m .40915 .67607 L .45133 .6953 L p 0 .698 .496 r
F P
0 g
s
.45018 .74718 m .45021 .74715 L .44036 .7516 L p 0 .1 .1 r
F P
0 g
s
.45018 .74718 m .40702 .72872 L p .45133 .6953 L 0 .698 .496 r
F P
0 g
s
.45133 .6953 m .45021 .74715 L .45018 .74718 L p 0 .698 .496 r
F P
0 g
s
.40702 .72872 m .40915 .67607 L .45133 .6953 L p 0 .698 .496 r
F P
0 g
s
.45018 .74718 m .40702 .72872 L p .45133 .6953 L 0 .698 .496 r
F P
0 g
s
.45133 .6953 m .45021 .74715 L .45018 .74718 L p 0 .698 .496 r
F P
0 g
s
.32703 .67607 m .37104 .6953 L .38034 .69061 L p 0 .916 0 r
F P
0 g
s
.37758 .74268 m .38034 .69061 L .37104 .6953 L p 0 .1 0 r
F P
0 g
s
.37104 .6953 m .36809 .74719 L .37758 .74268 L p 0 .1 0 r
F P
0 g
s
.37104 .6953 m .32703 .67607 L .31787 .68092 L p 0 .916 0 r
F P
0 g
s
.32297 .72872 m .32703 .67607 L .37104 .6953 L p 0 .702 0 r
F P
0 g
s
.37104 .6953 m .36809 .74719 L .3587 .75164 L p 0 .1 0 r
F P
0 g
s
.37104 .6953 m .36809 .74719 L .32297 .72872 L p 0 .702 0 r
F P
0 g
s
.32297 .72872 m .32703 .67607 L .37104 .6953 L p 0 .702 0 r
F P
0 g
s
.37104 .6953 m .36809 .74719 L .32297 .72872 L p 0 .702 0 r
F P
0 g
s
.36809 .74719 m .37104 .6953 L .38034 .69061 L p 0 .1 0 r
F P
0 g
s
.32703 .67607 m .3309 .62577 L .33998 .62069 L p 0 .1 0 r
F P
0 g
s
.33629 .67116 m .38034 .69061 L .37104 .6953 L p 0 .916 0 r
F P
0 g
s
.37104 .6953 m .32703 .67607 L .33629 .67116 L p 0 .916 0 r
F P
0 g
s
.3309 .62577 m .32703 .67607 L .31787 .68092 L p 0 .1 0 r
F P
0 g
s
.45021 .60495 m .49144 .62576 L .50141 .62067 L p 0 .914 0 r
F P
0 g
s
.50147 .67116 m .50144 .62072 L .49147 .62581 L p 0 .114 0 r
F P
0 g
s
.49147 .62581 m .49127 .67607 L .50147 .67116 L p 0 .114 0 r
F P
0 g
s
.50144 .62072 m .50141 .62067 L .49144 .62576 L p 0 .562 0 r
F P
0 g
s
.49144 .62576 m .49147 .62581 L .50144 .62072 L p 0 .562 0 r
F P
0 g
s
.49144 .62576 m .45021 .60495 L .44036 .6102 L p 0 .914 0 r
F P
0 g
s
.44904 .65593 m .45021 .60495 L .49144 .62576 L p 0 .694 0 r
F P
0 g
s
.49127 .67607 m .44904 .65593 L p .49144 .62576 L 0 .694 0 r
F P
0 g
s
.49144 .62576 m .49147 .62581 L .49127 .67607 L p 0 .694 0 r
F P
0 g
s
.44904 .65593 m .45021 .60495 L .49144 .62576 L p 0 .694 0 r
F P
0 g
s
.49127 .67607 m .44904 .65593 L p .49144 .62576 L 0 .694 0 r
F P
0 g
s
.49144 .62576 m .49147 .62581 L .49127 .67607 L p 0 .694 0 r
F P
0 g
s
.37758 .74268 m .42068 .76051 L .41116 .76481 L p 0 .916 0 r
F P
0 g
s
.41116 .76481 m .36809 .74719 L .37758 .74268 L p 0 .916 0 r
F P
0 g
s
.21658 .54227 m .2166 .54232 L .21097 .54602 L p 0 .546 .889 r
F P
0 g
s
.21097 .54602 m .21094 .54597 L .21658 .54227 L p 0 .546 .889 r
F P
0 g
s
.17235 .62096 m .16557 .6252 L .16561 .62518 L p 0 .93 .764 r
F P
0 g
s
.25307 .76073 m .24591 .76431 L .199 .74665 L p 0 .916 1 r
F P
0 g
s
.2061 .7429 m .199 .74665 L .20574 .69474 L p 0 .1 .396 r
F P
0 g
s
.20574 .69474 m .21271 .69083 L .2061 .7429 L p 0 .1 .396 r
F P
0 g
s
.19196 .75036 m .199 .74665 L .24591 .76431 L p 0 .916 1 r
F P
0 g
s
.21271 .69083 m .20574 .69474 L .15791 .67548 L p 0 .916 1 r
F P
0 g
s
.15107 .67953 m .15791 .67548 L .20574 .69474 L p 0 .916 1 r
F P
0 g
s
.16481 .67139 m .15791 .67548 L .20574 .69474 L p 0 .916 1 r
F P
0 g
s
.20574 .69474 m .21271 .69083 L .16481 .67139 L p 0 .916 1 r
F P
0 g
s
.21271 .69083 m .20574 .69474 L .199 .74665 L p 0 .1 .396 r
F P
0 g
s
.14988 .72812 m .15791 .67548 L .20574 .69474 L p 0 .707 .545 r
F P
0 g
s
.14991 .72817 m .14988 .72812 L p .20574 .69474 L 0 .707 .545 r
F P
0 g
s
.19196 .75036 m .199 .74665 L .20574 .69474 L p 0 .1 .396 r
F P
0 g
s
.20574 .69474 m .199 .74665 L .14991 .72817 L p 0 .707 .545 r
F P
0 g
s
.14988 .72812 m .15791 .67548 L .20574 .69474 L p 0 .707 .545 r
F P
0 g
s
.14991 .72817 m .14988 .72812 L p .20574 .69474 L 0 .707 .545 r
F P
0 g
s
.20574 .69474 m .199 .74665 L .14991 .72817 L p 0 .707 .545 r
F P
0 g
s
.16481 .67139 m .15791 .67548 L .16557 .6252 L p 0 .1 .365 r
F P
0 g
s
.16557 .6252 m .17235 .62096 L .16481 .67139 L p 0 .1 .365 r
F P
0 g
s
.2917 .59809 m .28268 .60342 L .32776 .62431 L p 0 .914 0 r
F P
0 g
s
.32776 .62431 m .33683 .61922 L .2917 .59809 L p 0 .914 0 r
F P
0 g
s
.33683 .61922 m .32776 .62431 L .32381 .67466 L p 0 .1 0 r
F P
0 g
s
.27757 .65446 m .28268 .60342 L .32776 .62431 L p 0 .702 0 r
F P
0 g
s
.31465 .67953 m .32381 .67466 L .32776 .62431 L p 0 .1 0 r
F P
0 g
s
.32776 .62431 m .32381 .67466 L .27757 .65446 L p 0 .702 0 r
F P
0 g
s
.27757 .65446 m .28268 .60342 L .32776 .62431 L p 0 .702 0 r
F P
0 g
s
.32776 .62431 m .32381 .67466 L .27757 .65446 L p 0 .702 0 r
F P
0 g
s
.29512 .74262 m .34011 .76046 L .334 .76336 L p 0 .916 1 r
F P
0 g
s
.334 .76336 m .28905 .74565 L .29512 .74262 L p 0 .916 1 r
F P
0 g
s
.28905 .74565 m .29378 .6937 L .29974 .69054 L p 0 .1 .425 r
F P
0 g
s
.55195 .53839 m .54167 .54394 L .54165 .54396 L p 0 .1 .1 r
F P
0 g
s
.54167 .54394 m .54165 .54396 L .50147 .52122 L p 0 .687 .449 r
F P
0 g
s
.54167 .54394 m .54165 .54396 L .50147 .52122 L p 0 .687 .449 r
F P
0 g
s
.53223 .45607 m .54263 .44993 L .54167 .40459 L p 0 .1 0 r
F P
0 g
s
.54167 .40459 m .54263 .44993 L .5015 .42442 L p 0 .681 0 r
F P
0 g
s
.5015 .42442 m .50147 .37863 L .54167 .40459 L p 0 .681 0 r
F P
0 g
s
.57316 .52693 m .58379 .52118 L .58191 .47428 L p 0 .114 0 r
F P
0 g
s
.58191 .47428 m .58379 .52118 L p .54363 .49739 L 0 .681 0 r
F P
0 g
s
.53223 .45607 m .54263 .44993 L .58191 .47428 L p 0 .907 0 r
F P
0 g
s
.54363 .49739 m .54263 .44993 L .58191 .47428 L p 0 .681 0 r
F P
0 g
s
.50147 .37863 m .54167 .40459 L .55195 .39825 L p 0 .903 0 r
F P
0 g
s
.54167 .40459 m .54263 .44993 L .58191 .47428 L p 0 .681 0 r
F P
0 g
s
.54167 .40459 m .54263 .44993 L .55315 .44371 L p 0 .1 0 r
F P
0 g
s
.55315 .44371 m .55195 .39825 L .54167 .40459 L p 0 .1 0 r
F P
0 g
s
.54263 .44993 m .54167 .40459 L .50147 .37863 L p 0 .681 0 r
F P
0 g
s
.54263 .44993 m .54167 .40459 L .55195 .39825 L p 0 .1 0 r
F P
0 g
s
.54263 .44993 m .58191 .47428 L .59241 .46834 L p 0 .907 0 r
F P
0 g
s
.58191 .47428 m .58379 .52118 L .59455 .51537 L p 0 .114 0 r
F P
0 g
s
.59455 .51537 m .59241 .46834 L .58191 .47428 L p 0 .114 0 r
F P
0 g
s
.58379 .52118 m .57316 .52693 L .57313 .52695 L p 0 .1 0 r
F P
0 g
s
.57313 .52695 m .58376 .5212 L .58379 .52118 L p 0 .1 0 r
F P
0 g
s
.58379 .52118 m .58376 .5212 L .54363 .49739 L p 0 .681 0 r
F P
0 g
s
.58191 .47428 m .54263 .44993 L p .58376 .5212 L 0 .681 0 r
F P
0 g
s
.58376 .5212 m .58379 .52118 L .58191 .47428 L p 0 .681 0 r
F P
0 g
s
.58191 .47428 m .54263 .44993 L .55315 .44371 L p 0 .907 0 r
F P
0 g
s
.55315 .44371 m .59241 .46834 L .58191 .47428 L p 0 .907 0 r
F P
0 g
s
.47103 .53842 m .4612 .54397 L .41915 .52122 L p 0 .911 0 r
F P
0 g
s
.42896 .51541 m .41915 .52122 L .42096 .47428 L p 0 .1 0 r
F P
0 g
s
.42096 .47428 m .43056 .46834 L .42896 .51541 L p 0 .1 0 r
F P
0 g
s
.40945 .52696 m .41915 .52122 L .4612 .54397 L p 0 .911 0 r
F P
0 g
s
.47036 .44371 m .46031 .44993 L .50144 .47428 L p 0 .907 1 r
F P
0 g
s
.50144 .47428 m .51149 .46834 L .47036 .44371 L p 0 .907 1 r
F P
0 g
s
.51149 .46834 m .50144 .47428 L .50147 .52122 L p 0 .1 .45 r
F P
0 g
s
.4913 .52696 m .50147 .52122 L .50144 .47428 L p 0 .1 .45 r
F P
0 g
s
.50144 .47428 m .50147 .52122 L .45938 .49739 L p 0 .687 .449 r
F P
0 g
s
.45038 .45607 m .46031 .44993 L .50144 .47428 L p 0 .907 1 r
F P
0 g
s
.45938 .49739 m .46031 .44993 L .50144 .47428 L p 0 .687 .449 r
F P
0 g
s
.50144 .47428 m .50147 .52122 L .45938 .49739 L p 0 .687 .449 r
F P
0 g
s
.45938 .49739 m .46031 .44993 L .50144 .47428 L p 0 .687 .449 r
F P
0 g
s
.51149 .46834 m .50144 .47428 L .46031 .44993 L p 0 .907 1 r
F P
0 g
s
.47036 .44371 m .46031 .44993 L .4612 .40459 L p 0 .1 .425 r
F P
0 g
s
.4612 .40459 m .47103 .39825 L .47036 .44371 L p 0 .1 .425 r
F P
0 g
s
.51175 .51541 m .50147 .52122 L .50144 .47428 L p 0 .1 .45 r
F P
0 g
s
.50144 .47428 m .51149 .46834 L .51175 .51541 L p 0 .1 .45 r
F P
0 g
s
.62212 .40457 m .58379 .37863 L .57316 .38519 L p 0 .903 1 r
F P
0 g
s
.62212 .40457 m .58379 .37863 L p .62495 .44993 L 0 .673 .397 r
F P
0 g
s
.62495 .44993 m .62215 .40462 L .62212 .40457 L p 0 .673 .397 r
F P
0 g
s
.58379 .37863 m .62212 .40457 L .63285 .39824 L p 0 .903 1 r
F P
0 g
s
.62212 .40457 m .62215 .40462 L .63288 .39829 L p 0 .575 .884 r
F P
0 g
s
.63288 .39829 m .63285 .39824 L .62212 .40457 L p 0 .575 .884 r
F P
0 g
s
.62215 .40462 m .62495 .44993 L .63595 .44371 L p 0 .114 .472 r
F P
0 g
s
.63595 .44371 m .63288 .39829 L .62215 .40462 L p 0 .114 .472 r
F P
0 g
s
.62212 .40457 m .58379 .37863 L p .62495 .44993 L 0 .673 .397 r
F P
0 g
s
.62495 .44993 m .62215 .40462 L .62212 .40457 L p 0 .673 .397 r
F P
0 g
s
.54165 .54396 m .55192 .5384 L .55195 .53839 L p 0 .1 .1 r
F P
0 g
s
.55192 .5384 m .54165 .54396 L .50147 .52122 L p 0 .911 1 r
F P
0 g
s
.4913 .52696 m .50147 .52122 L .54165 .54396 L p 0 .911 1 r
F P
0 g
s
.25046 .66966 m .24455 .67298 L .29058 .69235 L p 0 .916 1 r
F P
0 g
s
.29058 .69235 m .29653 .68918 L .25046 .66966 L p 0 .916 1 r
F P
0 g
s
.29653 .68918 m .29058 .69235 L .28576 .74435 L p 0 .1 .423 r
F P
0 g
s
.23854 .72575 m .24455 .67298 L .29058 .69235 L p 0 .704 .528 r
F P
0 g
s
.29058 .69235 m .28576 .74435 L .23854 .72575 L p 0 .704 .528 r
F P
0 g
s
.29653 .68918 m .29058 .69235 L .24455 .67298 L p 0 .916 1 r
F P
0 g
s
.25046 .66966 m .24455 .67298 L .25029 .62257 L p 0 .1 .396 r
F P
0 g
s
.25029 .62257 m .25609 .61914 L .25046 .66966 L p 0 .1 .396 r
F P
0 g
s
.20913 .59802 m .20337 .60161 L .25029 .62257 L p 0 .914 1 r
F P
0 g
s
.25029 .62257 m .25609 .61914 L .20913 .59802 L p 0 .914 1 r
F P
0 g
s
.25609 .61914 m .25029 .62257 L .24455 .67298 L p 0 .1 .396 r
F P
0 g
s
.20334 .60163 m .20337 .60161 L .25029 .62257 L p 0 .704 .528 r
F P
0 g
s
.19636 .6527 m .20334 .60163 L p .25029 .62257 L 0 .704 .528 r
F P
0 g
s
.25029 .62257 m .24455 .67298 L .19636 .6527 L p 0 .704 .528 r
F P
0 g
s
.29705 .4028 m .29709 .40279 L .30601 .39644 L p 0 1 .86 r
F P
0 g
s
.29238 .44814 m .29705 .4028 L .29709 .40279 L p 0 .697 .491 r
F P
0 g
s
.29238 .44814 m .29705 .4028 L .29709 .40279 L p 0 .697 .491 r
F P
0 g
s
.25119 .51957 m .25116 .51952 L .25675 .47258 L p 0 .701 0 r
F P
0 g
s
.25116 .51952 m .25675 .47258 L .26545 .46662 L p 0 .1 0 r
F P
0 g
s
.42588 .51372 m .42756 .46662 L .41796 .47258 L p 0 .1 0 r
F P
0 g
s
.41796 .47258 m .41607 .51955 L .42588 .51372 L p 0 .1 0 r
F P
0 g
s
.37484 .44814 m .41796 .47258 L .42756 .46662 L p 0 .907 0 r
F P
0 g
s
.41796 .47258 m .41607 .51955 L .37189 .49565 L p 0 .693 0 r
F P
0 g
s
.41796 .47258 m .37484 .44814 L .36538 .45431 L p 0 .907 0 r
F P
0 g
s
.37189 .49565 m .37484 .44814 L .41796 .47258 L p 0 .693 0 r
F P
0 g
s
.41796 .47258 m .41607 .51955 L .37189 .49565 L p 0 .693 0 r
F P
0 g
s
.37189 .49565 m .37484 .44814 L .41796 .47258 L p 0 .693 0 r
F P
0 g
s
.38441 .4419 m .42756 .46662 L .41796 .47258 L p 0 .907 0 r
F P
0 g
s
.41796 .47258 m .37484 .44814 L .38441 .4419 L p 0 .907 0 r
F P
0 g
s
.37484 .44814 m .37766 .40277 L .38703 .39642 L p 0 .1 0 r
F P
0 g
s
.37766 .40277 m .37484 .44814 L .36538 .45431 L p 0 .1 0 r
F P
0 g
s
.38441 .4419 m .38703 .39642 L .37766 .40277 L p 0 .1 0 r
F P
0 g
s
.37766 .40277 m .37484 .44814 L .38441 .4419 L p 0 .1 0 r
F P
0 g
s
.33364 .37675 m .37766 .40277 L .38703 .39642 L p 0 .903 0 r
F P
0 g
s
.37766 .40277 m .37484 .44814 L .32969 .42256 L p 0 .693 0 r
F P
0 g
s
.37766 .40277 m .33364 .37675 L .32441 .38333 L p 0 .903 0 r
F P
0 g
s
.33364 .37675 m .37766 .40277 L p .32969 .42256 L 0 .693 0 r
F P
0 g
s
.37766 .40277 m .37484 .44814 L .32969 .42256 L p 0 .693 0 r
F P
0 g
s
.33364 .37675 m .37766 .40277 L p .32969 .42256 L 0 .693 0 r
F P
0 g
s
.25675 .47258 m .25116 .51952 L .2424 .52528 L p 0 .1 0 r
F P
0 g
s
.34295 .51372 m .38703 .53681 L .37766 .54238 L p 0 .911 1 r
F P
0 g
s
.37766 .54238 m .33361 .51955 L .34295 .51372 L p 0 .911 1 r
F P
0 g
s
.33361 .51955 m .33735 .47258 L .3465 .46662 L p 0 .1 .396 r
F P
0 g
s
.33735 .47258 m .33361 .51955 L .32438 .52532 L p 0 .1 .396 r
F P
0 g
s
.34295 .51372 m .3465 .46662 L .33735 .47258 L p 0 .1 .396 r
F P
0 g
s
.33735 .47258 m .33361 .51955 L .34295 .51372 L p 0 .1 .396 r
F P
0 g
s
.29238 .44814 m .33735 .47258 L .3465 .46662 L p 0 .907 1 r
F P
0 g
s
.33735 .47258 m .33361 .51955 L .28753 .49567 L p 0 .697 .491 r
F P
0 g
s
.33735 .47258 m .29238 .44814 L .28339 .45431 L p 0 .907 1 r
F P
0 g
s
.29238 .44814 m .33735 .47258 L p .28753 .49567 L 0 .697 .491 r
F P
0 g
s
.33735 .47258 m .33361 .51955 L .28753 .49567 L p 0 .697 .491 r
F P
0 g
s
.29238 .44814 m .33735 .47258 L p .28753 .49567 L 0 .697 .491 r
F P
0 g
s
.30148 .4419 m .3465 .46662 L .33735 .47258 L p 0 .907 1 r
F P
0 g
s
.33735 .47258 m .29238 .44814 L .30148 .4419 L p 0 .907 1 r
F P
0 g
s
.46735 .4419 m .46808 .39642 L .45826 .40277 L p 0 .1 .423 r
F P
0 g
s
.45826 .40277 m .4573 .44814 L .46735 .4419 L p 0 .1 .423 r
F P
0 g
s
.41607 .37673 m .45826 .40277 L .46808 .39642 L p 0 .903 1 r
F P
0 g
s
.45826 .40277 m .4573 .44814 L .41409 .42256 L p 0 .687 .449 r
F P
0 g
s
.45826 .40277 m .41607 .37673 L .40637 .38331 L p 0 .903 1 r
F P
0 g
s
.41409 .42256 m .41607 .37673 L .45826 .40277 L p 0 .687 .449 r
F P
0 g
s
.45826 .40277 m .4573 .44814 L .41409 .42256 L p 0 .687 .449 r
F P
0 g
s
.41409 .42256 m .41607 .37673 L .45826 .40277 L p 0 .687 .449 r
F P
0 g
s
.30601 .39644 m .30597 .39645 L .29705 .4028 L p 0 1 .86 r
F P
0 g
s
.29238 .44814 m .29705 .4028 L .30597 .39645 L p 0 .1 .365 r
F P
0 g
s
.29705 .4028 m .29238 .44814 L .28339 .45431 L p 0 .1 .365 r
F P
0 g
s
.22225 .53853 m .22228 .53858 L .2166 .54232 L p 0 .546 .889 r
F P
0 g
s
.2166 .54232 m .21658 .54227 L .22225 .53853 L p 0 .546 .889 r
F P
0 g
s
.199 .74665 m .2061 .7429 L .25307 .76073 L p 0 .916 1 r
F P
0 g
s
.15791 .67548 m .16481 .67139 L .21271 .69083 L p 0 .916 1 r
F P
0 g
s
.199 .74665 m .2061 .7429 L .21271 .69083 L p 0 .1 .396 r
F P
0 g
s
.15691 .72419 m .16481 .67139 L .21271 .69083 L p 0 .707 .542 r
F P
0 g
s
.15694 .72424 m .15691 .72419 L p .21271 .69083 L 0 .707 .542 r
F P
0 g
s
.21271 .69083 m .2061 .7429 L .15694 .72424 L p 0 .707 .542 r
F P
0 g
s
.42071 .76049 m .42068 .76051 L .43031 .75616 L p 0 .1 0 r
F P
0 g
s
.37758 .59963 m .42071 .62069 L .43034 .61555 L p 0 .914 1 r
F P
0 g
s
.42872 .66619 m .43034 .61555 L .42071 .62069 L p 0 .1 .45 r
F P
0 g
s
.42071 .62069 m .41888 .67116 L .42872 .66619 L p 0 .1 .45 r
F P
0 g
s
.42071 .62069 m .37758 .59963 L .36809 .60495 L p 0 .914 1 r
F P
0 g
s
.3747 .65079 m .37758 .59963 L .42071 .62069 L p 0 .697 .491 r
F P
0 g
s
.42071 .62069 m .41888 .67116 L .40915 .67607 L p 0 .1 .45 r
F P
0 g
s
.42071 .62069 m .41888 .67116 L .3747 .65079 L p 0 .697 .491 r
F P
0 g
s
.3747 .65079 m .37758 .59963 L .42071 .62069 L p 0 .697 .491 r
F P
0 g
s
.42071 .62069 m .41888 .67116 L .3747 .65079 L p 0 .697 .491 r
F P
0 g
s
.41888 .67116 m .42071 .62069 L .43034 .61555 L p 0 .1 .45 r
F P
0 g
s
.42872 .66619 m .47093 .68586 L .46108 .69061 L p 0 .916 1 r
F P
0 g
s
.46108 .69061 m .41888 .67116 L .42872 .66619 L p 0 .916 1 r
F P
0 g
s
.41888 .67116 m .46108 .69061 L .47093 .68586 L p 0 .916 1 r
F P
0 g
s
.47026 .73809 m .47093 .68586 L .46108 .69061 L p 0 .114 .472 r
F P
0 g
s
.46108 .69061 m .46018 .74265 L .47026 .73809 L p 0 .114 .472 r
F P
0 g
s
.46108 .69061 m .41888 .67116 L .40915 .67607 L p 0 .916 1 r
F P
0 g
s
.41697 .724 m .41888 .67116 L .46108 .69061 L p 0 .697 .491 r
F P
0 g
s
.46015 .74267 m .46018 .74265 L .45021 .74715 L p 0 .1 .1 r
F P
0 g
s
.46015 .74267 m .41697 .724 L p .46108 .69061 L 0 .697 .491 r
F P
0 g
s
.46108 .69061 m .46018 .74265 L .46015 .74267 L p 0 .697 .491 r
F P
0 g
s
.41697 .724 m .41888 .67116 L .46108 .69061 L p 0 .697 .491 r
F P
0 g
s
.46015 .74267 m .41697 .724 L p .46108 .69061 L 0 .697 .491 r
F P
0 g
s
.46108 .69061 m .46018 .74265 L .46015 .74267 L p 0 .697 .491 r
F P
0 g
s
.34566 .66619 m .38975 .68586 L .38034 .69061 L p 0 .916 0 r
F P
0 g
s
.38034 .69061 m .33629 .67116 L .34566 .66619 L p 0 .916 0 r
F P
0 g
s
.33629 .67116 m .38034 .69061 L .38975 .68586 L p 0 .916 0 r
F P
0 g
s
.38719 .73813 m .38975 .68586 L .38034 .69061 L p 0 .1 0 r
F P
0 g
s
.38034 .69061 m .37758 .74268 L .38719 .73813 L p 0 .1 0 r
F P
0 g
s
.38034 .69061 m .33629 .67116 L .32703 .67607 L p 0 .916 0 r
F P
0 g
s
.33243 .724 m .33629 .67116 L .38034 .69061 L p 0 .701 0 r
F P
0 g
s
.38034 .69061 m .37758 .74268 L .36809 .74719 L p 0 .1 0 r
F P
0 g
s
.38034 .69061 m .37758 .74268 L .33243 .724 L p 0 .701 0 r
F P
0 g
s
.37758 .74268 m .38034 .69061 L .38975 .68586 L p 0 .1 0 r
F P
0 g
s
.33629 .67116 m .33998 .62069 L .34915 .61555 L p 0 .1 0 r
F P
0 g
s
.33243 .724 m .33629 .67116 L .38034 .69061 L p 0 .701 0 r
F P
0 g
s
.38034 .69061 m .37758 .74268 L .33243 .724 L p 0 .701 0 r
F P
0 g
s
.33998 .62069 m .33629 .67116 L .32703 .67607 L p 0 .1 0 r
F P
0 g
s
.46018 .59963 m .50141 .62067 L .5115 .61554 L p 0 .914 0 r
F P
0 g
s
.51179 .66619 m .51153 .61559 L .50144 .62072 L p 0 .114 0 r
F P
0 g
s
.50144 .62072 m .50147 .67116 L .51179 .66619 L p 0 .114 0 r
F P
0 g
s
.51153 .61559 m .5115 .61554 L .50141 .62067 L p 0 .562 0 r
F P
0 g
s
.50141 .62067 m .50144 .62072 L .51153 .61559 L p 0 .562 0 r
F P
0 g
s
.50141 .62067 m .46018 .59963 L .45021 .60495 L p 0 .914 0 r
F P
0 g
s
.45924 .65079 m .46018 .59963 L .50141 .62067 L p 0 .693 0 r
F P
0 g
s
.50147 .67116 m .45924 .65079 L p .50141 .62067 L 0 .693 0 r
F P
0 g
s
.50141 .62067 m .50144 .62072 L .50147 .67116 L p 0 .693 0 r
F P
0 g
s
.45924 .65079 m .46018 .59963 L .50141 .62067 L p 0 .693 0 r
F P
0 g
s
.50147 .67116 m .45924 .65079 L p .50141 .62067 L 0 .693 0 r
F P
0 g
s
.50141 .62067 m .50144 .62072 L .50147 .67116 L p 0 .693 0 r
F P
0 g
s
.38719 .73813 m .43031 .75616 L .42068 .76051 L p 0 .916 0 r
F P
0 g
s
.42068 .76051 m .37758 .74268 L .38719 .73813 L p 0 .916 0 r
F P
0 g
s
.29512 .74262 m .29974 .69054 L .30574 .68736 L p 0 .1 .425 r
F P
0 g
s
.29974 .69054 m .29512 .74262 L .28905 .74565 L p 0 .1 .425 r
F P
0 g
s
.30124 .73956 m .34626 .75754 L .34011 .76046 L p 0 .916 1 r
F P
0 g
s
.34011 .76046 m .29512 .74262 L .30124 .73956 L p 0 .916 1 r
F P
0 g
s
.30083 .59269 m .2917 .59809 L .33683 .61922 L p 0 .914 0 r
F P
0 g
s
.33683 .61922 m .346 .61406 L .30083 .59269 L p 0 .914 0 r
F P
0 g
s
.346 .61406 m .33683 .61922 L .33306 .66973 L p 0 .1 0 r
F P
0 g
s
.28678 .6493 m .2917 .59809 L .33683 .61922 L p 0 .701 0 r
F P
0 g
s
.32381 .67466 m .33306 .66973 L .33683 .61922 L p 0 .1 0 r
F P
0 g
s
.33683 .61922 m .33306 .66973 L .28678 .6493 L p 0 .701 0 r
F P
0 g
s
.28678 .6493 m .2917 .59809 L .33683 .61922 L p 0 .701 0 r
F P
0 g
s
.33683 .61922 m .33306 .66973 L .28678 .6493 L p 0 .701 0 r
F P
0 g
s
.25642 .66632 m .25046 .66966 L .25609 .61914 L p 0 .1 .396 r
F P
0 g
s
.25609 .61914 m .26194 .61569 L .25642 .66632 L p 0 .1 .396 r
F P
0 g
s
.25642 .66632 m .25046 .66966 L .29653 .68918 L p 0 .916 1 r
F P
0 g
s
.29653 .68918 m .30252 .68599 L .25642 .66632 L p 0 .916 1 r
F P
0 g
s
.30252 .68599 m .29653 .68918 L .29183 .74131 L p 0 .1 .423 r
F P
0 g
s
.24455 .67298 m .25046 .66966 L .29653 .68918 L p 0 .916 1 r
F P
0 g
s
.24456 .72257 m .25046 .66966 L .29653 .68918 L p 0 .704 .526 r
F P
0 g
s
.28576 .74435 m .29183 .74131 L .29653 .68918 L p 0 .1 .423 r
F P
0 g
s
.29653 .68918 m .29183 .74131 L .24456 .72257 L p 0 .704 .526 r
F P
0 g
s
.24456 .72257 m .25046 .66966 L .29653 .68918 L p 0 .704 .526 r
F P
0 g
s
.29653 .68918 m .29183 .74131 L .24456 .72257 L p 0 .704 .526 r
F P
0 g
s
.21493 .59441 m .20913 .59802 L .25609 .61914 L p 0 .914 1 r
F P
0 g
s
.25609 .61914 m .26194 .61569 L .21493 .59441 L p 0 .914 1 r
F P
0 g
s
.26194 .61569 m .25609 .61914 L .25046 .66966 L p 0 .1 .396 r
F P
0 g
s
.20337 .60161 m .20913 .59802 L .20909 .59805 L p 0 .93 .764 r
F P
0 g
s
.20909 .59805 m .20913 .59802 L .25609 .61914 L p 0 .704 .526 r
F P
0 g
s
.20222 .64922 m .20909 .59805 L p .25609 .61914 L 0 .704 .526 r
F P
0 g
s
.24455 .67298 m .25046 .66966 L .25609 .61914 L p 0 .1 .396 r
F P
0 g
s
.25609 .61914 m .25046 .66966 L .20222 .64922 L p 0 .704 .526 r
F P
0 g
s
.20909 .59805 m .20913 .59802 L .25609 .61914 L p 0 .704 .526 r
F P
0 g
s
.20222 .64922 m .20909 .59805 L p .25609 .61914 L 0 .704 .526 r
F P
0 g
s
.25609 .61914 m .25046 .66966 L .20222 .64922 L p 0 .704 .526 r
F P
0 g
s
.30252 .68599 m .29653 .68918 L .25046 .66966 L p 0 .916 1 r
F P
0 g
s
.18408 .61365 m .1759 .61875 L .17594 .61873 L p 0 .93 0 r
F P
0 g
s
.26545 .75453 m .25681 .75885 L .2098 .74094 L p 0 .916 0 r
F P
0 g
s
.21837 .73641 m .2098 .74094 L .21635 .68879 L p 0 .1 0 r
F P
0 g
s
.21635 .68879 m .22477 .68407 L .21837 .73641 L p 0 .1 0 r
F P
0 g
s
.22477 .68407 m .21635 .68879 L .16842 .66925 L p 0 .916 0 r
F P
0 g
s
.17675 .66431 m .16842 .66925 L .21635 .68879 L p 0 .916 0 r
F P
0 g
s
.21635 .68879 m .22477 .68407 L .17675 .66431 L p 0 .916 0 r
F P
0 g
s
.22477 .68407 m .21635 .68879 L .2098 .74094 L p 0 .1 0 r
F P
0 g
s
.16058 .72214 m .16842 .66925 L .21635 .68879 L p 0 .706 0 r
F P
0 g
s
.16061 .72219 m .16058 .72214 L p .21635 .68879 L 0 .706 0 r
F P
0 g
s
.21635 .68879 m .2098 .74094 L .16061 .72219 L p 0 .706 0 r
F P
0 g
s
.17675 .66431 m .16842 .66925 L .1759 .61875 L p 0 .1 0 r
F P
0 g
s
.1759 .61875 m .18408 .61365 L .17675 .66431 L p 0 .1 0 r
F P
0 g
s
.22797 .53477 m .228 .53482 L .22228 .53858 L p 0 .546 .889 r
F P
0 g
s
.22228 .53858 m .22225 .53853 L .22797 .53477 L p 0 .546 .889 r
F P
0 g
s
.56234 .53277 m .55195 .53839 L .55192 .5384 L p 0 .1 .1 r
F P
0 g
s
.55195 .53839 m .55192 .5384 L .51175 .51541 L p 0 .686 .443 r
F P
0 g
s
.55195 .53839 m .55192 .5384 L .51175 .51541 L p 0 .686 .443 r
F P
0 g
s
.51175 .372 m .55195 .39825 L .56234 .39185 L p 0 .903 0 r
F P
0 g
s
.55195 .39825 m .55315 .44371 L .59241 .46834 L p 0 .679 0 r
F P
0 g
s
.55195 .39825 m .55315 .44371 L .59241 .46834 L p 0 .679 0 r
F P
0 g
s
.55195 .39825 m .55315 .44371 L .56379 .43741 L p 0 .1 0 r
F P
0 g
s
.56379 .43741 m .56234 .39185 L .55195 .39825 L p 0 .1 0 r
F P
0 g
s
.59241 .46834 m .55315 .44371 L .54263 .44993 L p 0 .907 0 r
F P
0 g
s
.59452 .51539 m .59455 .51537 L .58379 .52118 L p 0 .1 0 r
F P
0 g
s
.59241 .46834 m .55315 .44371 L p .59452 .51539 L 0 .679 0 r
F P
0 g
s
.59452 .51539 m .59455 .51537 L .59241 .46834 L p 0 .679 0 r
F P
0 g
s
.55315 .44371 m .59241 .46834 L .60303 .46233 L p 0 .907 0 r
F P
0 g
s
.59241 .46834 m .59455 .51537 L .60543 .5095 L p 0 .114 0 r
F P
0 g
s
.60543 .5095 m .60303 .46233 L .59241 .46834 L p 0 .114 0 r
F P
0 g
s
.59241 .46834 m .55315 .44371 L p .59452 .51539 L 0 .679 0 r
F P
0 g
s
.59452 .51539 m .59455 .51537 L .59241 .46834 L p 0 .679 0 r
F P
0 g
s
.55315 .44371 m .55195 .39825 L .56234 .39185 L p 0 .1 0 r
F P
0 g
s
.55195 .39825 m .51175 .372 L .50147 .37863 L p 0 .903 0 r
F P
0 g
s
.55195 .39825 m .55315 .44371 L .54263 .44993 L p 0 .1 0 r
F P
0 g
s
.55315 .44371 m .55195 .39825 L .51175 .372 L p 0 .679 0 r
F P
0 g
s
.55315 .44371 m .55195 .39825 L .51175 .372 L p 0 .679 0 r
F P
0 g
s
.59241 .46834 m .55315 .44371 L .56379 .43741 L p 0 .907 0 r
F P
0 g
s
.56379 .43741 m .60303 .46233 L .59241 .46834 L p 0 .907 0 r
F P
0 g
s
.43888 .50953 m .42896 .51541 L .43056 .46834 L p 0 .1 0 r
F P
0 g
s
.43056 .46834 m .44027 .46233 L .43888 .50953 L p 0 .1 0 r
F P
0 g
s
.48096 .53281 m .47103 .53842 L .42896 .51541 L p 0 .911 0 r
F P
0 g
s
.41915 .52122 m .42896 .51541 L .47103 .53842 L p 0 .911 0 r
F P
0 g
s
.48052 .43741 m .47036 .44371 L .51149 .46834 L p 0 .907 1 r
F P
0 g
s
.51149 .46834 m .52165 .46233 L .48052 .43741 L p 0 .907 1 r
F P
0 g
s
.52165 .46233 m .51149 .46834 L .51175 .51541 L p 0 .1 .45 r
F P
0 g
s
.50147 .52122 m .51175 .51541 L .51149 .46834 L p 0 .1 .45 r
F P
0 g
s
.51149 .46834 m .51175 .51541 L .46966 .49131 L p 0 .686 .443 r
F P
0 g
s
.46031 .44993 m .47036 .44371 L .51149 .46834 L p 0 .907 1 r
F P
0 g
s
.46966 .49131 m .47036 .44371 L .51149 .46834 L p 0 .686 .443 r
F P
0 g
s
.51149 .46834 m .51175 .51541 L .46966 .49131 L p 0 .686 .443 r
F P
0 g
s
.46966 .49131 m .47036 .44371 L .51149 .46834 L p 0 .686 .443 r
F P
0 g
s
.52165 .46233 m .51149 .46834 L .47036 .44371 L p 0 .907 1 r
F P
0 g
s
.48052 .43741 m .47036 .44371 L .47103 .39825 L p 0 .1 .425 r
F P
0 g
s
.47103 .39825 m .48096 .39185 L .48052 .43741 L p 0 .1 .425 r
F P
0 g
s
.52216 .50953 m .51175 .51541 L .51149 .46834 L p 0 .1 .45 r
F P
0 g
s
.51149 .46834 m .52165 .46233 L .52216 .50953 L p 0 .1 .45 r
F P
0 g
s
.63595 .44371 m .63288 .39829 L .63285 .39824 L p 0 .671 .39 r
F P
0 g
s
.63285 .39824 m .63288 .39829 L .64373 .39188 L p 0 .575 .884 r
F P
0 g
s
.63288 .39829 m .63595 .44371 L .64706 .43741 L p 0 .114 .472 r
F P
0 g
s
.64706 .43741 m .64373 .39188 L .63288 .39829 L p 0 .114 .472 r
F P
0 g
s
.63595 .44371 m .63288 .39829 L .63285 .39824 L p 0 .671 .39 r
F P
0 g
s
.63285 .39824 m .59455 .372 L .58379 .37863 L p 0 .903 1 r
F P
0 g
s
.63285 .39824 m .59455 .372 L p .63595 .44371 L 0 .671 .39 r
F P
0 g
s
.59455 .372 m .63285 .39824 L .6437 .39183 L p 0 .903 1 r
F P
0 g
s
.64373 .39188 m .6437 .39183 L .63285 .39824 L p 0 .575 .884 r
F P
0 g
s
.63285 .39824 m .59455 .372 L p .63595 .44371 L 0 .671 .39 r
F P
0 g
s
.55192 .5384 m .56232 .53279 L .56234 .53277 L p 0 .1 .1 r
F P
0 g
s
.56232 .53279 m .55192 .5384 L .51175 .51541 L p 0 .911 1 r
F P
0 g
s
.50147 .52122 m .51175 .51541 L .55192 .5384 L p 0 .911 1 r
F P
0 g
s
.30124 .73956 m .30574 .68736 L .31178 .68415 L p 0 .1 .425 r
F P
0 g
s
.30741 .73649 m .35246 .7546 L .34626 .75754 L p 0 .916 1 r
F P
0 g
s
.34626 .75754 m .30124 .73956 L .30741 .73649 L p 0 .916 1 r
F P
0 g
s
.30574 .68736 m .30124 .73956 L .29512 .74262 L p 0 .1 .425 r
F P
0 g
s
.30597 .39645 m .30601 .39644 L .31503 .39001 L p 0 1 .86 r
F P
0 g
s
.30148 .4419 m .30597 .39645 L .30601 .39644 L p 0 .696 .486 r
F P
0 g
s
.30148 .4419 m .30597 .39645 L .30601 .39644 L p 0 .696 .486 r
F P
0 g
s
.26902 .50784 m .31499 .53118 L .30597 .53681 L p 0 .911 0 r
F P
0 g
s
.30597 .53681 m .26005 .51374 L .26902 .50784 L p 0 .911 0 r
F P
0 g
s
.26005 .51374 m .26002 .51369 L .26545 .46662 L p 0 .7 0 r
F P
0 g
s
.26005 .51374 m .26002 .51369 L .26545 .46662 L p 0 .7 0 r
F P
0 g
s
.26002 .51369 m .26545 .46662 L .27424 .46059 L p 0 .1 0 r
F P
0 g
s
.26545 .46662 m .26002 .51369 L .25116 .51952 L p 0 .1 0 r
F P
0 g
s
.4358 .50783 m .43726 .46059 L .42756 .46662 L p 0 .1 0 r
F P
0 g
s
.42756 .46662 m .42588 .51372 L .4358 .50783 L p 0 .1 0 r
F P
0 g
s
.38441 .4419 m .42756 .46662 L .43726 .46059 L p 0 .907 0 r
F P
0 g
s
.42756 .46662 m .42588 .51372 L .38168 .48954 L p 0 .692 0 r
F P
0 g
s
.42756 .46662 m .38441 .4419 L .37484 .44814 L p 0 .907 0 r
F P
0 g
s
.38168 .48954 m .38441 .4419 L .42756 .46662 L p 0 .692 0 r
F P
0 g
s
.42756 .46662 m .42588 .51372 L .38168 .48954 L p 0 .692 0 r
F P
0 g
s
.38168 .48954 m .38441 .4419 L .42756 .46662 L p 0 .692 0 r
F P
0 g
s
.3941 .43559 m .43726 .46059 L .42756 .46662 L p 0 .907 0 r
F P
0 g
s
.42756 .46662 m .38441 .4419 L .3941 .43559 L p 0 .907 0 r
F P
0 g
s
.38441 .4419 m .38703 .39642 L .39651 .38999 L p 0 .1 0 r
F P
0 g
s
.38703 .39642 m .38441 .4419 L .37484 .44814 L p 0 .1 0 r
F P
0 g
s
.3941 .43559 m .39651 .38999 L .38703 .39642 L p 0 .1 0 r
F P
0 g
s
.38703 .39642 m .38441 .4419 L .3941 .43559 L p 0 .1 0 r
F P
0 g
s
.34298 .3701 m .38703 .39642 L .39651 .38999 L p 0 .903 0 r
F P
0 g
s
.38703 .39642 m .38441 .4419 L .33923 .41602 L p 0 .692 0 r
F P
0 g
s
.38703 .39642 m .34298 .3701 L .33364 .37675 L p 0 .903 0 r
F P
0 g
s
.34298 .3701 m .38703 .39642 L p .33923 .41602 L 0 .692 0 r
F P
0 g
s
.38703 .39642 m .38441 .4419 L .33923 .41602 L p 0 .692 0 r
F P
0 g
s
.34298 .3701 m .38703 .39642 L p .33923 .41602 L 0 .692 0 r
F P
0 g
s
.3465 .46662 m .34295 .51372 L .33361 .51955 L p 0 .1 .396 r
F P
0 g
s
.3465 .46662 m .30148 .4419 L .29238 .44814 L p 0 .907 1 r
F P
0 g
s
.31069 .43559 m .35575 .46059 L .3465 .46662 L p 0 .907 1 r
F P
0 g
s
.3465 .46662 m .30148 .4419 L .31069 .43559 L p 0 .907 1 r
F P
0 g
s
.35239 .50783 m .39651 .53118 L .38703 .53681 L p 0 .911 1 r
F P
0 g
s
.38703 .53681 m .34295 .51372 L .35239 .50783 L p 0 .911 1 r
F P
0 g
s
.34295 .51372 m .3465 .46662 L .35575 .46059 L p 0 .1 .396 r
F P
0 g
s
.35239 .50783 m .35575 .46059 L .3465 .46662 L p 0 .1 .396 r
F P
0 g
s
.3465 .46662 m .34295 .51372 L .35239 .50783 L p 0 .1 .396 r
F P
0 g
s
.30148 .4419 m .3465 .46662 L .35575 .46059 L p 0 .907 1 r
F P
0 g
s
.3465 .46662 m .34295 .51372 L .29681 .48956 L p 0 .696 .486 r
F P
0 g
s
.30148 .4419 m .3465 .46662 L p .29681 .48956 L 0 .696 .486 r
F P
0 g
s
.3465 .46662 m .34295 .51372 L .29681 .48956 L p 0 .696 .486 r
F P
0 g
s
.30148 .4419 m .3465 .46662 L p .29681 .48956 L 0 .696 .486 r
F P
0 g
s
.47751 .43559 m .47802 .38999 L .46808 .39642 L p 0 .1 .423 r
F P
0 g
s
.46808 .39642 m .46735 .4419 L .47751 .43559 L p 0 .1 .423 r
F P
0 g
s
.42588 .37008 m .46808 .39642 L .47802 .38999 L p 0 .903 1 r
F P
0 g
s
.46808 .39642 m .46735 .4419 L .42412 .41602 L p 0 .686 .443 r
F P
0 g
s
.46808 .39642 m .42588 .37008 L .41607 .37673 L p 0 .903 1 r
F P
0 g
s
.42412 .41602 m .42588 .37008 L .46808 .39642 L p 0 .686 .443 r
F P
0 g
s
.46808 .39642 m .46735 .4419 L .42412 .41602 L p 0 .686 .443 r
F P
0 g
s
.42412 .41602 m .42588 .37008 L .46808 .39642 L p 0 .686 .443 r
F P
0 g
s
.31503 .39001 m .31499 .39003 L .30597 .39645 L p 0 1 .86 r
F P
0 g
s
.30148 .4419 m .30597 .39645 L .31499 .39003 L p 0 .1 .365 r
F P
0 g
s
.30597 .39645 m .30148 .4419 L .29238 .44814 L p 0 .1 .365 r
F P
0 g
s
.30857 .68277 m .30252 .68599 L .25642 .66632 L p 0 .916 1 r
F P
0 g
s
.26242 .66295 m .25642 .66632 L .26194 .61569 L p 0 .1 .396 r
F P
0 g
s
.26194 .61569 m .26782 .61221 L .26242 .66295 L p 0 .1 .396 r
F P
0 g
s
.25046 .66966 m .25642 .66632 L .30252 .68599 L p 0 .916 1 r
F P
0 g
s
.26242 .66295 m .25642 .66632 L .30252 .68599 L p 0 .916 1 r
F P
0 g
s
.30252 .68599 m .30857 .68277 L .26242 .66295 L p 0 .916 1 r
F P
0 g
s
.30857 .68277 m .30252 .68599 L .29795 .73825 L p 0 .1 .423 r
F P
0 g
s
.25064 .71936 m .25642 .66632 L .30252 .68599 L p 0 .704 .523 r
F P
0 g
s
.29183 .74131 m .29795 .73825 L .30252 .68599 L p 0 .1 .423 r
F P
0 g
s
.30252 .68599 m .29795 .73825 L .25064 .71936 L p 0 .704 .523 r
F P
0 g
s
.25064 .71936 m .25642 .66632 L .30252 .68599 L p 0 .704 .523 r
F P
0 g
s
.30252 .68599 m .29795 .73825 L .25064 .71936 L p 0 .704 .523 r
F P
0 g
s
.22077 .59076 m .21493 .59441 L .26194 .61569 L p 0 .914 1 r
F P
0 g
s
.26194 .61569 m .26782 .61221 L .22077 .59076 L p 0 .914 1 r
F P
0 g
s
.26782 .61221 m .26194 .61569 L .25642 .66632 L p 0 .1 .396 r
F P
0 g
s
.20913 .59802 m .21493 .59441 L .21489 .59443 L p 0 .93 .764 r
F P
0 g
s
.21489 .59443 m .21493 .59441 L .26194 .61569 L p 0 .704 .523 r
F P
0 g
s
.20813 .64572 m .21489 .59443 L p .26194 .61569 L 0 .704 .523 r
F P
0 g
s
.25046 .66966 m .25642 .66632 L .26194 .61569 L p 0 .1 .396 r
F P
0 g
s
.26194 .61569 m .25642 .66632 L .20813 .64572 L p 0 .704 .523 r
F P
0 g
s
.21489 .59443 m .21493 .59441 L .26194 .61569 L p 0 .704 .523 r
F P
0 g
s
.20813 .64572 m .21489 .59443 L p .26194 .61569 L 0 .704 .523 r
F P
0 g
s
.26194 .61569 m .25642 .66632 L .20813 .64572 L p 0 .704 .523 r
F P
0 g
s
.43034 .75613 m .43031 .75616 L .44005 .75176 L p 0 .1 0 r
F P
0 g
s
.43034 .61555 m .38719 .59425 L .37758 .59963 L p 0 .914 1 r
F P
0 g
s
.43868 .66116 m .4809 .68106 L .47093 .68586 L p 0 .916 1 r
F P
0 g
s
.47093 .68586 m .42872 .66619 L .43868 .66116 L p 0 .916 1 r
F P
0 g
s
.43034 .61555 m .42872 .66619 L .41888 .67116 L p 0 .1 .45 r
F P
0 g
s
.38719 .59425 m .43034 .61555 L .44008 .61035 L p 0 .914 1 r
F P
0 g
s
.43868 .66116 m .44008 .61035 L .43034 .61555 L p 0 .1 .45 r
F P
0 g
s
.43034 .61555 m .42872 .66619 L .43868 .66116 L p 0 .1 .45 r
F P
0 g
s
.38451 .64558 m .38719 .59425 L .43034 .61555 L p 0 .696 .486 r
F P
0 g
s
.43034 .61555 m .42872 .66619 L .38451 .64558 L p 0 .696 .486 r
F P
0 g
s
.38451 .64558 m .38719 .59425 L .43034 .61555 L p 0 .696 .486 r
F P
0 g
s
.43034 .61555 m .42872 .66619 L .38451 .64558 L p 0 .696 .486 r
F P
0 g
s
.42872 .66619 m .43034 .61555 L .44008 .61035 L p 0 .1 .45 r
F P
0 g
s
.42872 .66619 m .47093 .68586 L .4809 .68106 L p 0 .916 1 r
F P
0 g
s
.48046 .73348 m .4809 .68106 L .47093 .68586 L p 0 .114 .472 r
F P
0 g
s
.47093 .68586 m .47026 .73809 L .48046 .73348 L p 0 .114 .472 r
F P
0 g
s
.47093 .68586 m .42872 .66619 L .41888 .67116 L p 0 .916 1 r
F P
0 g
s
.42703 .71923 m .42872 .66619 L .47093 .68586 L p 0 .696 .486 r
F P
0 g
s
.47023 .73811 m .47026 .73809 L .46018 .74265 L p 0 .1 .1 r
F P
0 g
s
.47023 .73811 m .42703 .71923 L p .47093 .68586 L 0 .696 .486 r
F P
0 g
s
.47093 .68586 m .47026 .73809 L .47023 .73811 L p 0 .696 .486 r
F P
0 g
s
.42703 .71923 m .42872 .66619 L .47093 .68586 L p 0 .696 .486 r
F P
0 g
s
.47023 .73811 m .42703 .71923 L p .47093 .68586 L 0 .696 .486 r
F P
0 g
s
.47093 .68586 m .47026 .73809 L .47023 .73811 L p 0 .696 .486 r
F P
0 g
s
.34566 .66619 m .34915 .61555 L .35843 .61035 L p 0 .1 0 r
F P
0 g
s
.35513 .66116 m .39925 .68106 L .38975 .68586 L p 0 .916 0 r
F P
0 g
s
.38975 .68586 m .34566 .66619 L .35513 .66116 L p 0 .916 0 r
F P
0 g
s
.34915 .61555 m .34566 .66619 L .33629 .67116 L p 0 .1 0 r
F P
0 g
s
.34566 .66619 m .38975 .68586 L .39925 .68106 L p 0 .916 0 r
F P
0 g
s
.39691 .73352 m .39925 .68106 L .38975 .68586 L p 0 .1 0 r
F P
0 g
s
.38975 .68586 m .38719 .73813 L .39691 .73352 L p 0 .1 0 r
F P
0 g
s
.38975 .68586 m .34566 .66619 L .33629 .67116 L p 0 .916 0 r
F P
0 g
s
.34199 .71923 m .34566 .66619 L .38975 .68586 L p 0 .7 0 r
F P
0 g
s
.38975 .68586 m .38719 .73813 L .37758 .74268 L p 0 .1 0 r
F P
0 g
s
.38975 .68586 m .38719 .73813 L .34199 .71923 L p 0 .7 0 r
F P
0 g
s
.34199 .71923 m .34566 .66619 L .38975 .68586 L p 0 .7 0 r
F P
0 g
s
.38975 .68586 m .38719 .73813 L .34199 .71923 L p 0 .7 0 r
F P
0 g
s
.38719 .73813 m .38975 .68586 L .39925 .68106 L p 0 .1 0 r
F P
0 g
s
.47026 .59425 m .5115 .61554 L .52169 .61034 L p 0 .914 0 r
F P
0 g
s
.52223 .66116 m .52172 .61039 L .51153 .61559 L p 0 .114 0 r
F P
0 g
s
.51153 .61559 m .51179 .66619 L .52223 .66116 L p 0 .114 0 r
F P
0 g
s
.52172 .61039 m .52169 .61034 L .5115 .61554 L p 0 .562 0 r
F P
0 g
s
.5115 .61554 m .51153 .61559 L .52172 .61039 L p 0 .562 0 r
F P
0 g
s
.5115 .61554 m .47026 .59425 L .46018 .59963 L p 0 .914 0 r
F P
0 g
s
.46955 .64558 m .47026 .59425 L .5115 .61554 L p 0 .692 0 r
F P
0 g
s
.51179 .66619 m .46955 .64558 L p .5115 .61554 L 0 .692 0 r
F P
0 g
s
.5115 .61554 m .51153 .61559 L .51179 .66619 L p 0 .692 0 r
F P
0 g
s
.46955 .64558 m .47026 .59425 L .5115 .61554 L p 0 .692 0 r
F P
0 g
s
.51179 .66619 m .46955 .64558 L p .5115 .61554 L 0 .692 0 r
F P
0 g
s
.5115 .61554 m .51153 .61559 L .51179 .66619 L p 0 .692 0 r
F P
0 g
s
.39691 .73352 m .44005 .75176 L .43031 .75616 L p 0 .916 0 r
F P
0 g
s
.43031 .75616 m .38719 .73813 L .39691 .73352 L p 0 .916 0 r
F P
0 g
s
.23373 .53098 m .23376 .53103 L .228 .53482 L p 0 .546 .889 r
F P
0 g
s
.228 .53482 m .22797 .53477 L .23373 .53098 L p 0 .546 .889 r
F P
0 g
s
.31006 .58723 m .30083 .59269 L .346 .61406 L p 0 .914 0 r
F P
0 g
s
.346 .61406 m .35528 .60885 L .31006 .58723 L p 0 .914 0 r
F P
0 g
s
.35528 .60885 m .346 .61406 L .34243 .66475 L p 0 .1 0 r
F P
0 g
s
.29609 .64407 m .30083 .59269 L .346 .61406 L p 0 .7 0 r
F P
0 g
s
.33306 .66973 m .34243 .66475 L .346 .61406 L p 0 .1 0 r
F P
0 g
s
.346 .61406 m .34243 .66475 L .29609 .64407 L p 0 .7 0 r
F P
0 g
s
.29609 .64407 m .30083 .59269 L .346 .61406 L p 0 .7 0 r
F P
0 g
s
.346 .61406 m .34243 .66475 L .29609 .64407 L p 0 .7 0 r
F P
0 g
s
.30741 .73649 m .31178 .68415 L .31787 .68092 L p 0 .1 .425 r
F P
0 g
s
.31362 .73339 m .3587 .75164 L .35246 .7546 L p 0 .916 1 r
F P
0 g
s
.35246 .7546 m .30741 .73649 L .31362 .73339 L p 0 .916 1 r
F P
0 g
s
.31178 .68415 m .30741 .73649 L .30124 .73956 L p 0 .1 .425 r
F P
0 g
s
.19236 .60848 m .18408 .61365 L .18412 .61363 L p 0 .93 0 r
F P
0 g
s
.22704 .73183 m .21837 .73641 L .22477 .68407 L p 0 .1 0 r
F P
0 g
s
.22477 .68407 m .23328 .6793 L .22704 .73183 L p 0 .1 0 r
F P
0 g
s
.27418 .75015 m .26545 .75453 L .21837 .73641 L p 0 .916 0 r
F P
0 g
s
.2098 .74094 m .21837 .73641 L .26545 .75453 L p 0 .916 0 r
F P
0 g
s
.23328 .6793 m .22477 .68407 L .17675 .66431 L p 0 .916 0 r
F P
0 g
s
.16842 .66925 m .17675 .66431 L .22477 .68407 L p 0 .916 0 r
F P
0 g
s
.18518 .65932 m .17675 .66431 L .22477 .68407 L p 0 .916 0 r
F P
0 g
s
.22477 .68407 m .23328 .6793 L .18518 .65932 L p 0 .916 0 r
F P
0 g
s
.23328 .6793 m .22477 .68407 L .21837 .73641 L p 0 .1 0 r
F P
0 g
s
.16907 .71739 m .17675 .66431 L .22477 .68407 L p 0 .706 0 r
F P
0 g
s
.1691 .71744 m .16907 .71739 L p .22477 .68407 L 0 .706 0 r
F P
0 g
s
.2098 .74094 m .21837 .73641 L .22477 .68407 L p 0 .1 0 r
F P
0 g
s
.22477 .68407 m .21837 .73641 L .1691 .71744 L p 0 .706 0 r
F P
0 g
s
.16907 .71739 m .17675 .66431 L .22477 .68407 L p 0 .706 0 r
F P
0 g
s
.1691 .71744 m .16907 .71739 L p .22477 .68407 L 0 .706 0 r
F P
0 g
s
.22477 .68407 m .21837 .73641 L .1691 .71744 L p 0 .706 0 r
F P
0 g
s
.18518 .65932 m .17675 .66431 L .18408 .61365 L p 0 .1 0 r
F P
0 g
s
.18408 .61365 m .19236 .60848 L .18518 .65932 L p 0 .1 0 r
F P
0 g
s
.56234 .53277 m .56232 .53279 L .52216 .50953 L p 0 .684 .437 r
F P
0 g
s
.56234 .39185 m .52216 .3653 L .51175 .372 L p 0 .903 0 r
F P
0 g
s
.56234 .39185 m .56379 .43741 L .55315 .44371 L p 0 .1 0 r
F P
0 g
s
.56379 .43741 m .56234 .39185 L .52216 .3653 L p 0 .677 0 r
F P
0 g
s
.56234 .39185 m .56379 .43741 L .60303 .46233 L p 0 .677 0 r
F P
0 g
s
.60303 .46233 m .56379 .43741 L .55315 .44371 L p 0 .907 0 r
F P
0 g
s
.6054 .50951 m .60543 .5095 L .59455 .51537 L p 0 .1 0 r
F P
0 g
s
.60303 .46233 m .56379 .43741 L p .6054 .50951 L 0 .677 0 r
F P
0 g
s
.6054 .50951 m .60543 .5095 L .60303 .46233 L p 0 .677 0 r
F P
0 g
s
.42896 .51541 m .43888 .50953 L .48096 .53281 L p 0 .911 0 r
F P
0 g
s
.51175 .51541 m .52216 .50953 L .52165 .46233 L p 0 .1 .45 r
F P
0 g
s
.52165 .46233 m .52216 .50953 L .48006 .48515 L p 0 .684 .437 r
F P
0 g
s
.47036 .44371 m .48052 .43741 L .52165 .46233 L p 0 .907 1 r
F P
0 g
s
.48006 .48515 m .48052 .43741 L .52165 .46233 L p 0 .684 .437 r
F P
0 g
s
.64706 .43741 m .64373 .39188 L .6437 .39183 L p 0 .668 .382 r
F P
0 g
s
.6437 .39183 m .60543 .3653 L .59455 .372 L p 0 .903 1 r
F P
0 g
s
.6437 .39183 m .60543 .3653 L p .64706 .43741 L 0 .668 .382 r
F P
0 g
s
.51175 .51541 m .52216 .50953 L .56232 .53279 L p 0 .911 1 r
F P
0 g
s
.57316 .52693 m .56264 .53261 L .56262 .53263 L p 0 .1 0 r
F P
0 g
s
.56264 .53261 m .56262 .53263 L .52246 .50936 L p 0 .684 0 r
F P
0 g
s
.52246 .3651 m .56264 .39166 L .57316 .38519 L p 0 .903 1 r
F P
0 g
s
.56264 .39166 m .5641 .43723 L .60334 .46215 L p 0 .677 .411 r
F P
0 g
s
.56264 .39166 m .5641 .43723 L .57487 .43087 L p 0 .1 .45 r
F P
0 g
s
.57487 .43087 m .57316 .38519 L .56264 .39166 L p 0 .1 .45 r
F P
0 g
s
.5641 .43723 m .56264 .39166 L .52246 .3651 L p 0 .677 .411 r
F P
0 g
s
.5641 .43723 m .56264 .39166 L .57316 .38519 L p 0 .1 .45 r
F P
0 g
s
.5641 .43723 m .60334 .46215 L .61409 .45607 L p 0 .907 1 r
F P
0 g
s
.60334 .46215 m .60574 .50932 L .61675 .50338 L p 0 .114 .472 r
F P
0 g
s
.61675 .50338 m .61409 .45607 L .60334 .46215 L p 0 .114 .472 r
F P
0 g
s
.60334 .46215 m .5641 .43723 L p .60572 .50934 L 0 .677 .411 r
F P
0 g
s
.60572 .50934 m .60574 .50932 L .60334 .46215 L p 0 .677 .411 r
F P
0 g
s
.60334 .46215 m .5641 .43723 L .57487 .43087 L p 0 .907 1 r
F P
0 g
s
.57487 .43087 m .61409 .45607 L .60334 .46215 L p 0 .907 1 r
F P
0 g
s
.4911 .43087 m .48081 .43723 L .52195 .46215 L p 0 .907 0 r
F P
0 g
s
.52195 .46215 m .53223 .45607 L .4911 .43087 L p 0 .907 0 r
F P
0 g
s
.53223 .45607 m .52195 .46215 L .52246 .50936 L p 0 .1 0 r
F P
0 g
s
.52195 .46215 m .52246 .50936 L .48036 .48497 L p 0 .684 0 r
F P
0 g
s
.48036 .48497 m .48081 .43723 L .52195 .46215 L p 0 .684 0 r
F P
0 g
s
.53223 .45607 m .52195 .46215 L .48081 .43723 L p 0 .907 0 r
F P
0 g
s
.4911 .43087 m .48081 .43723 L .48125 .39166 L p 0 .1 0 r
F P
0 g
s
.48125 .39166 m .4913 .38519 L .4911 .43087 L p 0 .1 0 r
F P
0 g
s
.53298 .50341 m .52246 .50936 L .52195 .46215 L p 0 .1 0 r
F P
0 g
s
.52195 .46215 m .53223 .45607 L .53298 .50341 L p 0 .1 0 r
F P
0 g
s
.44922 .50341 m .43917 .50936 L .44055 .46215 L p 0 .1 .425 r
F P
0 g
s
.44055 .46215 m .45038 .45607 L .44922 .50341 L p 0 .1 .425 r
F P
0 g
s
.4913 .52696 m .48125 .53264 L .43917 .50936 L p 0 .911 1 r
F P
0 g
s
.64739 .43723 m .64404 .3917 L .64401 .39165 L p 0 .668 0 r
F P
0 g
s
.60574 .3651 m .64401 .39165 L .65499 .38517 L p 0 .903 0 r
F P
0 g
s
.64401 .39165 m .64404 .3917 L .65502 .38522 L p 0 .575 0 r
F P
0 g
s
.65502 .38522 m .65499 .38517 L .64401 .39165 L p 0 .575 0 r
F P
0 g
s
.64404 .3917 m .64739 .43723 L .65864 .43087 L p 0 .114 0 r
F P
0 g
s
.65864 .43087 m .65502 .38522 L .64404 .3917 L p 0 .114 0 r
F P
0 g
s
.64401 .39165 m .60574 .3651 L p .64739 .43723 L 0 .668 0 r
F P
0 g
s
.56262 .53263 m .57313 .52695 L .57316 .52693 L p 0 .1 0 r
F P
0 g
s
.57313 .52695 m .56262 .53263 L .52246 .50936 L p 0 .911 0 r
F P
0 g
s
.26847 .65956 m .26242 .66295 L .30857 .68277 L p 0 .916 1 r
F P
0 g
s
.30857 .68277 m .31465 .67953 L .26847 .65956 L p 0 .916 1 r
F P
0 g
s
.31465 .67953 m .30857 .68277 L .30411 .73516 L p 0 .1 .423 r
F P
0 g
s
.25642 .66632 m .26242 .66295 L .30857 .68277 L p 0 .916 1 r
F P
0 g
s
.25676 .71612 m .26242 .66295 L .30857 .68277 L p 0 .703 .52 r
F P
0 g
s
.29795 .73825 m .30411 .73516 L .30857 .68277 L p 0 .1 .423 r
F P
0 g
s
.30857 .68277 m .30411 .73516 L .25676 .71612 L p 0 .703 .52 r
F P
0 g
s
.25676 .71612 m .26242 .66295 L .30857 .68277 L p 0 .703 .52 r
F P
0 g
s
.30857 .68277 m .30411 .73516 L .25676 .71612 L p 0 .703 .52 r
F P
0 g
s
.31465 .67953 m .30857 .68277 L .26242 .66295 L p 0 .916 1 r
F P
0 g
s
.26847 .65956 m .26242 .66295 L .26782 .61221 L p 0 .1 .396 r
F P
0 g
s
.26782 .61221 m .27376 .6087 L .26847 .65956 L p 0 .1 .396 r
F P
0 g
s
.22666 .58709 m .22077 .59076 L .26782 .61221 L p 0 .914 1 r
F P
0 g
s
.26782 .61221 m .27376 .6087 L .22666 .58709 L p 0 .914 1 r
F P
0 g
s
.27376 .6087 m .26782 .61221 L .26242 .66295 L p 0 .1 .396 r
F P
0 g
s
.21493 .59441 m .22077 .59076 L .22073 .59078 L p 0 .93 .764 r
F P
0 g
s
.22073 .59078 m .22077 .59076 L .26782 .61221 L p 0 .703 .52 r
F P
0 g
s
.21408 .64219 m .22073 .59078 L p .26782 .61221 L 0 .703 .52 r
F P
0 g
s
.25642 .66632 m .26242 .66295 L .26782 .61221 L p 0 .1 .396 r
F P
0 g
s
.26782 .61221 m .26242 .66295 L .21408 .64219 L p 0 .703 .52 r
F P
0 g
s
.22073 .59078 m .22077 .59076 L .26782 .61221 L p 0 .703 .52 r
F P
0 g
s
.21408 .64219 m .22073 .59078 L p .26782 .61221 L 0 .703 .52 r
F P
0 g
s
.26782 .61221 m .26242 .66295 L .21408 .64219 L p 0 .703 .52 r
F P
0 g
s
.31069 .43559 m .31499 .39003 L .31503 .39001 L p 0 .695 .481 r
F P
0 g
s
.27424 .46059 m .26899 .50779 L .26002 .51369 L p 0 .1 0 r
F P
0 g
s
.26902 .50784 m .26899 .50779 L .27424 .46059 L p 0 .699 0 r
F P
0 g
s
.43726 .46059 m .3941 .43559 L .38441 .4419 L p 0 .907 0 r
F P
0 g
s
.43726 .46059 m .4358 .50783 L .39158 .48336 L p 0 .69 0 r
F P
0 g
s
.39158 .48336 m .3941 .43559 L .43726 .46059 L p 0 .69 0 r
F P
0 g
s
.39651 .38999 m .3941 .43559 L .38441 .4419 L p 0 .1 0 r
F P
0 g
s
.39651 .38999 m .35243 .36337 L .34298 .3701 L p 0 .903 0 r
F P
0 g
s
.39651 .38999 m .3941 .43559 L .34888 .4094 L p 0 .69 0 r
F P
0 g
s
.35243 .36337 m .39651 .38999 L p .34888 .4094 L 0 .69 0 r
F P
0 g
s
.35575 .46059 m .31069 .43559 L .30148 .4419 L p 0 .907 1 r
F P
0 g
s
.35575 .46059 m .35239 .50783 L .34295 .51372 L p 0 .1 .396 r
F P
0 g
s
.35575 .46059 m .35239 .50783 L .30621 .48338 L p 0 .695 .481 r
F P
0 g
s
.31069 .43559 m .35575 .46059 L p .30621 .48338 L 0 .695 .481 r
F P
0 g
s
.47802 .38999 m .4358 .36335 L .42588 .37008 L p 0 .903 1 r
F P
0 g
s
.47802 .38999 m .47751 .43559 L .43427 .4094 L p 0 .684 .437 r
F P
0 g
s
.43427 .4094 m .4358 .36335 L .47802 .38999 L p 0 .684 .437 r
F P
0 g
s
.31499 .39003 m .31069 .43559 L .30148 .4419 L p 0 .1 .365 r
F P
0 g
s
.31525 .38984 m .31529 .38983 L .32441 .38333 L p 0 1 0 r
F P
0 g
s
.31095 .43541 m .31525 .38984 L .31529 .38983 L p 0 .695 0 r
F P
0 g
s
.2424 .52528 m .24243 .52533 L .23376 .53103 L p 0 .546 0 r
F P
0 g
s
.23376 .53103 m .23373 .53098 L .2424 .52528 L p 0 .546 0 r
F P
0 g
s
.36222 .50169 m .40637 .52532 L .39678 .53102 L p 0 .911 0 r
F P
0 g
s
.39678 .53102 m .35267 .50765 L .36222 .50169 L p 0 .911 0 r
F P
0 g
s
.35267 .50765 m .35602 .46041 L .36538 .45431 L p 0 .1 0 r
F P
0 g
s
.36222 .50169 m .36538 .45431 L .35602 .46041 L p 0 .1 0 r
F P
0 g
s
.35602 .46041 m .35267 .50765 L .36222 .50169 L p 0 .1 0 r
F P
0 g
s
.31095 .43541 m .35602 .46041 L .36538 .45431 L p 0 .907 0 r
F P
0 g
s
.35602 .46041 m .35267 .50765 L .30648 .4832 L p 0 .695 0 r
F P
0 g
s
.31095 .43541 m .35602 .46041 L p .30648 .4832 L 0 .695 0 r
F P
0 g
s
.32027 .42902 m .36538 .45431 L .35602 .46041 L p 0 .907 0 r
F P
0 g
s
.35602 .46041 m .31095 .43541 L .32027 .42902 L p 0 .907 0 r
F P
0 g
s
.48809 .42902 m .48836 .38331 L .47831 .38981 L p 0 .1 0 r
F P
0 g
s
.47831 .38981 m .4778 .43541 L .48809 .42902 L p 0 .1 0 r
F P
0 g
s
.43609 .36316 m .47831 .38981 L .48836 .38331 L p 0 .903 0 r
F P
0 g
s
.47831 .38981 m .4778 .43541 L .43457 .40921 L p 0 .684 0 r
F P
0 g
s
.43457 .40921 m .43609 .36316 L .47831 .38981 L p 0 .684 0 r
F P
0 g
s
.27835 .5017 m .32438 .52532 L .31526 .53102 L p 0 .911 1 r
F P
0 g
s
.31526 .53102 m .26928 .50767 L .27835 .5017 L p 0 .911 1 r
F P
0 g
s
.26928 .50767 m .26925 .50762 L .27449 .46041 L p 0 .699 .5 r
F P
0 g
s
.26925 .50762 m .27449 .46041 L .28339 .45431 L p 0 .1 .365 r
F P
0 g
s
.40418 .42902 m .44737 .45431 L .43754 .46041 L p 0 .907 1 r
F P
0 g
s
.43754 .46041 m .39438 .43541 L .40418 .42902 L p 0 .907 1 r
F P
0 g
s
.39438 .43541 m .39678 .38981 L .40637 .38331 L p 0 .1 .396 r
F P
0 g
s
.40418 .42902 m .40637 .38331 L .39678 .38981 L p 0 .1 .396 r
F P
0 g
s
.39678 .38981 m .39438 .43541 L .40418 .42902 L p 0 .1 .396 r
F P
0 g
s
.3527 .36318 m .39678 .38981 L .40637 .38331 L p 0 .903 1 r
F P
0 g
s
.39678 .38981 m .39438 .43541 L .34916 .40921 L p 0 .69 .46 r
F P
0 g
s
.3527 .36318 m .39678 .38981 L p .34916 .40921 L 0 .69 .46 r
F P
0 g
s
.44613 .50169 m .44737 .45431 L .43754 .46041 L p 0 .1 .423 r
F P
0 g
s
.43754 .46041 m .43609 .50765 L .44613 .50169 L p 0 .1 .423 r
F P
0 g
s
.39438 .43541 m .43754 .46041 L .44737 .45431 L p 0 .907 1 r
F P
0 g
s
.43754 .46041 m .43609 .50765 L .39186 .48318 L p 0 .69 .46 r
F P
0 g
s
.39186 .48318 m .39438 .43541 L .43754 .46041 L p 0 .69 .46 r
F P
0 g
s
.32441 .38333 m .32438 .38334 L .31525 .38984 L p 0 1 0 r
F P
0 g
s
.31095 .43541 m .31525 .38984 L .32438 .38334 L p 0 .1 0 r
F P
0 g
s
.4809 .68106 m .43868 .66116 L .42872 .66619 L p 0 .916 1 r
F P
0 g
s
.44008 .61035 m .39691 .58881 L .38719 .59425 L p 0 .914 1 r
F P
0 g
s
.39445 .64032 m .39691 .58881 L .44008 .61035 L p 0 .695 .481 r
F P
0 g
s
.44008 .61035 m .43868 .66116 L .42872 .66619 L p 0 .1 .45 r
F P
0 g
s
.44008 .61035 m .43868 .66116 L .39445 .64032 L p 0 .695 .481 r
F P
0 g
s
.43722 .7144 m .43868 .66116 L .4809 .68106 L p 0 .695 .481 r
F P
0 g
s
.48043 .73351 m .48046 .73348 L .47026 .73809 L p 0 .1 .1 r
F P
0 g
s
.48043 .73351 m .43722 .7144 L p .4809 .68106 L 0 .695 .481 r
F P
0 g
s
.4809 .68106 m .48046 .73348 L .48043 .73351 L p 0 .695 .481 r
F P
0 g
s
.39925 .68106 m .35513 .66116 L .34566 .66619 L p 0 .916 0 r
F P
0 g
s
.35167 .7144 m .35513 .66116 L .39925 .68106 L p 0 .699 0 r
F P
0 g
s
.39925 .68106 m .39691 .73352 L .38719 .73813 L p 0 .1 0 r
F P
0 g
s
.39925 .68106 m .39691 .73352 L .35167 .7144 L p 0 .699 0 r
F P
0 g
s
.35843 .61035 m .35513 .66116 L .34566 .66619 L p 0 .1 0 r
F P
0 g
s
.52169 .61034 m .48046 .58881 L .47026 .59425 L p 0 .914 0 r
F P
0 g
s
.47999 .64032 m .48046 .58881 L .52169 .61034 L p 0 .69 0 r
F P
0 g
s
.52223 .66116 m .47999 .64032 L p .52169 .61034 L 0 .69 0 r
F P
0 g
s
.52169 .61034 m .52172 .61039 L .52223 .66116 L p 0 .69 0 r
F P
0 g
s
.44036 .7516 m .44033 .75163 L .45018 .74718 L p 0 .1 .1 r
F P
0 g
s
.365 .65593 m .40915 .67607 L .39953 .68092 L p 0 .916 1 r
F P
0 g
s
.39953 .68092 m .35541 .66102 L .365 .65593 L p 0 .916 1 r
F P
0 g
s
.35541 .66102 m .39953 .68092 L .40915 .67607 L p 0 .916 1 r
F P
0 g
s
.40702 .72872 m .40915 .67607 L .39953 .68092 L p 0 .1 .45 r
F P
0 g
s
.39953 .68092 m .39719 .73339 L .40702 .72872 L p 0 .1 .45 r
F P
0 g
s
.35195 .71426 m .35541 .66102 L .39953 .68092 L p 0 .699 .5 r
F P
0 g
s
.39953 .68092 m .39719 .73339 L .35195 .71426 L p 0 .699 .5 r
F P
0 g
s
.39719 .73339 m .39953 .68092 L .40915 .67607 L p 0 .1 .45 r
F P
0 g
s
.35541 .66102 m .3587 .6102 L .36809 .60495 L p 0 .1 .425 r
F P
0 g
s
.43897 .66102 m .48119 .68092 L .49127 .67607 L p 0 .916 0 r
F P
0 g
s
.49107 .72868 m .49127 .67607 L .48119 .68092 L p 0 .114 0 r
F P
0 g
s
.48119 .68092 m .48075 .73335 L .49107 .72868 L p 0 .114 0 r
F P
0 g
s
.43751 .71426 m .43897 .66102 L .48119 .68092 L p 0 .695 0 r
F P
0 g
s
.48072 .73337 m .43751 .71426 L p .48119 .68092 L 0 .695 0 r
F P
0 g
s
.48119 .68092 m .48075 .73335 L .48072 .73337 L p 0 .695 0 r
F P
0 g
s
.39719 .58865 m .44036 .6102 L .45021 .60495 L p 0 .914 0 r
F P
0 g
s
.44904 .65593 m .45021 .60495 L .44036 .6102 L p 0 .1 0 r
F P
0 g
s
.44036 .6102 m .43897 .66102 L .44904 .65593 L p 0 .1 0 r
F P
0 g
s
.39473 .64016 m .39719 .58865 L .44036 .6102 L p 0 .695 0 r
F P
0 g
s
.44036 .6102 m .43897 .66102 L .39473 .64016 L p 0 .695 0 r
F P
0 g
s
.44904 .65593 m .49127 .67607 L .48119 .68092 L p 0 .916 0 r
F P
0 g
s
.48119 .68092 m .43897 .66102 L .44904 .65593 L p 0 .916 0 r
F P
0 g
s
.43897 .66102 m .44036 .6102 L .45021 .60495 L p 0 .1 0 r
F P
0 g
s
.31787 .68092 m .31362 .73339 L .30741 .73649 L p 0 .1 .425 r
F P
0 g
s
.32297 .72872 m .36809 .74719 L .3587 .75164 L p 0 .916 0 r
F P
0 g
s
.3587 .75164 m .31362 .73339 L .32297 .72872 L p 0 .916 0 r
F P
0 g
s
.31362 .73339 m .31787 .68092 L .32703 .67607 L p 0 .1 0 r
F P
0 g
s
.40702 .72872 m .45018 .74718 L .44033 .75163 L p 0 .916 1 r
F P
0 g
s
.44033 .75163 m .39719 .73339 L .40702 .72872 L p 0 .916 1 r
F P
0 g
s
.48075 .58865 m .52199 .61019 L .53231 .60493 L p 0 .914 1 r
F P
0 g
s
.53309 .65593 m .53234 .60498 L .52202 .61024 L p 0 .114 .472 r
F P
0 g
s
.52202 .61024 m .52253 .66102 L .53309 .65593 L p 0 .114 .472 r
F P
0 g
s
.53234 .60498 m .53231 .60493 L .52199 .61019 L p 0 .562 .887 r
F P
0 g
s
.52199 .61019 m .52202 .61024 L .53234 .60498 L p 0 .562 .887 r
F P
0 g
s
.48029 .64016 m .48075 .58865 L .52199 .61019 L p 0 .69 .46 r
F P
0 g
s
.52253 .66102 m .48029 .64016 L p .52199 .61019 L 0 .69 .46 r
F P
0 g
s
.52199 .61019 m .52202 .61024 L .52253 .66102 L p 0 .69 .46 r
F P
0 g
s
.34243 .66475 m .3519 .65971 L .35528 .60885 L p 0 .1 0 r
F P
0 g
s
.30552 .63879 m .31006 .58723 L .35528 .60885 L p 0 .699 0 r
F P
0 g
s
.35528 .60885 m .3519 .65971 L .30552 .63879 L p 0 .699 0 r
F P
0 g
s
.31967 .58155 m .31032 .58707 L .35555 .6087 L p 0 .914 1 r
F P
0 g
s
.35555 .6087 m .36494 .60342 L .31967 .58155 L p 0 .914 1 r
F P
0 g
s
.36494 .60342 m .35555 .6087 L .35218 .65956 L p 0 .1 .423 r
F P
0 g
s
.30579 .63864 m .31032 .58707 L .35555 .6087 L p 0 .699 .5 r
F P
0 g
s
.35555 .6087 m .35218 .65956 L .30579 .63864 L p 0 .699 .5 r
F P
0 g
s
.30411 .73516 m .31032 .73205 L .31465 .67953 L p 0 .1 .423 r
F P
0 g
s
.26242 .66295 m .26847 .65956 L .31465 .67953 L p 0 .916 1 r
F P
0 g
s
.26294 .71286 m .26847 .65956 L .31465 .67953 L p 0 .703 .518 r
F P
0 g
s
.31465 .67953 m .31032 .73205 L .26294 .71286 L p 0 .703 .518 r
F P
0 g
s
.22077 .59076 m .22666 .58709 L .22662 .58711 L p 0 .93 .764 r
F P
0 g
s
.22662 .58711 m .22666 .58709 L .27376 .6087 L p 0 .703 .518 r
F P
0 g
s
.22008 .63864 m .22662 .58711 L p .27376 .6087 L 0 .703 .518 r
F P
0 g
s
.26242 .66295 m .26847 .65956 L .27376 .6087 L p 0 .1 .396 r
F P
0 g
s
.27376 .6087 m .26847 .65956 L .22008 .63864 L p 0 .703 .518 r
F P
0 g
s
.14988 .72812 m .14293 .73201 L .15107 .67953 L p 0 .1 .365 r
F P
0 g
s
.15107 .67953 m .15791 .67548 L .14988 .72812 L p 0 .1 .365 r
F P
0 g
s
.199 .74665 m .19196 .75036 L .14296 .73206 L p 0 .916 1 r
F P
0 g
s
.27757 .65446 m .26847 .65956 L .31465 .67953 L p 0 .916 0 r
F P
0 g
s
.31465 .67953 m .32381 .67466 L .27757 .65446 L p 0 .916 0 r
F P
0 g
s
.32381 .67466 m .31465 .67953 L .31032 .73205 L p 0 .1 0 r
F P
0 g
s
.26294 .71286 m .26847 .65956 L .31465 .67953 L p 0 .703 0 r
F P
0 g
s
.31465 .67953 m .31032 .73205 L .26294 .71286 L p 0 .703 0 r
F P
0 g
s
.27757 .65446 m .26847 .65956 L .27376 .6087 L p 0 .1 0 r
F P
0 g
s
.27376 .6087 m .28268 .60342 L .27757 .65446 L p 0 .1 0 r
F P
0 g
s
.23551 .58156 m .22666 .58709 L .27376 .6087 L p 0 .914 0 r
F P
0 g
s
.27376 .6087 m .28268 .60342 L .23551 .58156 L p 0 .914 0 r
F P
0 g
s
.28268 .60342 m .27376 .6087 L .26847 .65956 L p 0 .1 0 r
F P
0 g
s
.22662 .58711 m .22666 .58709 L .27376 .6087 L p 0 .703 0 r
F P
0 g
s
.22008 .63864 m .22662 .58711 L p .27376 .6087 L 0 .703 0 r
F P
0 g
s
.27376 .6087 m .26847 .65956 L .22008 .63864 L p 0 .703 0 r
F P
0 g
s
.32381 .67466 m .31465 .67953 L .26847 .65956 L p 0 .916 0 r
F P
0 g
s
.21837 .73641 m .22704 .73183 L .27418 .75015 L p 0 .916 0 r
F P
0 g
s
.17675 .66431 m .18518 .65932 L .23328 .6793 L p 0 .916 0 r
F P
0 g
s
.21837 .73641 m .22704 .73183 L .23328 .6793 L p 0 .1 0 r
F P
0 g
s
.17766 .71258 m .18518 .65932 L .23328 .6793 L p 0 .705 0 r
F P
0 g
s
.17769 .71264 m .17766 .71258 L p .23328 .6793 L 0 .705 0 r
F P
0 g
s
.23328 .6793 m .22704 .73183 L .17769 .71264 L p 0 .705 0 r
F P
0 g
s
.57316 .52693 m .57313 .52695 L .53298 .50341 L p 0 .683 0 r
F P
0 g
s
.57316 .52693 m .57313 .52695 L .53298 .50341 L p 0 .683 0 r
F P
0 g
s
.57316 .38519 m .53298 .35832 L .52246 .3651 L p 0 .903 1 r
F P
0 g
s
.57316 .38519 m .57487 .43087 L .5641 .43723 L p 0 .1 .45 r
F P
0 g
s
.57487 .43087 m .57316 .38519 L .53298 .35832 L p 0 .675 .404 r
F P
0 g
s
.53298 .35832 m .57316 .38519 L .58379 .37863 L p 0 .903 1 r
F P
0 g
s
.57316 .38519 m .57487 .43087 L .61409 .45607 L p 0 .675 .404 r
F P
0 g
s
.57316 .38519 m .57487 .43087 L .61409 .45607 L p 0 .675 .404 r
F P
0 g
s
.57316 .38519 m .57487 .43087 L .58576 .42442 L p 0 .1 .45 r
F P
0 g
s
.58576 .42442 m .58379 .37863 L .57316 .38519 L p 0 .1 .45 r
F P
0 g
s
.57487 .43087 m .57316 .38519 L .53298 .35832 L p 0 .675 .404 r
F P
0 g
s
.57487 .43087 m .57316 .38519 L .58379 .37863 L p 0 .1 .45 r
F P
0 g
s
.61409 .45607 m .57487 .43087 L .5641 .43723 L p 0 .907 1 r
F P
0 g
s
.61672 .50339 m .61675 .50338 L .60574 .50932 L p 0 .1 .1 r
F P
0 g
s
.61409 .45607 m .57487 .43087 L p .61672 .50339 L 0 .675 .404 r
F P
0 g
s
.61672 .50339 m .61675 .50338 L .61409 .45607 L p 0 .675 .404 r
F P
0 g
s
.57487 .43087 m .61409 .45607 L .62495 .44993 L p 0 .907 1 r
F P
0 g
s
.61409 .45607 m .61675 .50338 L .62789 .49736 L p 0 .114 .472 r
F P
0 g
s
.62789 .49736 m .62495 .44993 L .61409 .45607 L p 0 .114 .472 r
F P
0 g
s
.61409 .45607 m .57487 .43087 L p .61672 .50339 L 0 .675 .404 r
F P
0 g
s
.61672 .50339 m .61675 .50338 L .61409 .45607 L p 0 .675 .404 r
F P
0 g
s
.61409 .45607 m .57487 .43087 L .58576 .42442 L p 0 .907 1 r
F P
0 g
s
.58576 .42442 m .62495 .44993 L .61409 .45607 L p 0 .907 1 r
F P
0 g
s
.5015 .42442 m .4911 .43087 L .53223 .45607 L p 0 .907 0 r
F P
0 g
s
.53223 .45607 m .54263 .44993 L .5015 .42442 L p 0 .907 0 r
F P
0 g
s
.54263 .44993 m .53223 .45607 L .53298 .50341 L p 0 .1 0 r
F P
0 g
s
.52246 .50936 m .53298 .50341 L .53223 .45607 L p 0 .1 0 r
F P
0 g
s
.53223 .45607 m .53298 .50341 L .49089 .47873 L p 0 .683 0 r
F P
0 g
s
.48081 .43723 m .4911 .43087 L .53223 .45607 L p 0 .907 0 r
F P
0 g
s
.49089 .47873 m .4911 .43087 L .53223 .45607 L p 0 .683 0 r
F P
0 g
s
.53223 .45607 m .53298 .50341 L .49089 .47873 L p 0 .683 0 r
F P
0 g
s
.49089 .47873 m .4911 .43087 L .53223 .45607 L p 0 .683 0 r
F P
0 g
s
.54263 .44993 m .53223 .45607 L .4911 .43087 L p 0 .907 0 r
F P
0 g
s
.5015 .42442 m .4911 .43087 L .4913 .38519 L p 0 .1 0 r
F P
0 g
s
.4913 .38519 m .50147 .37863 L .5015 .42442 L p 0 .1 0 r
F P
0 g
s
.54363 .49739 m .53298 .50341 L .53223 .45607 L p 0 .1 0 r
F P
0 g
s
.53223 .45607 m .54263 .44993 L .54363 .49739 L p 0 .1 0 r
F P
0 g
s
.45938 .49739 m .44922 .50341 L .45038 .45607 L p 0 .1 .425 r
F P
0 g
s
.45038 .45607 m .46031 .44993 L .45938 .49739 L p 0 .1 .425 r
F P
0 g
s
.50147 .52122 m .4913 .52696 L .44922 .50341 L p 0 .911 1 r
F P
0 g
s
.43917 .50936 m .44922 .50341 L .4913 .52696 L p 0 .911 1 r
F P
0 g
s
.58376 .5212 m .57313 .52695 L .53298 .50341 L p 0 .911 0 r
F P
0 g
s
.52246 .50936 m .53298 .50341 L .57313 .52695 L p 0 .911 0 r
F P
0 g
s
.65499 .38517 m .61675 .35832 L .60574 .3651 L p 0 .903 0 r
F P
0 g
s
.65499 .38517 m .61675 .35832 L p .65864 .43087 L 0 .666 0 r
F P
0 g
s
.65864 .43087 m .65502 .38522 L .65499 .38517 L p 0 .666 0 r
F P
0 g
s
.61675 .35832 m .65499 .38517 L .66609 .37861 L p 0 .903 0 r
F P
0 g
s
.65499 .38517 m .65502 .38522 L .66612 .37866 L p 0 .575 0 r
F P
0 g
s
.66612 .37866 m .66609 .37861 L .65499 .38517 L p 0 .575 0 r
F P
0 g
s
.65502 .38522 m .65864 .43087 L .67002 .42442 L p 0 .114 0 r
F P
0 g
s
.67002 .42442 m .66612 .37866 L .65502 .38522 L p 0 .114 0 r
F P
0 g
s
.65499 .38517 m .61675 .35832 L p .65864 .43087 L 0 .666 0 r
F P
0 g
s
.65864 .43087 m .65502 .38522 L .65499 .38517 L p 0 .666 0 r
F P
0 g
s
.32438 .38334 m .32441 .38333 L .33364 .37675 L p 0 1 0 r
F P
0 g
s
.32027 .42902 m .32438 .38334 L .32441 .38333 L p 0 .694 0 r
F P
0 g
s
.32027 .42902 m .32438 .38334 L .32441 .38333 L p 0 .694 0 r
F P
0 g
s
.25116 .51952 m .25119 .51957 L .24243 .52533 L p 0 .546 0 r
F P
0 g
s
.24243 .52533 m .2424 .52528 L .25116 .51952 L p 0 .546 0 r
F P
0 g
s
.49849 .42256 m .49853 .37673 L .48836 .38331 L p 0 .1 0 r
F P
0 g
s
.48836 .38331 m .48809 .42902 L .49849 .42256 L p 0 .1 0 r
F P
0 g
s
.44613 .35635 m .48836 .38331 L .49853 .37673 L p 0 .903 0 r
F P
0 g
s
.48836 .38331 m .48809 .42902 L .44484 .40251 L p 0 .683 0 r
F P
0 g
s
.48836 .38331 m .44613 .35635 L .43609 .36316 L p 0 .903 0 r
F P
0 g
s
.44484 .40251 m .44613 .35635 L .48836 .38331 L p 0 .683 0 r
F P
0 g
s
.48836 .38331 m .48809 .42902 L .44484 .40251 L p 0 .683 0 r
F P
0 g
s
.44484 .40251 m .44613 .35635 L .48836 .38331 L p 0 .683 0 r
F P
0 g
s
.37189 .49565 m .41607 .51955 L .40637 .52532 L p 0 .911 0 r
F P
0 g
s
.40637 .52532 m .36222 .50169 L .37189 .49565 L p 0 .911 0 r
F P
0 g
s
.36538 .45431 m .36222 .50169 L .35267 .50765 L p 0 .1 0 r
F P
0 g
s
.36538 .45431 m .32027 .42902 L .31095 .43541 L p 0 .907 0 r
F P
0 g
s
.36222 .50169 m .36538 .45431 L .37484 .44814 L p 0 .1 0 r
F P
0 g
s
.37189 .49565 m .37484 .44814 L .36538 .45431 L p 0 .1 0 r
F P
0 g
s
.36538 .45431 m .36222 .50169 L .37189 .49565 L p 0 .1 0 r
F P
0 g
s
.32027 .42902 m .36538 .45431 L .37484 .44814 L p 0 .907 0 r
F P
0 g
s
.36538 .45431 m .36222 .50169 L .31599 .47694 L p 0 .694 0 r
F P
0 g
s
.32027 .42902 m .36538 .45431 L p .31599 .47694 L 0 .694 0 r
F P
0 g
s
.36538 .45431 m .36222 .50169 L .31599 .47694 L p 0 .694 0 r
F P
0 g
s
.32027 .42902 m .36538 .45431 L p .31599 .47694 L 0 .694 0 r
F P
0 g
s
.32969 .42256 m .37484 .44814 L .36538 .45431 L p 0 .907 0 r
F P
0 g
s
.36538 .45431 m .32027 .42902 L .32969 .42256 L p 0 .907 0 r
F P
0 g
s
.28753 .49567 m .33361 .51955 L .32438 .52532 L p 0 .911 1 r
F P
0 g
s
.32438 .52532 m .27835 .5017 L .28753 .49567 L p 0 .911 1 r
F P
0 g
s
.27835 .5017 m .27832 .50165 L .28339 .45431 L p 0 .698 .496 r
F P
0 g
s
.27835 .5017 m .27832 .50165 L .28339 .45431 L p 0 .698 .496 r
F P
0 g
s
.27832 .50165 m .28339 .45431 L .29238 .44814 L p 0 .1 .365 r
F P
0 g
s
.28339 .45431 m .27832 .50165 L .26925 .50762 L p 0 .1 .365 r
F P
0 g
s
.45629 .49565 m .4573 .44814 L .44737 .45431 L p 0 .1 .423 r
F P
0 g
s
.44737 .45431 m .44613 .50169 L .45629 .49565 L p 0 .1 .423 r
F P
0 g
s
.40418 .42902 m .44737 .45431 L .4573 .44814 L p 0 .907 1 r
F P
0 g
s
.44737 .45431 m .44613 .50169 L .40188 .47692 L p 0 .689 .454 r
F P
0 g
s
.44737 .45431 m .40418 .42902 L .39438 .43541 L p 0 .907 1 r
F P
0 g
s
.40188 .47692 m .40418 .42902 L .44737 .45431 L p 0 .689 .454 r
F P
0 g
s
.44737 .45431 m .44613 .50169 L .40188 .47692 L p 0 .689 .454 r
F P
0 g
s
.40188 .47692 m .40418 .42902 L .44737 .45431 L p 0 .689 .454 r
F P
0 g
s
.41409 .42256 m .4573 .44814 L .44737 .45431 L p 0 .907 1 r
F P
0 g
s
.44737 .45431 m .40418 .42902 L .41409 .42256 L p 0 .907 1 r
F P
0 g
s
.40418 .42902 m .40637 .38331 L .41607 .37673 L p 0 .1 .396 r
F P
0 g
s
.40637 .38331 m .40418 .42902 L .39438 .43541 L p 0 .1 .396 r
F P
0 g
s
.41409 .42256 m .41607 .37673 L .40637 .38331 L p 0 .1 .396 r
F P
0 g
s
.40637 .38331 m .40418 .42902 L .41409 .42256 L p 0 .1 .396 r
F P
0 g
s
.36226 .35637 m .40637 .38331 L .41607 .37673 L p 0 .903 1 r
F P
0 g
s
.40637 .38331 m .40418 .42902 L .35892 .40251 L p 0 .689 .454 r
F P
0 g
s
.40637 .38331 m .36226 .35637 L .3527 .36318 L p 0 .903 1 r
F P
0 g
s
.36226 .35637 m .40637 .38331 L p .35892 .40251 L 0 .689 .454 r
F P
0 g
s
.40637 .38331 m .40418 .42902 L .35892 .40251 L p 0 .689 .454 r
F P
0 g
s
.36226 .35637 m .40637 .38331 L p .35892 .40251 L 0 .689 .454 r
F P
0 g
s
.33364 .37675 m .33361 .37676 L .32438 .38334 L p 0 1 0 r
F P
0 g
s
.32027 .42902 m .32438 .38334 L .33361 .37676 L p 0 .1 0 r
F P
0 g
s
.32438 .38334 m .32027 .42902 L .31095 .43541 L p 0 .1 0 r
F P
0 g
s
.45021 .74715 m .45018 .74718 L .46015 .74267 L p 0 .1 .1 r
F P
0 g
s
.3747 .65079 m .41888 .67116 L .40915 .67607 L p 0 .916 1 r
F P
0 g
s
.40915 .67607 m .365 .65593 L .3747 .65079 L p 0 .916 1 r
F P
0 g
s
.365 .65593 m .40915 .67607 L .41888 .67116 L p 0 .916 1 r
F P
0 g
s
.41697 .724 m .41888 .67116 L .40915 .67607 L p 0 .1 .45 r
F P
0 g
s
.40915 .67607 m .40702 .72872 L .41697 .724 L p 0 .1 .45 r
F P
0 g
s
.40915 .67607 m .365 .65593 L .35541 .66102 L p 0 .916 1 r
F P
0 g
s
.36175 .70937 m .365 .65593 L .40915 .67607 L p 0 .698 .496 r
F P
0 g
s
.40915 .67607 m .40702 .72872 L .39719 .73339 L p 0 .1 .45 r
F P
0 g
s
.40915 .67607 m .40702 .72872 L .36175 .70937 L p 0 .698 .496 r
F P
0 g
s
.36175 .70937 m .365 .65593 L .40915 .67607 L p 0 .698 .496 r
F P
0 g
s
.40915 .67607 m .40702 .72872 L .36175 .70937 L p 0 .698 .496 r
F P
0 g
s
.40702 .72872 m .40915 .67607 L .41888 .67116 L p 0 .1 .45 r
F P
0 g
s
.365 .65593 m .36809 .60495 L .37758 .59963 L p 0 .1 .425 r
F P
0 g
s
.36809 .60495 m .365 .65593 L .35541 .66102 L p 0 .1 .425 r
F P
0 g
s
.40702 .58314 m .45021 .60495 L .46018 .59963 L p 0 .914 0 r
F P
0 g
s
.45924 .65079 m .46018 .59963 L .45021 .60495 L p 0 .1 0 r
F P
0 g
s
.45021 .60495 m .44904 .65593 L .45924 .65079 L p 0 .1 0 r
F P
0 g
s
.45021 .60495 m .40702 .58314 L .39719 .58865 L p 0 .914 0 r
F P
0 g
s
.40479 .63483 m .40702 .58314 L .45021 .60495 L p 0 .694 0 r
F P
0 g
s
.45021 .60495 m .44904 .65593 L .43897 .66102 L p 0 .1 0 r
F P
0 g
s
.45021 .60495 m .44904 .65593 L .40479 .63483 L p 0 .694 0 r
F P
0 g
s
.40479 .63483 m .40702 .58314 L .45021 .60495 L p 0 .694 0 r
F P
0 g
s
.45021 .60495 m .44904 .65593 L .40479 .63483 L p 0 .694 0 r
F P
0 g
s
.44904 .65593 m .49127 .67607 L .50147 .67116 L p 0 .916 0 r
F P
0 g
s
.50151 .72397 m .50147 .67116 L .49127 .67607 L p 0 .114 0 r
F P
0 g
s
.49127 .67607 m .49107 .72868 L .50151 .72397 L p 0 .114 0 r
F P
0 g
s
.49127 .67607 m .44904 .65593 L .43897 .66102 L p 0 .916 0 r
F P
0 g
s
.44782 .70937 m .44904 .65593 L .49127 .67607 L p 0 .694 0 r
F P
0 g
s
.49104 .72871 m .49107 .72868 L .48075 .73335 L p 0 .1 0 r
F P
0 g
s
.49104 .72871 m .44782 .70937 L p .49127 .67607 L 0 .694 0 r
F P
0 g
s
.49127 .67607 m .49107 .72868 L .49104 .72871 L p 0 .694 0 r
F P
0 g
s
.44782 .70937 m .44904 .65593 L .49127 .67607 L p 0 .694 0 r
F P
0 g
s
.49104 .72871 m .44782 .70937 L p .49127 .67607 L 0 .694 0 r
F P
0 g
s
.49127 .67607 m .49107 .72868 L .49104 .72871 L p 0 .694 0 r
F P
0 g
s
.44904 .65593 m .45021 .60495 L .46018 .59963 L p 0 .1 0 r
F P
0 g
s
.45924 .65079 m .50147 .67116 L .49127 .67607 L p 0 .916 0 r
F P
0 g
s
.49127 .67607 m .44904 .65593 L .45924 .65079 L p 0 .916 0 r
F P
0 g
s
.32297 .72872 m .32703 .67607 L .33629 .67116 L p 0 .1 0 r
F P
0 g
s
.32703 .67607 m .32297 .72872 L .31362 .73339 L p 0 .1 0 r
F P
0 g
s
.33243 .724 m .37758 .74268 L .36809 .74719 L p 0 .916 0 r
F P
0 g
s
.36809 .74719 m .32297 .72872 L .33243 .724 L p 0 .916 0 r
F P
0 g
s
.41697 .724 m .46015 .74267 L .45018 .74718 L p 0 .916 1 r
F P
0 g
s
.45018 .74718 m .40702 .72872 L .41697 .724 L p 0 .916 1 r
F P
0 g
s
.49107 .58314 m .53231 .60493 L .54274 .59961 L p 0 .914 1 r
F P
0 g
s
.54378 .65079 m .54277 .59966 L .53234 .60498 L p 0 .114 .472 r
F P
0 g
s
.53234 .60498 m .53309 .65593 L .54378 .65079 L p 0 .114 .472 r
F P
0 g
s
.54277 .59966 m .54274 .59961 L .53231 .60493 L p 0 .562 .887 r
F P
0 g
s
.53231 .60493 m .53234 .60498 L .54277 .59966 L p 0 .562 .887 r
F P
0 g
s
.53231 .60493 m .49107 .58314 L .48075 .58865 L p 0 .914 1 r
F P
0 g
s
.49086 .63483 m .49107 .58314 L .53231 .60493 L p 0 .689 .454 r
F P
0 g
s
.53309 .65593 m .49086 .63483 L p .53231 .60493 L 0 .689 .454 r
F P
0 g
s
.53231 .60493 m .53234 .60498 L .53309 .65593 L p 0 .689 .454 r
F P
0 g
s
.49086 .63483 m .49107 .58314 L .53231 .60493 L p 0 .689 .454 r
F P
0 g
s
.53309 .65593 m .49086 .63483 L p .53231 .60493 L 0 .689 .454 r
F P
0 g
s
.53231 .60493 m .53234 .60498 L .53309 .65593 L p 0 .689 .454 r
F P
0 g
s
.15691 .72419 m .14988 .72812 L .15791 .67548 L p 0 .1 .365 r
F P
0 g
s
.15791 .67548 m .16481 .67139 L .15691 .72419 L p 0 .1 .365 r
F P
0 g
s
.2061 .7429 m .199 .74665 L .14991 .72817 L p 0 .916 1 r
F P
0 g
s
.14296 .73206 m .14991 .72817 L .199 .74665 L p 0 .916 1 r
F P
0 g
s
.32912 .57596 m .31967 .58155 L .36494 .60342 L p 0 .914 1 r
F P
0 g
s
.36494 .60342 m .37443 .59809 L .32912 .57596 L p 0 .914 1 r
F P
0 g
s
.37443 .59809 m .36494 .60342 L .36176 .65446 L p 0 .1 .423 r
F P
0 g
s
.31533 .63329 m .31967 .58155 L .36494 .60342 L p 0 .698 .496 r
F P
0 g
s
.35218 .65956 m .36176 .65446 L .36494 .60342 L p 0 .1 .423 r
F P
0 g
s
.36494 .60342 m .36176 .65446 L .31533 .63329 L p 0 .698 .496 r
F P
0 g
s
.31533 .63329 m .31967 .58155 L .36494 .60342 L p 0 .698 .496 r
F P
0 g
s
.36494 .60342 m .36176 .65446 L .31533 .63329 L p 0 .698 .496 r
F P
0 g
s
.28678 .6493 m .27757 .65446 L .32381 .67466 L p 0 .916 0 r
F P
0 g
s
.32381 .67466 m .33306 .66973 L .28678 .6493 L p 0 .916 0 r
F P
0 g
s
.33306 .66973 m .32381 .67466 L .31967 .72737 L p 0 .1 0 r
F P
0 g
s
.26847 .65956 m .27757 .65446 L .32381 .67466 L p 0 .916 0 r
F P
0 g
s
.27222 .70795 m .27757 .65446 L .32381 .67466 L p 0 .702 0 r
F P
0 g
s
.31032 .73205 m .31967 .72737 L .32381 .67466 L p 0 .1 0 r
F P
0 g
s
.32381 .67466 m .31967 .72737 L .27222 .70795 L p 0 .702 0 r
F P
0 g
s
.27222 .70795 m .27757 .65446 L .32381 .67466 L p 0 .702 0 r
F P
0 g
s
.32381 .67466 m .31967 .72737 L .27222 .70795 L p 0 .702 0 r
F P
0 g
s
.33306 .66973 m .32381 .67466 L .27757 .65446 L p 0 .916 0 r
F P
0 g
s
.28678 .6493 m .27757 .65446 L .28268 .60342 L p 0 .1 0 r
F P
0 g
s
.28268 .60342 m .2917 .59809 L .28678 .6493 L p 0 .1 0 r
F P
0 g
s
.24447 .57597 m .23551 .58156 L .28268 .60342 L p 0 .914 0 r
F P
0 g
s
.28268 .60342 m .2917 .59809 L .24447 .57597 L p 0 .914 0 r
F P
0 g
s
.2917 .59809 m .28268 .60342 L .27757 .65446 L p 0 .1 0 r
F P
0 g
s
.22666 .58709 m .23551 .58156 L .23547 .58158 L p 0 .93 0 r
F P
0 g
s
.23547 .58158 m .23551 .58156 L .28268 .60342 L p 0 .702 0 r
F P
0 g
s
.22911 .63329 m .23547 .58158 L p .28268 .60342 L 0 .702 0 r
F P
0 g
s
.26847 .65956 m .27757 .65446 L .28268 .60342 L p 0 .1 0 r
F P
0 g
s
.28268 .60342 m .27757 .65446 L .22911 .63329 L p 0 .702 0 r
F P
0 g
s
.23547 .58158 m .23551 .58156 L .28268 .60342 L p 0 .702 0 r
F P
0 g
s
.22911 .63329 m .23547 .58158 L p .28268 .60342 L 0 .702 0 r
F P
0 g
s
.28268 .60342 m .27757 .65446 L .22911 .63329 L p 0 .702 0 r
F P
0 g
s
.58379 .52118 m .58376 .5212 L .59452 .51539 L p 0 .1 0 r
F P
0 g
s
.58379 .37863 m .54363 .35146 L .53298 .35832 L p 0 .903 1 r
F P
0 g
s
.58379 .37863 m .58576 .42442 L .57487 .43087 L p 0 .1 .45 r
F P
0 g
s
.58576 .42442 m .58379 .37863 L .54363 .35146 L p 0 .673 .397 r
F P
0 g
s
.54363 .35146 m .58379 .37863 L .59455 .372 L p 0 .903 1 r
F P
0 g
s
.58379 .37863 m .58576 .42442 L .62495 .44993 L p 0 .673 .397 r
F P
0 g
s
.58379 .37863 m .58576 .42442 L .62495 .44993 L p 0 .673 .397 r
F P
0 g
s
.58379 .37863 m .58576 .42442 L .59678 .41791 L p 0 .1 .45 r
F P
0 g
s
.59678 .41791 m .59455 .372 L .58379 .37863 L p 0 .1 .45 r
F P
0 g
s
.58576 .42442 m .58379 .37863 L .54363 .35146 L p 0 .673 .397 r
F P
0 g
s
.58576 .42442 m .58379 .37863 L .59455 .372 L p 0 .1 .45 r
F P
0 g
s
.62495 .44993 m .58576 .42442 L .57487 .43087 L p 0 .907 1 r
F P
0 g
s
.62786 .49738 m .62789 .49736 L .61675 .50338 L p 0 .1 .1 r
F P
0 g
s
.62495 .44993 m .58576 .42442 L p .62786 .49738 L 0 .673 .397 r
F P
0 g
s
.62786 .49738 m .62789 .49736 L .62495 .44993 L p 0 .673 .397 r
F P
0 g
s
.62495 .44993 m .58576 .42442 L p .62786 .49738 L 0 .673 .397 r
F P
0 g
s
.62786 .49738 m .62789 .49736 L .62495 .44993 L p 0 .673 .397 r
F P
0 g
s
.58576 .42442 m .62495 .44993 L .63595 .44371 L p 0 .907 1 r
F P
0 g
s
.62495 .44993 m .62789 .49736 L .63916 .49127 L p 0 .114 .472 r
F P
0 g
s
.63916 .49127 m .63595 .44371 L .62495 .44993 L p 0 .114 .472 r
F P
0 g
s
.62495 .44993 m .58576 .42442 L .59678 .41791 L p 0 .907 1 r
F P
0 g
s
.59678 .41791 m .63595 .44371 L .62495 .44993 L p 0 .907 1 r
F P
0 g
s
.53298 .50341 m .54363 .49739 L .54263 .44993 L p 0 .1 0 r
F P
0 g
s
.54263 .44993 m .54363 .49739 L .50154 .47242 L p 0 .681 0 r
F P
0 g
s
.4911 .43087 m .5015 .42442 L .54263 .44993 L p 0 .907 0 r
F P
0 g
s
.50154 .47242 m .5015 .42442 L .54263 .44993 L p 0 .681 0 r
F P
0 g
s
.50147 .37863 m .5015 .42442 L .54263 .44993 L p 0 .681 0 r
F P
0 g
s
.5015 .42442 m .54263 .44993 L .55315 .44371 L p 0 .907 0 r
F P
0 g
s
.54263 .44993 m .54363 .49739 L .58376 .5212 L p 0 .681 0 r
F P
0 g
s
.54263 .44993 m .54363 .49739 L .55441 .49131 L p 0 .1 0 r
F P
0 g
s
.55441 .49131 m .55315 .44371 L .54263 .44993 L p 0 .1 0 r
F P
0 g
s
.54363 .49739 m .54263 .44993 L .5015 .42442 L p 0 .681 0 r
F P
0 g
s
.54263 .44993 m .5015 .42442 L .51203 .41791 L p 0 .907 0 r
F P
0 g
s
.51203 .41791 m .55315 .44371 L .54263 .44993 L p 0 .907 0 r
F P
0 g
s
.5015 .42442 m .50147 .37863 L .51175 .372 L p 0 .1 0 r
F P
0 g
s
.54363 .49739 m .54263 .44993 L .55315 .44371 L p 0 .1 0 r
F P
0 g
s
.51175 .51541 m .50147 .52122 L .45938 .49739 L p 0 .911 1 r
F P
0 g
s
.46966 .49131 m .45938 .49739 L .46031 .44993 L p 0 .1 .425 r
F P
0 g
s
.46031 .44993 m .47036 .44371 L .46966 .49131 L p 0 .1 .425 r
F P
0 g
s
.44922 .50341 m .45938 .49739 L .50147 .52122 L p 0 .911 1 r
F P
0 g
s
.53298 .50341 m .54363 .49739 L .58376 .5212 L p 0 .911 0 r
F P
0 g
s
.58376 .5212 m .54363 .49739 L .55441 .49131 L p 0 .911 0 r
F P
0 g
s
.55441 .49131 m .59452 .51539 L .58376 .5212 L p 0 .911 0 r
F P
0 g
s
.62789 .35146 m .66609 .37861 L .67732 .37198 L p 0 .903 0 r
F P
0 g
s
.66609 .37861 m .66612 .37866 L .67735 .37204 L p 0 .575 0 r
F P
0 g
s
.67735 .37204 m .67732 .37198 L .66609 .37861 L p 0 .575 0 r
F P
0 g
s
.66612 .37866 m .67002 .42442 L .68154 .41791 L p 0 .114 0 r
F P
0 g
s
.68154 .41791 m .67735 .37204 L .66612 .37866 L p 0 .114 0 r
F P
0 g
s
.66609 .37861 m .62789 .35146 L .61675 .35832 L p 0 .903 0 r
F P
0 g
s
.66609 .37861 m .62789 .35146 L p .67002 .42442 L 0 .663 0 r
F P
0 g
s
.67002 .42442 m .66612 .37866 L .66609 .37861 L p 0 .663 0 r
F P
0 g
s
.66609 .37861 m .62789 .35146 L p .67002 .42442 L 0 .663 0 r
F P
0 g
s
.67002 .42442 m .66612 .37866 L .66609 .37861 L p 0 .663 0 r
F P
0 g
s
.20909 .59805 m .20334 .60163 L .20337 .60161 L p 0 .93 .764 r
F P
0 g
s
.29183 .74131 m .28576 .74435 L .23854 .72575 L p 0 .916 1 r
F P
0 g
s
.25046 .66966 m .24455 .67298 L .19636 .6527 L p 0 .916 1 r
F P
0 g
s
.24456 .72257 m .23854 .72575 L .24455 .67298 L p 0 .1 .396 r
F P
0 g
s
.24455 .67298 m .25046 .66966 L .24456 .72257 L p 0 .1 .396 r
F P
0 g
s
.20222 .64922 m .19636 .6527 L .24455 .67298 L p 0 .916 1 r
F P
0 g
s
.24455 .67298 m .25046 .66966 L .20222 .64922 L p 0 .916 1 r
F P
0 g
s
.25046 .66966 m .24455 .67298 L .23854 .72575 L p 0 .1 .396 r
F P
0 g
s
.18904 .70622 m .19636 .6527 L .24455 .67298 L p 0 .704 .528 r
F P
0 g
s
.18907 .70627 m .18904 .70622 L p .24455 .67298 L 0 .704 .528 r
F P
0 g
s
.24455 .67298 m .23854 .72575 L .18907 .70627 L p 0 .704 .528 r
F P
0 g
s
.20222 .64922 m .19636 .6527 L .20334 .60163 L p 0 .1 .365 r
F P
0 g
s
.20334 .60163 m .20909 .59805 L .20222 .64922 L p 0 .1 .365 r
F P
0 g
s
.26002 .51369 m .26005 .51374 L .25119 .51957 L p 0 .546 0 r
F P
0 g
s
.25119 .51957 m .25116 .51952 L .26002 .51369 L p 0 .546 0 r
F P
0 g
s
.33361 .37676 m .33364 .37675 L .34298 .3701 L p 0 1 0 r
F P
0 g
s
.32969 .42256 m .33361 .37676 L .33364 .37675 L p 0 .693 0 r
F P
0 g
s
.32969 .42256 m .33361 .37676 L .33364 .37675 L p 0 .693 0 r
F P
0 g
s
.49853 .37673 m .45629 .34947 L .44613 .35635 L p 0 .903 0 r
F P
0 g
s
.49853 .37673 m .49849 .42256 L .45524 .39574 L p 0 .681 0 r
F P
0 g
s
.45524 .39574 m .45629 .34947 L .49853 .37673 L p 0 .681 0 r
F P
0 g
s
.50881 .37008 m .49853 .37673 L .49849 .42256 L p 0 .1 0 r
F P
0 g
s
.49853 .37673 m .50881 .37008 L .46657 .3425 L p 0 .903 0 r
F P
0 g
s
.46657 .3425 m .45629 .34947 L .49853 .37673 L p 0 .903 0 r
F P
0 g
s
.49849 .42256 m .49853 .37673 L .45629 .34947 L p 0 .681 0 r
F P
0 g
s
.38168 .48954 m .42588 .51372 L .41607 .51955 L p 0 .911 0 r
F P
0 g
s
.41607 .51955 m .37189 .49565 L .38168 .48954 L p 0 .911 0 r
F P
0 g
s
.37189 .49565 m .37484 .44814 L .38441 .4419 L p 0 .1 0 r
F P
0 g
s
.37484 .44814 m .37189 .49565 L .36222 .50169 L p 0 .1 0 r
F P
0 g
s
.38168 .48954 m .38441 .4419 L .37484 .44814 L p 0 .1 0 r
F P
0 g
s
.37484 .44814 m .37189 .49565 L .38168 .48954 L p 0 .1 0 r
F P
0 g
s
.32969 .42256 m .37484 .44814 L .38441 .4419 L p 0 .907 0 r
F P
0 g
s
.37484 .44814 m .37189 .49565 L .32562 .47061 L p 0 .693 0 r
F P
0 g
s
.37484 .44814 m .32969 .42256 L .32027 .42902 L p 0 .907 0 r
F P
0 g
s
.32969 .42256 m .37484 .44814 L p .32562 .47061 L 0 .693 0 r
F P
0 g
s
.37484 .44814 m .37189 .49565 L .32562 .47061 L p 0 .693 0 r
F P
0 g
s
.32969 .42256 m .37484 .44814 L p .32562 .47061 L 0 .693 0 r
F P
0 g
s
.33923 .41602 m .38441 .4419 L .37484 .44814 L p 0 .907 0 r
F P
0 g
s
.37484 .44814 m .32969 .42256 L .33923 .41602 L p 0 .907 0 r
F P
0 g
s
.29681 .48956 m .34295 .51372 L .33361 .51955 L p 0 .911 1 r
F P
0 g
s
.33361 .51955 m .28753 .49567 L .29681 .48956 L p 0 .911 1 r
F P
0 g
s
.28753 .49567 m .2875 .49561 L .29238 .44814 L p 0 .697 .491 r
F P
0 g
s
.28753 .49567 m .2875 .49561 L .29238 .44814 L p 0 .697 .491 r
F P
0 g
s
.2875 .49561 m .29238 .44814 L .30148 .4419 L p 0 .1 .365 r
F P
0 g
s
.29238 .44814 m .2875 .49561 L .27832 .50165 L p 0 .1 .365 r
F P
0 g
s
.4573 .44814 m .41409 .42256 L .40418 .42902 L p 0 .907 1 r
F P
0 g
s
.42412 .41602 m .46735 .4419 L .4573 .44814 L p 0 .907 1 r
F P
0 g
s
.4573 .44814 m .41409 .42256 L .42412 .41602 L p 0 .907 1 r
F P
0 g
s
.41409 .42256 m .41607 .37673 L .42588 .37008 L p 0 .1 .396 r
F P
0 g
s
.41607 .37673 m .41409 .42256 L .40418 .42902 L p 0 .1 .396 r
F P
0 g
s
.42412 .41602 m .42588 .37008 L .41607 .37673 L p 0 .1 .396 r
F P
0 g
s
.41607 .37673 m .41409 .42256 L .42412 .41602 L p 0 .1 .396 r
F P
0 g
s
.37193 .34949 m .41607 .37673 L .42588 .37008 L p 0 .903 1 r
F P
0 g
s
.41607 .37673 m .41409 .42256 L .3688 .39574 L p 0 .687 .449 r
F P
0 g
s
.41607 .37673 m .37193 .34949 L .36226 .35637 L p 0 .903 1 r
F P
0 g
s
.37193 .34949 m .41607 .37673 L p .3688 .39574 L 0 .687 .449 r
F P
0 g
s
.41607 .37673 m .41409 .42256 L .3688 .39574 L p 0 .687 .449 r
F P
0 g
s
.37193 .34949 m .41607 .37673 L p .3688 .39574 L 0 .687 .449 r
F P
0 g
s
.46657 .48954 m .46735 .4419 L .4573 .44814 L p 0 .1 .423 r
F P
0 g
s
.4573 .44814 m .45629 .49565 L .46657 .48954 L p 0 .1 .423 r
F P
0 g
s
.41409 .42256 m .4573 .44814 L .46735 .4419 L p 0 .907 1 r
F P
0 g
s
.4573 .44814 m .45629 .49565 L .41202 .47059 L p 0 .687 .449 r
F P
0 g
s
.41202 .47059 m .41409 .42256 L .4573 .44814 L p 0 .687 .449 r
F P
0 g
s
.4573 .44814 m .45629 .49565 L .41202 .47059 L p 0 .687 .449 r
F P
0 g
s
.41202 .47059 m .41409 .42256 L .4573 .44814 L p 0 .687 .449 r
F P
0 g
s
.34298 .3701 m .34295 .37011 L .33361 .37676 L p 0 1 0 r
F P
0 g
s
.32969 .42256 m .33361 .37676 L .34295 .37011 L p 0 .1 0 r
F P
0 g
s
.33361 .37676 m .32969 .42256 L .32027 .42902 L p 0 .1 0 r
F P
0 g
s
.14991 .72817 m .15694 .72424 L .2061 .7429 L p 0 .916 1 r
F P
0 g
s
.46018 .74265 m .46015 .74267 L .47023 .73811 L p 0 .1 .1 r
F P
0 g
s
.38451 .64558 m .42872 .66619 L .41888 .67116 L p 0 .916 1 r
F P
0 g
s
.41888 .67116 m .3747 .65079 L .38451 .64558 L p 0 .916 1 r
F P
0 g
s
.3747 .65079 m .41888 .67116 L .42872 .66619 L p 0 .916 1 r
F P
0 g
s
.42703 .71923 m .42872 .66619 L .41888 .67116 L p 0 .1 .45 r
F P
0 g
s
.41888 .67116 m .41697 .724 L .42703 .71923 L p 0 .1 .45 r
F P
0 g
s
.41888 .67116 m .3747 .65079 L .365 .65593 L p 0 .916 1 r
F P
0 g
s
.37167 .70442 m .3747 .65079 L .41888 .67116 L p 0 .697 .491 r
F P
0 g
s
.41888 .67116 m .41697 .724 L .40702 .72872 L p 0 .1 .45 r
F P
0 g
s
.41888 .67116 m .41697 .724 L .37167 .70442 L p 0 .697 .491 r
F P
0 g
s
.37167 .70442 m .3747 .65079 L .41888 .67116 L p 0 .697 .491 r
F P
0 g
s
.41888 .67116 m .41697 .724 L .37167 .70442 L p 0 .697 .491 r
F P
0 g
s
.41697 .724 m .41888 .67116 L .42872 .66619 L p 0 .1 .45 r
F P
0 g
s
.3747 .65079 m .37758 .59963 L .38719 .59425 L p 0 .1 .425 r
F P
0 g
s
.37758 .59963 m .3747 .65079 L .365 .65593 L p 0 .1 .425 r
F P
0 g
s
.46018 .59963 m .41697 .57757 L .40702 .58314 L p 0 .914 0 r
F P
0 g
s
.41697 .57757 m .46018 .59963 L .47026 .59425 L p 0 .914 0 r
F P
0 g
s
.46955 .64558 m .47026 .59425 L .46018 .59963 L p 0 .1 0 r
F P
0 g
s
.46018 .59963 m .45924 .65079 L .46955 .64558 L p 0 .1 0 r
F P
0 g
s
.41496 .62944 m .41697 .57757 L .46018 .59963 L p 0 .693 0 r
F P
0 g
s
.46018 .59963 m .45924 .65079 L .44904 .65593 L p 0 .1 0 r
F P
0 g
s
.46018 .59963 m .45924 .65079 L .41496 .62944 L p 0 .693 0 r
F P
0 g
s
.41496 .62944 m .41697 .57757 L .46018 .59963 L p 0 .693 0 r
F P
0 g
s
.46018 .59963 m .45924 .65079 L .41496 .62944 L p 0 .693 0 r
F P
0 g
s
.45924 .65079 m .50147 .67116 L .51179 .66619 L p 0 .916 0 r
F P
0 g
s
.51207 .71919 m .51179 .66619 L .50147 .67116 L p 0 .114 0 r
F P
0 g
s
.50147 .67116 m .50151 .72397 L .51207 .71919 L p 0 .114 0 r
F P
0 g
s
.50147 .67116 m .45924 .65079 L .44904 .65593 L p 0 .916 0 r
F P
0 g
s
.45825 .70442 m .45924 .65079 L .50147 .67116 L p 0 .693 0 r
F P
0 g
s
.50148 .72399 m .50151 .72397 L .49107 .72868 L p 0 .1 0 r
F P
0 g
s
.50148 .72399 m .45825 .70442 L p .50147 .67116 L 0 .693 0 r
F P
0 g
s
.50147 .67116 m .50151 .72397 L .50148 .72399 L p 0 .693 0 r
F P
0 g
s
.45825 .70442 m .45924 .65079 L .50147 .67116 L p 0 .693 0 r
F P
0 g
s
.50148 .72399 m .45825 .70442 L p .50147 .67116 L 0 .693 0 r
F P
0 g
s
.50147 .67116 m .50151 .72397 L .50148 .72399 L p 0 .693 0 r
F P
0 g
s
.45924 .65079 m .46018 .59963 L .47026 .59425 L p 0 .1 0 r
F P
0 g
s
.46955 .64558 m .51179 .66619 L .50147 .67116 L p 0 .916 0 r
F P
0 g
s
.50147 .67116 m .45924 .65079 L .46955 .64558 L p 0 .916 0 r
F P
0 g
s
.34199 .71923 m .38719 .73813 L .37758 .74268 L p 0 .916 0 r
F P
0 g
s
.37758 .74268 m .33243 .724 L .34199 .71923 L p 0 .916 0 r
F P
0 g
s
.33243 .724 m .33629 .67116 L .34566 .66619 L p 0 .1 0 r
F P
0 g
s
.33629 .67116 m .33243 .724 L .32297 .72872 L p 0 .1 0 r
F P
0 g
s
.42703 .71923 m .47023 .73811 L .46015 .74267 L p 0 .916 1 r
F P
0 g
s
.46015 .74267 m .41697 .724 L .42703 .71923 L p 0 .916 1 r
F P
0 g
s
.50151 .57757 m .54274 .59961 L .5533 .59423 L p 0 .914 1 r
F P
0 g
s
.55459 .64558 m .55333 .59429 L .54277 .59966 L p 0 .114 .472 r
F P
0 g
s
.54277 .59966 m .54378 .65079 L .55459 .64558 L p 0 .114 .472 r
F P
0 g
s
.55333 .59429 m .5533 .59423 L .54274 .59961 L p 0 .562 .887 r
F P
0 g
s
.54274 .59961 m .54277 .59966 L .55333 .59429 L p 0 .562 .887 r
F P
0 g
s
.54274 .59961 m .50151 .57757 L .49107 .58314 L p 0 .914 1 r
F P
0 g
s
.50155 .62944 m .50151 .57757 L .54274 .59961 L p 0 .687 .449 r
F P
0 g
s
.54378 .65079 m .50155 .62944 L p .54274 .59961 L 0 .687 .449 r
F P
0 g
s
.54274 .59961 m .54277 .59966 L .54378 .65079 L p 0 .687 .449 r
F P
0 g
s
.50155 .62944 m .50151 .57757 L .54274 .59961 L p 0 .687 .449 r
F P
0 g
s
.54378 .65079 m .50155 .62944 L p .54274 .59961 L 0 .687 .449 r
F P
0 g
s
.54274 .59961 m .54277 .59966 L .54378 .65079 L p 0 .687 .449 r
F P
0 g
s
.33868 .5703 m .32912 .57596 L .37443 .59809 L p 0 .914 1 r
F P
0 g
s
.37443 .59809 m .38403 .59269 L .33868 .5703 L p 0 .914 1 r
F P
0 g
s
.38403 .59269 m .37443 .59809 L .37146 .6493 L p 0 .1 .423 r
F P
0 g
s
.32498 .62787 m .32912 .57596 L .37443 .59809 L p 0 .697 .491 r
F P
0 g
s
.36176 .65446 m .37146 .6493 L .37443 .59809 L p 0 .1 .423 r
F P
0 g
s
.37443 .59809 m .37146 .6493 L .32498 .62787 L p 0 .697 .491 r
F P
0 g
s
.32498 .62787 m .32912 .57596 L .37443 .59809 L p 0 .697 .491 r
F P
0 g
s
.37443 .59809 m .37146 .6493 L .32498 .62787 L p 0 .697 .491 r
F P
0 g
s
.29609 .64407 m .28678 .6493 L .33306 .66973 L p 0 .916 0 r
F P
0 g
s
.33306 .66973 m .34243 .66475 L .29609 .64407 L p 0 .916 0 r
F P
0 g
s
.34243 .66475 m .33306 .66973 L .32912 .72264 L p 0 .1 0 r
F P
0 g
s
.27757 .65446 m .28678 .6493 L .33306 .66973 L p 0 .916 0 r
F P
0 g
s
.28162 .70299 m .28678 .6493 L .33306 .66973 L p 0 .701 0 r
F P
0 g
s
.31967 .72737 m .32912 .72264 L .33306 .66973 L p 0 .1 0 r
F P
0 g
s
.33306 .66973 m .32912 .72264 L .28162 .70299 L p 0 .701 0 r
F P
0 g
s
.29609 .64407 m .28678 .6493 L .2917 .59809 L p 0 .1 0 r
F P
0 g
s
.2917 .59809 m .30083 .59269 L .29609 .64407 L p 0 .1 0 r
F P
0 g
s
.25353 .57032 m .24447 .57597 L .2917 .59809 L p 0 .914 0 r
F P
0 g
s
.2917 .59809 m .30083 .59269 L .25353 .57032 L p 0 .914 0 r
F P
0 g
s
.30083 .59269 m .2917 .59809 L .28678 .6493 L p 0 .1 0 r
F P
0 g
s
.23551 .58156 m .24447 .57597 L .24443 .57599 L p 0 .93 0 r
F P
0 g
s
.24443 .57599 m .24447 .57597 L .2917 .59809 L p 0 .701 0 r
F P
0 g
s
.23825 .62787 m .24443 .57599 L p .2917 .59809 L 0 .701 0 r
F P
0 g
s
.27757 .65446 m .28678 .6493 L .2917 .59809 L p 0 .1 0 r
F P
0 g
s
.2917 .59809 m .28678 .6493 L .23825 .62787 L p 0 .701 0 r
F P
0 g
s
.34243 .66475 m .33306 .66973 L .28678 .6493 L p 0 .916 0 r
F P
0 g
s
.28162 .70299 m .28678 .6493 L .33306 .66973 L p 0 .701 0 r
F P
0 g
s
.33306 .66973 m .32912 .72264 L .28162 .70299 L p 0 .701 0 r
F P
0 g
s
.24443 .57599 m .24447 .57597 L .2917 .59809 L p 0 .701 0 r
F P
0 g
s
.23825 .62787 m .24443 .57599 L p .2917 .59809 L 0 .701 0 r
F P
0 g
s
.2917 .59809 m .28678 .6493 L .23825 .62787 L p 0 .701 0 r
F P
0 g
s
.21489 .59443 m .20909 .59805 L .20913 .59802 L p 0 .93 .764 r
F P
0 g
s
.29795 .73825 m .29183 .74131 L .24456 .72257 L p 0 .916 1 r
F P
0 g
s
.23854 .72575 m .24456 .72257 L .29183 .74131 L p 0 .916 1 r
F P
0 g
s
.25064 .71936 m .24456 .72257 L .25046 .66966 L p 0 .1 .396 r
F P
0 g
s
.25046 .66966 m .25642 .66632 L .25064 .71936 L p 0 .1 .396 r
F P
0 g
s
.25642 .66632 m .25046 .66966 L .20222 .64922 L p 0 .916 1 r
F P
0 g
s
.19636 .6527 m .20222 .64922 L .25046 .66966 L p 0 .916 1 r
F P
0 g
s
.20813 .64572 m .20222 .64922 L .25046 .66966 L p 0 .916 1 r
F P
0 g
s
.25046 .66966 m .25642 .66632 L .20813 .64572 L p 0 .916 1 r
F P
0 g
s
.25642 .66632 m .25046 .66966 L .24456 .72257 L p 0 .1 .396 r
F P
0 g
s
.19502 .70287 m .20222 .64922 L .25046 .66966 L p 0 .704 .526 r
F P
0 g
s
.19505 .70293 m .19502 .70287 L p .25046 .66966 L 0 .704 .526 r
F P
0 g
s
.23854 .72575 m .24456 .72257 L .25046 .66966 L p 0 .1 .396 r
F P
0 g
s
.25046 .66966 m .24456 .72257 L .19505 .70293 L p 0 .704 .526 r
F P
0 g
s
.19502 .70287 m .20222 .64922 L .25046 .66966 L p 0 .704 .526 r
F P
0 g
s
.19505 .70293 m .19502 .70287 L p .25046 .66966 L 0 .704 .526 r
F P
0 g
s
.25046 .66966 m .24456 .72257 L .19505 .70293 L p 0 .704 .526 r
F P
0 g
s
.20813 .64572 m .20222 .64922 L .20909 .59805 L p 0 .1 .365 r
F P
0 g
s
.20909 .59805 m .21489 .59443 L .20813 .64572 L p 0 .1 .365 r
F P
0 g
s
.16907 .71739 m .16058 .72214 L .16842 .66925 L p 0 .1 0 r
F P
0 g
s
.16842 .66925 m .17675 .66431 L .16907 .71739 L p 0 .1 0 r
F P
0 g
s
.21837 .73641 m .2098 .74094 L .16061 .72219 L p 0 .916 0 r
F P
0 g
s
.59455 .51537 m .59452 .51539 L .6054 .50951 L p 0 .1 0 r
F P
0 g
s
.59455 .372 m .55441 .34451 L .54363 .35146 L p 0 .903 1 r
F P
0 g
s
.59455 .372 m .59678 .41791 L .58576 .42442 L p 0 .1 .45 r
F P
0 g
s
.59678 .41791 m .59455 .372 L .55441 .34451 L p 0 .671 .39 r
F P
0 g
s
.55441 .34451 m .59455 .372 L .60543 .3653 L p 0 .903 1 r
F P
0 g
s
.59455 .372 m .59678 .41791 L .63595 .44371 L p 0 .671 .39 r
F P
0 g
s
.59455 .372 m .59678 .41791 L .63595 .44371 L p 0 .671 .39 r
F P
0 g
s
.59455 .372 m .59678 .41791 L .60794 .41131 L p 0 .1 .45 r
F P
0 g
s
.60794 .41131 m .60543 .3653 L .59455 .372 L p 0 .1 .45 r
F P
0 g
s
.59678 .41791 m .59455 .372 L .55441 .34451 L p 0 .671 .39 r
F P
0 g
s
.59678 .41791 m .59455 .372 L .60543 .3653 L p 0 .1 .45 r
F P
0 g
s
.59678 .41791 m .63595 .44371 L .64706 .43741 L p 0 .907 1 r
F P
0 g
s
.63595 .44371 m .63916 .49127 L .65056 .48511 L p 0 .114 .472 r
F P
0 g
s
.65056 .48511 m .64706 .43741 L .63595 .44371 L p 0 .114 .472 r
F P
0 g
s
.63595 .44371 m .59678 .41791 L .58576 .42442 L p 0 .907 1 r
F P
0 g
s
.63913 .49129 m .63916 .49127 L .62789 .49736 L p 0 .1 .1 r
F P
0 g
s
.63595 .44371 m .59678 .41791 L p .63913 .49129 L 0 .671 .39 r
F P
0 g
s
.63913 .49129 m .63916 .49127 L .63595 .44371 L p 0 .671 .39 r
F P
0 g
s
.63595 .44371 m .59678 .41791 L p .63913 .49129 L 0 .671 .39 r
F P
0 g
s
.63913 .49129 m .63916 .49127 L .63595 .44371 L p 0 .671 .39 r
F P
0 g
s
.63595 .44371 m .59678 .41791 L .60794 .41131 L p 0 .907 1 r
F P
0 g
s
.60794 .41131 m .64706 .43741 L .63595 .44371 L p 0 .907 1 r
F P
0 g
s
.55315 .44371 m .51203 .41791 L .5015 .42442 L p 0 .907 0 r
F P
0 g
s
.55315 .44371 m .55441 .49131 L .54363 .49739 L p 0 .1 0 r
F P
0 g
s
.55441 .49131 m .55315 .44371 L .51203 .41791 L p 0 .679 0 r
F P
0 g
s
.51175 .372 m .51203 .41791 L .55315 .44371 L p 0 .679 0 r
F P
0 g
s
.51175 .372 m .51203 .41791 L .55315 .44371 L p 0 .679 0 r
F P
0 g
s
.51203 .41791 m .55315 .44371 L .56379 .43741 L p 0 .907 0 r
F P
0 g
s
.55315 .44371 m .55441 .49131 L .59452 .51539 L p 0 .679 0 r
F P
0 g
s
.55315 .44371 m .55441 .49131 L .59452 .51539 L p 0 .679 0 r
F P
0 g
s
.55315 .44371 m .55441 .49131 L .56531 .48515 L p 0 .1 0 r
F P
0 g
s
.56531 .48515 m .56379 .43741 L .55315 .44371 L p 0 .1 0 r
F P
0 g
s
.55441 .49131 m .55315 .44371 L .51203 .41791 L p 0 .679 0 r
F P
0 g
s
.51175 .372 m .51203 .41791 L .5015 .42442 L p 0 .1 0 r
F P
0 g
s
.55315 .44371 m .51203 .41791 L .52268 .41131 L p 0 .907 0 r
F P
0 g
s
.52268 .41131 m .56379 .43741 L .55315 .44371 L p 0 .907 0 r
F P
0 g
s
.51203 .41791 m .51175 .372 L .52216 .3653 L p 0 .1 0 r
F P
0 g
s
.55441 .49131 m .55315 .44371 L .56379 .43741 L p 0 .1 0 r
F P
0 g
s
.52216 .50953 m .51175 .51541 L .46966 .49131 L p 0 .911 1 r
F P
0 g
s
.48006 .48515 m .46966 .49131 L .47036 .44371 L p 0 .1 .425 r
F P
0 g
s
.47036 .44371 m .48052 .43741 L .48006 .48515 L p 0 .1 .425 r
F P
0 g
s
.45938 .49739 m .46966 .49131 L .51175 .51541 L p 0 .911 1 r
F P
0 g
s
.59452 .51539 m .55441 .49131 L .56531 .48515 L p 0 .911 0 r
F P
0 g
s
.56531 .48515 m .6054 .50951 L .59452 .51539 L p 0 .911 0 r
F P
0 g
s
.67732 .37198 m .67735 .37204 L .6887 .36533 L p 0 .575 0 r
F P
0 g
s
.67735 .37204 m .68154 .41791 L .69319 .41131 L p 0 .114 0 r
F P
0 g
s
.69319 .41131 m .6887 .36533 L .67735 .37204 L p 0 .114 0 r
F P
0 g
s
.67732 .37198 m .63916 .34451 L .62789 .35146 L p 0 .903 0 r
F P
0 g
s
.67732 .37198 m .63916 .34451 L p .68154 .41791 L 0 .661 0 r
F P
0 g
s
.68154 .41791 m .67735 .37204 L .67732 .37198 L p 0 .661 0 r
F P
0 g
s
.63916 .34451 m .67732 .37198 L .68867 .36528 L p 0 .903 0 r
F P
0 g
s
.6887 .36533 m .68867 .36528 L .67732 .37198 L p 0 .575 0 r
F P
0 g
s
.67732 .37198 m .63916 .34451 L p .68154 .41791 L 0 .661 0 r
F P
0 g
s
.68154 .41791 m .67735 .37204 L .67732 .37198 L p 0 .661 0 r
F P
0 g
s
.26899 .50779 m .26902 .50784 L .26005 .51374 L p 0 .546 0 r
F P
0 g
s
.26005 .51374 m .26002 .51369 L .26899 .50779 L p 0 .546 0 r
F P
0 g
s
.34295 .37011 m .34298 .3701 L .35243 .36337 L p 0 1 0 r
F P
0 g
s
.33923 .41602 m .34295 .37011 L .34298 .3701 L p 0 .692 0 r
F P
0 g
s
.33923 .41602 m .34295 .37011 L .34298 .3701 L p 0 .692 0 r
F P
0 g
s
.49849 .42256 m .50902 .41602 L .50881 .37008 L p 0 .1 0 r
F P
0 g
s
.50902 .41602 m .50881 .37008 L .46657 .3425 L p 0 .679 0 r
F P
0 g
s
.51921 .36335 m .50881 .37008 L .50902 .41602 L p 0 .1 0 r
F P
0 g
s
.50881 .37008 m .51921 .36335 L .47697 .33545 L p 0 .903 0 r
F P
0 g
s
.47697 .33545 m .46657 .3425 L .50881 .37008 L p 0 .903 0 r
F P
0 g
s
.50902 .41602 m .50881 .37008 L .46657 .3425 L p 0 .679 0 r
F P
0 g
s
.39158 .48336 m .4358 .50783 L .42588 .51372 L p 0 .911 0 r
F P
0 g
s
.42588 .51372 m .38168 .48954 L .39158 .48336 L p 0 .911 0 r
F P
0 g
s
.38168 .48954 m .38441 .4419 L .3941 .43559 L p 0 .1 0 r
F P
0 g
s
.38441 .4419 m .38168 .48954 L .37189 .49565 L p 0 .1 0 r
F P
0 g
s
.39158 .48336 m .3941 .43559 L .38441 .4419 L p 0 .1 0 r
F P
0 g
s
.38441 .4419 m .38168 .48954 L .39158 .48336 L p 0 .1 0 r
F P
0 g
s
.33923 .41602 m .38441 .4419 L .3941 .43559 L p 0 .907 0 r
F P
0 g
s
.38441 .4419 m .38168 .48954 L .33536 .4642 L p 0 .692 0 r
F P
0 g
s
.38441 .4419 m .33923 .41602 L .32969 .42256 L p 0 .907 0 r
F P
0 g
s
.33923 .41602 m .38441 .4419 L p .33536 .4642 L 0 .692 0 r
F P
0 g
s
.38441 .4419 m .38168 .48954 L .33536 .4642 L p 0 .692 0 r
F P
0 g
s
.33923 .41602 m .38441 .4419 L p .33536 .4642 L 0 .692 0 r
F P
0 g
s
.34888 .4094 m .3941 .43559 L .38441 .4419 L p 0 .907 0 r
F P
0 g
s
.38441 .4419 m .33923 .41602 L .34888 .4094 L p 0 .907 0 r
F P
0 g
s
.30148 .4419 m .29678 .48951 L .2875 .49561 L p 0 .1 .365 r
F P
0 g
s
.29681 .48956 m .29678 .48951 L .30148 .4419 L p 0 .696 .486 r
F P
0 g
s
.29681 .48956 m .29678 .48951 L .30148 .4419 L p 0 .696 .486 r
F P
0 g
s
.29678 .48951 m .30148 .4419 L .31069 .43559 L p 0 .1 .365 r
F P
0 g
s
.30621 .48338 m .35239 .50783 L .34295 .51372 L p 0 .911 1 r
F P
0 g
s
.34295 .51372 m .29681 .48956 L .30621 .48338 L p 0 .911 1 r
F P
0 g
s
.47697 .48336 m .47751 .43559 L .46735 .4419 L p 0 .1 .423 r
F P
0 g
s
.46735 .4419 m .46657 .48954 L .47697 .48336 L p 0 .1 .423 r
F P
0 g
s
.42412 .41602 m .46735 .4419 L .47751 .43559 L p 0 .907 1 r
F P
0 g
s
.46735 .4419 m .46657 .48954 L .42228 .46418 L p 0 .686 .443 r
F P
0 g
s
.46735 .4419 m .42412 .41602 L .41409 .42256 L p 0 .907 1 r
F P
0 g
s
.42228 .46418 m .42412 .41602 L .46735 .4419 L p 0 .686 .443 r
F P
0 g
s
.46735 .4419 m .46657 .48954 L .42228 .46418 L p 0 .686 .443 r
F P
0 g
s
.42228 .46418 m .42412 .41602 L .46735 .4419 L p 0 .686 .443 r
F P
0 g
s
.43427 .4094 m .47751 .43559 L .46735 .4419 L p 0 .907 1 r
F P
0 g
s
.46735 .4419 m .42412 .41602 L .43427 .4094 L p 0 .907 1 r
F P
0 g
s
.42412 .41602 m .42588 .37008 L .4358 .36335 L p 0 .1 .396 r
F P
0 g
s
.42588 .37008 m .42412 .41602 L .41409 .42256 L p 0 .1 .396 r
F P
0 g
s
.43427 .4094 m .4358 .36335 L .42588 .37008 L p 0 .1 .396 r
F P
0 g
s
.42588 .37008 m .42412 .41602 L .43427 .4094 L p 0 .1 .396 r
F P
0 g
s
.38171 .34252 m .42588 .37008 L .4358 .36335 L p 0 .903 1 r
F P
0 g
s
.42588 .37008 m .42412 .41602 L .37881 .38888 L p 0 .686 .443 r
F P
0 g
s
.42588 .37008 m .38171 .34252 L .37193 .34949 L p 0 .903 1 r
F P
0 g
s
.38171 .34252 m .42588 .37008 L p .37881 .38888 L 0 .686 .443 r
F P
0 g
s
.42588 .37008 m .42412 .41602 L .37881 .38888 L p 0 .686 .443 r
F P
0 g
s
.38171 .34252 m .42588 .37008 L p .37881 .38888 L 0 .686 .443 r
F P
0 g
s
.35243 .36337 m .35239 .36339 L .34295 .37011 L p 0 1 0 r
F P
0 g
s
.33923 .41602 m .34295 .37011 L .35239 .36339 L p 0 .1 0 r
F P
0 g
s
.34295 .37011 m .33923 .41602 L .32969 .42256 L p 0 .1 0 r
F P
0 g
s
.22073 .59078 m .21489 .59443 L .21493 .59441 L p 0 .93 .764 r
F P
0 g
s
.25676 .71612 m .25064 .71936 L .25642 .66632 L p 0 .1 .396 r
F P
0 g
s
.25642 .66632 m .26242 .66295 L .25676 .71612 L p 0 .1 .396 r
F P
0 g
s
.26242 .66295 m .25642 .66632 L .20813 .64572 L p 0 .916 1 r
F P
0 g
s
.20222 .64922 m .20813 .64572 L .25642 .66632 L p 0 .916 1 r
F P
0 g
s
.21408 .64219 m .20813 .64572 L .25642 .66632 L p 0 .916 1 r
F P
0 g
s
.25642 .66632 m .26242 .66295 L .21408 .64219 L p 0 .916 1 r
F P
0 g
s
.26242 .66295 m .25642 .66632 L .25064 .71936 L p 0 .1 .396 r
F P
0 g
s
.20104 .69951 m .20813 .64572 L .25642 .66632 L p 0 .704 .523 r
F P
0 g
s
.20107 .69956 m .20104 .69951 L p .25642 .66632 L 0 .704 .523 r
F P
0 g
s
.24456 .72257 m .25064 .71936 L .25642 .66632 L p 0 .1 .396 r
F P
0 g
s
.25642 .66632 m .25064 .71936 L .20107 .69956 L p 0 .704 .523 r
F P
0 g
s
.20104 .69951 m .20813 .64572 L .25642 .66632 L p 0 .704 .523 r
F P
0 g
s
.20107 .69956 m .20104 .69951 L p .25642 .66632 L 0 .704 .523 r
F P
0 g
s
.25642 .66632 m .25064 .71936 L .20107 .69956 L p 0 .704 .523 r
F P
0 g
s
.30411 .73516 m .29795 .73825 L .25064 .71936 L p 0 .916 1 r
F P
0 g
s
.24456 .72257 m .25064 .71936 L .29795 .73825 L p 0 .916 1 r
F P
0 g
s
.21408 .64219 m .20813 .64572 L .21489 .59443 L p 0 .1 .365 r
F P
0 g
s
.21489 .59443 m .22073 .59078 L .21408 .64219 L p 0 .1 .365 r
F P
0 g
s
.47026 .73809 m .47023 .73811 L .48043 .73351 L p 0 .1 .1 r
F P
0 g
s
.38451 .64558 m .42872 .66619 L .43868 .66116 L p 0 .916 1 r
F P
0 g
s
.43722 .7144 m .43868 .66116 L .42872 .66619 L p 0 .1 .45 r
F P
0 g
s
.42872 .66619 m .42703 .71923 L .43722 .7144 L p 0 .1 .45 r
F P
0 g
s
.42872 .66619 m .38451 .64558 L .3747 .65079 L p 0 .916 1 r
F P
0 g
s
.38171 .69941 m .38451 .64558 L .42872 .66619 L p 0 .696 .486 r
F P
0 g
s
.42872 .66619 m .42703 .71923 L .41697 .724 L p 0 .1 .45 r
F P
0 g
s
.42872 .66619 m .42703 .71923 L .38171 .69941 L p 0 .696 .486 r
F P
0 g
s
.38171 .69941 m .38451 .64558 L .42872 .66619 L p 0 .696 .486 r
F P
0 g
s
.42872 .66619 m .42703 .71923 L .38171 .69941 L p 0 .696 .486 r
F P
0 g
s
.42703 .71923 m .42872 .66619 L .43868 .66116 L p 0 .1 .45 r
F P
0 g
s
.39445 .64032 m .43868 .66116 L .42872 .66619 L p 0 .916 1 r
F P
0 g
s
.42872 .66619 m .38451 .64558 L .39445 .64032 L p 0 .916 1 r
F P
0 g
s
.38719 .59425 m .38451 .64558 L .3747 .65079 L p 0 .1 .425 r
F P
0 g
s
.38451 .64558 m .38719 .59425 L .39691 .58881 L p 0 .1 .425 r
F P
0 g
s
.42703 .57194 m .47026 .59425 L .48046 .58881 L p 0 .914 0 r
F P
0 g
s
.47999 .64032 m .48046 .58881 L .47026 .59425 L p 0 .1 0 r
F P
0 g
s
.47026 .59425 m .46955 .64558 L .47999 .64032 L p 0 .1 0 r
F P
0 g
s
.47026 .59425 m .42703 .57194 L .41697 .57757 L p 0 .914 0 r
F P
0 g
s
.42526 .62398 m .42703 .57194 L .47026 .59425 L p 0 .692 0 r
F P
0 g
s
.47026 .59425 m .46955 .64558 L .45924 .65079 L p 0 .1 0 r
F P
0 g
s
.47026 .59425 m .46955 .64558 L .42526 .62398 L p 0 .692 0 r
F P
0 g
s
.42526 .62398 m .42703 .57194 L .47026 .59425 L p 0 .692 0 r
F P
0 g
s
.47026 .59425 m .46955 .64558 L .42526 .62398 L p 0 .692 0 r
F P
0 g
s
.46955 .64558 m .47026 .59425 L .48046 .58881 L p 0 .1 0 r
F P
0 g
s
.46955 .64558 m .51179 .66619 L .52223 .66116 L p 0 .916 0 r
F P
0 g
s
.52276 .71436 m .52223 .66116 L .51179 .66619 L p 0 .114 0 r
F P
0 g
s
.51179 .66619 m .51207 .71919 L .52276 .71436 L p 0 .114 0 r
F P
0 g
s
.51179 .66619 m .46955 .64558 L .45924 .65079 L p 0 .916 0 r
F P
0 g
s
.46881 .69941 m .46955 .64558 L .51179 .66619 L p 0 .692 0 r
F P
0 g
s
.51204 .71922 m .51207 .71919 L .50151 .72397 L p 0 .1 0 r
F P
0 g
s
.51204 .71922 m .46881 .69941 L p .51179 .66619 L 0 .692 0 r
F P
0 g
s
.51179 .66619 m .51207 .71919 L .51204 .71922 L p 0 .692 0 r
F P
0 g
s
.46881 .69941 m .46955 .64558 L .51179 .66619 L p 0 .692 0 r
F P
0 g
s
.51204 .71922 m .46881 .69941 L p .51179 .66619 L 0 .692 0 r
F P
0 g
s
.51179 .66619 m .51207 .71919 L .51204 .71922 L p 0 .692 0 r
F P
0 g
s
.47999 .64032 m .52223 .66116 L .51179 .66619 L p 0 .916 0 r
F P
0 g
s
.51179 .66619 m .46955 .64558 L .47999 .64032 L p 0 .916 0 r
F P
0 g
s
.35167 .7144 m .39691 .73352 L .38719 .73813 L p 0 .916 0 r
F P
0 g
s
.38719 .73813 m .34199 .71923 L .35167 .7144 L p 0 .916 0 r
F P
0 g
s
.34199 .71923 m .34566 .66619 L .35513 .66116 L p 0 .1 0 r
F P
0 g
s
.34566 .66619 m .34199 .71923 L .33243 .724 L p 0 .1 0 r
F P
0 g
s
.43722 .7144 m .48043 .73351 L .47023 .73811 L p 0 .916 1 r
F P
0 g
s
.47023 .73811 m .42703 .71923 L .43722 .7144 L p 0 .916 1 r
F P
0 g
s
.51207 .57194 m .5533 .59423 L .56398 .58879 L p 0 .914 1 r
F P
0 g
s
.56553 .64032 m .56401 .58884 L .55333 .59429 L p 0 .114 .472 r
F P
0 g
s
.55333 .59429 m .55459 .64558 L .56553 .64032 L p 0 .114 .472 r
F P
0 g
s
.56401 .58884 m .56398 .58879 L .5533 .59423 L p 0 .562 .887 r
F P
0 g
s
.5533 .59423 m .55333 .59429 L .56401 .58884 L p 0 .562 .887 r
F P
0 g
s
.5533 .59423 m .51207 .57194 L .50151 .57757 L p 0 .914 1 r
F P
0 g
s
.51237 .62398 m .51207 .57194 L .5533 .59423 L p 0 .686 .443 r
F P
0 g
s
.55459 .64558 m .51237 .62398 L p .5533 .59423 L 0 .686 .443 r
F P
0 g
s
.5533 .59423 m .55333 .59429 L .55459 .64558 L p 0 .686 .443 r
F P
0 g
s
.51237 .62398 m .51207 .57194 L .5533 .59423 L p 0 .686 .443 r
F P
0 g
s
.55459 .64558 m .51237 .62398 L p .5533 .59423 L 0 .686 .443 r
F P
0 g
s
.5533 .59423 m .55333 .59429 L .55459 .64558 L p 0 .686 .443 r
F P
0 g
s
.37146 .6493 m .38127 .64407 L .38403 .59269 L p 0 .1 .423 r
F P
0 g
s
.34836 .56458 m .33868 .5703 L .38403 .59269 L p 0 .914 1 r
F P
0 g
s
.38403 .59269 m .39375 .58723 L .34836 .56458 L p 0 .914 1 r
F P
0 g
s
.39375 .58723 m .38403 .59269 L .38127 .64407 L p 0 .1 .423 r
F P
0 g
s
.33476 .62239 m .33868 .5703 L .38403 .59269 L p 0 .696 .486 r
F P
0 g
s
.38403 .59269 m .38127 .64407 L .33476 .62239 L p 0 .696 .486 r
F P
0 g
s
.33476 .62239 m .33868 .5703 L .38403 .59269 L p 0 .696 .486 r
F P
0 g
s
.38403 .59269 m .38127 .64407 L .33476 .62239 L p 0 .696 .486 r
F P
0 g
s
.3519 .65971 m .34243 .66475 L .29609 .64407 L p 0 .916 0 r
F P
0 g
s
.30552 .63879 m .29609 .64407 L .30083 .59269 L p 0 .1 0 r
F P
0 g
s
.30083 .59269 m .31006 .58723 L .30552 .63879 L p 0 .1 0 r
F P
0 g
s
.28678 .6493 m .29609 .64407 L .34243 .66475 L p 0 .916 0 r
F P
0 g
s
.30552 .63879 m .29609 .64407 L .34243 .66475 L p 0 .916 0 r
F P
0 g
s
.34243 .66475 m .3519 .65971 L .30552 .63879 L p 0 .916 0 r
F P
0 g
s
.3519 .65971 m .34243 .66475 L .33868 .71785 L p 0 .1 0 r
F P
0 g
s
.29113 .69796 m .29609 .64407 L .34243 .66475 L p 0 .7 0 r
F P
0 g
s
.32912 .72264 m .33868 .71785 L .34243 .66475 L p 0 .1 0 r
F P
0 g
s
.34243 .66475 m .33868 .71785 L .29113 .69796 L p 0 .7 0 r
F P
0 g
s
.29113 .69796 m .29609 .64407 L .34243 .66475 L p 0 .7 0 r
F P
0 g
s
.34243 .66475 m .33868 .71785 L .29113 .69796 L p 0 .7 0 r
F P
0 g
s
.26271 .5646 m .25353 .57032 L .30083 .59269 L p 0 .914 0 r
F P
0 g
s
.30083 .59269 m .31006 .58723 L .26271 .5646 L p 0 .914 0 r
F P
0 g
s
.31006 .58723 m .30083 .59269 L .29609 .64407 L p 0 .1 0 r
F P
0 g
s
.24447 .57597 m .25353 .57032 L .25349 .57034 L p 0 .93 0 r
F P
0 g
s
.25349 .57034 m .25353 .57032 L .30083 .59269 L p 0 .7 0 r
F P
0 g
s
.2475 .62239 m .25349 .57034 L p .30083 .59269 L 0 .7 0 r
F P
0 g
s
.28678 .6493 m .29609 .64407 L .30083 .59269 L p 0 .1 0 r
F P
0 g
s
.30083 .59269 m .29609 .64407 L .2475 .62239 L p 0 .7 0 r
F P
0 g
s
.25349 .57034 m .25353 .57032 L .30083 .59269 L p 0 .7 0 r
F P
0 g
s
.2475 .62239 m .25349 .57034 L p .30083 .59269 L 0 .7 0 r
F P
0 g
s
.30083 .59269 m .29609 .64407 L .2475 .62239 L p 0 .7 0 r
F P
0 g
s
.17766 .71258 m .16907 .71739 L .17675 .66431 L p 0 .1 0 r
F P
0 g
s
.17675 .66431 m .18518 .65932 L .17766 .71258 L p 0 .1 0 r
F P
0 g
s
.22704 .73183 m .21837 .73641 L .1691 .71744 L p 0 .916 0 r
F P
0 g
s
.16061 .72219 m .1691 .71744 L .21837 .73641 L p 0 .916 0 r
F P
0 g
s
.56379 .43741 m .52268 .41131 L .51203 .41791 L p 0 .907 0 r
F P
0 g
s
.56379 .43741 m .56531 .48515 L .55441 .49131 L p 0 .1 0 r
F P
0 g
s
.56531 .48515 m .56379 .43741 L .52268 .41131 L p 0 .677 0 r
F P
0 g
s
.52216 .3653 m .52268 .41131 L .51203 .41791 L p 0 .1 0 r
F P
0 g
s
.52216 .3653 m .52268 .41131 L .56379 .43741 L p 0 .677 0 r
F P
0 g
s
.56379 .43741 m .56531 .48515 L .6054 .50951 L p 0 .677 0 r
F P
0 g
s
.60543 .3653 m .56531 .33748 L .55441 .34451 L p 0 .903 1 r
F P
0 g
s
.60543 .3653 m .60794 .41131 L .59678 .41791 L p 0 .1 .45 r
F P
0 g
s
.60794 .41131 m .60543 .3653 L .56531 .33748 L p 0 .668 .382 r
F P
0 g
s
.64706 .43741 m .60794 .41131 L .59678 .41791 L p 0 .907 1 r
F P
0 g
s
.65053 .48513 m .65056 .48511 L .63916 .49127 L p 0 .1 .1 r
F P
0 g
s
.64706 .43741 m .60794 .41131 L p .65053 .48513 L 0 .668 .382 r
F P
0 g
s
.65053 .48513 m .65056 .48511 L .64706 .43741 L p 0 .668 .382 r
F P
0 g
s
.60543 .3653 m .60794 .41131 L .64706 .43741 L p 0 .668 .382 r
F P
0 g
s
.46966 .49131 m .48006 .48515 L .52216 .50953 L p 0 .911 1 r
F P
0 g
s
.69319 .41131 m .6887 .36533 L .68867 .36528 L p 0 .658 0 r
F P
0 g
s
.68867 .36528 m .65056 .33748 L .63916 .34451 L p 0 .903 0 r
F P
0 g
s
.68867 .36528 m .65056 .33748 L p .69319 .41131 L 0 .658 0 r
F P
0 g
s
.60574 .50932 m .60572 .50934 L .61672 .50339 L p 0 .1 .1 r
F P
0 g
s
.52246 .3651 m .52299 .41112 L .5641 .43723 L p 0 .677 .411 r
F P
0 g
s
.52299 .41112 m .5641 .43723 L .57487 .43087 L p 0 .907 1 r
F P
0 g
s
.5641 .43723 m .56563 .48497 L .60572 .50934 L p 0 .677 .411 r
F P
0 g
s
.5641 .43723 m .56563 .48497 L .57666 .47873 L p 0 .1 .45 r
F P
0 g
s
.57666 .47873 m .57487 .43087 L .5641 .43723 L p 0 .1 .45 r
F P
0 g
s
.56563 .48497 m .5641 .43723 L .52299 .41112 L p 0 .677 .411 r
F P
0 g
s
.52299 .41112 m .52246 .3651 L .53298 .35832 L p 0 .1 .425 r
F P
0 g
s
.56563 .48497 m .5641 .43723 L .57487 .43087 L p 0 .1 .45 r
F P
0 g
s
.5641 .43723 m .52299 .41112 L .53377 .40445 L p 0 .907 1 r
F P
0 g
s
.53377 .40445 m .57487 .43087 L .5641 .43723 L p 0 .907 1 r
F P
0 g
s
.56563 .33728 m .60574 .3651 L .61675 .35832 L p 0 .903 0 r
F P
0 g
s
.60574 .3651 m .60826 .41112 L .64739 .43723 L p 0 .668 0 r
F P
0 g
s
.60574 .3651 m .60826 .41112 L .61955 .40445 L p 0 .1 0 r
F P
0 g
s
.61955 .40445 m .61675 .35832 L .60574 .3651 L p 0 .1 0 r
F P
0 g
s
.60826 .41112 m .60574 .3651 L .56563 .33728 L p 0 .668 0 r
F P
0 g
s
.64739 .43723 m .60826 .41112 L p .65086 .48495 L 0 .668 0 r
F P
0 g
s
.65086 .48495 m .65089 .48493 L .64739 .43723 L p 0 .668 0 r
F P
0 g
s
.60826 .41112 m .60574 .3651 L .61675 .35832 L p 0 .1 0 r
F P
0 g
s
.60826 .41112 m .64739 .43723 L .65864 .43087 L p 0 .907 0 r
F P
0 g
s
.64739 .43723 m .65089 .48493 L .66243 .4787 L p 0 .114 0 r
F P
0 g
s
.66243 .4787 m .65864 .43087 L .64739 .43723 L p 0 .114 0 r
F P
0 g
s
.64739 .43723 m .60826 .41112 L .61955 .40445 L p 0 .907 0 r
F P
0 g
s
.61955 .40445 m .65864 .43087 L .64739 .43723 L p 0 .907 0 r
F P
0 g
s
.53298 .50341 m .52246 .50936 L .48036 .48497 L p 0 .911 0 r
F P
0 g
s
.49089 .47873 m .48036 .48497 L .48081 .43723 L p 0 .1 0 r
F P
0 g
s
.48081 .43723 m .4911 .43087 L .49089 .47873 L p 0 .1 0 r
F P
0 g
s
.60572 .50934 m .56563 .48497 L .57666 .47873 L p 0 .911 1 r
F P
0 g
s
.57666 .47873 m .61672 .50339 L .60572 .50934 L p 0 .911 1 r
F P
0 g
s
.689 .36509 m .65089 .33728 L p .69353 .41112 L 0 .658 .35 r
F P
0 g
s
.69353 .41112 m .68903 .36514 L .689 .36509 L p 0 .658 .35 r
F P
0 g
s
.65089 .33728 m .689 .36509 L .7005 .3583 L p 0 .903 1 r
F P
0 g
s
.689 .36509 m .68903 .36514 L .70053 .35835 L p 0 .575 .884 r
F P
0 g
s
.70053 .35835 m .7005 .3583 L .689 .36509 L p 0 .575 .884 r
F P
0 g
s
.68903 .36514 m .69353 .41112 L .70532 .40445 L p 0 .114 .472 r
F P
0 g
s
.70532 .40445 m .70053 .35835 L .68903 .36514 L p 0 .114 .472 r
F P
0 g
s
.22662 .58711 m .22073 .59078 L .22077 .59076 L p 0 .93 .764 r
F P
0 g
s
.31032 .73205 m .30411 .73516 L .25676 .71612 L p 0 .916 1 r
F P
0 g
s
.26294 .71286 m .25676 .71612 L .26242 .66295 L p 0 .1 .396 r
F P
0 g
s
.26242 .66295 m .26847 .65956 L .26294 .71286 L p 0 .1 .396 r
F P
0 g
s
.22008 .63864 m .21408 .64219 L .26242 .66295 L p 0 .916 1 r
F P
0 g
s
.26242 .66295 m .26847 .65956 L .22008 .63864 L p 0 .916 1 r
F P
0 g
s
.26847 .65956 m .26242 .66295 L .25676 .71612 L p 0 .1 .396 r
F P
0 g
s
.20813 .64572 m .21408 .64219 L .26242 .66295 L p 0 .916 1 r
F P
0 g
s
.20711 .69611 m .21408 .64219 L .26242 .66295 L p 0 .703 .52 r
F P
0 g
s
.20714 .69616 m .20711 .69611 L p .26242 .66295 L 0 .703 .52 r
F P
0 g
s
.25064 .71936 m .25676 .71612 L .26242 .66295 L p 0 .1 .396 r
F P
0 g
s
.26242 .66295 m .25676 .71612 L .20714 .69616 L p 0 .703 .52 r
F P
0 g
s
.20711 .69611 m .21408 .64219 L .26242 .66295 L p 0 .703 .52 r
F P
0 g
s
.20714 .69616 m .20711 .69611 L p .26242 .66295 L 0 .703 .52 r
F P
0 g
s
.26242 .66295 m .25676 .71612 L .20714 .69616 L p 0 .703 .52 r
F P
0 g
s
.26847 .65956 m .26242 .66295 L .21408 .64219 L p 0 .916 1 r
F P
0 g
s
.25064 .71936 m .25676 .71612 L .30411 .73516 L p 0 .916 1 r
F P
0 g
s
.22008 .63864 m .21408 .64219 L .22073 .59078 L p 0 .1 .365 r
F P
0 g
s
.22073 .59078 m .22662 .58711 L .22008 .63864 L p 0 .1 .365 r
F P
0 g
s
.34888 .4094 m .35239 .36339 L .35243 .36337 L p 0 .69 0 r
F P
0 g
s
.50902 .41602 m .51967 .4094 L .51921 .36335 L p 0 .1 0 r
F P
0 g
s
.51967 .4094 m .51921 .36335 L .47697 .33545 L p 0 .677 0 r
F P
0 g
s
.3941 .43559 m .39158 .48336 L .38168 .48954 L p 0 .1 0 r
F P
0 g
s
.3941 .43559 m .34888 .4094 L .33923 .41602 L p 0 .907 0 r
F P
0 g
s
.3941 .43559 m .39158 .48336 L .34522 .45772 L p 0 .69 0 r
F P
0 g
s
.34888 .4094 m .3941 .43559 L p .34522 .45772 L 0 .69 0 r
F P
0 g
s
.31069 .43559 m .30618 .48332 L .29678 .48951 L p 0 .1 .365 r
F P
0 g
s
.30621 .48338 m .30618 .48332 L .31069 .43559 L p 0 .695 .481 r
F P
0 g
s
.4358 .36335 m .43427 .4094 L .42412 .41602 L p 0 .1 .396 r
F P
0 g
s
.4358 .36335 m .39161 .33547 L .38171 .34252 L p 0 .903 1 r
F P
0 g
s
.4358 .36335 m .43427 .4094 L .38893 .38194 L p 0 .684 .437 r
F P
0 g
s
.39161 .33547 m .4358 .36335 L p .38893 .38194 L 0 .684 .437 r
F P
0 g
s
.47751 .43559 m .43427 .4094 L .42412 .41602 L p 0 .907 1 r
F P
0 g
s
.47751 .43559 m .47697 .48336 L .43267 .4577 L p 0 .684 .437 r
F P
0 g
s
.43267 .4577 m .43427 .4094 L .47751 .43559 L p 0 .684 .437 r
F P
0 g
s
.35239 .36339 m .34888 .4094 L .33923 .41602 L p 0 .1 0 r
F P
0 g
s
.27832 .50165 m .27835 .5017 L .26928 .50767 L p 0 .546 .889 r
F P
0 g
s
.26928 .50767 m .26925 .50762 L .27832 .50165 L p 0 .546 .889 r
F P
0 g
s
.35266 .36319 m .3527 .36318 L .36226 .35637 L p 0 1 .86 r
F P
0 g
s
.34916 .40921 m .35266 .36319 L .3527 .36318 L p 0 .69 .46 r
F P
0 g
s
.53004 .35635 m .51952 .36316 L .51998 .40921 L p 0 .1 .423 r
F P
0 g
s
.51952 .36316 m .53004 .35635 L .4878 .32811 L p 0 .903 1 r
F P
0 g
s
.4878 .32811 m .47727 .33524 L .51952 .36316 L p 0 .903 1 r
F P
0 g
s
.51998 .40921 m .51952 .36316 L .47727 .33524 L p 0 .677 .411 r
F P
0 g
s
.30648 .4832 m .30645 .48315 L .31095 .43541 L p 0 .695 0 r
F P
0 g
s
.30645 .48315 m .31095 .43541 L .32027 .42902 L p 0 .1 0 r
F P
0 g
s
.31599 .47694 m .36222 .50169 L .35267 .50765 L p 0 .911 0 r
F P
0 g
s
.35267 .50765 m .30648 .4832 L .31599 .47694 L p 0 .911 0 r
F P
0 g
s
.44484 .40251 m .48809 .42902 L .4778 .43541 L p 0 .907 0 r
F P
0 g
s
.4778 .43541 m .43457 .40921 L .44484 .40251 L p 0 .907 0 r
F P
0 g
s
.43457 .40921 m .43609 .36316 L .44613 .35635 L p 0 .1 0 r
F P
0 g
s
.44484 .40251 m .44613 .35635 L .43609 .36316 L p 0 .1 0 r
F P
0 g
s
.43609 .36316 m .43457 .40921 L .44484 .40251 L p 0 .1 0 r
F P
0 g
s
.39189 .33526 m .43609 .36316 L .44613 .35635 L p 0 .903 0 r
F P
0 g
s
.43609 .36316 m .43457 .40921 L .38922 .38174 L p 0 .684 0 r
F P
0 g
s
.39189 .33526 m .43609 .36316 L p .38922 .38174 L 0 .684 0 r
F P
0 g
s
.4878 .47692 m .48809 .42902 L .4778 .43541 L p 0 .1 0 r
F P
0 g
s
.4778 .43541 m .47727 .48318 L .4878 .47692 L p 0 .1 0 r
F P
0 g
s
.43457 .40921 m .4778 .43541 L .48809 .42902 L p 0 .907 0 r
F P
0 g
s
.4778 .43541 m .47727 .48318 L .43297 .45751 L p 0 .684 0 r
F P
0 g
s
.43297 .45751 m .43457 .40921 L .4778 .43541 L p 0 .684 0 r
F P
0 g
s
.40188 .47692 m .44613 .50169 L .43609 .50765 L p 0 .911 1 r
F P
0 g
s
.43609 .50765 m .39186 .48318 L .40188 .47692 L p 0 .911 1 r
F P
0 g
s
.40188 .47692 m .40418 .42902 L .39438 .43541 L p 0 .1 .396 r
F P
0 g
s
.39438 .43541 m .39186 .48318 L .40188 .47692 L p 0 .1 .396 r
F P
0 g
s
.34916 .40921 m .39438 .43541 L .40418 .42902 L p 0 .907 1 r
F P
0 g
s
.39438 .43541 m .39186 .48318 L .34551 .45753 L p 0 .69 .46 r
F P
0 g
s
.34916 .40921 m .39438 .43541 L p .34551 .45753 L 0 .69 .46 r
F P
0 g
s
.35892 .40251 m .40418 .42902 L .39438 .43541 L p 0 .907 1 r
F P
0 g
s
.39438 .43541 m .34916 .40921 L .35892 .40251 L p 0 .907 1 r
F P
0 g
s
.39186 .48318 m .39438 .43541 L .40418 .42902 L p 0 .1 .396 r
F P
0 g
s
.36226 .35637 m .36222 .35638 L .35266 .36319 L p 0 1 .86 r
F P
0 g
s
.34916 .40921 m .35266 .36319 L .36222 .35638 L p 0 .1 .365 r
F P
0 g
s
.43868 .66116 m .39445 .64032 L .38451 .64558 L p 0 .916 1 r
F P
0 g
s
.43868 .66116 m .43722 .7144 L .42703 .71923 L p 0 .1 .45 r
F P
0 g
s
.39186 .69434 m .39445 .64032 L .43868 .66116 L p 0 .695 .481 r
F P
0 g
s
.43868 .66116 m .43722 .7144 L .39186 .69434 L p 0 .695 .481 r
F P
0 g
s
.39691 .58881 m .39445 .64032 L .38451 .64558 L p 0 .1 .425 r
F P
0 g
s
.35513 .66116 m .35167 .7144 L .34199 .71923 L p 0 .1 0 r
F P
0 g
s
.48046 .58881 m .43722 .56623 L .42703 .57194 L p 0 .914 0 r
F P
0 g
s
.43568 .61845 m .43722 .56623 L .48046 .58881 L p 0 .69 0 r
F P
0 g
s
.48046 .58881 m .47999 .64032 L .46955 .64558 L p 0 .1 0 r
F P
0 g
s
.48046 .58881 m .47999 .64032 L .43568 .61845 L p 0 .69 0 r
F P
0 g
s
.52223 .66116 m .47999 .64032 L .46955 .64558 L p 0 .916 0 r
F P
0 g
s
.4795 .69434 m .47999 .64032 L .52223 .66116 L p 0 .69 0 r
F P
0 g
s
.52273 .71439 m .52276 .71436 L .51207 .71919 L p 0 .1 0 r
F P
0 g
s
.52273 .71439 m .4795 .69434 L p .52223 .66116 L 0 .69 0 r
F P
0 g
s
.52223 .66116 m .52276 .71436 L .52273 .71439 L p 0 .69 0 r
F P
0 g
s
.56398 .58879 m .52276 .56623 L .51207 .57194 L p 0 .914 1 r
F P
0 g
s
.52332 .61845 m .52276 .56623 L .56398 .58879 L p 0 .684 .437 r
F P
0 g
s
.56553 .64032 m .52332 .61845 L p .56398 .58879 L 0 .684 .437 r
F P
0 g
s
.56398 .58879 m .56401 .58884 L .56553 .64032 L p 0 .684 .437 r
F P
0 g
s
.48075 .73335 m .48072 .73337 L .49104 .72871 L p 0 .1 0 r
F P
0 g
s
.35195 .71426 m .35541 .66102 L .365 .65593 L p 0 .1 .425 r
F P
0 g
s
.36175 .70937 m .40702 .72872 L .39719 .73339 L p 0 .916 1 r
F P
0 g
s
.39719 .73339 m .35195 .71426 L .36175 .70937 L p 0 .916 1 r
F P
0 g
s
.39473 .64016 m .39719 .58865 L .40702 .58314 L p 0 .1 0 r
F P
0 g
s
.40479 .63483 m .44904 .65593 L .43897 .66102 L p 0 .916 0 r
F P
0 g
s
.43897 .66102 m .39473 .64016 L .40479 .63483 L p 0 .916 0 r
F P
0 g
s
.39473 .64016 m .43897 .66102 L .44904 .65593 L p 0 .916 0 r
F P
0 g
s
.44782 .70937 m .44904 .65593 L .43897 .66102 L p 0 .1 0 r
F P
0 g
s
.43897 .66102 m .43751 .71426 L .44782 .70937 L p 0 .1 0 r
F P
0 g
s
.39216 .6942 m .39473 .64016 L .43897 .66102 L p 0 .695 0 r
F P
0 g
s
.43897 .66102 m .43751 .71426 L .39216 .6942 L p 0 .695 0 r
F P
0 g
s
.43751 .71426 m .43897 .66102 L .44904 .65593 L p 0 .1 0 r
F P
0 g
s
.43751 .56607 m .48075 .58865 L .49107 .58314 L p 0 .914 1 r
F P
0 g
s
.49086 .63483 m .49107 .58314 L .48075 .58865 L p 0 .1 .45 r
F P
0 g
s
.48075 .58865 m .48029 .64016 L .49086 .63483 L p 0 .1 .45 r
F P
0 g
s
.43598 .61829 m .43751 .56607 L .48075 .58865 L p 0 .69 .46 r
F P
0 g
s
.48075 .58865 m .48029 .64016 L .43598 .61829 L p 0 .69 .46 r
F P
0 g
s
.48029 .64016 m .48075 .58865 L .49107 .58314 L p 0 .1 .45 r
F P
0 g
s
.48029 .64016 m .52253 .66102 L .53309 .65593 L p 0 .916 1 r
F P
0 g
s
.53389 .70933 m .53309 .65593 L .52253 .66102 L p 0 .114 .472 r
F P
0 g
s
.52253 .66102 m .52307 .71422 L .53389 .70933 L p 0 .114 .472 r
F P
0 g
s
.47981 .6942 m .48029 .64016 L .52253 .66102 L p 0 .69 .46 r
F P
0 g
s
.52304 .71425 m .47981 .6942 L p .52253 .66102 L 0 .69 .46 r
F P
0 g
s
.52253 .66102 m .52307 .71422 L .52304 .71425 L p 0 .69 .46 r
F P
0 g
s
.49086 .63483 m .53309 .65593 L .52253 .66102 L p 0 .916 1 r
F P
0 g
s
.52253 .66102 m .48029 .64016 L .49086 .63483 L p 0 .916 1 r
F P
0 g
s
.44782 .70937 m .49104 .72871 L .48072 .73337 L p 0 .916 0 r
F P
0 g
s
.48072 .73337 m .43751 .71426 L .44782 .70937 L p 0 .916 0 r
F P
0 g
s
.52307 .56607 m .56428 .58863 L .57509 .58313 L p 0 .914 0 r
F P
0 g
s
.57692 .63483 m .57512 .58318 L .56431 .58869 L p 0 .114 0 r
F P
0 g
s
.56431 .58869 m .56585 .64016 L .57692 .63483 L p 0 .114 0 r
F P
0 g
s
.57512 .58318 m .57509 .58313 L .56428 .58863 L p 0 .562 0 r
F P
0 g
s
.56428 .58863 m .56431 .58869 L .57512 .58318 L p 0 .562 0 r
F P
0 g
s
.52363 .61829 m .52307 .56607 L .56428 .58863 L p 0 .684 0 r
F P
0 g
s
.56585 .64016 m .52363 .61829 L p .56428 .58863 L 0 .684 0 r
F P
0 g
s
.56428 .58863 m .56431 .58869 L .56585 .64016 L p 0 .684 0 r
F P
0 g
s
.38127 .64407 m .3912 .63879 L .39375 .58723 L p 0 .1 .423 r
F P
0 g
s
.34465 .61685 m .34836 .56458 L .39375 .58723 L p 0 .695 .481 r
F P
0 g
s
.39375 .58723 m .3912 .63879 L .34465 .61685 L p 0 .695 .481 r
F P
0 g
s
.33868 .71785 m .34836 .713 L .3519 .65971 L p 0 .1 0 r
F P
0 g
s
.29609 .64407 m .30552 .63879 L .3519 .65971 L p 0 .916 0 r
F P
0 g
s
.30075 .69287 m .30552 .63879 L .3519 .65971 L p 0 .699 0 r
F P
0 g
s
.3519 .65971 m .34836 .713 L .30075 .69287 L p 0 .699 0 r
F P
0 g
s
.29609 .64407 m .30552 .63879 L .31006 .58723 L p 0 .1 0 r
F P
0 g
s
.25353 .57032 m .26271 .5646 L .26267 .56462 L p 0 .93 0 r
F P
0 g
s
.26267 .56462 m .26271 .5646 L .31006 .58723 L p 0 .699 0 r
F P
0 g
s
.25686 .61685 m .26267 .56462 L p .31006 .58723 L 0 .699 0 r
F P
0 g
s
.31006 .58723 m .30552 .63879 L .25686 .61685 L p 0 .699 0 r
F P
0 g
s
.14991 .72817 m .14296 .73206 L .14293 .73201 L p 0 .525 .891 r
F P
0 g
s
.14293 .73201 m .14988 .72812 L .14991 .72817 L p 0 .525 .891 r
F P
0 g
s
.23547 .58158 m .22662 .58711 L .22666 .58709 L p 0 .93 0 r
F P
0 g
s
.36176 .65446 m .35218 .65956 L .30579 .63864 L p 0 .916 1 r
F P
0 g
s
.31533 .63329 m .30579 .63864 L .35218 .65956 L p 0 .916 1 r
F P
0 g
s
.35218 .65956 m .36176 .65446 L .31533 .63329 L p 0 .916 1 r
F P
0 g
s
.36176 .65446 m .35218 .65956 L .34864 .71286 L p 0 .1 .423 r
F P
0 g
s
.30103 .69273 m .30579 .63864 L .35218 .65956 L p 0 .699 .5 r
F P
0 g
s
.35218 .65956 m .34864 .71286 L .30103 .69273 L p 0 .699 .5 r
F P
0 g
s
.31533 .63329 m .30579 .63864 L .31032 .58707 L p 0 .1 .396 r
F P
0 g
s
.31032 .58707 m .31967 .58155 L .31533 .63329 L p 0 .1 .396 r
F P
0 g
s
.27226 .55864 m .26297 .56443 L .31032 .58707 L p 0 .914 1 r
F P
0 g
s
.31032 .58707 m .31967 .58155 L .27226 .55864 L p 0 .914 1 r
F P
0 g
s
.31967 .58155 m .31032 .58707 L .30579 .63864 L p 0 .1 .396 r
F P
0 g
s
.26293 .56445 m .26297 .56443 L .31032 .58707 L p 0 .699 .5 r
F P
0 g
s
.25713 .61669 m .26293 .56445 L p .31032 .58707 L 0 .699 .5 r
F P
0 g
s
.31032 .58707 m .30579 .63864 L .25713 .61669 L p 0 .699 .5 r
F P
0 g
s
.35844 .55862 m .34864 .56441 L .39403 .58707 L p 0 .914 0 r
F P
0 g
s
.39403 .58707 m .40386 .58155 L .35844 .55862 L p 0 .914 0 r
F P
0 g
s
.40386 .58155 m .39403 .58707 L .39149 .63864 L p 0 .1 0 r
F P
0 g
s
.34493 .61669 m .34864 .56441 L .39403 .58707 L p 0 .695 0 r
F P
0 g
s
.39403 .58707 m .39149 .63864 L .34493 .61669 L p 0 .695 0 r
F P
0 g
s
.25676 .71612 m .26294 .71286 L .31032 .73205 L p 0 .916 1 r
F P
0 g
s
.25676 .71612 m .26294 .71286 L .26847 .65956 L p 0 .1 .396 r
F P
0 g
s
.21408 .64219 m .22008 .63864 L .26847 .65956 L p 0 .916 1 r
F P
0 g
s
.21323 .69269 m .22008 .63864 L .26847 .65956 L p 0 .703 .518 r
F P
0 g
s
.21326 .69274 m .21323 .69269 L p .26847 .65956 L 0 .703 .518 r
F P
0 g
s
.26847 .65956 m .26294 .71286 L .21326 .69274 L p 0 .703 .518 r
F P
0 g
s
.31967 .72737 m .31032 .73205 L .26294 .71286 L p 0 .916 0 r
F P
0 g
s
.27222 .70795 m .26294 .71286 L .26847 .65956 L p 0 .1 0 r
F P
0 g
s
.26847 .65956 m .27757 .65446 L .27222 .70795 L p 0 .1 0 r
F P
0 g
s
.22911 .63329 m .22008 .63864 L .26847 .65956 L p 0 .916 0 r
F P
0 g
s
.26847 .65956 m .27757 .65446 L .22911 .63329 L p 0 .916 0 r
F P
0 g
s
.27757 .65446 m .26847 .65956 L .26294 .71286 L p 0 .1 0 r
F P
0 g
s
.21323 .69269 m .22008 .63864 L .26847 .65956 L p 0 .703 0 r
F P
0 g
s
.21326 .69274 m .21323 .69269 L p .26847 .65956 L 0 .703 0 r
F P
0 g
s
.26847 .65956 m .26294 .71286 L .21326 .69274 L p 0 .703 0 r
F P
0 g
s
.27757 .65446 m .26847 .65956 L .22008 .63864 L p 0 .916 0 r
F P
0 g
s
.22911 .63329 m .22008 .63864 L .22662 .58711 L p 0 .1 0 r
F P
0 g
s
.22662 .58711 m .23547 .58158 L .22911 .63329 L p 0 .1 0 r
F P
0 g
s
.1691 .71744 m .17769 .71264 L .22704 .73183 L p 0 .916 0 r
F P
0 g
s
.61675 .50338 m .61672 .50339 L .62786 .49738 L p 0 .1 .1 r
F P
0 g
s
.57487 .43087 m .53377 .40445 L .52299 .41112 L p 0 .907 1 r
F P
0 g
s
.57487 .43087 m .57666 .47873 L .56563 .48497 L p 0 .1 .45 r
F P
0 g
s
.57666 .47873 m .57487 .43087 L .53377 .40445 L p 0 .675 .404 r
F P
0 g
s
.53298 .35832 m .53377 .40445 L .57487 .43087 L p 0 .675 .404 r
F P
0 g
s
.53298 .35832 m .53377 .40445 L .57487 .43087 L p 0 .675 .404 r
F P
0 g
s
.53377 .40445 m .57487 .43087 L .58576 .42442 L p 0 .907 1 r
F P
0 g
s
.57487 .43087 m .57666 .47873 L .61672 .50339 L p 0 .675 .404 r
F P
0 g
s
.57487 .43087 m .57666 .47873 L .61672 .50339 L p 0 .675 .404 r
F P
0 g
s
.57487 .43087 m .57666 .47873 L .58783 .47242 L p 0 .1 .45 r
F P
0 g
s
.58783 .47242 m .58576 .42442 L .57487 .43087 L p 0 .1 .45 r
F P
0 g
s
.57666 .47873 m .57487 .43087 L .53377 .40445 L p 0 .675 .404 r
F P
0 g
s
.53298 .35832 m .53377 .40445 L .52299 .41112 L p 0 .1 .425 r
F P
0 g
s
.53377 .40445 m .53298 .35832 L .54363 .35146 L p 0 .1 .425 r
F P
0 g
s
.57666 .47873 m .57487 .43087 L .58576 .42442 L p 0 .1 .45 r
F P
0 g
s
.57487 .43087 m .53377 .40445 L .54468 .3977 L p 0 .907 1 r
F P
0 g
s
.54468 .3977 m .58576 .42442 L .57487 .43087 L p 0 .907 1 r
F P
0 g
s
.54363 .49739 m .53298 .50341 L .49089 .47873 L p 0 .911 0 r
F P
0 g
s
.50154 .47242 m .49089 .47873 L .4911 .43087 L p 0 .1 0 r
F P
0 g
s
.4911 .43087 m .5015 .42442 L .50154 .47242 L p 0 .1 0 r
F P
0 g
s
.48036 .48497 m .49089 .47873 L .53298 .50341 L p 0 .911 0 r
F P
0 g
s
.61675 .35832 m .57666 .33017 L .56563 .33728 L p 0 .903 0 r
F P
0 g
s
.61675 .35832 m .61955 .40445 L .60826 .41112 L p 0 .1 0 r
F P
0 g
s
.61955 .40445 m .61675 .35832 L .57666 .33017 L p 0 .666 0 r
F P
0 g
s
.57666 .33017 m .61675 .35832 L .62789 .35146 L p 0 .903 0 r
F P
0 g
s
.61675 .35832 m .61955 .40445 L .65864 .43087 L p 0 .666 0 r
F P
0 g
s
.61675 .35832 m .61955 .40445 L .65864 .43087 L p 0 .666 0 r
F P
0 g
s
.61675 .35832 m .61955 .40445 L .63097 .3977 L p 0 .1 0 r
F P
0 g
s
.63097 .3977 m .62789 .35146 L .61675 .35832 L p 0 .1 0 r
F P
0 g
s
.61955 .40445 m .61675 .35832 L .57666 .33017 L p 0 .666 0 r
F P
0 g
s
.61955 .40445 m .61675 .35832 L .62789 .35146 L p 0 .1 0 r
F P
0 g
s
.65864 .43087 m .61955 .40445 L .60826 .41112 L p 0 .907 0 r
F P
0 g
s
.66241 .47871 m .66243 .4787 L .65089 .48493 L p 0 .1 0 r
F P
0 g
s
.65864 .43087 m .61955 .40445 L p .66241 .47871 L 0 .666 0 r
F P
0 g
s
.66241 .47871 m .66243 .4787 L .65864 .43087 L p 0 .666 0 r
F P
0 g
s
.61955 .40445 m .65864 .43087 L .67002 .42442 L p 0 .907 0 r
F P
0 g
s
.65864 .43087 m .66243 .4787 L .67411 .47239 L p 0 .114 0 r
F P
0 g
s
.67411 .47239 m .67002 .42442 L .65864 .43087 L p 0 .114 0 r
F P
0 g
s
.65864 .43087 m .61955 .40445 L p .66241 .47871 L 0 .666 0 r
F P
0 g
s
.66241 .47871 m .66243 .4787 L .65864 .43087 L p 0 .666 0 r
F P
0 g
s
.65864 .43087 m .61955 .40445 L .63097 .3977 L p 0 .907 0 r
F P
0 g
s
.63097 .3977 m .67002 .42442 L .65864 .43087 L p 0 .907 0 r
F P
0 g
s
.61672 .50339 m .57666 .47873 L .58783 .47242 L p 0 .911 1 r
F P
0 g
s
.58783 .47242 m .62786 .49738 L .61672 .50339 L p 0 .911 1 r
F P
0 g
s
.7005 .3583 m .66243 .33017 L .65089 .33728 L p 0 .903 1 r
F P
0 g
s
.7005 .3583 m .66243 .33017 L p .70532 .40445 L 0 .655 .342 r
F P
0 g
s
.70532 .40445 m .70053 .35835 L .7005 .3583 L p 0 .655 .342 r
F P
0 g
s
.66243 .33017 m .7005 .3583 L .71212 .35144 L p 0 .903 1 r
F P
0 g
s
.7005 .3583 m .70053 .35835 L .71215 .35149 L p 0 .575 .884 r
F P
0 g
s
.71215 .35149 m .71212 .35144 L .7005 .3583 L p 0 .575 .884 r
F P
0 g
s
.7005 .3583 m .66243 .33017 L p .70532 .40445 L 0 .655 .342 r
F P
0 g
s
.70532 .40445 m .70053 .35835 L .7005 .3583 L p 0 .655 .342 r
F P
0 g
s
.70053 .35835 m .70532 .40445 L .71726 .3977 L p 0 .114 .472 r
F P
0 g
s
.71726 .3977 m .71215 .35149 L .70053 .35835 L p 0 .114 .472 r
F P
0 g
s
.2875 .49561 m .28753 .49567 L .27835 .5017 L p 0 .546 .889 r
F P
0 g
s
.27835 .5017 m .27832 .50165 L .2875 .49561 L p 0 .546 .889 r
F P
0 g
s
.36222 .35638 m .36226 .35637 L .37193 .34949 L p 0 1 .86 r
F P
0 g
s
.35892 .40251 m .36222 .35638 L .36226 .35637 L p 0 .689 .454 r
F P
0 g
s
.35892 .40251 m .36222 .35638 L .36226 .35637 L p 0 .689 .454 r
F P
0 g
s
.51998 .40921 m .53076 .40251 L .53004 .35635 L p 0 .1 .423 r
F P
0 g
s
.53076 .40251 m .53004 .35635 L .4878 .32811 L p 0 .675 .404 r
F P
0 g
s
.54069 .34947 m .53004 .35635 L .53076 .40251 L p 0 .1 .423 r
F P
0 g
s
.53004 .35635 m .54069 .34947 L .49846 .32088 L p 0 .903 1 r
F P
0 g
s
.49846 .32088 m .4878 .32811 L .53004 .35635 L p 0 .903 1 r
F P
0 g
s
.53076 .40251 m .53004 .35635 L .4878 .32811 L p 0 .675 .404 r
F P
0 g
s
.49846 .47059 m .49849 .42256 L .48809 .42902 L p 0 .1 0 r
F P
0 g
s
.48809 .42902 m .4878 .47692 L .49846 .47059 L p 0 .1 0 r
F P
0 g
s
.44484 .40251 m .48809 .42902 L .49849 .42256 L p 0 .907 0 r
F P
0 g
s
.48809 .42902 m .4878 .47692 L .44349 .45095 L p 0 .683 0 r
F P
0 g
s
.48809 .42902 m .44484 .40251 L .43457 .40921 L p 0 .907 0 r
F P
0 g
s
.44349 .45095 m .44484 .40251 L .48809 .42902 L p 0 .683 0 r
F P
0 g
s
.48809 .42902 m .4878 .47692 L .44349 .45095 L p 0 .683 0 r
F P
0 g
s
.44349 .45095 m .44484 .40251 L .48809 .42902 L p 0 .683 0 r
F P
0 g
s
.45524 .39574 m .49849 .42256 L .48809 .42902 L p 0 .907 0 r
F P
0 g
s
.48809 .42902 m .44484 .40251 L .45524 .39574 L p 0 .907 0 r
F P
0 g
s
.44484 .40251 m .44613 .35635 L .45629 .34947 L p 0 .1 0 r
F P
0 g
s
.44613 .35635 m .44484 .40251 L .43457 .40921 L p 0 .1 0 r
F P
0 g
s
.45524 .39574 m .45629 .34947 L .44613 .35635 L p 0 .1 0 r
F P
0 g
s
.44613 .35635 m .44484 .40251 L .45524 .39574 L p 0 .1 0 r
F P
0 g
s
.40191 .32813 m .44613 .35635 L .45629 .34947 L p 0 .903 0 r
F P
0 g
s
.44613 .35635 m .44484 .40251 L .39947 .37471 L p 0 .683 0 r
F P
0 g
s
.44613 .35635 m .40191 .32813 L .39189 .33526 L p 0 .903 0 r
F P
0 g
s
.40191 .32813 m .44613 .35635 L p .39947 .37471 L 0 .683 0 r
F P
0 g
s
.44613 .35635 m .44484 .40251 L .39947 .37471 L p 0 .683 0 r
F P
0 g
s
.40191 .32813 m .44613 .35635 L p .39947 .37471 L 0 .683 0 r
F P
0 g
s
.32027 .42902 m .31596 .47689 L .30645 .48315 L p 0 .1 0 r
F P
0 g
s
.32562 .47061 m .37189 .49565 L .36222 .50169 L p 0 .911 0 r
F P
0 g
s
.36222 .50169 m .31599 .47694 L .32562 .47061 L p 0 .911 0 r
F P
0 g
s
.31599 .47694 m .31596 .47689 L .32027 .42902 L p 0 .694 0 r
F P
0 g
s
.31599 .47694 m .31596 .47689 L .32027 .42902 L p 0 .694 0 r
F P
0 g
s
.31596 .47689 m .32027 .42902 L .32969 .42256 L p 0 .1 0 r
F P
0 g
s
.41202 .47059 m .45629 .49565 L .44613 .50169 L p 0 .911 1 r
F P
0 g
s
.44613 .50169 m .40188 .47692 L .41202 .47059 L p 0 .911 1 r
F P
0 g
s
.41202 .47059 m .41409 .42256 L .40418 .42902 L p 0 .1 .396 r
F P
0 g
s
.40418 .42902 m .40188 .47692 L .41202 .47059 L p 0 .1 .396 r
F P
0 g
s
.35892 .40251 m .40418 .42902 L .41409 .42256 L p 0 .907 1 r
F P
0 g
s
.40418 .42902 m .40188 .47692 L .39186 .48318 L p 0 .1 .396 r
F P
0 g
s
.40418 .42902 m .40188 .47692 L .35549 .45096 L p 0 .689 .454 r
F P
0 g
s
.40418 .42902 m .35892 .40251 L .34916 .40921 L p 0 .907 1 r
F P
0 g
s
.35892 .40251 m .40418 .42902 L p .35549 .45096 L 0 .689 .454 r
F P
0 g
s
.40418 .42902 m .40188 .47692 L .35549 .45096 L p 0 .689 .454 r
F P
0 g
s
.35892 .40251 m .40418 .42902 L p .35549 .45096 L 0 .689 .454 r
F P
0 g
s
.3688 .39574 m .41409 .42256 L .40418 .42902 L p 0 .907 1 r
F P
0 g
s
.40418 .42902 m .35892 .40251 L .3688 .39574 L p 0 .907 1 r
F P
0 g
s
.40188 .47692 m .40418 .42902 L .41409 .42256 L p 0 .1 .396 r
F P
0 g
s
.37193 .34949 m .37189 .3495 L .36222 .35638 L p 0 1 .86 r
F P
0 g
s
.35892 .40251 m .36222 .35638 L .37189 .3495 L p 0 .1 .365 r
F P
0 g
s
.36222 .35638 m .35892 .40251 L .34916 .40921 L p 0 .1 .365 r
F P
0 g
s
.49107 .72868 m .49104 .72871 L .50148 .72399 L p 0 .1 0 r
F P
0 g
s
.36175 .70937 m .365 .65593 L .3747 .65079 L p 0 .1 .425 r
F P
0 g
s
.365 .65593 m .36175 .70937 L .35195 .71426 L p 0 .1 .425 r
F P
0 g
s
.37167 .70442 m .41697 .724 L .40702 .72872 L p 0 .916 1 r
F P
0 g
s
.40702 .72872 m .36175 .70937 L .37167 .70442 L p 0 .916 1 r
F P
0 g
s
.40479 .63483 m .40702 .58314 L .41697 .57757 L p 0 .1 0 r
F P
0 g
s
.40702 .58314 m .40479 .63483 L .39473 .64016 L p 0 .1 0 r
F P
0 g
s
.44904 .65593 m .44782 .70937 L .43751 .71426 L p 0 .1 0 r
F P
0 g
s
.41496 .62944 m .45924 .65079 L .44904 .65593 L p 0 .916 0 r
F P
0 g
s
.44904 .65593 m .40479 .63483 L .41496 .62944 L p 0 .916 0 r
F P
0 g
s
.44904 .65593 m .40479 .63483 L .39473 .64016 L p 0 .916 0 r
F P
0 g
s
.44782 .70937 m .44904 .65593 L .45924 .65079 L p 0 .1 0 r
F P
0 g
s
.40479 .63483 m .44904 .65593 L .45924 .65079 L p 0 .916 0 r
F P
0 g
s
.45825 .70442 m .45924 .65079 L .44904 .65593 L p 0 .1 0 r
F P
0 g
s
.44904 .65593 m .44782 .70937 L .45825 .70442 L p 0 .1 0 r
F P
0 g
s
.40244 .68906 m .40479 .63483 L .44904 .65593 L p 0 .694 0 r
F P
0 g
s
.44904 .65593 m .44782 .70937 L .40244 .68906 L p 0 .694 0 r
F P
0 g
s
.40244 .68906 m .40479 .63483 L .44904 .65593 L p 0 .694 0 r
F P
0 g
s
.44904 .65593 m .44782 .70937 L .40244 .68906 L p 0 .694 0 r
F P
0 g
s
.44782 .5603 m .49107 .58314 L .50151 .57757 L p 0 .914 1 r
F P
0 g
s
.50155 .62944 m .50151 .57757 L .49107 .58314 L p 0 .1 .45 r
F P
0 g
s
.49107 .58314 m .49086 .63483 L .50155 .62944 L p 0 .1 .45 r
F P
0 g
s
.49107 .58314 m .44782 .5603 L .43751 .56607 L p 0 .914 1 r
F P
0 g
s
.44654 .61269 m .44782 .5603 L .49107 .58314 L p 0 .689 .454 r
F P
0 g
s
.49107 .58314 m .49086 .63483 L .48029 .64016 L p 0 .1 .45 r
F P
0 g
s
.49107 .58314 m .49086 .63483 L .44654 .61269 L p 0 .689 .454 r
F P
0 g
s
.44654 .61269 m .44782 .5603 L .49107 .58314 L p 0 .689 .454 r
F P
0 g
s
.49107 .58314 m .49086 .63483 L .44654 .61269 L p 0 .689 .454 r
F P
0 g
s
.49086 .63483 m .49107 .58314 L .50151 .57757 L p 0 .1 .45 r
F P
0 g
s
.50155 .62944 m .54378 .65079 L .53309 .65593 L p 0 .916 1 r
F P
0 g
s
.53309 .65593 m .49086 .63483 L .50155 .62944 L p 0 .916 1 r
F P
0 g
s
.49086 .63483 m .53309 .65593 L .54378 .65079 L p 0 .916 1 r
F P
0 g
s
.54484 .70438 m .54378 .65079 L .53309 .65593 L p 0 .114 .472 r
F P
0 g
s
.53309 .65593 m .53389 .70933 L .54484 .70438 L p 0 .114 .472 r
F P
0 g
s
.53309 .65593 m .49086 .63483 L .48029 .64016 L p 0 .916 1 r
F P
0 g
s
.49063 .68906 m .49086 .63483 L .53309 .65593 L p 0 .689 .454 r
F P
0 g
s
.53386 .70936 m .53389 .70933 L .52307 .71422 L p 0 .1 .1 r
F P
0 g
s
.53386 .70936 m .49063 .68906 L p .53309 .65593 L 0 .689 .454 r
F P
0 g
s
.53309 .65593 m .53389 .70933 L .53386 .70936 L p 0 .689 .454 r
F P
0 g
s
.49063 .68906 m .49086 .63483 L .53309 .65593 L p 0 .689 .454 r
F P
0 g
s
.53386 .70936 m .49063 .68906 L p .53309 .65593 L 0 .689 .454 r
F P
0 g
s
.53309 .65593 m .53389 .70933 L .53386 .70936 L p 0 .689 .454 r
F P
0 g
s
.45825 .70442 m .50148 .72399 L .49104 .72871 L p 0 .916 0 r
F P
0 g
s
.49104 .72871 m .44782 .70937 L .45825 .70442 L p 0 .916 0 r
F P
0 g
s
.53389 .5603 m .57509 .58313 L .58602 .57756 L p 0 .914 0 r
F P
0 g
s
.58813 .62944 m .58605 .57761 L .57512 .58318 L p 0 .114 0 r
F P
0 g
s
.57512 .58318 m .57692 .63483 L .58813 .62944 L p 0 .114 0 r
F P
0 g
s
.58605 .57761 m .58602 .57756 L .57509 .58313 L p 0 .562 0 r
F P
0 g
s
.57509 .58313 m .57512 .58318 L .58605 .57761 L p 0 .562 0 r
F P
0 g
s
.57509 .58313 m .53389 .5603 L .52307 .56607 L p 0 .914 0 r
F P
0 g
s
.53472 .61269 m .53389 .5603 L .57509 .58313 L p 0 .683 0 r
F P
0 g
s
.57692 .63483 m .53472 .61269 L p .57509 .58313 L 0 .683 0 r
F P
0 g
s
.57509 .58313 m .57512 .58318 L .57692 .63483 L p 0 .683 0 r
F P
0 g
s
.53472 .61269 m .53389 .5603 L .57509 .58313 L p 0 .683 0 r
F P
0 g
s
.57692 .63483 m .53472 .61269 L p .57509 .58313 L 0 .683 0 r
F P
0 g
s
.57509 .58313 m .57512 .58318 L .57692 .63483 L p 0 .683 0 r
F P
0 g
s
.15694 .72424 m .14991 .72817 L .14988 .72812 L p 0 .525 .891 r
F P
0 g
s
.14988 .72812 m .15691 .72419 L .15694 .72424 L p 0 .525 .891 r
F P
0 g
s
.24443 .57599 m .23547 .58158 L .23551 .58156 L p 0 .93 0 r
F P
0 g
s
.37146 .6493 m .36176 .65446 L .31533 .63329 L p 0 .916 1 r
F P
0 g
s
.30579 .63864 m .31533 .63329 L .36176 .65446 L p 0 .916 1 r
F P
0 g
s
.32498 .62787 m .31533 .63329 L .36176 .65446 L p 0 .916 1 r
F P
0 g
s
.36176 .65446 m .37146 .6493 L .32498 .62787 L p 0 .916 1 r
F P
0 g
s
.37146 .6493 m .36176 .65446 L .35844 .70795 L p 0 .1 .423 r
F P
0 g
s
.31078 .68758 m .31533 .63329 L .36176 .65446 L p 0 .698 .496 r
F P
0 g
s
.34864 .71286 m .35844 .70795 L .36176 .65446 L p 0 .1 .423 r
F P
0 g
s
.36176 .65446 m .35844 .70795 L .31078 .68758 L p 0 .698 .496 r
F P
0 g
s
.31078 .68758 m .31533 .63329 L .36176 .65446 L p 0 .698 .496 r
F P
0 g
s
.36176 .65446 m .35844 .70795 L .31078 .68758 L p 0 .698 .496 r
F P
0 g
s
.32498 .62787 m .31533 .63329 L .31967 .58155 L p 0 .1 .396 r
F P
0 g
s
.31967 .58155 m .32912 .57596 L .32498 .62787 L p 0 .1 .396 r
F P
0 g
s
.28165 .55278 m .27226 .55864 L .31967 .58155 L p 0 .914 1 r
F P
0 g
s
.31967 .58155 m .32912 .57596 L .28165 .55278 L p 0 .914 1 r
F P
0 g
s
.32912 .57596 m .31967 .58155 L .31533 .63329 L p 0 .1 .396 r
F P
0 g
s
.26297 .56443 m .27226 .55864 L .27222 .55866 L p 0 .93 .764 r
F P
0 g
s
.27222 .55866 m .27226 .55864 L .31967 .58155 L p 0 .698 .496 r
F P
0 g
s
.26661 .61107 m .27222 .55866 L p .31967 .58155 L 0 .698 .496 r
F P
0 g
s
.30579 .63864 m .31533 .63329 L .31967 .58155 L p 0 .1 .396 r
F P
0 g
s
.31967 .58155 m .31533 .63329 L .26661 .61107 L p 0 .698 .496 r
F P
0 g
s
.27222 .55866 m .27226 .55864 L .31967 .58155 L p 0 .698 .496 r
F P
0 g
s
.26661 .61107 m .27222 .55866 L p .31967 .58155 L 0 .698 .496 r
F P
0 g
s
.31967 .58155 m .31533 .63329 L .26661 .61107 L p 0 .698 .496 r
F P
0 g
s
.36835 .55276 m .35844 .55862 L .40386 .58155 L p 0 .914 0 r
F P
0 g
s
.40386 .58155 m .4138 .57596 L .36835 .55276 L p 0 .914 0 r
F P
0 g
s
.4138 .57596 m .40386 .58155 L .40154 .63329 L p 0 .1 0 r
F P
0 g
s
.35495 .61107 m .35844 .55862 L .40386 .58155 L p 0 .694 0 r
F P
0 g
s
.39149 .63864 m .40154 .63329 L .40386 .58155 L p 0 .1 0 r
F P
0 g
s
.40386 .58155 m .40154 .63329 L .35495 .61107 L p 0 .694 0 r
F P
0 g
s
.35495 .61107 m .35844 .55862 L .40386 .58155 L p 0 .694 0 r
F P
0 g
s
.40386 .58155 m .40154 .63329 L .35495 .61107 L p 0 .694 0 r
F P
0 g
s
.32912 .72264 m .31967 .72737 L .27222 .70795 L p 0 .916 0 r
F P
0 g
s
.26294 .71286 m .27222 .70795 L .31967 .72737 L p 0 .916 0 r
F P
0 g
s
.28162 .70299 m .27222 .70795 L .27757 .65446 L p 0 .1 0 r
F P
0 g
s
.27757 .65446 m .28678 .6493 L .28162 .70299 L p 0 .1 0 r
F P
0 g
s
.28678 .6493 m .27757 .65446 L .22911 .63329 L p 0 .916 0 r
F P
0 g
s
.22008 .63864 m .22911 .63329 L .27757 .65446 L p 0 .916 0 r
F P
0 g
s
.23825 .62787 m .22911 .63329 L .27757 .65446 L p 0 .916 0 r
F P
0 g
s
.27757 .65446 m .28678 .6493 L .23825 .62787 L p 0 .916 0 r
F P
0 g
s
.28678 .6493 m .27757 .65446 L .27222 .70795 L p 0 .1 0 r
F P
0 g
s
.22244 .68754 m .22911 .63329 L .27757 .65446 L p 0 .702 0 r
F P
0 g
s
.22247 .68759 m .22244 .68754 L p .27757 .65446 L 0 .702 0 r
F P
0 g
s
.26294 .71286 m .27222 .70795 L .27757 .65446 L p 0 .1 0 r
F P
0 g
s
.27757 .65446 m .27222 .70795 L .22247 .68759 L p 0 .702 0 r
F P
0 g
s
.22244 .68754 m .22911 .63329 L .27757 .65446 L p 0 .702 0 r
F P
0 g
s
.22247 .68759 m .22244 .68754 L p .27757 .65446 L 0 .702 0 r
F P
0 g
s
.27757 .65446 m .27222 .70795 L .22247 .68759 L p 0 .702 0 r
F P
0 g
s
.23825 .62787 m .22911 .63329 L .23547 .58158 L p 0 .1 0 r
F P
0 g
s
.23547 .58158 m .24443 .57599 L .23825 .62787 L p 0 .1 0 r
F P
0 g
s
.62789 .49736 m .62786 .49738 L .63913 .49129 L p 0 .1 .1 r
F P
0 g
s
.58576 .42442 m .54468 .3977 L .53377 .40445 L p 0 .907 1 r
F P
0 g
s
.58576 .42442 m .58783 .47242 L .57666 .47873 L p 0 .1 .45 r
F P
0 g
s
.58783 .47242 m .58576 .42442 L .54468 .3977 L p 0 .673 .397 r
F P
0 g
s
.54363 .35146 m .54468 .3977 L .58576 .42442 L p 0 .673 .397 r
F P
0 g
s
.54363 .35146 m .54468 .3977 L .58576 .42442 L p 0 .673 .397 r
F P
0 g
s
.54468 .3977 m .58576 .42442 L .59678 .41791 L p 0 .907 1 r
F P
0 g
s
.58576 .42442 m .58783 .47242 L .62786 .49738 L p 0 .673 .397 r
F P
0 g
s
.58576 .42442 m .58783 .47242 L .62786 .49738 L p 0 .673 .397 r
F P
0 g
s
.58576 .42442 m .58783 .47242 L .59913 .46604 L p 0 .1 .45 r
F P
0 g
s
.59913 .46604 m .59678 .41791 L .58576 .42442 L p 0 .1 .45 r
F P
0 g
s
.58783 .47242 m .58576 .42442 L .54468 .3977 L p 0 .673 .397 r
F P
0 g
s
.54468 .3977 m .54363 .35146 L .55441 .34451 L p 0 .1 .425 r
F P
0 g
s
.54363 .35146 m .54468 .3977 L .53377 .40445 L p 0 .1 .425 r
F P
0 g
s
.58576 .42442 m .54468 .3977 L .55573 .39086 L p 0 .907 1 r
F P
0 g
s
.55573 .39086 m .59678 .41791 L .58576 .42442 L p 0 .907 1 r
F P
0 g
s
.58783 .47242 m .58576 .42442 L .59678 .41791 L p 0 .1 .45 r
F P
0 g
s
.49089 .47873 m .50154 .47242 L .54363 .49739 L p 0 .911 0 r
F P
0 g
s
.5015 .42442 m .50154 .47242 L .54363 .49739 L p 0 .681 0 r
F P
0 g
s
.54363 .49739 m .50154 .47242 L .51232 .46604 L p 0 .911 0 r
F P
0 g
s
.51232 .46604 m .55441 .49131 L .54363 .49739 L p 0 .911 0 r
F P
0 g
s
.50154 .47242 m .5015 .42442 L .51203 .41791 L p 0 .1 0 r
F P
0 g
s
.58783 .32297 m .62789 .35146 L .63916 .34451 L p 0 .903 0 r
F P
0 g
s
.62789 .35146 m .63097 .3977 L .67002 .42442 L p 0 .663 0 r
F P
0 g
s
.62789 .35146 m .63097 .3977 L .67002 .42442 L p 0 .663 0 r
F P
0 g
s
.62789 .35146 m .63097 .3977 L .64253 .39086 L p 0 .1 0 r
F P
0 g
s
.64253 .39086 m .63916 .34451 L .62789 .35146 L p 0 .1 0 r
F P
0 g
s
.62789 .35146 m .58783 .32297 L .57666 .33017 L p 0 .903 0 r
F P
0 g
s
.62789 .35146 m .63097 .3977 L .61955 .40445 L p 0 .1 0 r
F P
0 g
s
.63097 .3977 m .62789 .35146 L .58783 .32297 L p 0 .663 0 r
F P
0 g
s
.63097 .3977 m .62789 .35146 L .58783 .32297 L p 0 .663 0 r
F P
0 g
s
.67002 .42442 m .63097 .3977 L .61955 .40445 L p 0 .907 0 r
F P
0 g
s
.67409 .4724 m .67411 .47239 L .66243 .4787 L p 0 .1 0 r
F P
0 g
s
.67002 .42442 m .63097 .3977 L p .67409 .4724 L 0 .663 0 r
F P
0 g
s
.67409 .4724 m .67411 .47239 L .67002 .42442 L p 0 .663 0 r
F P
0 g
s
.63097 .3977 m .67002 .42442 L .68154 .41791 L p 0 .907 0 r
F P
0 g
s
.67002 .42442 m .67411 .47239 L .68593 .466 L p 0 .114 0 r
F P
0 g
s
.68593 .466 m .68154 .41791 L .67002 .42442 L p 0 .114 0 r
F P
0 g
s
.67002 .42442 m .63097 .3977 L p .67409 .4724 L 0 .663 0 r
F P
0 g
s
.67409 .4724 m .67411 .47239 L .67002 .42442 L p 0 .663 0 r
F P
0 g
s
.67002 .42442 m .63097 .3977 L .64253 .39086 L p 0 .907 0 r
F P
0 g
s
.64253 .39086 m .68154 .41791 L .67002 .42442 L p 0 .907 0 r
F P
0 g
s
.63097 .3977 m .62789 .35146 L .63916 .34451 L p 0 .1 0 r
F P
0 g
s
.62786 .49738 m .58783 .47242 L .59913 .46604 L p 0 .911 1 r
F P
0 g
s
.59913 .46604 m .63913 .49129 L .62786 .49738 L p 0 .911 1 r
F P
0 g
s
.71212 .35144 m .67411 .32297 L .66243 .33017 L p 0 .903 1 r
F P
0 g
s
.71212 .35144 m .67411 .32297 L p .71726 .3977 L 0 .652 .333 r
F P
0 g
s
.71726 .3977 m .71215 .35149 L .71212 .35144 L p 0 .652 .333 r
F P
0 g
s
.67411 .32297 m .71212 .35144 L .72389 .34449 L p 0 .903 1 r
F P
0 g
s
.71212 .35144 m .71215 .35149 L .72392 .34454 L p 0 .575 .884 r
F P
0 g
s
.72392 .34454 m .72389 .34449 L .71212 .35144 L p 0 .575 .884 r
F P
0 g
s
.71212 .35144 m .67411 .32297 L p .71726 .3977 L 0 .652 .333 r
F P
0 g
s
.71726 .3977 m .71215 .35149 L .71212 .35144 L p 0 .652 .333 r
F P
0 g
s
.71215 .35149 m .71726 .3977 L .72934 .39086 L p 0 .114 .472 r
F P
0 g
s
.72934 .39086 m .72392 .34454 L .71215 .35149 L p 0 .114 .472 r
F P
0 g
s
.19502 .70287 m .18904 .70622 L .19636 .6527 L p 0 .1 .365 r
F P
0 g
s
.19636 .6527 m .20222 .64922 L .19502 .70287 L p 0 .1 .365 r
F P
0 g
s
.24456 .72257 m .23854 .72575 L .18907 .70627 L p 0 .916 1 r
F P
0 g
s
.29678 .48951 m .29681 .48956 L .28753 .49567 L p 0 .546 .889 r
F P
0 g
s
.28753 .49567 m .2875 .49561 L .29678 .48951 L p 0 .546 .889 r
F P
0 g
s
.37189 .3495 m .37193 .34949 L .38171 .34252 L p 0 1 .86 r
F P
0 g
s
.3688 .39574 m .37189 .3495 L .37193 .34949 L p 0 .687 .449 r
F P
0 g
s
.3688 .39574 m .37189 .3495 L .37193 .34949 L p 0 .687 .449 r
F P
0 g
s
.55147 .3425 m .54069 .34947 L .54167 .39574 L p 0 .1 .423 r
F P
0 g
s
.54069 .34947 m .55147 .3425 L .50924 .31357 L p 0 .903 1 r
F P
0 g
s
.50924 .31357 m .49846 .32088 L .54069 .34947 L p 0 .903 1 r
F P
0 g
s
.53076 .40251 m .54167 .39574 L .54069 .34947 L p 0 .1 .423 r
F P
0 g
s
.54167 .39574 m .54069 .34947 L .49846 .32088 L p 0 .673 .397 r
F P
0 g
s
.54167 .39574 m .54069 .34947 L .49846 .32088 L p 0 .673 .397 r
F P
0 g
s
.49849 .42256 m .45524 .39574 L .44484 .40251 L p 0 .907 0 r
F P
0 g
s
.49849 .42256 m .49846 .47059 L .45413 .4443 L p 0 .681 0 r
F P
0 g
s
.45413 .4443 m .45524 .39574 L .49849 .42256 L p 0 .681 0 r
F P
0 g
s
.45629 .34947 m .45524 .39574 L .44484 .40251 L p 0 .1 0 r
F P
0 g
s
.45629 .34947 m .41205 .3209 L .40191 .32813 L p 0 .903 0 r
F P
0 g
s
.45629 .34947 m .45524 .39574 L .40985 .36759 L p 0 .681 0 r
F P
0 g
s
.41205 .3209 m .45629 .34947 L p .40985 .36759 L 0 .681 0 r
F P
0 g
s
.45629 .34947 m .45524 .39574 L .49849 .42256 L p 0 .681 0 r
F P
0 g
s
.45629 .34947 m .46657 .3425 L .46576 .38888 L p 0 .1 0 r
F P
0 g
s
.46576 .38888 m .45524 .39574 L .45629 .34947 L p 0 .1 0 r
F P
0 g
s
.46657 .3425 m .45629 .34947 L .45524 .39574 L p 0 .1 0 r
F P
0 g
s
.45629 .34947 m .46657 .3425 L .42232 .31359 L p 0 .903 0 r
F P
0 g
s
.42232 .31359 m .41205 .3209 L .45629 .34947 L p 0 .903 0 r
F P
0 g
s
.45524 .39574 m .45629 .34947 L .41205 .3209 L p 0 .681 0 r
F P
0 g
s
.50902 .41602 m .49849 .42256 L .49846 .47059 L p 0 .1 0 r
F P
0 g
s
.49849 .42256 m .50902 .41602 L .46576 .38888 L p 0 .907 0 r
F P
0 g
s
.46576 .38888 m .45524 .39574 L .49849 .42256 L p 0 .907 0 r
F P
0 g
s
.49846 .47059 m .49849 .42256 L .45524 .39574 L p 0 .681 0 r
F P
0 g
s
.50902 .41602 m .49849 .42256 L .45524 .39574 L p 0 .907 0 r
F P
0 g
s
.32562 .47061 m .32559 .47056 L .32969 .42256 L p 0 .693 0 r
F P
0 g
s
.32562 .47061 m .32559 .47056 L .32969 .42256 L p 0 .693 0 r
F P
0 g
s
.32559 .47056 m .32969 .42256 L .33923 .41602 L p 0 .1 0 r
F P
0 g
s
.32969 .42256 m .32559 .47056 L .31596 .47689 L p 0 .1 0 r
F P
0 g
s
.33536 .4642 m .38168 .48954 L .37189 .49565 L p 0 .911 0 r
F P
0 g
s
.37189 .49565 m .32562 .47061 L .33536 .4642 L p 0 .911 0 r
F P
0 g
s
.42228 .46418 m .46657 .48954 L .45629 .49565 L p 0 .911 1 r
F P
0 g
s
.45629 .49565 m .41202 .47059 L .42228 .46418 L p 0 .911 1 r
F P
0 g
s
.42228 .46418 m .42412 .41602 L .41409 .42256 L p 0 .1 .396 r
F P
0 g
s
.41409 .42256 m .41202 .47059 L .42228 .46418 L p 0 .1 .396 r
F P
0 g
s
.3688 .39574 m .41409 .42256 L .42412 .41602 L p 0 .907 1 r
F P
0 g
s
.41409 .42256 m .41202 .47059 L .40188 .47692 L p 0 .1 .396 r
F P
0 g
s
.41409 .42256 m .41202 .47059 L .3656 .44432 L p 0 .687 .449 r
F P
0 g
s
.41409 .42256 m .3688 .39574 L .35892 .40251 L p 0 .907 1 r
F P
0 g
s
.3688 .39574 m .41409 .42256 L p .3656 .44432 L 0 .687 .449 r
F P
0 g
s
.41409 .42256 m .41202 .47059 L .3656 .44432 L p 0 .687 .449 r
F P
0 g
s
.3688 .39574 m .41409 .42256 L p .3656 .44432 L 0 .687 .449 r
F P
0 g
s
.37881 .38888 m .42412 .41602 L .41409 .42256 L p 0 .907 1 r
F P
0 g
s
.41409 .42256 m .3688 .39574 L .37881 .38888 L p 0 .907 1 r
F P
0 g
s
.41202 .47059 m .41409 .42256 L .42412 .41602 L p 0 .1 .396 r
F P
0 g
s
.38171 .34252 m .38167 .34253 L .37189 .3495 L p 0 1 .86 r
F P
0 g
s
.3688 .39574 m .37189 .3495 L .38167 .34253 L p 0 .1 .365 r
F P
0 g
s
.37189 .3495 m .3688 .39574 L .35892 .40251 L p 0 .1 .365 r
F P
0 g
s
.50151 .72397 m .50148 .72399 L .51204 .71922 L p 0 .1 0 r
F P
0 g
s
.37167 .70442 m .3747 .65079 L .38451 .64558 L p 0 .1 .425 r
F P
0 g
s
.3747 .65079 m .37167 .70442 L .36175 .70937 L p 0 .1 .425 r
F P
0 g
s
.38171 .69941 m .42703 .71923 L .41697 .724 L p 0 .916 1 r
F P
0 g
s
.41697 .724 m .37167 .70442 L .38171 .69941 L p 0 .916 1 r
F P
0 g
s
.45825 .70442 m .45924 .65079 L .46955 .64558 L p 0 .1 0 r
F P
0 g
s
.41496 .62944 m .41697 .57757 L .42703 .57194 L p 0 .1 0 r
F P
0 g
s
.41697 .57757 m .41496 .62944 L .40479 .63483 L p 0 .1 0 r
F P
0 g
s
.42526 .62398 m .46955 .64558 L .45924 .65079 L p 0 .916 0 r
F P
0 g
s
.45924 .65079 m .41496 .62944 L .42526 .62398 L p 0 .916 0 r
F P
0 g
s
.41496 .62944 m .45924 .65079 L .46955 .64558 L p 0 .916 0 r
F P
0 g
s
.46881 .69941 m .46955 .64558 L .45924 .65079 L p 0 .1 0 r
F P
0 g
s
.45924 .65079 m .45825 .70442 L .46881 .69941 L p 0 .1 0 r
F P
0 g
s
.45924 .65079 m .41496 .62944 L .40479 .63483 L p 0 .916 0 r
F P
0 g
s
.41286 .68387 m .41496 .62944 L .45924 .65079 L p 0 .693 0 r
F P
0 g
s
.45924 .65079 m .45825 .70442 L .44782 .70937 L p 0 .1 0 r
F P
0 g
s
.45924 .65079 m .45825 .70442 L .41286 .68387 L p 0 .693 0 r
F P
0 g
s
.41286 .68387 m .41496 .62944 L .45924 .65079 L p 0 .693 0 r
F P
0 g
s
.45924 .65079 m .45825 .70442 L .41286 .68387 L p 0 .693 0 r
F P
0 g
s
.50151 .57757 m .45825 .55445 L .44782 .5603 L p 0 .914 1 r
F P
0 g
s
.45825 .55445 m .50151 .57757 L .51207 .57194 L p 0 .914 1 r
F P
0 g
s
.51237 .62398 m .51207 .57194 L .50151 .57757 L p 0 .1 .45 r
F P
0 g
s
.50151 .57757 m .50155 .62944 L .51237 .62398 L p 0 .1 .45 r
F P
0 g
s
.45722 .60703 m .45825 .55445 L .50151 .57757 L p 0 .687 .449 r
F P
0 g
s
.50151 .57757 m .50155 .62944 L .49086 .63483 L p 0 .1 .45 r
F P
0 g
s
.50151 .57757 m .50155 .62944 L .45722 .60703 L p 0 .687 .449 r
F P
0 g
s
.45722 .60703 m .45825 .55445 L .50151 .57757 L p 0 .687 .449 r
F P
0 g
s
.50151 .57757 m .50155 .62944 L .45722 .60703 L p 0 .687 .449 r
F P
0 g
s
.50155 .62944 m .50151 .57757 L .51207 .57194 L p 0 .1 .45 r
F P
0 g
s
.51237 .62398 m .55459 .64558 L .54378 .65079 L p 0 .916 1 r
F P
0 g
s
.54378 .65079 m .50155 .62944 L .51237 .62398 L p 0 .916 1 r
F P
0 g
s
.50155 .62944 m .54378 .65079 L .55459 .64558 L p 0 .916 1 r
F P
0 g
s
.55592 .69937 m .55459 .64558 L .54378 .65079 L p 0 .114 .472 r
F P
0 g
s
.54378 .65079 m .54484 .70438 L .55592 .69937 L p 0 .114 .472 r
F P
0 g
s
.54378 .65079 m .50155 .62944 L .49086 .63483 L p 0 .916 1 r
F P
0 g
s
.50158 .68387 m .50155 .62944 L .54378 .65079 L p 0 .687 .449 r
F P
0 g
s
.54481 .70441 m .54484 .70438 L .53389 .70933 L p 0 .1 .1 r
F P
0 g
s
.54481 .70441 m .50158 .68387 L p .54378 .65079 L 0 .687 .449 r
F P
0 g
s
.54378 .65079 m .54484 .70438 L .54481 .70441 L p 0 .687 .449 r
F P
0 g
s
.50158 .68387 m .50155 .62944 L .54378 .65079 L p 0 .687 .449 r
F P
0 g
s
.54481 .70441 m .50158 .68387 L p .54378 .65079 L 0 .687 .449 r
F P
0 g
s
.54378 .65079 m .54484 .70438 L .54481 .70441 L p 0 .687 .449 r
F P
0 g
s
.46881 .69941 m .51204 .71922 L .50148 .72399 L p 0 .916 0 r
F P
0 g
s
.50148 .72399 m .45825 .70442 L .46881 .69941 L p 0 .916 0 r
F P
0 g
s
.58602 .57756 m .54484 .55445 L .53389 .5603 L p 0 .914 0 r
F P
0 g
s
.54595 .60703 m .54484 .55445 L .58602 .57756 L p 0 .681 0 r
F P
0 g
s
.58813 .62944 m .54595 .60703 L p .58602 .57756 L 0 .681 0 r
F P
0 g
s
.58602 .57756 m .58605 .57761 L .58813 .62944 L p 0 .681 0 r
F P
0 g
s
.58602 .57756 m .59708 .57192 L .55592 .54854 L p 0 .914 0 r
F P
0 g
s
.55592 .54854 m .54484 .55445 L .58602 .57756 L p 0 .914 0 r
F P
0 g
s
.59711 .57197 m .58605 .57761 L .58813 .62944 L p 0 .114 0 r
F P
0 g
s
.58605 .57761 m .59711 .57197 L .59708 .57192 L p 0 .562 0 r
F P
0 g
s
.59708 .57192 m .58602 .57756 L .58605 .57761 L p 0 .562 0 r
F P
0 g
s
.58605 .57761 m .58602 .57756 L .54484 .55445 L p 0 .681 0 r
F P
0 g
s
.58813 .62944 m .58605 .57761 L p .54484 .55445 L 0 .681 0 r
F P
0 g
s
.25349 .57034 m .24443 .57599 L .24447 .57597 L p 0 .93 0 r
F P
0 g
s
.38127 .64407 m .37146 .6493 L .32498 .62787 L p 0 .916 1 r
F P
0 g
s
.31533 .63329 m .32498 .62787 L .37146 .6493 L p 0 .916 1 r
F P
0 g
s
.33476 .62239 m .32498 .62787 L .37146 .6493 L p 0 .916 1 r
F P
0 g
s
.37146 .6493 m .38127 .64407 L .33476 .62239 L p 0 .916 1 r
F P
0 g
s
.38127 .64407 m .37146 .6493 L .36835 .70299 L p 0 .1 .423 r
F P
0 g
s
.32064 .68236 m .32498 .62787 L .37146 .6493 L p 0 .697 .491 r
F P
0 g
s
.35844 .70795 m .36835 .70299 L .37146 .6493 L p 0 .1 .423 r
F P
0 g
s
.37146 .6493 m .36835 .70299 L .32064 .68236 L p 0 .697 .491 r
F P
0 g
s
.32064 .68236 m .32498 .62787 L .37146 .6493 L p 0 .697 .491 r
F P
0 g
s
.37146 .6493 m .36835 .70299 L .32064 .68236 L p 0 .697 .491 r
F P
0 g
s
.33476 .62239 m .32498 .62787 L .32912 .57596 L p 0 .1 .396 r
F P
0 g
s
.32912 .57596 m .33868 .5703 L .33476 .62239 L p 0 .1 .396 r
F P
0 g
s
.29116 .54684 m .28165 .55278 L .32912 .57596 L p 0 .914 1 r
F P
0 g
s
.32912 .57596 m .33868 .5703 L .29116 .54684 L p 0 .914 1 r
F P
0 g
s
.33868 .5703 m .32912 .57596 L .32498 .62787 L p 0 .1 .396 r
F P
0 g
s
.27226 .55864 m .28165 .55278 L .28161 .5528 L p 0 .93 .764 r
F P
0 g
s
.28161 .5528 m .28165 .55278 L .32912 .57596 L p 0 .697 .491 r
F P
0 g
s
.2762 .60538 m .28161 .5528 L p .32912 .57596 L 0 .697 .491 r
F P
0 g
s
.31533 .63329 m .32498 .62787 L .32912 .57596 L p 0 .1 .396 r
F P
0 g
s
.32912 .57596 m .32498 .62787 L .2762 .60538 L p 0 .697 .491 r
F P
0 g
s
.28161 .5528 m .28165 .55278 L .32912 .57596 L p 0 .697 .491 r
F P
0 g
s
.2762 .60538 m .28161 .5528 L p .32912 .57596 L 0 .697 .491 r
F P
0 g
s
.32912 .57596 m .32498 .62787 L .2762 .60538 L p 0 .697 .491 r
F P
0 g
s
.40154 .63329 m .41172 .62787 L .4138 .57596 L p 0 .1 0 r
F P
0 g
s
.37838 .54682 m .36835 .55276 L .4138 .57596 L p 0 .914 0 r
F P
0 g
s
.4138 .57596 m .42387 .5703 L .37838 .54682 L p 0 .914 0 r
F P
0 g
s
.42387 .5703 m .4138 .57596 L .41172 .62787 L p 0 .1 0 r
F P
0 g
s
.36509 .60538 m .36835 .55276 L .4138 .57596 L p 0 .693 0 r
F P
0 g
s
.4138 .57596 m .41172 .62787 L .36509 .60538 L p 0 .693 0 r
F P
0 g
s
.36509 .60538 m .36835 .55276 L .4138 .57596 L p 0 .693 0 r
F P
0 g
s
.4138 .57596 m .41172 .62787 L .36509 .60538 L p 0 .693 0 r
F P
0 g
s
.33868 .71785 m .32912 .72264 L .28162 .70299 L p 0 .916 0 r
F P
0 g
s
.29113 .69796 m .28162 .70299 L .28678 .6493 L p 0 .1 0 r
F P
0 g
s
.28678 .6493 m .29609 .64407 L .29113 .69796 L p 0 .1 0 r
F P
0 g
s
.29609 .64407 m .28678 .6493 L .23825 .62787 L p 0 .916 0 r
F P
0 g
s
.2475 .62239 m .23825 .62787 L .28678 .6493 L p 0 .916 0 r
F P
0 g
s
.28678 .6493 m .29609 .64407 L .2475 .62239 L p 0 .916 0 r
F P
0 g
s
.29609 .64407 m .28678 .6493 L .28162 .70299 L p 0 .1 0 r
F P
0 g
s
.22911 .63329 m .23825 .62787 L .28678 .6493 L p 0 .916 0 r
F P
0 g
s
.23176 .68232 m .23825 .62787 L .28678 .6493 L p 0 .701 0 r
F P
0 g
s
.23179 .68238 m .23176 .68232 L p .28678 .6493 L 0 .701 0 r
F P
0 g
s
.27222 .70795 m .28162 .70299 L .28678 .6493 L p 0 .1 0 r
F P
0 g
s
.28678 .6493 m .28162 .70299 L .23179 .68238 L p 0 .701 0 r
F P
0 g
s
.27222 .70795 m .28162 .70299 L .32912 .72264 L p 0 .916 0 r
F P
0 g
s
.23176 .68232 m .23825 .62787 L .28678 .6493 L p 0 .701 0 r
F P
0 g
s
.23179 .68238 m .23176 .68232 L p .28678 .6493 L 0 .701 0 r
F P
0 g
s
.28678 .6493 m .28162 .70299 L .23179 .68238 L p 0 .701 0 r
F P
0 g
s
.2475 .62239 m .23825 .62787 L .24443 .57599 L p 0 .1 0 r
F P
0 g
s
.24443 .57599 m .25349 .57034 L .2475 .62239 L p 0 .1 0 r
F P
0 g
s
.20104 .69951 m .19502 .70287 L .20222 .64922 L p 0 .1 .365 r
F P
0 g
s
.20222 .64922 m .20813 .64572 L .20104 .69951 L p 0 .1 .365 r
F P
0 g
s
.25064 .71936 m .24456 .72257 L .19505 .70293 L p 0 .916 1 r
F P
0 g
s
.18907 .70627 m .19505 .70293 L .24456 .72257 L p 0 .916 1 r
F P
0 g
s
.1691 .71744 m .16061 .72219 L .16058 .72214 L p 0 .525 0 r
F P
0 g
s
.16058 .72214 m .16907 .71739 L .1691 .71744 L p 0 .525 0 r
F P
0 g
s
.63916 .49127 m .63913 .49129 L .65053 .48513 L p 0 .1 .1 r
F P
0 g
s
.55441 .34451 m .55573 .39086 L .59678 .41791 L p 0 .671 .39 r
F P
0 g
s
.55441 .34451 m .55573 .39086 L .59678 .41791 L p 0 .671 .39 r
F P
0 g
s
.55573 .39086 m .59678 .41791 L .60794 .41131 L p 0 .907 1 r
F P
0 g
s
.59678 .41791 m .59913 .46604 L .63913 .49129 L p 0 .671 .39 r
F P
0 g
s
.59678 .41791 m .59913 .46604 L .63913 .49129 L p 0 .671 .39 r
F P
0 g
s
.59678 .41791 m .59913 .46604 L .61057 .45957 L p 0 .1 .45 r
F P
0 g
s
.61057 .45957 m .60794 .41131 L .59678 .41791 L p 0 .1 .45 r
F P
0 g
s
.59678 .41791 m .55573 .39086 L .54468 .3977 L p 0 .907 1 r
F P
0 g
s
.59678 .41791 m .59913 .46604 L .58783 .47242 L p 0 .1 .45 r
F P
0 g
s
.59913 .46604 m .59678 .41791 L .55573 .39086 L p 0 .671 .39 r
F P
0 g
s
.59913 .46604 m .59678 .41791 L .55573 .39086 L p 0 .671 .39 r
F P
0 g
s
.59913 .46604 m .59678 .41791 L .60794 .41131 L p 0 .1 .45 r
F P
0 g
s
.55441 .34451 m .55573 .39086 L .54468 .3977 L p 0 .1 .425 r
F P
0 g
s
.59678 .41791 m .55573 .39086 L .5669 .38394 L p 0 .907 1 r
F P
0 g
s
.5669 .38394 m .60794 .41131 L .59678 .41791 L p 0 .907 1 r
F P
0 g
s
.55573 .39086 m .55441 .34451 L .56531 .33748 L p 0 .1 .425 r
F P
0 g
s
.51203 .41791 m .51232 .46604 L .55441 .49131 L p 0 .679 0 r
F P
0 g
s
.51203 .41791 m .51232 .46604 L .55441 .49131 L p 0 .679 0 r
F P
0 g
s
.51232 .46604 m .51203 .41791 L .52268 .41131 L p 0 .1 0 r
F P
0 g
s
.51203 .41791 m .51232 .46604 L .50154 .47242 L p 0 .1 0 r
F P
0 g
s
.55441 .49131 m .51232 .46604 L .52324 .45957 L p 0 .911 0 r
F P
0 g
s
.52324 .45957 m .56531 .48515 L .55441 .49131 L p 0 .911 0 r
F P
0 g
s
.63916 .34451 m .59913 .31569 L .58783 .32297 L p 0 .903 0 r
F P
0 g
s
.63916 .34451 m .64253 .39086 L .63097 .3977 L p 0 .1 0 r
F P
0 g
s
.64253 .39086 m .63916 .34451 L .59913 .31569 L p 0 .661 0 r
F P
0 g
s
.64253 .39086 m .63916 .34451 L .59913 .31569 L p 0 .661 0 r
F P
0 g
s
.63916 .34451 m .64253 .39086 L .68154 .41791 L p 0 .661 0 r
F P
0 g
s
.63916 .34451 m .64253 .39086 L .68154 .41791 L p 0 .661 0 r
F P
0 g
s
.59913 .31569 m .63916 .34451 L .65056 .33748 L p 0 .903 0 r
F P
0 g
s
.63916 .34451 m .64253 .39086 L .65423 .38394 L p 0 .1 0 r
F P
0 g
s
.65423 .38394 m .65056 .33748 L .63916 .34451 L p 0 .1 0 r
F P
0 g
s
.64253 .39086 m .63916 .34451 L .65056 .33748 L p 0 .1 0 r
F P
0 g
s
.68154 .41791 m .64253 .39086 L .63097 .3977 L p 0 .907 0 r
F P
0 g
s
.68591 .46602 m .68593 .466 L .67411 .47239 L p 0 .1 0 r
F P
0 g
s
.68154 .41791 m .64253 .39086 L p .68591 .46602 L 0 .661 0 r
F P
0 g
s
.68591 .46602 m .68593 .466 L .68154 .41791 L p 0 .661 0 r
F P
0 g
s
.68154 .41791 m .64253 .39086 L p .68591 .46602 L 0 .661 0 r
F P
0 g
s
.68591 .46602 m .68593 .466 L .68154 .41791 L p 0 .661 0 r
F P
0 g
s
.64253 .39086 m .68154 .41791 L .69319 .41131 L p 0 .907 0 r
F P
0 g
s
.68154 .41791 m .68593 .466 L .69789 .45954 L p 0 .114 0 r
F P
0 g
s
.69789 .45954 m .69319 .41131 L .68154 .41791 L p 0 .114 0 r
F P
0 g
s
.68154 .41791 m .64253 .39086 L .65423 .38394 L p 0 .907 0 r
F P
0 g
s
.65423 .38394 m .69319 .41131 L .68154 .41791 L p 0 .907 0 r
F P
0 g
s
.63913 .49129 m .59913 .46604 L .61057 .45957 L p 0 .911 1 r
F P
0 g
s
.61057 .45957 m .65053 .48513 L .63913 .49129 L p 0 .911 1 r
F P
0 g
s
.72389 .34449 m .68593 .31569 L .67411 .32297 L p 0 .903 1 r
F P
0 g
s
.72389 .34449 m .68593 .31569 L p .72934 .39086 L 0 .648 .324 r
F P
0 g
s
.72934 .39086 m .72392 .34454 L .72389 .34449 L p 0 .648 .324 r
F P
0 g
s
.68593 .31569 m .72389 .34449 L .73579 .33746 L p 0 .903 1 r
F P
0 g
s
.72389 .34449 m .72392 .34454 L .73582 .33752 L p 0 .575 .884 r
F P
0 g
s
.73582 .33752 m .73579 .33746 L .72389 .34449 L p 0 .575 .884 r
F P
0 g
s
.72389 .34449 m .68593 .31569 L p .72934 .39086 L 0 .648 .324 r
F P
0 g
s
.72934 .39086 m .72392 .34454 L .72389 .34449 L p 0 .648 .324 r
F P
0 g
s
.72392 .34454 m .72934 .39086 L .74156 .38394 L p 0 .114 .472 r
F P
0 g
s
.74156 .38394 m .73582 .33752 L .72392 .34454 L p 0 .114 .472 r
F P
0 g
s
.30618 .48332 m .30621 .48338 L .29681 .48956 L p 0 .546 .889 r
F P
0 g
s
.29681 .48956 m .29678 .48951 L .30618 .48332 L p 0 .546 .889 r
F P
0 g
s
.38167 .34253 m .38171 .34252 L .39161 .33547 L p 0 1 .86 r
F P
0 g
s
.37881 .38888 m .38167 .34253 L .38171 .34252 L p 0 .686 .443 r
F P
0 g
s
.37881 .38888 m .38167 .34253 L .38171 .34252 L p 0 .686 .443 r
F P
0 g
s
.54167 .39574 m .55272 .38888 L .55147 .3425 L p 0 .1 .423 r
F P
0 g
s
.55272 .38888 m .55147 .3425 L .50924 .31357 L p 0 .671 .39 r
F P
0 g
s
.56237 .33545 m .55147 .3425 L .55272 .38888 L p 0 .1 .423 r
F P
0 g
s
.55147 .3425 m .56237 .33545 L .52015 .30618 L p 0 .903 1 r
F P
0 g
s
.52015 .30618 m .50924 .31357 L .55147 .3425 L p 0 .903 1 r
F P
0 g
s
.55272 .38888 m .55147 .3425 L .50924 .31357 L p 0 .671 .39 r
F P
0 g
s
.51967 .4094 m .50902 .41602 L .50924 .46418 L p 0 .1 0 r
F P
0 g
s
.46657 .3425 m .46576 .38888 L .50902 .41602 L p 0 .679 0 r
F P
0 g
s
.46657 .3425 m .46576 .38888 L .50902 .41602 L p 0 .679 0 r
F P
0 g
s
.50902 .41602 m .51967 .4094 L .47641 .38194 L p 0 .907 0 r
F P
0 g
s
.47641 .38194 m .46576 .38888 L .50902 .41602 L p 0 .907 0 r
F P
0 g
s
.45524 .39574 m .46576 .38888 L .50902 .41602 L p 0 .907 0 r
F P
0 g
s
.51967 .4094 m .50902 .41602 L .46576 .38888 L p 0 .907 0 r
F P
0 g
s
.46657 .3425 m .47697 .33545 L .47641 .38194 L p 0 .1 0 r
F P
0 g
s
.47641 .38194 m .46576 .38888 L .46657 .3425 L p 0 .1 0 r
F P
0 g
s
.45524 .39574 m .46576 .38888 L .46657 .3425 L p 0 .1 0 r
F P
0 g
s
.46576 .38888 m .46657 .3425 L .42232 .31359 L p 0 .679 0 r
F P
0 g
s
.47697 .33545 m .46657 .3425 L .46576 .38888 L p 0 .1 0 r
F P
0 g
s
.46657 .3425 m .47697 .33545 L .4327 .3062 L p 0 .903 0 r
F P
0 g
s
.4327 .3062 m .42232 .31359 L .46657 .3425 L p 0 .903 0 r
F P
0 g
s
.46576 .38888 m .46657 .3425 L .42232 .31359 L p 0 .679 0 r
F P
0 g
s
.49846 .47059 m .50924 .46418 L .50902 .41602 L p 0 .1 0 r
F P
0 g
s
.50924 .46418 m .50902 .41602 L .46576 .38888 L p 0 .679 0 r
F P
0 g
s
.50924 .46418 m .50902 .41602 L .46576 .38888 L p 0 .679 0 r
F P
0 g
s
.33536 .4642 m .33533 .46415 L .33923 .41602 L p 0 .692 0 r
F P
0 g
s
.33536 .4642 m .33533 .46415 L .33923 .41602 L p 0 .692 0 r
F P
0 g
s
.33533 .46415 m .33923 .41602 L .34888 .4094 L p 0 .1 0 r
F P
0 g
s
.33923 .41602 m .33533 .46415 L .32559 .47056 L p 0 .1 0 r
F P
0 g
s
.34522 .45772 m .39158 .48336 L .38168 .48954 L p 0 .911 0 r
F P
0 g
s
.38168 .48954 m .33536 .4642 L .34522 .45772 L p 0 .911 0 r
F P
0 g
s
.43267 .4577 m .47697 .48336 L .46657 .48954 L p 0 .911 1 r
F P
0 g
s
.46657 .48954 m .42228 .46418 L .43267 .4577 L p 0 .911 1 r
F P
0 g
s
.43267 .4577 m .43427 .4094 L .42412 .41602 L p 0 .1 .396 r
F P
0 g
s
.42412 .41602 m .42228 .46418 L .43267 .4577 L p 0 .1 .396 r
F P
0 g
s
.37881 .38888 m .42412 .41602 L .43427 .4094 L p 0 .907 1 r
F P
0 g
s
.42412 .41602 m .42228 .46418 L .41202 .47059 L p 0 .1 .396 r
F P
0 g
s
.42412 .41602 m .42228 .46418 L .37583 .43759 L p 0 .686 .443 r
F P
0 g
s
.42412 .41602 m .37881 .38888 L .3688 .39574 L p 0 .907 1 r
F P
0 g
s
.37881 .38888 m .42412 .41602 L p .37583 .43759 L 0 .686 .443 r
F P
0 g
s
.42412 .41602 m .42228 .46418 L .37583 .43759 L p 0 .686 .443 r
F P
0 g
s
.37881 .38888 m .42412 .41602 L p .37583 .43759 L 0 .686 .443 r
F P
0 g
s
.38893 .38194 m .43427 .4094 L .42412 .41602 L p 0 .907 1 r
F P
0 g
s
.42412 .41602 m .37881 .38888 L .38893 .38194 L p 0 .907 1 r
F P
0 g
s
.42228 .46418 m .42412 .41602 L .43427 .4094 L p 0 .1 .396 r
F P
0 g
s
.39161 .33547 m .39157 .33548 L .38167 .34253 L p 0 1 .86 r
F P
0 g
s
.37881 .38888 m .38167 .34253 L .39157 .33548 L p 0 .1 .365 r
F P
0 g
s
.38167 .34253 m .37881 .38888 L .3688 .39574 L p 0 .1 .365 r
F P
0 g
s
.25676 .71612 m .25064 .71936 L .20107 .69956 L p 0 .916 1 r
F P
0 g
s
.19505 .70293 m .20107 .69956 L .25064 .71936 L p 0 .916 1 r
F P
0 g
s
.20711 .69611 m .20104 .69951 L .20813 .64572 L p 0 .1 .365 r
F P
0 g
s
.20813 .64572 m .21408 .64219 L .20711 .69611 L p 0 .1 .365 r
F P
0 g
s
.51207 .71919 m .51204 .71922 L .52273 .71439 L p 0 .1 0 r
F P
0 g
s
.38171 .69941 m .38451 .64558 L .39445 .64032 L p 0 .1 .425 r
F P
0 g
s
.38451 .64558 m .38171 .69941 L .37167 .70442 L p 0 .1 .425 r
F P
0 g
s
.39186 .69434 m .43722 .7144 L .42703 .71923 L p 0 .916 1 r
F P
0 g
s
.42703 .71923 m .38171 .69941 L .39186 .69434 L p 0 .916 1 r
F P
0 g
s
.42526 .62398 m .42703 .57194 L .43722 .56623 L p 0 .1 0 r
F P
0 g
s
.43568 .61845 m .47999 .64032 L .46955 .64558 L p 0 .916 0 r
F P
0 g
s
.46955 .64558 m .42526 .62398 L .43568 .61845 L p 0 .916 0 r
F P
0 g
s
.42526 .62398 m .46955 .64558 L .47999 .64032 L p 0 .916 0 r
F P
0 g
s
.4795 .69434 m .47999 .64032 L .46955 .64558 L p 0 .1 0 r
F P
0 g
s
.46955 .64558 m .46881 .69941 L .4795 .69434 L p 0 .1 0 r
F P
0 g
s
.46955 .64558 m .42526 .62398 L .41496 .62944 L p 0 .916 0 r
F P
0 g
s
.4234 .67861 m .42526 .62398 L .46955 .64558 L p 0 .692 0 r
F P
0 g
s
.46955 .64558 m .46881 .69941 L .45825 .70442 L p 0 .1 0 r
F P
0 g
s
.46955 .64558 m .46881 .69941 L .4234 .67861 L p 0 .692 0 r
F P
0 g
s
.4234 .67861 m .42526 .62398 L .46955 .64558 L p 0 .692 0 r
F P
0 g
s
.46955 .64558 m .46881 .69941 L .4234 .67861 L p 0 .692 0 r
F P
0 g
s
.46881 .69941 m .46955 .64558 L .47999 .64032 L p 0 .1 0 r
F P
0 g
s
.42703 .57194 m .42526 .62398 L .41496 .62944 L p 0 .1 0 r
F P
0 g
s
.46881 .54854 m .51207 .57194 L .52276 .56623 L p 0 .914 1 r
F P
0 g
s
.52332 .61845 m .52276 .56623 L .51207 .57194 L p 0 .1 .45 r
F P
0 g
s
.51207 .57194 m .51237 .62398 L .52332 .61845 L p 0 .1 .45 r
F P
0 g
s
.51207 .57194 m .46881 .54854 L .45825 .55445 L p 0 .914 1 r
F P
0 g
s
.46804 .60129 m .46881 .54854 L .51207 .57194 L p 0 .686 .443 r
F P
0 g
s
.51207 .57194 m .51237 .62398 L .50155 .62944 L p 0 .1 .45 r
F P
0 g
s
.51207 .57194 m .51237 .62398 L .46804 .60129 L p 0 .686 .443 r
F P
0 g
s
.46804 .60129 m .46881 .54854 L .51207 .57194 L p 0 .686 .443 r
F P
0 g
s
.51207 .57194 m .51237 .62398 L .46804 .60129 L p 0 .686 .443 r
F P
0 g
s
.51237 .62398 m .51207 .57194 L .52276 .56623 L p 0 .1 .45 r
F P
0 g
s
.52332 .61845 m .56553 .64032 L .55459 .64558 L p 0 .916 1 r
F P
0 g
s
.55459 .64558 m .51237 .62398 L .52332 .61845 L p 0 .916 1 r
F P
0 g
s
.51237 .62398 m .55459 .64558 L .56553 .64032 L p 0 .916 1 r
F P
0 g
s
.56713 .6943 m .56553 .64032 L .55459 .64558 L p 0 .114 .472 r
F P
0 g
s
.55459 .64558 m .55592 .69937 L .56713 .6943 L p 0 .114 .472 r
F P
0 g
s
.55459 .64558 m .51237 .62398 L .50155 .62944 L p 0 .916 1 r
F P
0 g
s
.51267 .67861 m .51237 .62398 L .55459 .64558 L p 0 .686 .443 r
F P
0 g
s
.55589 .6994 m .55592 .69937 L .54484 .70438 L p 0 .1 .1 r
F P
0 g
s
.55589 .6994 m .51267 .67861 L p .55459 .64558 L 0 .686 .443 r
F P
0 g
s
.55459 .64558 m .55592 .69937 L .55589 .6994 L p 0 .686 .443 r
F P
0 g
s
.51267 .67861 m .51237 .62398 L .55459 .64558 L p 0 .686 .443 r
F P
0 g
s
.55589 .6994 m .51267 .67861 L p .55459 .64558 L 0 .686 .443 r
F P
0 g
s
.55459 .64558 m .55592 .69937 L .55589 .6994 L p 0 .686 .443 r
F P
0 g
s
.4795 .69434 m .52273 .71439 L .51204 .71922 L p 0 .916 0 r
F P
0 g
s
.51204 .71922 m .46881 .69941 L .4795 .69434 L p 0 .916 0 r
F P
0 g
s
.58813 .62944 m .59947 .62398 L .59711 .57197 L p 0 .114 0 r
F P
0 g
s
.59711 .57197 m .59708 .57192 L .55592 .54854 L p 0 .679 0 r
F P
0 g
s
.59947 .62398 m .59711 .57197 L p .55592 .54854 L 0 .679 0 r
F P
0 g
s
.59708 .57192 m .60828 .56622 L .56713 .54255 L p 0 .914 0 r
F P
0 g
s
.56713 .54255 m .55592 .54854 L .59708 .57192 L p 0 .914 0 r
F P
0 g
s
.60831 .56627 m .59711 .57197 L .59947 .62398 L p 0 .114 0 r
F P
0 g
s
.59711 .57197 m .60831 .56627 L .60828 .56622 L p 0 .562 0 r
F P
0 g
s
.60828 .56622 m .59708 .57192 L .59711 .57197 L p 0 .562 0 r
F P
0 g
s
.59711 .57197 m .59708 .57192 L .55592 .54854 L p 0 .679 0 r
F P
0 g
s
.59947 .62398 m .59711 .57197 L p .55592 .54854 L 0 .679 0 r
F P
0 g
s
.26267 .56462 m .25349 .57034 L .25353 .57032 L p 0 .93 0 r
F P
0 g
s
.32498 .62787 m .33476 .62239 L .38127 .64407 L p 0 .916 1 r
F P
0 g
s
.34465 .61685 m .33476 .62239 L .38127 .64407 L p 0 .916 1 r
F P
0 g
s
.38127 .64407 m .3912 .63879 L .34465 .61685 L p 0 .916 1 r
F P
0 g
s
.3912 .63879 m .38127 .64407 L .37838 .69796 L p 0 .1 .423 r
F P
0 g
s
.33063 .67708 m .33476 .62239 L .38127 .64407 L p 0 .696 .486 r
F P
0 g
s
.36835 .70299 m .37838 .69796 L .38127 .64407 L p 0 .1 .423 r
F P
0 g
s
.38127 .64407 m .37838 .69796 L .33063 .67708 L p 0 .696 .486 r
F P
0 g
s
.33063 .67708 m .33476 .62239 L .38127 .64407 L p 0 .696 .486 r
F P
0 g
s
.38127 .64407 m .37838 .69796 L .33063 .67708 L p 0 .696 .486 r
F P
0 g
s
.32498 .62787 m .33476 .62239 L .33868 .5703 L p 0 .1 .396 r
F P
0 g
s
.3912 .63879 m .38127 .64407 L .33476 .62239 L p 0 .916 1 r
F P
0 g
s
.34465 .61685 m .33476 .62239 L .33868 .5703 L p 0 .1 .396 r
F P
0 g
s
.33868 .5703 m .34836 .56458 L .34465 .61685 L p 0 .1 .396 r
F P
0 g
s
.30079 .54084 m .29116 .54684 L .33868 .5703 L p 0 .914 1 r
F P
0 g
s
.33868 .5703 m .34836 .56458 L .30079 .54084 L p 0 .914 1 r
F P
0 g
s
.34836 .56458 m .33868 .5703 L .33476 .62239 L p 0 .1 .396 r
F P
0 g
s
.28165 .55278 m .29116 .54684 L .29112 .54686 L p 0 .93 .764 r
F P
0 g
s
.29112 .54686 m .29116 .54684 L .33868 .5703 L p 0 .696 .486 r
F P
0 g
s
.28591 .59963 m .29112 .54686 L p .33868 .5703 L 0 .696 .486 r
F P
0 g
s
.33868 .5703 m .33476 .62239 L .28591 .59963 L p 0 .696 .486 r
F P
0 g
s
.29112 .54686 m .29116 .54684 L .33868 .5703 L p 0 .696 .486 r
F P
0 g
s
.28591 .59963 m .29112 .54686 L p .33868 .5703 L 0 .696 .486 r
F P
0 g
s
.33868 .5703 m .33476 .62239 L .28591 .59963 L p 0 .696 .486 r
F P
0 g
s
.38854 .54082 m .37838 .54682 L .42387 .5703 L p 0 .914 0 r
F P
0 g
s
.42387 .5703 m .43405 .56458 L .38854 .54082 L p 0 .914 0 r
F P
0 g
s
.43405 .56458 m .42387 .5703 L .42201 .62239 L p 0 .1 0 r
F P
0 g
s
.37535 .59963 m .37838 .54682 L .42387 .5703 L p 0 .692 0 r
F P
0 g
s
.41172 .62787 m .42201 .62239 L .42387 .5703 L p 0 .1 0 r
F P
0 g
s
.42387 .5703 m .42201 .62239 L .37535 .59963 L p 0 .692 0 r
F P
0 g
s
.37535 .59963 m .37838 .54682 L .42387 .5703 L p 0 .692 0 r
F P
0 g
s
.42387 .5703 m .42201 .62239 L .37535 .59963 L p 0 .692 0 r
F P
0 g
s
.30075 .69287 m .29113 .69796 L .29609 .64407 L p 0 .1 0 r
F P
0 g
s
.29609 .64407 m .30552 .63879 L .30075 .69287 L p 0 .1 0 r
F P
0 g
s
.30552 .63879 m .29609 .64407 L .2475 .62239 L p 0 .916 0 r
F P
0 g
s
.23825 .62787 m .2475 .62239 L .29609 .64407 L p 0 .916 0 r
F P
0 g
s
.25686 .61685 m .2475 .62239 L .29609 .64407 L p 0 .916 0 r
F P
0 g
s
.29609 .64407 m .30552 .63879 L .25686 .61685 L p 0 .916 0 r
F P
0 g
s
.30552 .63879 m .29609 .64407 L .29113 .69796 L p 0 .1 0 r
F P
0 g
s
.2412 .67704 m .2475 .62239 L .29609 .64407 L p 0 .7 0 r
F P
0 g
s
.24123 .6771 m .2412 .67704 L p .29609 .64407 L 0 .7 0 r
F P
0 g
s
.28162 .70299 m .29113 .69796 L .29609 .64407 L p 0 .1 0 r
F P
0 g
s
.29609 .64407 m .29113 .69796 L .24123 .6771 L p 0 .7 0 r
F P
0 g
s
.2412 .67704 m .2475 .62239 L .29609 .64407 L p 0 .7 0 r
F P
0 g
s
.24123 .6771 m .2412 .67704 L p .29609 .64407 L 0 .7 0 r
F P
0 g
s
.29609 .64407 m .29113 .69796 L .24123 .6771 L p 0 .7 0 r
F P
0 g
s
.34836 .713 m .33868 .71785 L .29113 .69796 L p 0 .916 0 r
F P
0 g
s
.28162 .70299 m .29113 .69796 L .33868 .71785 L p 0 .916 0 r
F P
0 g
s
.25686 .61685 m .2475 .62239 L .25349 .57034 L p 0 .1 0 r
F P
0 g
s
.25349 .57034 m .26267 .56462 L .25686 .61685 L p 0 .1 0 r
F P
0 g
s
.17769 .71264 m .1691 .71744 L .16907 .71739 L p 0 .525 0 r
F P
0 g
s
.16907 .71739 m .17766 .71258 L .17769 .71264 L p 0 .525 0 r
F P
0 g
s
.52268 .41131 m .52324 .45957 L .51232 .46604 L p 0 .1 0 r
F P
0 g
s
.52268 .41131 m .52324 .45957 L .56531 .48515 L p 0 .677 0 r
F P
0 g
s
.60794 .41131 m .5669 .38394 L .55573 .39086 L p 0 .907 1 r
F P
0 g
s
.60794 .41131 m .61057 .45957 L .59913 .46604 L p 0 .1 .45 r
F P
0 g
s
.61057 .45957 m .60794 .41131 L .5669 .38394 L p 0 .668 .382 r
F P
0 g
s
.60794 .41131 m .61057 .45957 L .65053 .48513 L p 0 .668 .382 r
F P
0 g
s
.56531 .33748 m .5669 .38394 L .55573 .39086 L p 0 .1 .425 r
F P
0 g
s
.56531 .33748 m .5669 .38394 L .60794 .41131 L p 0 .668 .382 r
F P
0 g
s
.65056 .33748 m .61057 .30831 L .59913 .31569 L p 0 .903 0 r
F P
0 g
s
.65056 .33748 m .65423 .38394 L .64253 .39086 L p 0 .1 0 r
F P
0 g
s
.65423 .38394 m .65056 .33748 L .61057 .30831 L p 0 .658 0 r
F P
0 g
s
.65056 .33748 m .65423 .38394 L .69319 .41131 L p 0 .658 0 r
F P
0 g
s
.69319 .41131 m .65423 .38394 L .64253 .39086 L p 0 .907 0 r
F P
0 g
s
.69787 .45956 m .69789 .45954 L .68593 .466 L p 0 .1 0 r
F P
0 g
s
.69319 .41131 m .65423 .38394 L p .69787 .45956 L 0 .658 0 r
F P
0 g
s
.69787 .45956 m .69789 .45954 L .69319 .41131 L p 0 .658 0 r
F P
0 g
s
.73579 .33746 m .6979 .30831 L .68593 .31569 L p 0 .903 1 r
F P
0 g
s
.73579 .33746 m .6979 .30831 L p .74156 .38394 L 0 .645 .315 r
F P
0 g
s
.74156 .38394 m .73582 .33752 L .73579 .33746 L p 0 .645 .315 r
F P
0 g
s
.65089 .48493 m .65086 .48495 L .66241 .47871 L p 0 .1 0 r
F P
0 g
s
.52299 .41112 m .52355 .45939 L .56563 .48497 L p 0 .677 .411 r
F P
0 g
s
.52355 .45939 m .52299 .41112 L .53377 .40445 L p 0 .1 .425 r
F P
0 g
s
.56563 .48497 m .52355 .45939 L .5346 .45284 L p 0 .911 1 r
F P
0 g
s
.5346 .45284 m .57666 .47873 L .56563 .48497 L p 0 .911 1 r
F P
0 g
s
.6109 .45939 m .60826 .41112 L .56722 .38374 L p 0 .668 0 r
F P
0 g
s
.56563 .33728 m .56722 .38374 L .60826 .41112 L p 0 .668 0 r
F P
0 g
s
.60826 .41112 m .6109 .45939 L .65086 .48495 L p 0 .668 0 r
F P
0 g
s
.56722 .38374 m .60826 .41112 L .61955 .40445 L p 0 .907 0 r
F P
0 g
s
.60826 .41112 m .6109 .45939 L .62248 .45284 L p 0 .1 0 r
F P
0 g
s
.62248 .45284 m .61955 .40445 L .60826 .41112 L p 0 .1 0 r
F P
0 g
s
.60826 .41112 m .56722 .38374 L .57854 .37674 L p 0 .907 0 r
F P
0 g
s
.57854 .37674 m .61955 .40445 L .60826 .41112 L p 0 .907 0 r
F P
0 g
s
.56722 .38374 m .56563 .33728 L .57666 .33017 L p 0 .1 0 r
F P
0 g
s
.6109 .45939 m .60826 .41112 L .61955 .40445 L p 0 .1 0 r
F P
0 g
s
.65089 .33728 m .65457 .38374 L .69353 .41112 L p 0 .658 .35 r
F P
0 g
s
.65457 .38374 m .65089 .33728 L .6109 .3081 L p 0 .658 .35 r
F P
0 g
s
.65457 .38374 m .69353 .41112 L .70532 .40445 L p 0 .907 1 r
F P
0 g
s
.69353 .41112 m .69824 .45935 L .71035 .45281 L p 0 .114 .472 r
F P
0 g
s
.71035 .45281 m .70532 .40445 L .69353 .41112 L p 0 .114 .472 r
F P
0 g
s
.69353 .41112 m .65457 .38374 L p .69821 .45937 L 0 .658 .35 r
F P
0 g
s
.69821 .45937 m .69824 .45935 L .69353 .41112 L p 0 .658 .35 r
F P
0 g
s
.65457 .38374 m .65089 .33728 L .66243 .33017 L p 0 .1 .45 r
F P
0 g
s
.6109 .3081 m .65089 .33728 L .66243 .33017 L p 0 .903 1 r
F P
0 g
s
.65089 .33728 m .65457 .38374 L .66642 .37674 L p 0 .1 .45 r
F P
0 g
s
.66642 .37674 m .66243 .33017 L .65089 .33728 L p 0 .1 .45 r
F P
0 g
s
.69353 .41112 m .65457 .38374 L .66642 .37674 L p 0 .907 1 r
F P
0 g
s
.66642 .37674 m .70532 .40445 L .69353 .41112 L p 0 .907 1 r
F P
0 g
s
.65086 .48495 m .6109 .45939 L .62248 .45284 L p 0 .911 0 r
F P
0 g
s
.62248 .45284 m .66241 .47871 L .65086 .48495 L p 0 .911 0 r
F P
0 g
s
.73613 .33726 m .73616 .33731 L .74821 .3302 L p 0 .575 0 r
F P
0 g
s
.73616 .33731 m .74192 .38374 L .75429 .37674 L p 0 .114 0 r
F P
0 g
s
.75429 .37674 m .74821 .3302 L .73616 .33731 L p 0 .114 0 r
F P
0 g
s
.74192 .38374 m .73616 .33731 L .73613 .33726 L p 0 .645 0 r
F P
0 g
s
.69824 .3081 m .73613 .33726 L .74818 .33015 L p 0 .903 0 r
F P
0 g
s
.74821 .3302 m .74818 .33015 L .73613 .33726 L p 0 .575 0 r
F P
0 g
s
.73613 .33726 m .69824 .3081 L p .74192 .38374 L 0 .645 0 r
F P
0 g
s
.21323 .69269 m .20711 .69611 L .21408 .64219 L p 0 .1 .365 r
F P
0 g
s
.21408 .64219 m .22008 .63864 L .21323 .69269 L p 0 .1 .365 r
F P
0 g
s
.26294 .71286 m .25676 .71612 L .20714 .69616 L p 0 .916 1 r
F P
0 g
s
.20107 .69956 m .20714 .69616 L .25676 .71612 L p 0 .916 1 r
F P
0 g
s
.38893 .38194 m .39157 .33548 L .39161 .33547 L p 0 .684 .437 r
F P
0 g
s
.50924 .46418 m .52015 .4577 L .51967 .4094 L p 0 .1 0 r
F P
0 g
s
.46576 .38888 m .47641 .38194 L .51967 .4094 L p 0 .907 0 r
F P
0 g
s
.52015 .4577 m .51967 .4094 L .47641 .38194 L p 0 .677 0 r
F P
0 g
s
.47697 .33545 m .47641 .38194 L .51967 .4094 L p 0 .677 0 r
F P
0 g
s
.46576 .38888 m .47641 .38194 L .47697 .33545 L p 0 .1 0 r
F P
0 g
s
.47641 .38194 m .47697 .33545 L .4327 .3062 L p 0 .677 0 r
F P
0 g
s
.55272 .38888 m .56389 .38194 L .56237 .33545 L p 0 .1 .423 r
F P
0 g
s
.56389 .38194 m .56237 .33545 L .52015 .30618 L p 0 .668 .382 r
F P
0 g
s
.34888 .4094 m .34519 .45766 L .33533 .46415 L p 0 .1 0 r
F P
0 g
s
.34522 .45772 m .34519 .45766 L .34888 .4094 L p 0 .69 0 r
F P
0 g
s
.43427 .4094 m .38893 .38194 L .37881 .38888 L p 0 .907 1 r
F P
0 g
s
.43427 .4094 m .43267 .4577 L .42228 .46418 L p 0 .1 .396 r
F P
0 g
s
.43427 .4094 m .43267 .4577 L .38618 .43078 L p 0 .684 .437 r
F P
0 g
s
.38893 .38194 m .43427 .4094 L p .38618 .43078 L 0 .684 .437 r
F P
0 g
s
.39157 .33548 m .38893 .38194 L .37881 .38888 L p 0 .1 .365 r
F P
0 g
s
.31596 .47689 m .31599 .47694 L .30648 .4832 L p 0 .546 0 r
F P
0 g
s
.30648 .4832 m .30645 .48315 L .31596 .47689 L p 0 .546 0 r
F P
0 g
s
.39186 .33527 m .39189 .33526 L .40191 .32813 L p 0 1 0 r
F P
0 g
s
.38922 .38174 m .39186 .33527 L .39189 .33526 L p 0 .684 0 r
F P
0 g
s
.53076 .40251 m .51998 .40921 L .52047 .45751 L p 0 .1 .423 r
F P
0 g
s
.47727 .33524 m .47672 .38174 L .51998 .40921 L p 0 .677 .411 r
F P
0 g
s
.51998 .40921 m .53076 .40251 L .4875 .37471 L p 0 .907 1 r
F P
0 g
s
.4875 .37471 m .47672 .38174 L .51998 .40921 L p 0 .907 1 r
F P
0 g
s
.52047 .45751 m .51998 .40921 L .47672 .38174 L p 0 .677 .411 r
F P
0 g
s
.53076 .40251 m .51998 .40921 L .47672 .38174 L p 0 .907 1 r
F P
0 g
s
.47727 .33524 m .4878 .32811 L .4875 .37471 L p 0 .1 .396 r
F P
0 g
s
.4875 .37471 m .47672 .38174 L .47727 .33524 L p 0 .1 .396 r
F P
0 g
s
.4878 .32811 m .47727 .33524 L .47672 .38174 L p 0 .1 .396 r
F P
0 g
s
.47727 .33524 m .4878 .32811 L .44352 .29849 L p 0 .903 1 r
F P
0 g
s
.44352 .29849 m .433 .30598 L .47727 .33524 L p 0 .903 1 r
F P
0 g
s
.47672 .38174 m .47727 .33524 L .433 .30598 L p 0 .677 .411 r
F P
0 g
s
.44349 .45095 m .4878 .47692 L .47727 .48318 L p 0 .911 0 r
F P
0 g
s
.47727 .48318 m .43297 .45751 L .44349 .45095 L p 0 .911 0 r
F P
0 g
s
.44349 .45095 m .44484 .40251 L .43457 .40921 L p 0 .1 0 r
F P
0 g
s
.43457 .40921 m .43297 .45751 L .44349 .45095 L p 0 .1 0 r
F P
0 g
s
.38922 .38174 m .43457 .40921 L .44484 .40251 L p 0 .907 0 r
F P
0 g
s
.43457 .40921 m .43297 .45751 L .38648 .43058 L p 0 .684 0 r
F P
0 g
s
.38922 .38174 m .43457 .40921 L p .38648 .43058 L 0 .684 0 r
F P
0 g
s
.39947 .37471 m .44484 .40251 L .43457 .40921 L p 0 .907 0 r
F P
0 g
s
.43457 .40921 m .38922 .38174 L .39947 .37471 L p 0 .907 0 r
F P
0 g
s
.43297 .45751 m .43457 .40921 L .44484 .40251 L p 0 .1 0 r
F P
0 g
s
.56422 .38174 m .56269 .33524 L .52047 .30596 L p 0 .668 0 r
F P
0 g
s
.57372 .32811 m .56269 .33524 L .56422 .38174 L p 0 .1 0 r
F P
0 g
s
.56269 .33524 m .57372 .32811 L .53152 .29847 L p 0 .903 0 r
F P
0 g
s
.53152 .29847 m .52047 .30596 L .56269 .33524 L p 0 .903 0 r
F P
0 g
s
.34551 .45753 m .34548 .45748 L .34916 .40921 L p 0 .69 .46 r
F P
0 g
s
.34548 .45748 m .34916 .40921 L .35892 .40251 L p 0 .1 .365 r
F P
0 g
s
.35549 .45096 m .40188 .47692 L .39186 .48318 L p 0 .911 1 r
F P
0 g
s
.39186 .48318 m .34551 .45753 L .35549 .45096 L p 0 .911 1 r
F P
0 g
s
.40191 .32813 m .40188 .32814 L .39186 .33527 L p 0 1 0 r
F P
0 g
s
.38922 .38174 m .39186 .33527 L .40188 .32814 L p 0 .1 0 r
F P
0 g
s
.39445 .64032 m .39186 .69434 L .38171 .69941 L p 0 .1 .425 r
F P
0 g
s
.47999 .64032 m .43568 .61845 L .42526 .62398 L p 0 .916 0 r
F P
0 g
s
.47999 .64032 m .4795 .69434 L .46881 .69941 L p 0 .1 0 r
F P
0 g
s
.43722 .56623 m .43568 .61845 L .42526 .62398 L p 0 .1 0 r
F P
0 g
s
.43407 .67328 m .43568 .61845 L .47999 .64032 L p 0 .69 0 r
F P
0 g
s
.47999 .64032 m .4795 .69434 L .43407 .67328 L p 0 .69 0 r
F P
0 g
s
.52276 .56623 m .4795 .54255 L .46881 .54854 L p 0 .914 1 r
F P
0 g
s
.47899 .59549 m .4795 .54255 L .52276 .56623 L p 0 .684 .437 r
F P
0 g
s
.52276 .56623 m .52332 .61845 L .51237 .62398 L p 0 .1 .45 r
F P
0 g
s
.52276 .56623 m .52332 .61845 L .47899 .59549 L p 0 .684 .437 r
F P
0 g
s
.56553 .64032 m .52332 .61845 L .51237 .62398 L p 0 .916 1 r
F P
0 g
s
.5239 .67328 m .52332 .61845 L .56553 .64032 L p 0 .684 .437 r
F P
0 g
s
.5671 .69433 m .56713 .6943 L .55592 .69937 L p 0 .1 .1 r
F P
0 g
s
.5671 .69433 m .5239 .67328 L p .56553 .64032 L 0 .684 .437 r
F P
0 g
s
.56553 .64032 m .56713 .6943 L .5671 .69433 L p 0 .684 .437 r
F P
0 g
s
.59947 .62398 m .61095 .61845 L .60831 .56627 L p 0 .114 0 r
F P
0 g
s
.60831 .56627 m .60828 .56622 L .56713 .54255 L p 0 .677 0 r
F P
0 g
s
.61095 .61845 m .60831 .56627 L p .56713 .54255 L 0 .677 0 r
F P
0 g
s
.52307 .71422 m .52304 .71425 L .53386 .70936 L p 0 .1 .1 r
F P
0 g
s
.40244 .68906 m .44782 .70937 L .43751 .71426 L p 0 .916 0 r
F P
0 g
s
.43751 .71426 m .39216 .6942 L .40244 .68906 L p 0 .916 0 r
F P
0 g
s
.39216 .6942 m .39473 .64016 L .40479 .63483 L p 0 .1 0 r
F P
0 g
s
.44654 .61269 m .49086 .63483 L .48029 .64016 L p 0 .916 1 r
F P
0 g
s
.48029 .64016 m .43598 .61829 L .44654 .61269 L p 0 .916 1 r
F P
0 g
s
.43598 .61829 m .48029 .64016 L .49086 .63483 L p 0 .916 1 r
F P
0 g
s
.49063 .68906 m .49086 .63483 L .48029 .64016 L p 0 .1 .45 r
F P
0 g
s
.48029 .64016 m .47981 .6942 L .49063 .68906 L p 0 .1 .45 r
F P
0 g
s
.43438 .67313 m .43598 .61829 L .48029 .64016 L p 0 .69 .46 r
F P
0 g
s
.48029 .64016 m .47981 .6942 L .43438 .67313 L p 0 .69 .46 r
F P
0 g
s
.47981 .6942 m .48029 .64016 L .49086 .63483 L p 0 .1 .45 r
F P
0 g
s
.43598 .61829 m .43751 .56607 L .44782 .5603 L p 0 .1 .425 r
F P
0 g
s
.47981 .54238 m .52307 .56607 L .53389 .5603 L p 0 .914 0 r
F P
0 g
s
.53472 .61269 m .53389 .5603 L .52307 .56607 L p 0 .1 0 r
F P
0 g
s
.52307 .56607 m .52363 .61829 L .53472 .61269 L p 0 .1 0 r
F P
0 g
s
.4793 .59532 m .47981 .54238 L .52307 .56607 L p 0 .684 0 r
F P
0 g
s
.52307 .56607 m .52363 .61829 L .4793 .59532 L p 0 .684 0 r
F P
0 g
s
.52363 .61829 m .52307 .56607 L .53389 .5603 L p 0 .1 0 r
F P
0 g
s
.53472 .61269 m .57692 .63483 L .56585 .64016 L p 0 .916 0 r
F P
0 g
s
.56585 .64016 m .52363 .61829 L .53472 .61269 L p 0 .916 0 r
F P
0 g
s
.52363 .61829 m .56585 .64016 L .57692 .63483 L p 0 .916 0 r
F P
0 g
s
.57881 .68902 m .57692 .63483 L .56585 .64016 L p 0 .114 0 r
F P
0 g
s
.56585 .64016 m .56746 .69416 L .57881 .68902 L p 0 .114 0 r
F P
0 g
s
.52423 .67313 m .52363 .61829 L .56585 .64016 L p 0 .684 0 r
F P
0 g
s
.56743 .69418 m .52423 .67313 L p .56585 .64016 L 0 .684 0 r
F P
0 g
s
.56585 .64016 m .56746 .69416 L .56743 .69418 L p 0 .684 0 r
F P
0 g
s
.6086 .56605 m .61993 .56028 L .57882 .53632 L p 0 .914 1 r
F P
0 g
s
.57882 .53632 m .56746 .54238 L .6086 .56605 L p 0 .914 1 r
F P
0 g
s
.61996 .56033 m .60863 .5661 L .61128 .61829 L p 0 .114 .472 r
F P
0 g
s
.60863 .5661 m .61996 .56033 L .61993 .56028 L p 0 .562 .887 r
F P
0 g
s
.61993 .56028 m .6086 .56605 L .60863 .5661 L p 0 .562 .887 r
F P
0 g
s
.60863 .5661 m .6086 .56605 L .56746 .54238 L p 0 .677 .411 r
F P
0 g
s
.61128 .61829 m .60863 .5661 L p .56746 .54238 L 0 .677 .411 r
F P
0 g
s
.49063 .68906 m .53386 .70936 L .52304 .71425 L p 0 .916 1 r
F P
0 g
s
.52304 .71425 m .47981 .6942 L .49063 .68906 L p 0 .916 1 r
F P
0 g
s
.37838 .69796 m .38854 .69287 L .3912 .63879 L p 0 .1 .423 r
F P
0 g
s
.33476 .62239 m .34465 .61685 L .3912 .63879 L p 0 .916 1 r
F P
0 g
s
.34074 .67174 m .34465 .61685 L .3912 .63879 L p 0 .695 .481 r
F P
0 g
s
.3912 .63879 m .38854 .69287 L .34074 .67174 L p 0 .695 .481 r
F P
0 g
s
.33476 .62239 m .34465 .61685 L .34836 .56458 L p 0 .1 .396 r
F P
0 g
s
.29116 .54684 m .30079 .54084 L .30075 .54086 L p 0 .93 .764 r
F P
0 g
s
.30075 .54086 m .30079 .54084 L .34836 .56458 L p 0 .695 .481 r
F P
0 g
s
.29575 .5938 m .30075 .54086 L p .34836 .56458 L 0 .695 .481 r
F P
0 g
s
.34836 .56458 m .34465 .61685 L .29575 .5938 L p 0 .695 .481 r
F P
0 g
s
.29113 .69796 m .30075 .69287 L .34836 .713 L p 0 .916 0 r
F P
0 g
s
.2475 .62239 m .25686 .61685 L .30552 .63879 L p 0 .916 0 r
F P
0 g
s
.29113 .69796 m .30075 .69287 L .30552 .63879 L p 0 .1 0 r
F P
0 g
s
.25076 .6717 m .25686 .61685 L .30552 .63879 L p 0 .699 0 r
F P
0 g
s
.25079 .67175 m .25076 .6717 L p .30552 .63879 L 0 .699 0 r
F P
0 g
s
.30552 .63879 m .30075 .69287 L .25079 .67175 L p 0 .699 0 r
F P
0 g
s
.42201 .62239 m .43243 .61685 L .43405 .56458 L p 0 .1 0 r
F P
0 g
s
.38574 .5938 m .38854 .54082 L .43405 .56458 L p 0 .69 0 r
F P
0 g
s
.43405 .56458 m .43243 .61685 L .38574 .5938 L p 0 .69 0 r
F P
0 g
s
.27222 .55866 m .26293 .56445 L .26297 .56443 L p 0 .93 .764 r
F P
0 g
s
.31078 .68758 m .30103 .69273 L .30579 .63864 L p 0 .1 .396 r
F P
0 g
s
.30579 .63864 m .31533 .63329 L .31078 .68758 L p 0 .1 .396 r
F P
0 g
s
.26661 .61107 m .25713 .61669 L .30579 .63864 L p 0 .916 1 r
F P
0 g
s
.30579 .63864 m .31533 .63329 L .26661 .61107 L p 0 .916 1 r
F P
0 g
s
.31533 .63329 m .30579 .63864 L .30103 .69273 L p 0 .1 .396 r
F P
0 g
s
.25103 .67154 m .25713 .61669 L .30579 .63864 L p 0 .699 .5 r
F P
0 g
s
.25107 .6716 m .25103 .67154 L p .30579 .63864 L 0 .699 .5 r
F P
0 g
s
.30579 .63864 m .30103 .69273 L .25107 .6716 L p 0 .699 .5 r
F P
0 g
s
.35844 .70795 m .34864 .71286 L .30103 .69273 L p 0 .916 1 r
F P
0 g
s
.31533 .63329 m .30579 .63864 L .25713 .61669 L p 0 .916 1 r
F P
0 g
s
.35495 .61107 m .34493 .61669 L .39149 .63864 L p 0 .916 0 r
F P
0 g
s
.39149 .63864 m .40154 .63329 L .35495 .61107 L p 0 .916 0 r
F P
0 g
s
.40154 .63329 m .39149 .63864 L .38883 .69273 L p 0 .1 0 r
F P
0 g
s
.34104 .67158 m .34493 .61669 L .39149 .63864 L p 0 .695 0 r
F P
0 g
s
.39149 .63864 m .38883 .69273 L .34104 .67158 L p 0 .695 0 r
F P
0 g
s
.40154 .63329 m .39149 .63864 L .34493 .61669 L p 0 .916 0 r
F P
0 g
s
.35495 .61107 m .34493 .61669 L .34864 .56441 L p 0 .1 0 r
F P
0 g
s
.34864 .56441 m .35844 .55862 L .35495 .61107 L p 0 .1 0 r
F P
0 g
s
.31081 .53458 m .30107 .54066 L .34864 .56441 L p 0 .914 0 r
F P
0 g
s
.34864 .56441 m .35844 .55862 L .31081 .53458 L p 0 .914 0 r
F P
0 g
s
.35844 .55862 m .34864 .56441 L .34493 .61669 L p 0 .1 0 r
F P
0 g
s
.30103 .54068 m .30107 .54066 L .34864 .56441 L p 0 .695 0 r
F P
0 g
s
.29603 .59363 m .30103 .54068 L p .34864 .56441 L 0 .695 0 r
F P
0 g
s
.34864 .56441 m .34493 .61669 L .29603 .59363 L p 0 .695 0 r
F P
0 g
s
.20714 .69616 m .21326 .69274 L .26294 .71286 L p 0 .916 1 r
F P
0 g
s
.39912 .53456 m .38883 .54065 L .43434 .56441 L p 0 .914 1 r
F P
0 g
s
.43434 .56441 m .44465 .55862 L .39912 .53456 L p 0 .914 1 r
F P
0 g
s
.44465 .55862 m .43434 .56441 L .43274 .61669 L p 0 .1 .423 r
F P
0 g
s
.38604 .59363 m .38883 .54065 L .43434 .56441 L p 0 .69 .46 r
F P
0 g
s
.43434 .56441 m .43274 .61669 L .38604 .59363 L p 0 .69 .46 r
F P
0 g
s
.27222 .70795 m .26294 .71286 L .21326 .69274 L p 0 .916 0 r
F P
0 g
s
.22244 .68754 m .21323 .69269 L .22008 .63864 L p 0 .1 0 r
F P
0 g
s
.22008 .63864 m .22911 .63329 L .22244 .68754 L p 0 .1 0 r
F P
0 g
s
.26661 .61107 m .25713 .61669 L .26293 .56445 L p 0 .1 .365 r
F P
0 g
s
.26293 .56445 m .27222 .55866 L .26661 .61107 L p 0 .1 .365 r
F P
0 g
s
.66243 .4787 m .66241 .47871 L .67409 .4724 L p 0 .1 0 r
F P
0 g
s
.53377 .40445 m .5346 .45284 L .52355 .45939 L p 0 .1 .425 r
F P
0 g
s
.53377 .40445 m .5346 .45284 L .57666 .47873 L p 0 .675 .404 r
F P
0 g
s
.53377 .40445 m .5346 .45284 L .57666 .47873 L p 0 .675 .404 r
F P
0 g
s
.5346 .45284 m .53377 .40445 L .54468 .3977 L p 0 .1 .425 r
F P
0 g
s
.57666 .47873 m .5346 .45284 L .54579 .44622 L p 0 .911 1 r
F P
0 g
s
.54579 .44622 m .58783 .47242 L .57666 .47873 L p 0 .911 1 r
F P
0 g
s
.61955 .40445 m .57854 .37674 L .56722 .38374 L p 0 .907 0 r
F P
0 g
s
.61955 .40445 m .62248 .45284 L .6109 .45939 L p 0 .1 0 r
F P
0 g
s
.62248 .45284 m .61955 .40445 L .57854 .37674 L p 0 .666 0 r
F P
0 g
s
.57666 .33017 m .57854 .37674 L .61955 .40445 L p 0 .666 0 r
F P
0 g
s
.57666 .33017 m .57854 .37674 L .61955 .40445 L p 0 .666 0 r
F P
0 g
s
.57854 .37674 m .61955 .40445 L .63097 .3977 L p 0 .907 0 r
F P
0 g
s
.61955 .40445 m .62248 .45284 L .66241 .47871 L p 0 .666 0 r
F P
0 g
s
.61955 .40445 m .62248 .45284 L .66241 .47871 L p 0 .666 0 r
F P
0 g
s
.61955 .40445 m .62248 .45284 L .6342 .44622 L p 0 .1 0 r
F P
0 g
s
.6342 .44622 m .63097 .3977 L .61955 .40445 L p 0 .1 0 r
F P
0 g
s
.62248 .45284 m .61955 .40445 L .57854 .37674 L p 0 .666 0 r
F P
0 g
s
.57666 .33017 m .57854 .37674 L .56722 .38374 L p 0 .1 0 r
F P
0 g
s
.61955 .40445 m .57854 .37674 L .58999 .36965 L p 0 .907 0 r
F P
0 g
s
.58999 .36965 m .63097 .3977 L .61955 .40445 L p 0 .907 0 r
F P
0 g
s
.57854 .37674 m .57666 .33017 L .58783 .32297 L p 0 .1 0 r
F P
0 g
s
.62248 .45284 m .61955 .40445 L .63097 .3977 L p 0 .1 0 r
F P
0 g
s
.70532 .40445 m .66642 .37674 L .65457 .38374 L p 0 .907 1 r
F P
0 g
s
.71033 .45282 m .71035 .45281 L .69824 .45935 L p 0 .1 .1 r
F P
0 g
s
.70532 .40445 m .66642 .37674 L p .71033 .45282 L 0 .655 .342 r
F P
0 g
s
.71033 .45282 m .71035 .45281 L .70532 .40445 L p 0 .655 .342 r
F P
0 g
s
.70532 .40445 m .66642 .37674 L p .71033 .45282 L 0 .655 .342 r
F P
0 g
s
.71033 .45282 m .71035 .45281 L .70532 .40445 L p 0 .655 .342 r
F P
0 g
s
.66243 .33017 m .66642 .37674 L .65457 .38374 L p 0 .1 .45 r
F P
0 g
s
.66243 .33017 m .66642 .37674 L .70532 .40445 L p 0 .655 .342 r
F P
0 g
s
.66243 .33017 m .66642 .37674 L .70532 .40445 L p 0 .655 .342 r
F P
0 g
s
.66642 .37674 m .66243 .33017 L .67411 .32297 L p 0 .1 .45 r
F P
0 g
s
.66243 .33017 m .62248 .30064 L .6109 .3081 L p 0 .903 1 r
F P
0 g
s
.66642 .37674 m .66243 .33017 L .62248 .30064 L p 0 .655 .342 r
F P
0 g
s
.62248 .30064 m .66243 .33017 L .67411 .32297 L p 0 .903 1 r
F P
0 g
s
.66243 .33017 m .66642 .37674 L .67841 .36965 L p 0 .1 .45 r
F P
0 g
s
.67841 .36965 m .67411 .32297 L .66243 .33017 L p 0 .1 .45 r
F P
0 g
s
.66642 .37674 m .66243 .33017 L .62248 .30064 L p 0 .655 .342 r
F P
0 g
s
.66642 .37674 m .70532 .40445 L .71726 .3977 L p 0 .907 1 r
F P
0 g
s
.70532 .40445 m .71035 .45281 L .72261 .44618 L p 0 .114 .472 r
F P
0 g
s
.72261 .44618 m .71726 .3977 L .70532 .40445 L p 0 .114 .472 r
F P
0 g
s
.70532 .40445 m .66642 .37674 L .67841 .36965 L p 0 .907 1 r
F P
0 g
s
.67841 .36965 m .71726 .3977 L .70532 .40445 L p 0 .907 1 r
F P
0 g
s
.75429 .37674 m .74821 .3302 L .74818 .33015 L p 0 .641 0 r
F P
0 g
s
.74818 .33015 m .74821 .3302 L .7604 .323 L p 0 .575 0 r
F P
0 g
s
.74821 .3302 m .75429 .37674 L .76682 .36965 L p 0 .114 0 r
F P
0 g
s
.76682 .36965 m .7604 .323 L .74821 .3302 L p 0 .114 0 r
F P
0 g
s
.75429 .37674 m .74821 .3302 L .74818 .33015 L p 0 .641 0 r
F P
0 g
s
.74818 .33015 m .71036 .30064 L .69824 .3081 L p 0 .903 0 r
F P
0 g
s
.74818 .33015 m .71036 .30064 L p .75429 .37674 L 0 .641 0 r
F P
0 g
s
.71036 .30064 m .74818 .33015 L .76037 .32295 L p 0 .903 0 r
F P
0 g
s
.7604 .323 m .76037 .32295 L .74818 .33015 L p 0 .575 0 r
F P
0 g
s
.74818 .33015 m .71036 .30064 L p .75429 .37674 L 0 .641 0 r
F P
0 g
s
.66241 .47871 m .62248 .45284 L .6342 .44622 L p 0 .911 0 r
F P
0 g
s
.6342 .44622 m .67409 .4724 L .66241 .47871 L p 0 .911 0 r
F P
0 g
s
.40188 .32814 m .40191 .32813 L .41205 .3209 L p 0 1 0 r
F P
0 g
s
.39947 .37471 m .40188 .32814 L .40191 .32813 L p 0 .683 0 r
F P
0 g
s
.39947 .37471 m .40188 .32814 L .40191 .32813 L p 0 .683 0 r
F P
0 g
s
.32559 .47056 m .32562 .47061 L .31599 .47694 L p 0 .546 0 r
F P
0 g
s
.31599 .47694 m .31596 .47689 L .32559 .47056 L p 0 .546 0 r
F P
0 g
s
.52047 .45751 m .53152 .45095 L .53076 .40251 L p 0 .1 .423 r
F P
0 g
s
.47672 .38174 m .4875 .37471 L .53076 .40251 L p 0 .907 1 r
F P
0 g
s
.53152 .45095 m .53076 .40251 L .4875 .37471 L p 0 .675 .404 r
F P
0 g
s
.54167 .39574 m .53076 .40251 L .53152 .45095 L p 0 .1 .423 r
F P
0 g
s
.4878 .32811 m .4875 .37471 L .53076 .40251 L p 0 .675 .404 r
F P
0 g
s
.4878 .32811 m .4875 .37471 L .53076 .40251 L p 0 .675 .404 r
F P
0 g
s
.53076 .40251 m .54167 .39574 L .49842 .36759 L p 0 .907 1 r
F P
0 g
s
.49842 .36759 m .4875 .37471 L .53076 .40251 L p 0 .907 1 r
F P
0 g
s
.53152 .45095 m .53076 .40251 L .4875 .37471 L p 0 .675 .404 r
F P
0 g
s
.54167 .39574 m .53076 .40251 L .4875 .37471 L p 0 .907 1 r
F P
0 g
s
.4878 .32811 m .49846 .32088 L .49842 .36759 L p 0 .1 .396 r
F P
0 g
s
.49842 .36759 m .4875 .37471 L .4878 .32811 L p 0 .1 .396 r
F P
0 g
s
.47672 .38174 m .4875 .37471 L .4878 .32811 L p 0 .1 .396 r
F P
0 g
s
.4875 .37471 m .4878 .32811 L .44352 .29849 L p 0 .675 .404 r
F P
0 g
s
.49846 .32088 m .4878 .32811 L .4875 .37471 L p 0 .1 .396 r
F P
0 g
s
.4878 .32811 m .49846 .32088 L .45417 .29091 L p 0 .903 1 r
F P
0 g
s
.45417 .29091 m .44352 .29849 L .4878 .32811 L p 0 .903 1 r
F P
0 g
s
.4875 .37471 m .4878 .32811 L .44352 .29849 L p 0 .675 .404 r
F P
0 g
s
.45413 .4443 m .49846 .47059 L .4878 .47692 L p 0 .911 0 r
F P
0 g
s
.4878 .47692 m .44349 .45095 L .45413 .4443 L p 0 .911 0 r
F P
0 g
s
.45413 .4443 m .45524 .39574 L .44484 .40251 L p 0 .1 0 r
F P
0 g
s
.44484 .40251 m .44349 .45095 L .45413 .4443 L p 0 .1 0 r
F P
0 g
s
.39947 .37471 m .44484 .40251 L .45524 .39574 L p 0 .907 0 r
F P
0 g
s
.44484 .40251 m .44349 .45095 L .43297 .45751 L p 0 .1 0 r
F P
0 g
s
.44484 .40251 m .44349 .45095 L .39697 .42368 L p 0 .683 0 r
F P
0 g
s
.44484 .40251 m .39947 .37471 L .38922 .38174 L p 0 .907 0 r
F P
0 g
s
.39947 .37471 m .44484 .40251 L p .39697 .42368 L 0 .683 0 r
F P
0 g
s
.44484 .40251 m .44349 .45095 L .39697 .42368 L p 0 .683 0 r
F P
0 g
s
.39947 .37471 m .44484 .40251 L p .39697 .42368 L 0 .683 0 r
F P
0 g
s
.40985 .36759 m .45524 .39574 L .44484 .40251 L p 0 .907 0 r
F P
0 g
s
.44484 .40251 m .39947 .37471 L .40985 .36759 L p 0 .907 0 r
F P
0 g
s
.44349 .45095 m .44484 .40251 L .45524 .39574 L p 0 .1 0 r
F P
0 g
s
.56422 .38174 m .57553 .37471 L .57372 .32811 L p 0 .1 0 r
F P
0 g
s
.57553 .37471 m .57372 .32811 L .53152 .29847 L p 0 .666 0 r
F P
0 g
s
.58489 .32088 m .57372 .32811 L .57553 .37471 L p 0 .1 0 r
F P
0 g
s
.57372 .32811 m .58489 .32088 L .5427 .29089 L p 0 .903 0 r
F P
0 g
s
.5427 .29089 m .53152 .29847 L .57372 .32811 L p 0 .903 0 r
F P
0 g
s
.57553 .37471 m .57372 .32811 L .53152 .29847 L p 0 .666 0 r
F P
0 g
s
.35549 .45096 m .35546 .45091 L .35892 .40251 L p 0 .689 .454 r
F P
0 g
s
.35549 .45096 m .35546 .45091 L .35892 .40251 L p 0 .689 .454 r
F P
0 g
s
.35546 .45091 m .35892 .40251 L .3688 .39574 L p 0 .1 .365 r
F P
0 g
s
.3656 .44432 m .41202 .47059 L .40188 .47692 L p 0 .911 1 r
F P
0 g
s
.40188 .47692 m .35549 .45096 L .3656 .44432 L p 0 .911 1 r
F P
0 g
s
.35892 .40251 m .35546 .45091 L .34548 .45748 L p 0 .1 .365 r
F P
0 g
s
.41205 .3209 m .41202 .32092 L .40188 .32814 L p 0 1 0 r
F P
0 g
s
.39947 .37471 m .40188 .32814 L .41202 .32092 L p 0 .1 0 r
F P
0 g
s
.40188 .32814 m .39947 .37471 L .38922 .38174 L p 0 .1 0 r
F P
0 g
s
.53389 .70933 m .53386 .70936 L .54481 .70441 L p 0 .1 .1 r
F P
0 g
s
.40244 .68906 m .40479 .63483 L .41496 .62944 L p 0 .1 0 r
F P
0 g
s
.40479 .63483 m .40244 .68906 L .39216 .6942 L p 0 .1 0 r
F P
0 g
s
.41286 .68387 m .45825 .70442 L .44782 .70937 L p 0 .916 0 r
F P
0 g
s
.44782 .70937 m .40244 .68906 L .41286 .68387 L p 0 .916 0 r
F P
0 g
s
.49063 .53632 m .53389 .5603 L .54484 .55445 L p 0 .914 0 r
F P
0 g
s
.54595 .60703 m .54484 .55445 L .53389 .5603 L p 0 .1 0 r
F P
0 g
s
.53389 .5603 m .53472 .61269 L .54595 .60703 L p 0 .1 0 r
F P
0 g
s
.53389 .5603 m .49063 .53632 L .47981 .54238 L p 0 .914 0 r
F P
0 g
s
.49039 .58944 m .49063 .53632 L .53389 .5603 L p 0 .683 0 r
F P
0 g
s
.53389 .5603 m .53472 .61269 L .52363 .61829 L p 0 .1 0 r
F P
0 g
s
.53389 .5603 m .53472 .61269 L .49039 .58944 L p 0 .683 0 r
F P
0 g
s
.49039 .58944 m .49063 .53632 L .53389 .5603 L p 0 .683 0 r
F P
0 g
s
.53389 .5603 m .53472 .61269 L .49039 .58944 L p 0 .683 0 r
F P
0 g
s
.57692 .63483 m .53472 .61269 L .52363 .61829 L p 0 .916 0 r
F P
0 g
s
.53472 .61269 m .53389 .5603 L .54484 .55445 L p 0 .1 0 r
F P
0 g
s
.54595 .60703 m .58813 .62944 L .57692 .63483 L p 0 .916 0 r
F P
0 g
s
.57692 .63483 m .53472 .61269 L .54595 .60703 L p 0 .916 0 r
F P
0 g
s
.53472 .61269 m .57692 .63483 L .58813 .62944 L p 0 .916 0 r
F P
0 g
s
.59031 .68383 m .58813 .62944 L .57692 .63483 L p 0 .114 0 r
F P
0 g
s
.57692 .63483 m .57881 .68902 L .59031 .68383 L p 0 .114 0 r
F P
0 g
s
.5356 .66773 m .53472 .61269 L .57692 .63483 L p 0 .683 0 r
F P
0 g
s
.57879 .68905 m .57881 .68902 L .56746 .69416 L p 0 .1 0 r
F P
0 g
s
.57879 .68905 m .5356 .66773 L p .57692 .63483 L 0 .683 0 r
F P
0 g
s
.57692 .63483 m .57881 .68902 L .57879 .68905 L p 0 .683 0 r
F P
0 g
s
.5356 .66773 m .53472 .61269 L .57692 .63483 L p 0 .683 0 r
F P
0 g
s
.57879 .68905 m .5356 .66773 L p .57692 .63483 L 0 .683 0 r
F P
0 g
s
.57692 .63483 m .57881 .68902 L .57879 .68905 L p 0 .683 0 r
F P
0 g
s
.45722 .60703 m .50155 .62944 L .49086 .63483 L p 0 .916 1 r
F P
0 g
s
.49086 .63483 m .44654 .61269 L .45722 .60703 L p 0 .916 1 r
F P
0 g
s
.44654 .61269 m .44782 .5603 L .45825 .55445 L p 0 .1 .425 r
F P
0 g
s
.44654 .61269 m .49086 .63483 L .50155 .62944 L p 0 .916 1 r
F P
0 g
s
.50158 .68387 m .50155 .62944 L .49086 .63483 L p 0 .1 .45 r
F P
0 g
s
.49086 .63483 m .49063 .68906 L .50158 .68387 L p 0 .1 .45 r
F P
0 g
s
.49086 .63483 m .44654 .61269 L .43598 .61829 L p 0 .916 1 r
F P
0 g
s
.44519 .66773 m .44654 .61269 L .49086 .63483 L p 0 .689 .454 r
F P
0 g
s
.49086 .63483 m .49063 .68906 L .47981 .6942 L p 0 .1 .45 r
F P
0 g
s
.49086 .63483 m .49063 .68906 L .44519 .66773 L p 0 .689 .454 r
F P
0 g
s
.44519 .66773 m .44654 .61269 L .49086 .63483 L p 0 .689 .454 r
F P
0 g
s
.49086 .63483 m .49063 .68906 L .44519 .66773 L p 0 .689 .454 r
F P
0 g
s
.49063 .68906 m .49086 .63483 L .50155 .62944 L p 0 .1 .45 r
F P
0 g
s
.44782 .5603 m .44654 .61269 L .43598 .61829 L p 0 .1 .425 r
F P
0 g
s
.61128 .61829 m .62291 .61269 L .61996 .56033 L p 0 .114 .472 r
F P
0 g
s
.61996 .56033 m .61993 .56028 L .57882 .53632 L p 0 .675 .404 r
F P
0 g
s
.62291 .61269 m .61996 .56033 L p .57882 .53632 L 0 .675 .404 r
F P
0 g
s
.61993 .56028 m .63139 .55444 L .59031 .53019 L p 0 .914 1 r
F P
0 g
s
.59031 .53019 m .57882 .53632 L .61993 .56028 L p 0 .914 1 r
F P
0 g
s
.63142 .55449 m .61996 .56033 L .62291 .61269 L p 0 .114 .472 r
F P
0 g
s
.61996 .56033 m .63142 .55449 L .63139 .55444 L p 0 .562 .887 r
F P
0 g
s
.63139 .55444 m .61993 .56028 L .61996 .56033 L p 0 .562 .887 r
F P
0 g
s
.61996 .56033 m .61993 .56028 L .57882 .53632 L p 0 .675 .404 r
F P
0 g
s
.62291 .61269 m .61996 .56033 L p .57882 .53632 L 0 .675 .404 r
F P
0 g
s
.50158 .68387 m .54481 .70441 L .53386 .70936 L p 0 .916 1 r
F P
0 g
s
.53386 .70936 m .49063 .68906 L .50158 .68387 L p 0 .916 1 r
F P
0 g
s
.28161 .5528 m .27222 .55866 L .27226 .55864 L p 0 .93 .764 r
F P
0 g
s
.32064 .68236 m .31078 .68758 L .31533 .63329 L p 0 .1 .396 r
F P
0 g
s
.31533 .63329 m .32498 .62787 L .32064 .68236 L p 0 .1 .396 r
F P
0 g
s
.2762 .60538 m .26661 .61107 L .31533 .63329 L p 0 .916 1 r
F P
0 g
s
.31533 .63329 m .32498 .62787 L .2762 .60538 L p 0 .916 1 r
F P
0 g
s
.32498 .62787 m .31533 .63329 L .31078 .68758 L p 0 .1 .396 r
F P
0 g
s
.25713 .61669 m .26661 .61107 L .31533 .63329 L p 0 .916 1 r
F P
0 g
s
.26071 .66613 m .26661 .61107 L .31533 .63329 L p 0 .698 .496 r
F P
0 g
s
.26074 .66619 m .26071 .66613 L p .31533 .63329 L 0 .698 .496 r
F P
0 g
s
.30103 .69273 m .31078 .68758 L .31533 .63329 L p 0 .1 .396 r
F P
0 g
s
.31533 .63329 m .31078 .68758 L .26074 .66619 L p 0 .698 .496 r
F P
0 g
s
.26071 .66613 m .26661 .61107 L .31533 .63329 L p 0 .698 .496 r
F P
0 g
s
.26074 .66619 m .26071 .66613 L p .31533 .63329 L 0 .698 .496 r
F P
0 g
s
.31533 .63329 m .31078 .68758 L .26074 .66619 L p 0 .698 .496 r
F P
0 g
s
.36835 .70299 m .35844 .70795 L .31078 .68758 L p 0 .916 1 r
F P
0 g
s
.30103 .69273 m .31078 .68758 L .35844 .70795 L p 0 .916 1 r
F P
0 g
s
.32498 .62787 m .31533 .63329 L .26661 .61107 L p 0 .916 1 r
F P
0 g
s
.36509 .60538 m .35495 .61107 L .40154 .63329 L p 0 .916 0 r
F P
0 g
s
.40154 .63329 m .41172 .62787 L .36509 .60538 L p 0 .916 0 r
F P
0 g
s
.41172 .62787 m .40154 .63329 L .39912 .68758 L p 0 .1 0 r
F P
0 g
s
.34493 .61669 m .35495 .61107 L .40154 .63329 L p 0 .916 0 r
F P
0 g
s
.35128 .66617 m .35495 .61107 L .40154 .63329 L p 0 .694 0 r
F P
0 g
s
.38883 .69273 m .39912 .68758 L .40154 .63329 L p 0 .1 0 r
F P
0 g
s
.40154 .63329 m .39912 .68758 L .35128 .66617 L p 0 .694 0 r
F P
0 g
s
.35128 .66617 m .35495 .61107 L .40154 .63329 L p 0 .694 0 r
F P
0 g
s
.40154 .63329 m .39912 .68758 L .35128 .66617 L p 0 .694 0 r
F P
0 g
s
.41172 .62787 m .40154 .63329 L .35495 .61107 L p 0 .916 0 r
F P
0 g
s
.36509 .60538 m .35495 .61107 L .35844 .55862 L p 0 .1 0 r
F P
0 g
s
.35844 .55862 m .36835 .55276 L .36509 .60538 L p 0 .1 0 r
F P
0 g
s
.32068 .52843 m .31081 .53458 L .35844 .55862 L p 0 .914 0 r
F P
0 g
s
.35844 .55862 m .36835 .55276 L .32068 .52843 L p 0 .914 0 r
F P
0 g
s
.36835 .55276 m .35844 .55862 L .35495 .61107 L p 0 .1 0 r
F P
0 g
s
.30107 .54066 m .31081 .53458 L .31077 .5346 L p 0 .93 0 r
F P
0 g
s
.31077 .5346 m .31081 .53458 L .35844 .55862 L p 0 .694 0 r
F P
0 g
s
.30599 .58773 m .31077 .5346 L p .35844 .55862 L 0 .694 0 r
F P
0 g
s
.34493 .61669 m .35495 .61107 L .35844 .55862 L p 0 .1 0 r
F P
0 g
s
.35844 .55862 m .35495 .61107 L .30599 .58773 L p 0 .694 0 r
F P
0 g
s
.31077 .5346 m .31081 .53458 L .35844 .55862 L p 0 .694 0 r
F P
0 g
s
.30599 .58773 m .31077 .5346 L p .35844 .55862 L 0 .694 0 r
F P
0 g
s
.35844 .55862 m .35495 .61107 L .30599 .58773 L p 0 .694 0 r
F P
0 g
s
.28162 .70299 m .27222 .70795 L .22247 .68759 L p 0 .916 0 r
F P
0 g
s
.21326 .69274 m .22247 .68759 L .27222 .70795 L p 0 .916 0 r
F P
0 g
s
.23176 .68232 m .22244 .68754 L .22911 .63329 L p 0 .1 0 r
F P
0 g
s
.22911 .63329 m .23825 .62787 L .23176 .68232 L p 0 .1 0 r
F P
0 g
s
.40953 .52841 m .39912 .53456 L .44465 .55862 L p 0 .914 1 r
F P
0 g
s
.44465 .55862 m .45508 .55276 L .40953 .52841 L p 0 .914 1 r
F P
0 g
s
.45508 .55276 m .44465 .55862 L .44329 .61107 L p 0 .1 .423 r
F P
0 g
s
.39657 .58773 m .39912 .53456 L .44465 .55862 L p 0 .689 .454 r
F P
0 g
s
.43274 .61669 m .44329 .61107 L .44465 .55862 L p 0 .1 .423 r
F P
0 g
s
.44465 .55862 m .44329 .61107 L .39657 .58773 L p 0 .689 .454 r
F P
0 g
s
.39657 .58773 m .39912 .53456 L .44465 .55862 L p 0 .689 .454 r
F P
0 g
s
.44465 .55862 m .44329 .61107 L .39657 .58773 L p 0 .689 .454 r
F P
0 g
s
.2762 .60538 m .26661 .61107 L .27222 .55866 L p 0 .1 .365 r
F P
0 g
s
.27222 .55866 m .28161 .5528 L .2762 .60538 L p 0 .1 .365 r
F P
0 g
s
.67411 .47239 m .67409 .4724 L .68591 .46602 L p 0 .1 0 r
F P
0 g
s
.54468 .3977 m .54579 .44622 L .5346 .45284 L p 0 .1 .425 r
F P
0 g
s
.54468 .3977 m .54579 .44622 L .58783 .47242 L p 0 .673 .397 r
F P
0 g
s
.54468 .3977 m .54579 .44622 L .58783 .47242 L p 0 .673 .397 r
F P
0 g
s
.54579 .44622 m .54468 .3977 L .55573 .39086 L p 0 .1 .425 r
F P
0 g
s
.58783 .47242 m .54579 .44622 L .55711 .43951 L p 0 .911 1 r
F P
0 g
s
.55711 .43951 m .59913 .46604 L .58783 .47242 L p 0 .911 1 r
F P
0 g
s
.63097 .3977 m .58999 .36965 L .57854 .37674 L p 0 .907 0 r
F P
0 g
s
.63097 .3977 m .6342 .44622 L .62248 .45284 L p 0 .1 0 r
F P
0 g
s
.6342 .44622 m .63097 .3977 L .58999 .36965 L p 0 .663 0 r
F P
0 g
s
.58783 .32297 m .58999 .36965 L .63097 .3977 L p 0 .663 0 r
F P
0 g
s
.58783 .32297 m .58999 .36965 L .63097 .3977 L p 0 .663 0 r
F P
0 g
s
.58999 .36965 m .63097 .3977 L .64253 .39086 L p 0 .907 0 r
F P
0 g
s
.63097 .3977 m .6342 .44622 L .67409 .4724 L p 0 .663 0 r
F P
0 g
s
.63097 .3977 m .6342 .44622 L .67409 .4724 L p 0 .663 0 r
F P
0 g
s
.63097 .3977 m .6342 .44622 L .64607 .43951 L p 0 .1 0 r
F P
0 g
s
.64607 .43951 m .64253 .39086 L .63097 .3977 L p 0 .1 0 r
F P
0 g
s
.6342 .44622 m .63097 .3977 L .58999 .36965 L p 0 .663 0 r
F P
0 g
s
.63097 .3977 m .58999 .36965 L .60159 .36247 L p 0 .907 0 r
F P
0 g
s
.60159 .36247 m .64253 .39086 L .63097 .3977 L p 0 .907 0 r
F P
0 g
s
.6342 .44622 m .63097 .3977 L .64253 .39086 L p 0 .1 0 r
F P
0 g
s
.58783 .32297 m .58999 .36965 L .57854 .37674 L p 0 .1 0 r
F P
0 g
s
.58999 .36965 m .58783 .32297 L .59913 .31569 L p 0 .1 0 r
F P
0 g
s
.67411 .32297 m .67841 .36965 L .66642 .37674 L p 0 .1 .45 r
F P
0 g
s
.67411 .32297 m .67841 .36965 L .71726 .3977 L p 0 .652 .333 r
F P
0 g
s
.67411 .32297 m .67841 .36965 L .71726 .3977 L p 0 .652 .333 r
F P
0 g
s
.67841 .36965 m .67411 .32297 L .68593 .31569 L p 0 .1 .45 r
F P
0 g
s
.67411 .32297 m .6342 .29308 L .62248 .30064 L p 0 .903 1 r
F P
0 g
s
.67841 .36965 m .67411 .32297 L .6342 .29308 L p 0 .652 .333 r
F P
0 g
s
.6342 .29308 m .67411 .32297 L .68593 .31569 L p 0 .903 1 r
F P
0 g
s
.67411 .32297 m .67841 .36965 L .69055 .36247 L p 0 .1 .45 r
F P
0 g
s
.69055 .36247 m .68593 .31569 L .67411 .32297 L p 0 .1 .45 r
F P
0 g
s
.67841 .36965 m .67411 .32297 L .6342 .29308 L p 0 .652 .333 r
F P
0 g
s
.71726 .3977 m .67841 .36965 L .66642 .37674 L p 0 .907 1 r
F P
0 g
s
.72259 .4462 m .72261 .44618 L .71035 .45281 L p 0 .1 .1 r
F P
0 g
s
.71726 .3977 m .67841 .36965 L p .72259 .4462 L 0 .652 .333 r
F P
0 g
s
.72259 .4462 m .72261 .44618 L .71726 .3977 L p 0 .652 .333 r
F P
0 g
s
.67841 .36965 m .71726 .3977 L .72934 .39086 L p 0 .907 1 r
F P
0 g
s
.71726 .3977 m .72261 .44618 L .73502 .43948 L p 0 .114 .472 r
F P
0 g
s
.73502 .43948 m .72934 .39086 L .71726 .3977 L p 0 .114 .472 r
F P
0 g
s
.71726 .3977 m .67841 .36965 L p .72259 .4462 L 0 .652 .333 r
F P
0 g
s
.72259 .4462 m .72261 .44618 L .71726 .3977 L p 0 .652 .333 r
F P
0 g
s
.71726 .3977 m .67841 .36965 L .69055 .36247 L p 0 .907 1 r
F P
0 g
s
.69055 .36247 m .72934 .39086 L .71726 .3977 L p 0 .907 1 r
F P
0 g
s
.76037 .32295 m .7604 .323 L .77274 .31572 L p 0 .575 0 r
F P
0 g
s
.7604 .323 m .76682 .36965 L .77951 .36247 L p 0 .114 0 r
F P
0 g
s
.77951 .36247 m .77274 .31572 L .7604 .323 L p 0 .114 0 r
F P
0 g
s
.76682 .36965 m .7604 .323 L .76037 .32295 L p 0 .638 0 r
F P
0 g
s
.72262 .29308 m .76037 .32295 L .77271 .31566 L p 0 .903 0 r
F P
0 g
s
.77274 .31572 m .77271 .31566 L .76037 .32295 L p 0 .575 0 r
F P
0 g
s
.76037 .32295 m .72262 .29308 L .71036 .30064 L p 0 .903 0 r
F P
0 g
s
.76037 .32295 m .72262 .29308 L p .76682 .36965 L 0 .638 0 r
F P
0 g
s
.76682 .36965 m .7604 .323 L .76037 .32295 L p 0 .638 0 r
F P
0 g
s
.76037 .32295 m .72262 .29308 L p .76682 .36965 L 0 .638 0 r
F P
0 g
s
.67409 .4724 m .6342 .44622 L .64607 .43951 L p 0 .911 0 r
F P
0 g
s
.64607 .43951 m .68591 .46602 L .67409 .4724 L p 0 .911 0 r
F P
0 g
s
.19505 .70293 m .18907 .70627 L .18904 .70622 L p 0 .525 .891 r
F P
0 g
s
.18904 .70622 m .19502 .70287 L .19505 .70293 L p 0 .525 .891 r
F P
0 g
s
.40985 .36759 m .41202 .32092 L .41205 .3209 L p 0 .681 0 r
F P
0 g
s
.41205 .3209 m .42232 .31359 L .42228 .31361 L p 0 1 0 r
F P
0 g
s
.42228 .31361 m .41202 .32092 L .41205 .3209 L p 0 1 0 r
F P
0 g
s
.41205 .3209 m .41202 .32092 L p .45524 .39574 L 0 .681 0 r
F P
0 g
s
.33533 .46415 m .33536 .4642 L .32562 .47061 L p 0 .546 0 r
F P
0 g
s
.32562 .47061 m .32559 .47056 L .33533 .46415 L p 0 .546 0 r
F P
0 g
s
.53152 .45095 m .5427 .4443 L .54167 .39574 L p 0 .1 .423 r
F P
0 g
s
.4875 .37471 m .49842 .36759 L .54167 .39574 L p 0 .907 1 r
F P
0 g
s
.5427 .4443 m .54167 .39574 L .49842 .36759 L p 0 .673 .397 r
F P
0 g
s
.5427 .4443 m .54167 .39574 L .49842 .36759 L p 0 .673 .397 r
F P
0 g
s
.49846 .32088 m .49842 .36759 L .54167 .39574 L p 0 .673 .397 r
F P
0 g
s
.49846 .32088 m .49842 .36759 L .54167 .39574 L p 0 .673 .397 r
F P
0 g
s
.49846 .32088 m .50924 .31357 L .50947 .36039 L p 0 .1 .396 r
F P
0 g
s
.50947 .36039 m .49842 .36759 L .49846 .32088 L p 0 .1 .396 r
F P
0 g
s
.4875 .37471 m .49842 .36759 L .49846 .32088 L p 0 .1 .396 r
F P
0 g
s
.49842 .36759 m .49846 .32088 L .45417 .29091 L p 0 .673 .397 r
F P
0 g
s
.50924 .31357 m .49846 .32088 L .49842 .36759 L p 0 .1 .396 r
F P
0 g
s
.49846 .32088 m .50924 .31357 L .46494 .28323 L p 0 .903 1 r
F P
0 g
s
.46494 .28323 m .45417 .29091 L .49846 .32088 L p 0 .903 1 r
F P
0 g
s
.49842 .36759 m .49846 .32088 L .45417 .29091 L p 0 .673 .397 r
F P
0 g
s
.55272 .38888 m .54167 .39574 L .49842 .36759 L p 0 .907 1 r
F P
0 g
s
.55272 .38888 m .54167 .39574 L .5427 .4443 L p 0 .1 .423 r
F P
0 g
s
.54167 .39574 m .55272 .38888 L .50947 .36039 L p 0 .907 1 r
F P
0 g
s
.50947 .36039 m .49842 .36759 L .54167 .39574 L p 0 .907 1 r
F P
0 g
s
.45524 .39574 m .40985 .36759 L .39947 .37471 L p 0 .907 0 r
F P
0 g
s
.45524 .39574 m .45413 .4443 L .44349 .45095 L p 0 .1 0 r
F P
0 g
s
.45524 .39574 m .45413 .4443 L .4076 .41669 L p 0 .681 0 r
F P
0 g
s
.40985 .36759 m .45524 .39574 L p .4076 .41669 L 0 .681 0 r
F P
0 g
s
.45524 .39574 m .45413 .4443 L .49846 .47059 L p 0 .681 0 r
F P
0 g
s
.46576 .38888 m .45524 .39574 L .45413 .4443 L p 0 .1 0 r
F P
0 g
s
.41202 .32092 m .40985 .36759 L .45524 .39574 L p 0 .681 0 r
F P
0 g
s
.45524 .39574 m .46576 .38888 L .42035 .36039 L p 0 .907 0 r
F P
0 g
s
.42035 .36039 m .40985 .36759 L .45524 .39574 L p 0 .907 0 r
F P
0 g
s
.45413 .4443 m .45524 .39574 L .40985 .36759 L p 0 .681 0 r
F P
0 g
s
.46576 .38888 m .45524 .39574 L .40985 .36759 L p 0 .907 0 r
F P
0 g
s
.50924 .46418 m .49846 .47059 L .45413 .4443 L p 0 .911 0 r
F P
0 g
s
.45524 .39574 m .46576 .38888 L .46491 .43757 L p 0 .1 0 r
F P
0 g
s
.46491 .43757 m .45413 .4443 L .45524 .39574 L p 0 .1 0 r
F P
0 g
s
.59619 .31357 m .58489 .32088 L .58699 .36759 L p 0 .1 0 r
F P
0 g
s
.58489 .32088 m .59619 .31357 L .55403 .28321 L p 0 .903 0 r
F P
0 g
s
.55403 .28321 m .5427 .29089 L .58489 .32088 L p 0 .903 0 r
F P
0 g
s
.57553 .37471 m .58699 .36759 L .58489 .32088 L p 0 .1 0 r
F P
0 g
s
.58699 .36759 m .58489 .32088 L .5427 .29089 L p 0 .663 0 r
F P
0 g
s
.58699 .36759 m .58489 .32088 L .5427 .29089 L p 0 .663 0 r
F P
0 g
s
.3688 .39574 m .36556 .44426 L .35546 .45091 L p 0 .1 .365 r
F P
0 g
s
.3656 .44432 m .36556 .44426 L .3688 .39574 L p 0 .687 .449 r
F P
0 g
s
.3656 .44432 m .36556 .44426 L .3688 .39574 L p 0 .687 .449 r
F P
0 g
s
.36556 .44426 m .3688 .39574 L .37881 .38888 L p 0 .1 .365 r
F P
0 g
s
.37583 .43759 m .42228 .46418 L .41202 .47059 L p 0 .911 1 r
F P
0 g
s
.41202 .47059 m .3656 .44432 L .37583 .43759 L p 0 .911 1 r
F P
0 g
s
.41202 .32092 m .40985 .36759 L .39947 .37471 L p 0 .1 0 r
F P
0 g
s
.41202 .32092 m .42228 .31361 L .42035 .36039 L p 0 .1 0 r
F P
0 g
s
.42035 .36039 m .40985 .36759 L .41202 .32092 L p 0 .1 0 r
F P
0 g
s
.54484 .70438 m .54481 .70441 L .55589 .6994 L p 0 .1 .1 r
F P
0 g
s
.41286 .68387 m .41496 .62944 L .42526 .62398 L p 0 .1 0 r
F P
0 g
s
.41496 .62944 m .41286 .68387 L .40244 .68906 L p 0 .1 0 r
F P
0 g
s
.4234 .67861 m .46881 .69941 L .45825 .70442 L p 0 .916 0 r
F P
0 g
s
.45825 .70442 m .41286 .68387 L .4234 .67861 L p 0 .916 0 r
F P
0 g
s
.54484 .55445 m .50158 .53019 L .49063 .53632 L p 0 .914 0 r
F P
0 g
s
.50162 .58348 m .50158 .53019 L .54484 .55445 L p 0 .681 0 r
F P
0 g
s
.54484 .55445 m .54595 .60703 L .53472 .61269 L p 0 .1 0 r
F P
0 g
s
.54484 .55445 m .54595 .60703 L .50162 .58348 L p 0 .681 0 r
F P
0 g
s
.58813 .62944 m .54595 .60703 L .53472 .61269 L p 0 .916 0 r
F P
0 g
s
.54711 .66227 m .54595 .60703 L .58813 .62944 L p 0 .681 0 r
F P
0 g
s
.59028 .68385 m .59031 .68383 L .57881 .68902 L p 0 .1 0 r
F P
0 g
s
.59028 .68385 m .54711 .66227 L p .58813 .62944 L 0 .681 0 r
F P
0 g
s
.58813 .62944 m .59031 .68383 L .59028 .68385 L p 0 .681 0 r
F P
0 g
s
.54484 .55445 m .55592 .54854 L .51267 .52398 L p 0 .914 0 r
F P
0 g
s
.51267 .52398 m .50158 .53019 L .54484 .55445 L p 0 .914 0 r
F P
0 g
s
.54484 .55445 m .54595 .60703 L .58813 .62944 L p 0 .681 0 r
F P
0 g
s
.55592 .54854 m .54484 .55445 L .54595 .60703 L p 0 .1 0 r
F P
0 g
s
.54595 .60703 m .54484 .55445 L .50158 .53019 L p 0 .681 0 r
F P
0 g
s
.54484 .55445 m .55592 .54854 L .55731 .60129 L p 0 .1 0 r
F P
0 g
s
.55731 .60129 m .54595 .60703 L .54484 .55445 L p 0 .1 0 r
F P
0 g
s
.59947 .62398 m .58813 .62944 L .54595 .60703 L p 0 .916 0 r
F P
0 g
s
.58813 .62944 m .59947 .62398 L .55731 .60129 L p 0 .916 0 r
F P
0 g
s
.55731 .60129 m .54595 .60703 L .58813 .62944 L p 0 .916 0 r
F P
0 g
s
.59947 .62398 m .58813 .62944 L .59031 .68383 L p 0 .114 0 r
F P
0 g
s
.59031 .68383 m .58813 .62944 L .54595 .60703 L p 0 .681 0 r
F P
0 g
s
.46804 .60129 m .51237 .62398 L .50155 .62944 L p 0 .916 1 r
F P
0 g
s
.50155 .62944 m .45722 .60703 L .46804 .60129 L p 0 .916 1 r
F P
0 g
s
.45825 .55445 m .45722 .60703 L .44654 .61269 L p 0 .1 .425 r
F P
0 g
s
.45722 .60703 m .50155 .62944 L .51237 .62398 L p 0 .916 1 r
F P
0 g
s
.51267 .67861 m .51237 .62398 L .50155 .62944 L p 0 .1 .45 r
F P
0 g
s
.50155 .62944 m .50158 .68387 L .51267 .67861 L p 0 .1 .45 r
F P
0 g
s
.50155 .62944 m .45722 .60703 L .44654 .61269 L p 0 .916 1 r
F P
0 g
s
.45613 .66227 m .45722 .60703 L .50155 .62944 L p 0 .687 .449 r
F P
0 g
s
.50155 .62944 m .50158 .68387 L .49063 .68906 L p 0 .1 .45 r
F P
0 g
s
.50155 .62944 m .50158 .68387 L .45613 .66227 L p 0 .687 .449 r
F P
0 g
s
.45613 .66227 m .45722 .60703 L .50155 .62944 L p 0 .687 .449 r
F P
0 g
s
.50155 .62944 m .50158 .68387 L .45613 .66227 L p 0 .687 .449 r
F P
0 g
s
.50158 .68387 m .50155 .62944 L .51237 .62398 L p 0 .1 .45 r
F P
0 g
s
.45722 .60703 m .45825 .55445 L .46881 .54854 L p 0 .1 .425 r
F P
0 g
s
.62291 .61269 m .63468 .60703 L .63142 .55449 L p 0 .114 .472 r
F P
0 g
s
.63142 .55449 m .63139 .55444 L .59031 .53019 L p 0 .673 .397 r
F P
0 g
s
.63468 .60703 m .63142 .55449 L p .59031 .53019 L 0 .673 .397 r
F P
0 g
s
.63139 .55444 m .643 .54852 L .60195 .52398 L p 0 .914 1 r
F P
0 g
s
.60195 .52398 m .59031 .53019 L .63139 .55444 L p 0 .914 1 r
F P
0 g
s
.64303 .54858 m .63142 .55449 L .63468 .60703 L p 0 .114 .472 r
F P
0 g
s
.63142 .55449 m .64303 .54858 L .643 .54852 L p 0 .562 .887 r
F P
0 g
s
.643 .54852 m .63139 .55444 L .63142 .55449 L p 0 .562 .887 r
F P
0 g
s
.63142 .55449 m .63139 .55444 L .59031 .53019 L p 0 .673 .397 r
F P
0 g
s
.63468 .60703 m .63142 .55449 L p .59031 .53019 L 0 .673 .397 r
F P
0 g
s
.51267 .67861 m .55589 .6994 L .54481 .70441 L p 0 .916 1 r
F P
0 g
s
.54481 .70441 m .50158 .68387 L .51267 .67861 L p 0 .916 1 r
F P
0 g
s
.29112 .54686 m .28161 .5528 L .28165 .55278 L p 0 .93 .764 r
F P
0 g
s
.33063 .67708 m .32064 .68236 L .32498 .62787 L p 0 .1 .396 r
F P
0 g
s
.32498 .62787 m .33476 .62239 L .33063 .67708 L p 0 .1 .396 r
F P
0 g
s
.28591 .59963 m .2762 .60538 L .32498 .62787 L p 0 .916 1 r
F P
0 g
s
.32498 .62787 m .33476 .62239 L .28591 .59963 L p 0 .916 1 r
F P
0 g
s
.33476 .62239 m .32498 .62787 L .32064 .68236 L p 0 .1 .396 r
F P
0 g
s
.26661 .61107 m .2762 .60538 L .32498 .62787 L p 0 .916 1 r
F P
0 g
s
.27051 .66065 m .2762 .60538 L .32498 .62787 L p 0 .697 .491 r
F P
0 g
s
.27055 .6607 m .27051 .66065 L p .32498 .62787 L 0 .697 .491 r
F P
0 g
s
.31078 .68758 m .32064 .68236 L .32498 .62787 L p 0 .1 .396 r
F P
0 g
s
.32498 .62787 m .32064 .68236 L .27055 .6607 L p 0 .697 .491 r
F P
0 g
s
.27051 .66065 m .2762 .60538 L .32498 .62787 L p 0 .697 .491 r
F P
0 g
s
.27055 .6607 m .27051 .66065 L p .32498 .62787 L 0 .697 .491 r
F P
0 g
s
.32498 .62787 m .32064 .68236 L .27055 .6607 L p 0 .697 .491 r
F P
0 g
s
.37838 .69796 m .36835 .70299 L .32064 .68236 L p 0 .916 1 r
F P
0 g
s
.31078 .68758 m .32064 .68236 L .36835 .70299 L p 0 .916 1 r
F P
0 g
s
.33476 .62239 m .32498 .62787 L .2762 .60538 L p 0 .916 1 r
F P
0 g
s
.37535 .59963 m .36509 .60538 L .41172 .62787 L p 0 .916 0 r
F P
0 g
s
.41172 .62787 m .42201 .62239 L .37535 .59963 L p 0 .916 0 r
F P
0 g
s
.42201 .62239 m .41172 .62787 L .40953 .68236 L p 0 .1 0 r
F P
0 g
s
.35495 .61107 m .36509 .60538 L .41172 .62787 L p 0 .916 0 r
F P
0 g
s
.36165 .66069 m .36509 .60538 L .41172 .62787 L p 0 .693 0 r
F P
0 g
s
.39912 .68758 m .40953 .68236 L .41172 .62787 L p 0 .1 0 r
F P
0 g
s
.41172 .62787 m .40953 .68236 L .36165 .66069 L p 0 .693 0 r
F P
0 g
s
.36165 .66069 m .36509 .60538 L .41172 .62787 L p 0 .693 0 r
F P
0 g
s
.41172 .62787 m .40953 .68236 L .36165 .66069 L p 0 .693 0 r
F P
0 g
s
.42201 .62239 m .41172 .62787 L .36509 .60538 L p 0 .916 0 r
F P
0 g
s
.35495 .61107 m .36509 .60538 L .36835 .55276 L p 0 .1 0 r
F P
0 g
s
.37535 .59963 m .36509 .60538 L .36835 .55276 L p 0 .1 0 r
F P
0 g
s
.36835 .55276 m .37838 .54682 L .37535 .59963 L p 0 .1 0 r
F P
0 g
s
.33067 .52219 m .32068 .52843 L .36835 .55276 L p 0 .914 0 r
F P
0 g
s
.36835 .55276 m .37838 .54682 L .33067 .52219 L p 0 .914 0 r
F P
0 g
s
.37838 .54682 m .36835 .55276 L .36509 .60538 L p 0 .1 0 r
F P
0 g
s
.31081 .53458 m .32068 .52843 L .32064 .52845 L p 0 .93 0 r
F P
0 g
s
.32064 .52845 m .32068 .52843 L .36835 .55276 L p 0 .693 0 r
F P
0 g
s
.31608 .58175 m .32064 .52845 L p .36835 .55276 L 0 .693 0 r
F P
0 g
s
.36835 .55276 m .36509 .60538 L .31608 .58175 L p 0 .693 0 r
F P
0 g
s
.32064 .52845 m .32068 .52843 L .36835 .55276 L p 0 .693 0 r
F P
0 g
s
.31608 .58175 m .32064 .52845 L p .36835 .55276 L 0 .693 0 r
F P
0 g
s
.36835 .55276 m .36509 .60538 L .31608 .58175 L p 0 .693 0 r
F P
0 g
s
.2412 .67704 m .23176 .68232 L .23825 .62787 L p 0 .1 0 r
F P
0 g
s
.23825 .62787 m .2475 .62239 L .2412 .67704 L p 0 .1 0 r
F P
0 g
s
.29113 .69796 m .28162 .70299 L .23179 .68238 L p 0 .916 0 r
F P
0 g
s
.22247 .68759 m .23179 .68238 L .28162 .70299 L p 0 .916 0 r
F P
0 g
s
.44329 .61107 m .45397 .60538 L .45508 .55276 L p 0 .1 .423 r
F P
0 g
s
.42007 .52218 m .40953 .52841 L .45508 .55276 L p 0 .914 1 r
F P
0 g
s
.45508 .55276 m .46564 .54682 L .42007 .52218 L p 0 .914 1 r
F P
0 g
s
.46564 .54682 m .45508 .55276 L .45397 .60538 L p 0 .1 .423 r
F P
0 g
s
.40723 .58175 m .40953 .52841 L .45508 .55276 L p 0 .687 .449 r
F P
0 g
s
.45508 .55276 m .45397 .60538 L .40723 .58175 L p 0 .687 .449 r
F P
0 g
s
.40723 .58175 m .40953 .52841 L .45508 .55276 L p 0 .687 .449 r
F P
0 g
s
.45508 .55276 m .45397 .60538 L .40723 .58175 L p 0 .687 .449 r
F P
0 g
s
.28591 .59963 m .2762 .60538 L .28161 .5528 L p 0 .1 .365 r
F P
0 g
s
.28161 .5528 m .29112 .54686 L .28591 .59963 L p 0 .1 .365 r
F P
0 g
s
.20107 .69956 m .19505 .70293 L .19502 .70287 L p 0 .525 .891 r
F P
0 g
s
.19502 .70287 m .20104 .69951 L .20107 .69956 L p 0 .525 .891 r
F P
0 g
s
.68593 .466 m .68591 .46602 L .69787 .45956 L p 0 .1 0 r
F P
0 g
s
.55573 .39086 m .55711 .43951 L .59913 .46604 L p 0 .671 .39 r
F P
0 g
s
.55573 .39086 m .55711 .43951 L .59913 .46604 L p 0 .671 .39 r
F P
0 g
s
.55711 .43951 m .55573 .39086 L .5669 .38394 L p 0 .1 .425 r
F P
0 g
s
.55573 .39086 m .55711 .43951 L .54579 .44622 L p 0 .1 .425 r
F P
0 g
s
.59913 .46604 m .55711 .43951 L .56857 .43272 L p 0 .911 1 r
F P
0 g
s
.56857 .43272 m .61057 .45957 L .59913 .46604 L p 0 .911 1 r
F P
0 g
s
.59913 .31569 m .60159 .36247 L .58999 .36965 L p 0 .1 0 r
F P
0 g
s
.59913 .31569 m .60159 .36247 L .64253 .39086 L p 0 .661 0 r
F P
0 g
s
.59913 .31569 m .60159 .36247 L .64253 .39086 L p 0 .661 0 r
F P
0 g
s
.64253 .39086 m .60159 .36247 L .58999 .36965 L p 0 .907 0 r
F P
0 g
s
.64253 .39086 m .64607 .43951 L .6342 .44622 L p 0 .1 0 r
F P
0 g
s
.64607 .43951 m .64253 .39086 L .60159 .36247 L p 0 .661 0 r
F P
0 g
s
.64607 .43951 m .64253 .39086 L .60159 .36247 L p 0 .661 0 r
F P
0 g
s
.64253 .39086 m .64607 .43951 L .68591 .46602 L p 0 .661 0 r
F P
0 g
s
.64253 .39086 m .64607 .43951 L .68591 .46602 L p 0 .661 0 r
F P
0 g
s
.60159 .36247 m .64253 .39086 L .65423 .38394 L p 0 .907 0 r
F P
0 g
s
.64253 .39086 m .64607 .43951 L .65808 .43272 L p 0 .1 0 r
F P
0 g
s
.65808 .43272 m .65423 .38394 L .64253 .39086 L p 0 .1 0 r
F P
0 g
s
.64253 .39086 m .60159 .36247 L .61333 .35521 L p 0 .907 0 r
F P
0 g
s
.61333 .35521 m .65423 .38394 L .64253 .39086 L p 0 .907 0 r
F P
0 g
s
.64607 .43951 m .64253 .39086 L .65423 .38394 L p 0 .1 0 r
F P
0 g
s
.60159 .36247 m .59913 .31569 L .61057 .30831 L p 0 .1 0 r
F P
0 g
s
.68593 .31569 m .69055 .36247 L .67841 .36965 L p 0 .1 .45 r
F P
0 g
s
.68593 .31569 m .69055 .36247 L .72934 .39086 L p 0 .648 .324 r
F P
0 g
s
.68593 .31569 m .69055 .36247 L .72934 .39086 L p 0 .648 .324 r
F P
0 g
s
.69055 .36247 m .68593 .31569 L .6979 .30831 L p 0 .1 .45 r
F P
0 g
s
.68593 .31569 m .64607 .28543 L .6342 .29308 L p 0 .903 1 r
F P
0 g
s
.69055 .36247 m .68593 .31569 L .64607 .28543 L p 0 .648 .324 r
F P
0 g
s
.64607 .28543 m .68593 .31569 L .6979 .30831 L p 0 .903 1 r
F P
0 g
s
.68593 .31569 m .69055 .36247 L .70284 .35521 L p 0 .1 .45 r
F P
0 g
s
.70284 .35521 m .6979 .30831 L .68593 .31569 L p 0 .1 .45 r
F P
0 g
s
.69055 .36247 m .68593 .31569 L .64607 .28543 L p 0 .648 .324 r
F P
0 g
s
.72934 .39086 m .69055 .36247 L .67841 .36965 L p 0 .907 1 r
F P
0 g
s
.735 .43949 m .73502 .43948 L .72261 .44618 L p 0 .1 .1 r
F P
0 g
s
.72934 .39086 m .69055 .36247 L p .735 .43949 L 0 .648 .324 r
F P
0 g
s
.735 .43949 m .73502 .43948 L .72934 .39086 L p 0 .648 .324 r
F P
0 g
s
.69055 .36247 m .72934 .39086 L .74156 .38394 L p 0 .907 1 r
F P
0 g
s
.72934 .39086 m .73502 .43948 L .74759 .43269 L p 0 .114 .472 r
F P
0 g
s
.74759 .43269 m .74156 .38394 L .72934 .39086 L p 0 .114 .472 r
F P
0 g
s
.72934 .39086 m .69055 .36247 L p .735 .43949 L 0 .648 .324 r
F P
0 g
s
.735 .43949 m .73502 .43948 L .72934 .39086 L p 0 .648 .324 r
F P
0 g
s
.72934 .39086 m .69055 .36247 L .70284 .35521 L p 0 .907 1 r
F P
0 g
s
.70284 .35521 m .74156 .38394 L .72934 .39086 L p 0 .907 1 r
F P
0 g
s
.77951 .36247 m .77274 .31572 L .77271 .31566 L p 0 .634 0 r
F P
0 g
s
.77271 .31566 m .77274 .31572 L .78523 .30835 L p 0 .575 0 r
F P
0 g
s
.77274 .31572 m .77951 .36247 L .79235 .35521 L p 0 .114 0 r
F P
0 g
s
.79235 .35521 m .78523 .30835 L .77274 .31572 L p 0 .114 0 r
F P
0 g
s
.78523 .30835 m .7852 .30829 L .77271 .31566 L p 0 .575 0 r
F P
0 g
s
.79235 .35521 m .78523 .30835 L .7852 .30829 L p 0 .63 .275 r
F P
0 g
s
.77951 .36247 m .77274 .31572 L .77271 .31566 L p 0 .634 0 r
F P
0 g
s
.77271 .31566 m .73503 .28543 L .72262 .29308 L p 0 .903 0 r
F P
0 g
s
.77271 .31566 m .73503 .28543 L p .77951 .36247 L 0 .634 0 r
F P
0 g
s
.73503 .28543 m .77271 .31566 L .7852 .30829 L p 0 .903 0 r
F P
0 g
s
.77271 .31566 m .73503 .28543 L p .77951 .36247 L 0 .634 0 r
F P
0 g
s
.7852 .30829 m .74759 .27769 L .73503 .28543 L p 0 .903 0 r
F P
0 g
s
.7852 .30829 m .74759 .27769 L p .79235 .35521 L 0 .63 .275 r
F P
0 g
s
.68591 .46602 m .64607 .43951 L .65808 .43272 L p 0 .911 0 r
F P
0 g
s
.65808 .43272 m .69787 .45956 L .68591 .46602 L p 0 .911 0 r
F P
0 g
s
.42232 .31359 m .42228 .31361 L p .46576 .38888 L 0 .679 0 r
F P
0 g
s
.42232 .31359 m .4327 .3062 L .43267 .30621 L p 0 1 0 r
F P
0 g
s
.43267 .30621 m .42228 .31361 L .42232 .31359 L p 0 1 0 r
F P
0 g
s
.42232 .31359 m .42228 .31361 L p .46576 .38888 L 0 .679 0 r
F P
0 g
s
.34519 .45766 m .34522 .45772 L .33536 .4642 L p 0 .546 0 r
F P
0 g
s
.33536 .4642 m .33533 .46415 L .34519 .45766 L p 0 .546 0 r
F P
0 g
s
.56389 .38194 m .55272 .38888 L .55403 .43757 L p 0 .1 .423 r
F P
0 g
s
.50924 .31357 m .50947 .36039 L .55272 .38888 L p 0 .671 .39 r
F P
0 g
s
.50924 .31357 m .50947 .36039 L .55272 .38888 L p 0 .671 .39 r
F P
0 g
s
.55272 .38888 m .56389 .38194 L .52066 .3531 L p 0 .907 1 r
F P
0 g
s
.52066 .3531 m .50947 .36039 L .55272 .38888 L p 0 .907 1 r
F P
0 g
s
.50924 .31357 m .52015 .30618 L .52066 .3531 L p 0 .1 .396 r
F P
0 g
s
.52066 .3531 m .50947 .36039 L .50924 .31357 L p 0 .1 .396 r
F P
0 g
s
.49842 .36759 m .50947 .36039 L .50924 .31357 L p 0 .1 .396 r
F P
0 g
s
.50947 .36039 m .50924 .31357 L .46494 .28323 L p 0 .671 .39 r
F P
0 g
s
.52015 .30618 m .50924 .31357 L .50947 .36039 L p 0 .1 .396 r
F P
0 g
s
.50924 .31357 m .52015 .30618 L .47585 .27546 L p 0 .903 1 r
F P
0 g
s
.47585 .27546 m .46494 .28323 L .50924 .31357 L p 0 .903 1 r
F P
0 g
s
.50947 .36039 m .50924 .31357 L .46494 .28323 L p 0 .671 .39 r
F P
0 g
s
.49842 .36759 m .50947 .36039 L .55272 .38888 L p 0 .907 1 r
F P
0 g
s
.56389 .38194 m .55272 .38888 L .50947 .36039 L p 0 .907 1 r
F P
0 g
s
.5427 .4443 m .55403 .43757 L .55272 .38888 L p 0 .1 .423 r
F P
0 g
s
.55403 .43757 m .55272 .38888 L .50947 .36039 L p 0 .671 .39 r
F P
0 g
s
.55403 .43757 m .55272 .38888 L .50947 .36039 L p 0 .671 .39 r
F P
0 g
s
.46576 .38888 m .46491 .43757 L .50924 .46418 L p 0 .679 0 r
F P
0 g
s
.46576 .38888 m .46491 .43757 L .50924 .46418 L p 0 .679 0 r
F P
0 g
s
.47641 .38194 m .46576 .38888 L .46491 .43757 L p 0 .1 0 r
F P
0 g
s
.42228 .31361 m .42035 .36039 L .46576 .38888 L p 0 .679 0 r
F P
0 g
s
.42228 .31361 m .42035 .36039 L .46576 .38888 L p 0 .679 0 r
F P
0 g
s
.46576 .38888 m .47641 .38194 L .43099 .3531 L p 0 .907 0 r
F P
0 g
s
.43099 .3531 m .42035 .36039 L .46576 .38888 L p 0 .907 0 r
F P
0 g
s
.46576 .38888 m .47641 .38194 L .47582 .43076 L p 0 .1 0 r
F P
0 g
s
.47582 .43076 m .46491 .43757 L .46576 .38888 L p 0 .1 0 r
F P
0 g
s
.45413 .4443 m .46491 .43757 L .46576 .38888 L p 0 .1 0 r
F P
0 g
s
.40985 .36759 m .42035 .36039 L .46576 .38888 L p 0 .907 0 r
F P
0 g
s
.46491 .43757 m .46576 .38888 L .42035 .36039 L p 0 .679 0 r
F P
0 g
s
.46491 .43757 m .46576 .38888 L .42035 .36039 L p 0 .679 0 r
F P
0 g
s
.47641 .38194 m .46576 .38888 L .42035 .36039 L p 0 .907 0 r
F P
0 g
s
.52015 .4577 m .50924 .46418 L .46491 .43757 L p 0 .911 0 r
F P
0 g
s
.45413 .4443 m .46491 .43757 L .50924 .46418 L p 0 .911 0 r
F P
0 g
s
.58699 .36759 m .59859 .36039 L .59619 .31357 L p 0 .1 0 r
F P
0 g
s
.59859 .36039 m .59619 .31357 L .55403 .28321 L p 0 .661 0 r
F P
0 g
s
.60763 .30618 m .59619 .31357 L .59859 .36039 L p 0 .1 0 r
F P
0 g
s
.59619 .31357 m .60763 .30618 L .56549 .27544 L p 0 .903 0 r
F P
0 g
s
.56549 .27544 m .55403 .28321 L .59619 .31357 L p 0 .903 0 r
F P
0 g
s
.59859 .36039 m .59619 .31357 L .55403 .28321 L p 0 .661 0 r
F P
0 g
s
.37583 .43759 m .37579 .43753 L .37881 .38888 L p 0 .686 .443 r
F P
0 g
s
.37583 .43759 m .37579 .43753 L .37881 .38888 L p 0 .686 .443 r
F P
0 g
s
.37579 .43753 m .37881 .38888 L .38893 .38194 L p 0 .1 .365 r
F P
0 g
s
.37881 .38888 m .37579 .43753 L .36556 .44426 L p 0 .1 .365 r
F P
0 g
s
.38618 .43078 m .43267 .4577 L .42228 .46418 L p 0 .911 1 r
F P
0 g
s
.42228 .46418 m .37583 .43759 L .38618 .43078 L p 0 .911 1 r
F P
0 g
s
.42228 .31361 m .43267 .30621 L .43099 .3531 L p 0 .1 0 r
F P
0 g
s
.43099 .3531 m .42035 .36039 L .42228 .31361 L p 0 .1 0 r
F P
0 g
s
.20714 .69616 m .20107 .69956 L .20104 .69951 L p 0 .525 .891 r
F P
0 g
s
.20104 .69951 m .20711 .69611 L .20714 .69616 L p 0 .525 .891 r
F P
0 g
s
.55592 .69937 m .55589 .6994 L .5671 .69433 L p 0 .1 .1 r
F P
0 g
s
.42526 .62398 m .4234 .67861 L .41286 .68387 L p 0 .1 0 r
F P
0 g
s
.43407 .67328 m .4795 .69434 L .46881 .69941 L p 0 .916 0 r
F P
0 g
s
.46881 .69941 m .4234 .67861 L .43407 .67328 L p 0 .916 0 r
F P
0 g
s
.4234 .67861 m .42526 .62398 L .43568 .61845 L p 0 .1 0 r
F P
0 g
s
.54595 .60703 m .55731 .60129 L .55592 .54854 L p 0 .1 0 r
F P
0 g
s
.55731 .60129 m .55592 .54854 L .51267 .52398 L p 0 .679 0 r
F P
0 g
s
.55592 .54854 m .56713 .54255 L .5239 .51769 L p 0 .914 0 r
F P
0 g
s
.5239 .51769 m .51267 .52398 L .55592 .54854 L p 0 .914 0 r
F P
0 g
s
.55592 .54854 m .55731 .60129 L .59947 .62398 L p 0 .679 0 r
F P
0 g
s
.55592 .54854 m .55731 .60129 L .59947 .62398 L p 0 .679 0 r
F P
0 g
s
.56713 .54255 m .55592 .54854 L .55731 .60129 L p 0 .1 0 r
F P
0 g
s
.55731 .60129 m .55592 .54854 L .51267 .52398 L p 0 .679 0 r
F P
0 g
s
.54595 .60703 m .55731 .60129 L .59947 .62398 L p 0 .916 0 r
F P
0 g
s
.61095 .61845 m .59947 .62398 L .55731 .60129 L p 0 .916 0 r
F P
0 g
s
.59031 .68383 m .60195 .67857 L .59947 .62398 L p 0 .114 0 r
F P
0 g
s
.60195 .67857 m .59947 .62398 L .55731 .60129 L p 0 .679 0 r
F P
0 g
s
.60195 .67857 m .59947 .62398 L .55731 .60129 L p 0 .679 0 r
F P
0 g
s
.55592 .54854 m .56713 .54255 L .56882 .59549 L p 0 .1 0 r
F P
0 g
s
.56882 .59549 m .55731 .60129 L .55592 .54854 L p 0 .1 0 r
F P
0 g
s
.59947 .62398 m .61095 .61845 L .56882 .59549 L p 0 .916 0 r
F P
0 g
s
.56882 .59549 m .55731 .60129 L .59947 .62398 L p 0 .916 0 r
F P
0 g
s
.61095 .61845 m .59947 .62398 L .60195 .67857 L p 0 .114 0 r
F P
0 g
s
.47899 .59549 m .52332 .61845 L .51237 .62398 L p 0 .916 1 r
F P
0 g
s
.51237 .62398 m .46804 .60129 L .47899 .59549 L p 0 .916 1 r
F P
0 g
s
.46804 .60129 m .51237 .62398 L .52332 .61845 L p 0 .916 1 r
F P
0 g
s
.5239 .67328 m .52332 .61845 L .51237 .62398 L p 0 .1 .45 r
F P
0 g
s
.51237 .62398 m .51267 .67861 L .5239 .67328 L p 0 .1 .45 r
F P
0 g
s
.51237 .62398 m .46804 .60129 L .45722 .60703 L p 0 .916 1 r
F P
0 g
s
.46722 .65674 m .46804 .60129 L .51237 .62398 L p 0 .686 .443 r
F P
0 g
s
.51237 .62398 m .51267 .67861 L .50158 .68387 L p 0 .1 .45 r
F P
0 g
s
.51237 .62398 m .51267 .67861 L .46722 .65674 L p 0 .686 .443 r
F P
0 g
s
.46722 .65674 m .46804 .60129 L .51237 .62398 L p 0 .686 .443 r
F P
0 g
s
.51237 .62398 m .51267 .67861 L .46722 .65674 L p 0 .686 .443 r
F P
0 g
s
.51267 .67861 m .51237 .62398 L .52332 .61845 L p 0 .1 .45 r
F P
0 g
s
.46804 .60129 m .46881 .54854 L .4795 .54255 L p 0 .1 .425 r
F P
0 g
s
.46881 .54854 m .46804 .60129 L .45722 .60703 L p 0 .1 .425 r
F P
0 g
s
.643 .54852 m .65474 .54254 L .61373 .51769 L p 0 .914 1 r
F P
0 g
s
.61373 .51769 m .60195 .52398 L .643 .54852 L p 0 .914 1 r
F P
0 g
s
.65477 .54259 m .64303 .54858 L .64659 .60129 L p 0 .114 .472 r
F P
0 g
s
.64303 .54858 m .65477 .54259 L .65474 .54254 L p 0 .562 .887 r
F P
0 g
s
.65474 .54254 m .643 .54852 L .64303 .54858 L p 0 .562 .887 r
F P
0 g
s
.63468 .60703 m .64659 .60129 L .64303 .54858 L p 0 .114 .472 r
F P
0 g
s
.64303 .54858 m .643 .54852 L .60195 .52398 L p 0 .671 .39 r
F P
0 g
s
.64659 .60129 m .64303 .54858 L p .60195 .52398 L 0 .671 .39 r
F P
0 g
s
.64303 .54858 m .643 .54852 L .60195 .52398 L p 0 .671 .39 r
F P
0 g
s
.64659 .60129 m .64303 .54858 L p .60195 .52398 L 0 .671 .39 r
F P
0 g
s
.5239 .67328 m .5671 .69433 L .55589 .6994 L p 0 .916 1 r
F P
0 g
s
.55589 .6994 m .51267 .67861 L .5239 .67328 L p 0 .916 1 r
F P
0 g
s
.30075 .54086 m .29112 .54686 L .29116 .54684 L p 0 .93 .764 r
F P
0 g
s
.34074 .67174 m .33063 .67708 L .33476 .62239 L p 0 .1 .396 r
F P
0 g
s
.33476 .62239 m .34465 .61685 L .34074 .67174 L p 0 .1 .396 r
F P
0 g
s
.29575 .5938 m .28591 .59963 L .33476 .62239 L p 0 .916 1 r
F P
0 g
s
.33476 .62239 m .34465 .61685 L .29575 .5938 L p 0 .916 1 r
F P
0 g
s
.34465 .61685 m .33476 .62239 L .33063 .67708 L p 0 .1 .396 r
F P
0 g
s
.2762 .60538 m .28591 .59963 L .33476 .62239 L p 0 .916 1 r
F P
0 g
s
.28044 .6551 m .28591 .59963 L .33476 .62239 L p 0 .696 .486 r
F P
0 g
s
.28047 .65515 m .28044 .6551 L p .33476 .62239 L 0 .696 .486 r
F P
0 g
s
.32064 .68236 m .33063 .67708 L .33476 .62239 L p 0 .1 .396 r
F P
0 g
s
.33476 .62239 m .33063 .67708 L .28047 .65515 L p 0 .696 .486 r
F P
0 g
s
.28044 .6551 m .28591 .59963 L .33476 .62239 L p 0 .696 .486 r
F P
0 g
s
.28047 .65515 m .28044 .6551 L p .33476 .62239 L 0 .696 .486 r
F P
0 g
s
.33476 .62239 m .33063 .67708 L .28047 .65515 L p 0 .696 .486 r
F P
0 g
s
.38854 .69287 m .37838 .69796 L .33063 .67708 L p 0 .916 1 r
F P
0 g
s
.32064 .68236 m .33063 .67708 L .37838 .69796 L p 0 .916 1 r
F P
0 g
s
.34465 .61685 m .33476 .62239 L .28591 .59963 L p 0 .916 1 r
F P
0 g
s
.40953 .68236 m .42007 .67708 L .42201 .62239 L p 0 .1 0 r
F P
0 g
s
.38574 .5938 m .37535 .59963 L .42201 .62239 L p 0 .916 0 r
F P
0 g
s
.42201 .62239 m .43243 .61685 L .38574 .5938 L p 0 .916 0 r
F P
0 g
s
.43243 .61685 m .42201 .62239 L .42007 .67708 L p 0 .1 0 r
F P
0 g
s
.36509 .60538 m .37535 .59963 L .42201 .62239 L p 0 .916 0 r
F P
0 g
s
.37216 .65514 m .37535 .59963 L .42201 .62239 L p 0 .692 0 r
F P
0 g
s
.42201 .62239 m .42007 .67708 L .37216 .65514 L p 0 .692 0 r
F P
0 g
s
.37216 .65514 m .37535 .59963 L .42201 .62239 L p 0 .692 0 r
F P
0 g
s
.42201 .62239 m .42007 .67708 L .37216 .65514 L p 0 .692 0 r
F P
0 g
s
.43243 .61685 m .42201 .62239 L .37535 .59963 L p 0 .916 0 r
F P
0 g
s
.38574 .5938 m .37535 .59963 L .37838 .54682 L p 0 .1 0 r
F P
0 g
s
.37838 .54682 m .38854 .54082 L .38574 .5938 L p 0 .1 0 r
F P
0 g
s
.34078 .51588 m .33067 .52219 L .37838 .54682 L p 0 .914 0 r
F P
0 g
s
.37838 .54682 m .38854 .54082 L .34078 .51588 L p 0 .914 0 r
F P
0 g
s
.38854 .54082 m .37838 .54682 L .37535 .59963 L p 0 .1 0 r
F P
0 g
s
.32068 .52843 m .33067 .52219 L .33063 .52221 L p 0 .93 0 r
F P
0 g
s
.33063 .52221 m .33067 .52219 L .37838 .54682 L p 0 .692 0 r
F P
0 g
s
.3263 .5757 m .33063 .52221 L p .37838 .54682 L 0 .692 0 r
F P
0 g
s
.36509 .60538 m .37535 .59963 L .37838 .54682 L p 0 .1 0 r
F P
0 g
s
.37838 .54682 m .37535 .59963 L .3263 .5757 L p 0 .692 0 r
F P
0 g
s
.33063 .52221 m .33067 .52219 L .37838 .54682 L p 0 .692 0 r
F P
0 g
s
.3263 .5757 m .33063 .52221 L p .37838 .54682 L 0 .692 0 r
F P
0 g
s
.37838 .54682 m .37535 .59963 L .3263 .5757 L p 0 .692 0 r
F P
0 g
s
.25076 .6717 m .2412 .67704 L .2475 .62239 L p 0 .1 0 r
F P
0 g
s
.2475 .62239 m .25686 .61685 L .25076 .6717 L p 0 .1 0 r
F P
0 g
s
.30075 .69287 m .29113 .69796 L .24123 .6771 L p 0 .916 0 r
F P
0 g
s
.23179 .68238 m .24123 .6771 L .29113 .69796 L p 0 .916 0 r
F P
0 g
s
.43074 .51587 m .42007 .52218 L .46564 .54682 L p 0 .914 1 r
F P
0 g
s
.46564 .54682 m .47633 .54082 L .43074 .51587 L p 0 .914 1 r
F P
0 g
s
.47633 .54082 m .46564 .54682 L .46478 .59963 L p 0 .1 .423 r
F P
0 g
s
.41802 .5757 m .42007 .52218 L .46564 .54682 L p 0 .686 .443 r
F P
0 g
s
.45397 .60538 m .46478 .59963 L .46564 .54682 L p 0 .1 .423 r
F P
0 g
s
.46564 .54682 m .46478 .59963 L .41802 .5757 L p 0 .686 .443 r
F P
0 g
s
.41802 .5757 m .42007 .52218 L .46564 .54682 L p 0 .686 .443 r
F P
0 g
s
.46564 .54682 m .46478 .59963 L .41802 .5757 L p 0 .686 .443 r
F P
0 g
s
.29575 .5938 m .28591 .59963 L .29112 .54686 L p 0 .1 .365 r
F P
0 g
s
.29112 .54686 m .30075 .54086 L .29575 .5938 L p 0 .1 .365 r
F P
0 g
s
.5669 .38394 m .56857 .43272 L .55711 .43951 L p 0 .1 .425 r
F P
0 g
s
.5669 .38394 m .56857 .43272 L .61057 .45957 L p 0 .668 .382 r
F P
0 g
s
.65423 .38394 m .61333 .35521 L .60159 .36247 L p 0 .907 0 r
F P
0 g
s
.65423 .38394 m .65808 .43272 L .64607 .43951 L p 0 .1 0 r
F P
0 g
s
.65808 .43272 m .65423 .38394 L .61333 .35521 L p 0 .658 0 r
F P
0 g
s
.61057 .30831 m .61333 .35521 L .65423 .38394 L p 0 .658 0 r
F P
0 g
s
.65423 .38394 m .65808 .43272 L .69787 .45956 L p 0 .658 0 r
F P
0 g
s
.61057 .30831 m .61333 .35521 L .60159 .36247 L p 0 .1 0 r
F P
0 g
s
.6979 .30831 m .70284 .35521 L .69055 .36247 L p 0 .1 .45 r
F P
0 g
s
.6979 .30831 m .70284 .35521 L .74156 .38394 L p 0 .645 .315 r
F P
0 g
s
.6979 .30831 m .65808 .27769 L .64607 .28543 L p 0 .903 1 r
F P
0 g
s
.70284 .35521 m .6979 .30831 L .65808 .27769 L p 0 .645 .315 r
F P
0 g
s
.74156 .38394 m .70284 .35521 L .69055 .36247 L p 0 .907 1 r
F P
0 g
s
.74757 .4327 m .74759 .43269 L .73502 .43948 L p 0 .1 .1 r
F P
0 g
s
.74156 .38394 m .70284 .35521 L p .74757 .4327 L 0 .645 .315 r
F P
0 g
s
.74757 .4327 m .74759 .43269 L .74156 .38394 L p 0 .645 .315 r
F P
0 g
s
.79235 .35521 m .78523 .30835 L .7852 .30829 L p 0 .63 0 r
F P
0 g
s
.7852 .30829 m .74759 .27769 L p .79235 .35521 L 0 .63 0 r
F P
0 g
s
.7852 .30829 m .78523 .30835 L .7937 .30335 L p 0 .575 .884 r
F P
0 g
s
.78523 .30835 m .79235 .35521 L .80106 .35028 L p 0 .114 .472 r
F P
0 g
s
.80106 .35028 m .7937 .30335 L .78523 .30835 L p 0 .114 .472 r
F P
0 g
s
.74759 .27769 m .7852 .30829 L .79367 .30329 L p 0 .903 1 r
F P
0 g
s
.7937 .30335 m .79367 .30329 L .7852 .30829 L p 0 .575 .884 r
F P
0 g
s
.69824 .45935 m .69821 .45937 L .71033 .45282 L p 0 .1 .1 r
F P
0 g
s
.56722 .38374 m .5689 .43253 L .6109 .45939 L p 0 .668 0 r
F P
0 g
s
.5689 .43253 m .56722 .38374 L .57854 .37674 L p 0 .1 0 r
F P
0 g
s
.6109 .45939 m .5689 .43253 L .58051 .42565 L p 0 .911 0 r
F P
0 g
s
.58051 .42565 m .62248 .45284 L .6109 .45939 L p 0 .911 0 r
F P
0 g
s
.65843 .27746 m .69824 .3081 L .71036 .30064 L p 0 .903 0 r
F P
0 g
s
.69824 .3081 m .70319 .355 L .74192 .38374 L p 0 .645 0 r
F P
0 g
s
.69824 .3081 m .70319 .355 L .71564 .34764 L p 0 .1 0 r
F P
0 g
s
.71564 .34764 m .71036 .30064 L .69824 .3081 L p 0 .1 0 r
F P
0 g
s
.70319 .355 m .69824 .3081 L .65843 .27746 L p 0 .645 0 r
F P
0 g
s
.70319 .355 m .69824 .3081 L .71036 .30064 L p 0 .1 0 r
F P
0 g
s
.70319 .355 m .74192 .38374 L .75429 .37674 L p 0 .907 0 r
F P
0 g
s
.74192 .38374 m .74795 .43249 L .76068 .42562 L p 0 .114 0 r
F P
0 g
s
.76068 .42562 m .75429 .37674 L .74192 .38374 L p 0 .114 0 r
F P
0 g
s
.74192 .38374 m .70319 .355 L p .74793 .43251 L 0 .645 0 r
F P
0 g
s
.74793 .43251 m .74795 .43249 L .74192 .38374 L p 0 .645 0 r
F P
0 g
s
.74192 .38374 m .70319 .355 L .71564 .34764 L p 0 .907 0 r
F P
0 g
s
.71564 .34764 m .75429 .37674 L .74192 .38374 L p 0 .907 0 r
F P
0 g
s
.65457 .38374 m .65843 .43253 L .69821 .45937 L p 0 .658 .35 r
F P
0 g
s
.65843 .43253 m .65457 .38374 L .66642 .37674 L p 0 .1 .45 r
F P
0 g
s
.6109 .3081 m .61367 .355 L .65457 .38374 L p 0 .658 .35 r
F P
0 g
s
.61367 .355 m .65457 .38374 L .66642 .37674 L p 0 .907 1 r
F P
0 g
s
.65457 .38374 m .65843 .43253 L .6706 .42565 L p 0 .1 .45 r
F P
0 g
s
.6706 .42565 m .66642 .37674 L .65457 .38374 L p 0 .1 .45 r
F P
0 g
s
.65843 .43253 m .65457 .38374 L .61367 .355 L p 0 .658 .35 r
F P
0 g
s
.61367 .355 m .6109 .3081 L .62248 .30064 L p 0 .1 .425 r
F P
0 g
s
.65457 .38374 m .61367 .355 L .62556 .34764 L p 0 .907 1 r
F P
0 g
s
.62556 .34764 m .66642 .37674 L .65457 .38374 L p 0 .907 1 r
F P
0 g
s
.69821 .45937 m .65843 .43253 L .6706 .42565 L p 0 .911 1 r
F P
0 g
s
.6706 .42565 m .71033 .45282 L .69821 .45937 L p 0 .911 1 r
F P
0 g
s
.21326 .69274 m .20714 .69616 L .20711 .69611 L p 0 .525 .891 r
F P
0 g
s
.20711 .69611 m .21323 .69269 L .21326 .69274 L p 0 .525 .891 r
F P
0 g
s
.4327 .3062 m .43267 .30621 L p .47641 .38194 L 0 .677 0 r
F P
0 g
s
.46491 .43757 m .47582 .43076 L .47641 .38194 L p 0 .1 0 r
F P
0 g
s
.42035 .36039 m .43099 .3531 L .47641 .38194 L p 0 .907 0 r
F P
0 g
s
.47582 .43076 m .47641 .38194 L .43099 .3531 L p 0 .677 0 r
F P
0 g
s
.47641 .38194 m .47582 .43076 L .52015 .4577 L p 0 .677 0 r
F P
0 g
s
.43267 .30621 m .43099 .3531 L .47641 .38194 L p 0 .677 0 r
F P
0 g
s
.46491 .43757 m .47582 .43076 L .52015 .4577 L p 0 .911 0 r
F P
0 g
s
.52015 .30618 m .52066 .3531 L .56389 .38194 L p 0 .668 .382 r
F P
0 g
s
.50947 .36039 m .52066 .3531 L .52015 .30618 L p 0 .1 .396 r
F P
0 g
s
.52066 .3531 m .52015 .30618 L .47585 .27546 L p 0 .668 .382 r
F P
0 g
s
.55403 .43757 m .56549 .43076 L .56389 .38194 L p 0 .1 .423 r
F P
0 g
s
.50947 .36039 m .52066 .3531 L .56389 .38194 L p 0 .907 1 r
F P
0 g
s
.56549 .43076 m .56389 .38194 L .52066 .3531 L p 0 .668 .382 r
F P
0 g
s
.59859 .36039 m .61033 .3531 L .60763 .30618 L p 0 .1 0 r
F P
0 g
s
.61033 .3531 m .60763 .30618 L .56549 .27544 L p 0 .658 0 r
F P
0 g
s
.38893 .38194 m .38615 .43072 L .37579 .43753 L p 0 .1 .365 r
F P
0 g
s
.38618 .43078 m .38615 .43072 L .38893 .38194 L p 0 .684 .437 r
F P
0 g
s
.433 .30598 m .44352 .29849 L .44349 .2985 L p 0 1 .86 r
F P
0 g
s
.44349 .2985 m .43297 .30599 L .433 .30598 L p 0 1 .86 r
F P
0 g
s
.433 .30598 m .43297 .30599 L p .47672 .38174 L 0 .677 .411 r
F P
0 g
s
.35546 .45091 m .35549 .45096 L .34551 .45753 L p 0 .546 .889 r
F P
0 g
s
.34551 .45753 m .34548 .45748 L .35546 .45091 L p 0 .546 .889 r
F P
0 g
s
.47672 .38174 m .47614 .43056 L .52047 .45751 L p 0 .677 .411 r
F P
0 g
s
.4875 .37471 m .47672 .38174 L .47614 .43056 L p 0 .1 .396 r
F P
0 g
s
.43297 .30599 m .43129 .35289 L .47672 .38174 L p 0 .677 .411 r
F P
0 g
s
.47672 .38174 m .4875 .37471 L .44206 .3455 L p 0 .907 1 r
F P
0 g
s
.44206 .3455 m .43129 .35289 L .47672 .38174 L p 0 .907 1 r
F P
0 g
s
.47614 .43056 m .47672 .38174 L .43129 .35289 L p 0 .677 .411 r
F P
0 g
s
.47672 .38174 m .4875 .37471 L .48719 .42366 L p 0 .1 .396 r
F P
0 g
s
.48719 .42366 m .47614 .43056 L .47672 .38174 L p 0 .1 .396 r
F P
0 g
s
.4875 .37471 m .47672 .38174 L .43129 .35289 L p 0 .907 1 r
F P
0 g
s
.53152 .45095 m .52047 .45751 L .47614 .43056 L p 0 .911 1 r
F P
0 g
s
.38648 .43058 m .38645 .43052 L .38922 .38174 L p 0 .684 0 r
F P
0 g
s
.38645 .43052 m .38922 .38174 L .39947 .37471 L p 0 .1 0 r
F P
0 g
s
.39697 .42368 m .44349 .45095 L .43297 .45751 L p 0 .911 0 r
F P
0 g
s
.43297 .45751 m .38648 .43058 L .39697 .42368 L p 0 .911 0 r
F P
0 g
s
.52047 .30596 m .52098 .35289 L .56422 .38174 L p 0 .668 0 r
F P
0 g
s
.52098 .35289 m .52047 .30596 L .47617 .27524 L p 0 .668 0 r
F P
0 g
s
.57553 .37471 m .56422 .38174 L .52098 .35289 L p 0 .907 0 r
F P
0 g
s
.57553 .37471 m .56422 .38174 L .56582 .43056 L p 0 .1 0 r
F P
0 g
s
.56422 .38174 m .57553 .37471 L .53231 .3455 L p 0 .907 0 r
F P
0 g
s
.53231 .3455 m .52098 .35289 L .56422 .38174 L p 0 .907 0 r
F P
0 g
s
.56582 .43056 m .56422 .38174 L .52098 .35289 L p 0 .668 0 r
F P
0 g
s
.52047 .30596 m .53152 .29847 L .53231 .3455 L p 0 .1 0 r
F P
0 g
s
.53231 .3455 m .52098 .35289 L .52047 .30596 L p 0 .1 0 r
F P
0 g
s
.53152 .29847 m .52047 .30596 L .52098 .35289 L p 0 .1 0 r
F P
0 g
s
.52047 .30596 m .53152 .29847 L .48722 .26737 L p 0 .903 0 r
F P
0 g
s
.48722 .26737 m .47617 .27524 L .52047 .30596 L p 0 .903 0 r
F P
0 g
s
.61067 .35289 m .60797 .30596 L .56582 .27522 L p 0 .658 .35 r
F P
0 g
s
.61955 .29847 m .60797 .30596 L .61067 .35289 L p 0 .1 .423 r
F P
0 g
s
.60797 .30596 m .61955 .29847 L .57744 .26734 L p 0 .903 1 r
F P
0 g
s
.57744 .26734 m .56582 .27522 L .60797 .30596 L p 0 .903 1 r
F P
0 g
s
.43297 .30599 m .44349 .2985 L .44206 .3455 L p 0 .1 .365 r
F P
0 g
s
.44206 .3455 m .43129 .35289 L .43297 .30599 L p 0 .1 .365 r
F P
0 g
s
.43568 .61845 m .43407 .67328 L .4234 .67861 L p 0 .1 0 r
F P
0 g
s
.55731 .60129 m .56882 .59549 L .56713 .54255 L p 0 .1 0 r
F P
0 g
s
.56882 .59549 m .56713 .54255 L .5239 .51769 L p 0 .677 0 r
F P
0 g
s
.56713 .54255 m .56882 .59549 L .61095 .61845 L p 0 .677 0 r
F P
0 g
s
.55731 .60129 m .56882 .59549 L .61095 .61845 L p 0 .916 0 r
F P
0 g
s
.60195 .67857 m .61373 .67324 L .61095 .61845 L p 0 .114 0 r
F P
0 g
s
.61373 .67324 m .61095 .61845 L .56882 .59549 L p 0 .677 0 r
F P
0 g
s
.52332 .61845 m .47899 .59549 L .46804 .60129 L p 0 .916 1 r
F P
0 g
s
.52332 .61845 m .5239 .67328 L .51267 .67861 L p 0 .1 .45 r
F P
0 g
s
.47845 .65114 m .47899 .59549 L .52332 .61845 L p 0 .684 .437 r
F P
0 g
s
.52332 .61845 m .5239 .67328 L .47845 .65114 L p 0 .684 .437 r
F P
0 g
s
.4795 .54255 m .47899 .59549 L .46804 .60129 L p 0 .1 .425 r
F P
0 g
s
.64659 .60129 m .65865 .59549 L .65477 .54259 L p 0 .114 .472 r
F P
0 g
s
.65477 .54259 m .65474 .54254 L .61373 .51769 L p 0 .668 .382 r
F P
0 g
s
.65865 .59549 m .65477 .54259 L p .61373 .51769 L 0 .668 .382 r
F P
0 g
s
.56746 .69416 m .56743 .69418 L .57879 .68905 L p 0 .1 0 r
F P
0 g
s
.56746 .54238 m .57882 .53632 L .5356 .51114 L p 0 .914 1 r
F P
0 g
s
.5356 .51114 m .52423 .51751 L .56746 .54238 L p 0 .914 1 r
F P
0 g
s
.56746 .54238 m .56915 .59532 L .61128 .61829 L p 0 .677 .411 r
F P
0 g
s
.57882 .53632 m .56746 .54238 L .56915 .59532 L p 0 .1 .45 r
F P
0 g
s
.56915 .59532 m .56746 .54238 L .52423 .51751 L p 0 .677 .411 r
F P
0 g
s
.56746 .54238 m .57882 .53632 L .5808 .58944 L p 0 .1 .45 r
F P
0 g
s
.5808 .58944 m .56915 .59532 L .56746 .54238 L p 0 .1 .45 r
F P
0 g
s
.62291 .61269 m .61128 .61829 L .56915 .59532 L p 0 .916 1 r
F P
0 g
s
.61128 .61829 m .62291 .61269 L .5808 .58944 L p 0 .916 1 r
F P
0 g
s
.5808 .58944 m .56915 .59532 L .61128 .61829 L p 0 .916 1 r
F P
0 g
s
.62291 .61269 m .61128 .61829 L .61407 .67309 L p 0 .114 .472 r
F P
0 g
s
.61407 .67309 m .61128 .61829 L .56915 .59532 L p 0 .677 .411 r
F P
0 g
s
.43438 .67313 m .43598 .61829 L .44654 .61269 L p 0 .1 .425 r
F P
0 g
s
.44519 .66773 m .49063 .68906 L .47981 .6942 L p 0 .916 1 r
F P
0 g
s
.47981 .6942 m .43438 .67313 L .44519 .66773 L p 0 .916 1 r
F P
0 g
s
.4793 .59532 m .52363 .61829 L .53472 .61269 L p 0 .916 0 r
F P
0 g
s
.5356 .66773 m .53472 .61269 L .52363 .61829 L p 0 .1 0 r
F P
0 g
s
.52363 .61829 m .52423 .67313 L .5356 .66773 L p 0 .1 0 r
F P
0 g
s
.47877 .65098 m .4793 .59532 L .52363 .61829 L p 0 .684 0 r
F P
0 g
s
.52363 .61829 m .52423 .67313 L .47877 .65098 L p 0 .684 0 r
F P
0 g
s
.52423 .67313 m .52363 .61829 L .53472 .61269 L p 0 .1 0 r
F P
0 g
s
.49039 .58944 m .53472 .61269 L .52363 .61829 L p 0 .916 0 r
F P
0 g
s
.52363 .61829 m .4793 .59532 L .49039 .58944 L p 0 .916 0 r
F P
0 g
s
.4793 .59532 m .47981 .54238 L .49063 .53632 L p 0 .1 0 r
F P
0 g
s
.65511 .54242 m .65508 .54236 L .61407 .51751 L p 0 .668 0 r
F P
0 g
s
.659 .59532 m .65511 .54242 L p .61407 .51751 L 0 .668 0 r
F P
0 g
s
.667 .53636 m .65511 .54242 L .659 .59532 L p 0 .114 0 r
F P
0 g
s
.65511 .54242 m .667 .53636 L .66697 .5363 L p 0 .562 0 r
F P
0 g
s
.66697 .5363 m .65508 .54236 L .65511 .54242 L p 0 .562 0 r
F P
0 g
s
.65508 .54236 m .66697 .5363 L .62601 .51114 L p 0 .914 0 r
F P
0 g
s
.62601 .51114 m .61407 .51751 L .65508 .54236 L p 0 .914 0 r
F P
0 g
s
.5356 .66773 m .57879 .68905 L .56743 .69418 L p 0 .916 0 r
F P
0 g
s
.56743 .69418 m .52423 .67313 L .5356 .66773 L p 0 .916 0 r
F P
0 g
s
.79367 .30329 m .7937 .30335 L .80224 .2983 L p 0 .575 .884 r
F P
0 g
s
.7937 .30335 m .80106 .35028 L .80985 .3453 L p 0 .114 .472 r
F P
0 g
s
.80985 .3453 m .80224 .2983 L .7937 .30335 L p 0 .114 .472 r
F P
0 g
s
.75612 .27243 m .79367 .30329 L .80221 .29825 L p 0 .903 1 r
F P
0 g
s
.80224 .2983 m .80221 .29825 L .79367 .30329 L p 0 .575 .884 r
F P
0 g
s
.80106 .35028 m .7937 .30335 L .79367 .30329 L p 0 .627 .269 r
F P
0 g
s
.80106 .35028 m .7937 .30335 L .79367 .30329 L p 0 .627 .269 r
F P
0 g
s
.79367 .30329 m .75612 .27243 L .74759 .27769 L p 0 .903 1 r
F P
0 g
s
.79367 .30329 m .75612 .27243 L p .80106 .35028 L 0 .627 .269 r
F P
0 g
s
.79367 .30329 m .75612 .27243 L p .80106 .35028 L 0 .627 .269 r
F P
0 g
s
.33063 .67708 m .34074 .67174 L .34465 .61685 L p 0 .1 .396 r
F P
0 g
s
.33063 .67708 m .34074 .67174 L .38854 .69287 L p 0 .916 1 r
F P
0 g
s
.28591 .59963 m .29575 .5938 L .34465 .61685 L p 0 .916 1 r
F P
0 g
s
.29049 .64947 m .29575 .5938 L .34465 .61685 L p 0 .695 .481 r
F P
0 g
s
.29052 .64953 m .29049 .64947 L p .34465 .61685 L 0 .695 .481 r
F P
0 g
s
.34465 .61685 m .34074 .67174 L .29052 .64953 L p 0 .695 .481 r
F P
0 g
s
.24123 .6771 m .25079 .67175 L .30075 .69287 L p 0 .916 0 r
F P
0 g
s
.42007 .67708 m .43074 .67174 L .43243 .61685 L p 0 .1 0 r
F P
0 g
s
.37535 .59963 m .38574 .5938 L .43243 .61685 L p 0 .916 0 r
F P
0 g
s
.3828 .64951 m .38574 .5938 L .43243 .61685 L p 0 .69 0 r
F P
0 g
s
.43243 .61685 m .43074 .67174 L .3828 .64951 L p 0 .69 0 r
F P
0 g
s
.37535 .59963 m .38574 .5938 L .38854 .54082 L p 0 .1 0 r
F P
0 g
s
.33067 .52219 m .34078 .51588 L .34074 .5159 L p 0 .93 0 r
F P
0 g
s
.34074 .5159 m .34078 .51588 L .38854 .54082 L p 0 .69 0 r
F P
0 g
s
.33664 .56957 m .34074 .5159 L p .38854 .54082 L 0 .69 0 r
F P
0 g
s
.38854 .54082 m .38574 .5938 L .33664 .56957 L p 0 .69 0 r
F P
0 g
s
.46478 .59963 m .47573 .5938 L .47633 .54082 L p 0 .1 .423 r
F P
0 g
s
.42895 .56957 m .43074 .51587 L .47633 .54082 L p 0 .684 .437 r
F P
0 g
s
.47633 .54082 m .47573 .5938 L .42895 .56957 L p 0 .684 .437 r
F P
0 g
s
.31077 .5346 m .30103 .54068 L .30107 .54066 L p 0 .93 0 r
F P
0 g
s
.22247 .68759 m .21326 .69274 L .21323 .69269 L p 0 .525 0 r
F P
0 g
s
.21323 .69269 m .22244 .68754 L .22247 .68759 L p 0 .525 0 r
F P
0 g
s
.26071 .66613 m .25103 .67154 L .25713 .61669 L p 0 .1 .365 r
F P
0 g
s
.25713 .61669 m .26661 .61107 L .26071 .66613 L p 0 .1 .365 r
F P
0 g
s
.31078 .68758 m .30103 .69273 L .25107 .6716 L p 0 .916 1 r
F P
0 g
s
.39912 .68758 m .38883 .69273 L .34104 .67158 L p 0 .916 0 r
F P
0 g
s
.35128 .66617 m .34104 .67158 L .34493 .61669 L p 0 .1 0 r
F P
0 g
s
.34493 .61669 m .35495 .61107 L .35128 .66617 L p 0 .1 0 r
F P
0 g
s
.35495 .61107 m .34493 .61669 L .29603 .59363 L p 0 .916 0 r
F P
0 g
s
.30599 .58773 m .29603 .59363 L .34493 .61669 L p 0 .916 0 r
F P
0 g
s
.34493 .61669 m .35495 .61107 L .30599 .58773 L p 0 .916 0 r
F P
0 g
s
.35495 .61107 m .34493 .61669 L .34104 .67158 L p 0 .1 0 r
F P
0 g
s
.29078 .64931 m .29603 .59363 L .34493 .61669 L p 0 .695 0 r
F P
0 g
s
.29082 .64937 m .29078 .64931 L p .34493 .61669 L 0 .695 0 r
F P
0 g
s
.34493 .61669 m .34104 .67158 L .29082 .64937 L p 0 .695 0 r
F P
0 g
s
.39657 .58773 m .38604 .59363 L .43274 .61669 L p 0 .916 1 r
F P
0 g
s
.43274 .61669 m .44329 .61107 L .39657 .58773 L p 0 .916 1 r
F P
0 g
s
.44329 .61107 m .43274 .61669 L .43105 .67158 L p 0 .1 .423 r
F P
0 g
s
.38311 .64935 m .38604 .59363 L .43274 .61669 L p 0 .69 .46 r
F P
0 g
s
.43274 .61669 m .43105 .67158 L .38311 .64935 L p 0 .69 .46 r
F P
0 g
s
.39657 .58773 m .38604 .59363 L .38883 .54065 L p 0 .1 .396 r
F P
0 g
s
.38883 .54065 m .39912 .53456 L .39657 .58773 L p 0 .1 .396 r
F P
0 g
s
.35132 .50931 m .34107 .5157 L .38883 .54065 L p 0 .914 1 r
F P
0 g
s
.38883 .54065 m .39912 .53456 L .35132 .50931 L p 0 .914 1 r
F P
0 g
s
.39912 .53456 m .38883 .54065 L .38604 .59363 L p 0 .1 .396 r
F P
0 g
s
.34103 .51572 m .34107 .5157 L .38883 .54065 L p 0 .69 .46 r
F P
0 g
s
.33694 .56939 m .34103 .51572 L p .38883 .54065 L 0 .69 .46 r
F P
0 g
s
.38883 .54065 m .38604 .59363 L .33694 .56939 L p 0 .69 .46 r
F P
0 g
s
.44329 .61107 m .43274 .61669 L .38604 .59363 L p 0 .916 1 r
F P
0 g
s
.44185 .50929 m .43105 .51568 L .47664 .54065 L p 0 .914 0 r
F P
0 g
s
.47664 .54065 m .48746 .53456 L .44185 .50929 L p 0 .914 0 r
F P
0 g
s
.48746 .53456 m .47664 .54065 L .47605 .59363 L p 0 .1 0 r
F P
0 g
s
.42927 .56939 m .43105 .51568 L .47664 .54065 L p 0 .684 0 r
F P
0 g
s
.47664 .54065 m .47605 .59363 L .42927 .56939 L p 0 .684 0 r
F P
0 g
s
.30599 .58773 m .29603 .59363 L .30103 .54068 L p 0 .1 0 r
F P
0 g
s
.30103 .54068 m .31077 .5346 L .30599 .58773 L p 0 .1 0 r
F P
0 g
s
.71035 .45281 m .71033 .45282 L .72259 .4462 L p 0 .1 .1 r
F P
0 g
s
.71036 .30064 m .6706 .26962 L .65843 .27746 L p 0 .903 0 r
F P
0 g
s
.71036 .30064 m .71564 .34764 L .70319 .355 L p 0 .1 0 r
F P
0 g
s
.71564 .34764 m .71036 .30064 L .6706 .26962 L p 0 .641 0 r
F P
0 g
s
.6706 .26962 m .71036 .30064 L .72262 .29308 L p 0 .903 0 r
F P
0 g
s
.71036 .30064 m .71564 .34764 L .75429 .37674 L p 0 .641 0 r
F P
0 g
s
.71036 .30064 m .71564 .34764 L .75429 .37674 L p 0 .641 0 r
F P
0 g
s
.71036 .30064 m .71564 .34764 L .72825 .34018 L p 0 .1 0 r
F P
0 g
s
.72825 .34018 m .72262 .29308 L .71036 .30064 L p 0 .1 0 r
F P
0 g
s
.71564 .34764 m .71036 .30064 L .6706 .26962 L p 0 .641 0 r
F P
0 g
s
.71564 .34764 m .71036 .30064 L .72262 .29308 L p 0 .1 0 r
F P
0 g
s
.75429 .37674 m .71564 .34764 L .70319 .355 L p 0 .907 0 r
F P
0 g
s
.76066 .42563 m .76068 .42562 L .74795 .43249 L p 0 .1 0 r
F P
0 g
s
.75429 .37674 m .71564 .34764 L p .76066 .42563 L 0 .641 0 r
F P
0 g
s
.76066 .42563 m .76068 .42562 L .75429 .37674 L p 0 .641 0 r
F P
0 g
s
.71564 .34764 m .75429 .37674 L .76682 .36965 L p 0 .907 0 r
F P
0 g
s
.75429 .37674 m .76068 .42562 L .77357 .41865 L p 0 .114 0 r
F P
0 g
s
.77357 .41865 m .76682 .36965 L .75429 .37674 L p 0 .114 0 r
F P
0 g
s
.75429 .37674 m .71564 .34764 L p .76066 .42563 L 0 .641 0 r
F P
0 g
s
.76066 .42563 m .76068 .42562 L .75429 .37674 L p 0 .641 0 r
F P
0 g
s
.75429 .37674 m .71564 .34764 L .72825 .34018 L p 0 .907 0 r
F P
0 g
s
.72825 .34018 m .76682 .36965 L .75429 .37674 L p 0 .907 0 r
F P
0 g
s
.57854 .37674 m .58051 .42565 L .62248 .45284 L p 0 .666 0 r
F P
0 g
s
.57854 .37674 m .58051 .42565 L .62248 .45284 L p 0 .666 0 r
F P
0 g
s
.58051 .42565 m .57854 .37674 L .58999 .36965 L p 0 .1 0 r
F P
0 g
s
.62248 .45284 m .58051 .42565 L .59227 .41869 L p 0 .911 0 r
F P
0 g
s
.59227 .41869 m .6342 .44622 L .62248 .45284 L p 0 .911 0 r
F P
0 g
s
.57854 .37674 m .58051 .42565 L .5689 .43253 L p 0 .1 0 r
F P
0 g
s
.66642 .37674 m .6706 .42565 L .65843 .43253 L p 0 .1 .45 r
F P
0 g
s
.66642 .37674 m .6706 .42565 L .71033 .45282 L p 0 .655 .342 r
F P
0 g
s
.66642 .37674 m .6706 .42565 L .71033 .45282 L p 0 .655 .342 r
F P
0 g
s
.66642 .37674 m .62556 .34764 L .61367 .355 L p 0 .907 1 r
F P
0 g
s
.6706 .42565 m .66642 .37674 L .62556 .34764 L p 0 .655 .342 r
F P
0 g
s
.6706 .42565 m .66642 .37674 L .62556 .34764 L p 0 .655 .342 r
F P
0 g
s
.62248 .30064 m .62556 .34764 L .61367 .355 L p 0 .1 .425 r
F P
0 g
s
.62248 .30064 m .62556 .34764 L .66642 .37674 L p 0 .655 .342 r
F P
0 g
s
.62248 .30064 m .62556 .34764 L .66642 .37674 L p 0 .655 .342 r
F P
0 g
s
.62556 .34764 m .62248 .30064 L .6342 .29308 L p 0 .1 .425 r
F P
0 g
s
.6706 .42565 m .66642 .37674 L .67841 .36965 L p 0 .1 .45 r
F P
0 g
s
.62556 .34764 m .66642 .37674 L .67841 .36965 L p 0 .907 1 r
F P
0 g
s
.66642 .37674 m .6706 .42565 L .68292 .41869 L p 0 .1 .45 r
F P
0 g
s
.68292 .41869 m .67841 .36965 L .66642 .37674 L p 0 .1 .45 r
F P
0 g
s
.66642 .37674 m .62556 .34764 L .6376 .34018 L p 0 .907 1 r
F P
0 g
s
.6376 .34018 m .67841 .36965 L .66642 .37674 L p 0 .907 1 r
F P
0 g
s
.71033 .45282 m .6706 .42565 L .68292 .41869 L p 0 .911 1 r
F P
0 g
s
.68292 .41869 m .72259 .4462 L .71033 .45282 L p 0 .911 1 r
F P
0 g
s
.44352 .29849 m .44349 .2985 L p .4875 .37471 L 0 .675 .404 r
F P
0 g
s
.44352 .29849 m .45417 .29091 L .45413 .29092 L p 0 1 .86 r
F P
0 g
s
.45413 .29092 m .44349 .2985 L .44352 .29849 L p 0 1 .86 r
F P
0 g
s
.44352 .29849 m .44349 .2985 L p .4875 .37471 L 0 .675 .404 r
F P
0 g
s
.36556 .44426 m .3656 .44432 L .35549 .45096 L p 0 .546 .889 r
F P
0 g
s
.35549 .45096 m .35546 .45091 L .36556 .44426 L p 0 .546 .889 r
F P
0 g
s
.4875 .37471 m .48719 .42366 L .53152 .45095 L p 0 .675 .404 r
F P
0 g
s
.4875 .37471 m .48719 .42366 L .53152 .45095 L p 0 .675 .404 r
F P
0 g
s
.4875 .37471 m .49842 .36759 L .49838 .41667 L p 0 .1 .396 r
F P
0 g
s
.49838 .41667 m .48719 .42366 L .4875 .37471 L p 0 .1 .396 r
F P
0 g
s
.47614 .43056 m .48719 .42366 L .4875 .37471 L p 0 .1 .396 r
F P
0 g
s
.43129 .35289 m .44206 .3455 L .4875 .37471 L p 0 .907 1 r
F P
0 g
s
.48719 .42366 m .4875 .37471 L .44206 .3455 L p 0 .675 .404 r
F P
0 g
s
.49842 .36759 m .4875 .37471 L .48719 .42366 L p 0 .1 .396 r
F P
0 g
s
.44349 .2985 m .44206 .3455 L .4875 .37471 L p 0 .675 .404 r
F P
0 g
s
.44349 .2985 m .44206 .3455 L .4875 .37471 L p 0 .675 .404 r
F P
0 g
s
.4875 .37471 m .49842 .36759 L .45297 .33802 L p 0 .907 1 r
F P
0 g
s
.45297 .33802 m .44206 .3455 L .4875 .37471 L p 0 .907 1 r
F P
0 g
s
.48719 .42366 m .4875 .37471 L .44206 .3455 L p 0 .675 .404 r
F P
0 g
s
.49842 .36759 m .4875 .37471 L .44206 .3455 L p 0 .907 1 r
F P
0 g
s
.47614 .43056 m .48719 .42366 L .53152 .45095 L p 0 .911 1 r
F P
0 g
s
.5427 .4443 m .53152 .45095 L .48719 .42366 L p 0 .911 1 r
F P
0 g
s
.39697 .42368 m .39694 .42362 L .39947 .37471 L p 0 .683 0 r
F P
0 g
s
.39697 .42368 m .39694 .42362 L .39947 .37471 L p 0 .683 0 r
F P
0 g
s
.39694 .42362 m .39947 .37471 L .40985 .36759 L p 0 .1 0 r
F P
0 g
s
.39947 .37471 m .39694 .42362 L .38645 .43052 L p 0 .1 0 r
F P
0 g
s
.4076 .41669 m .45413 .4443 L .44349 .45095 L p 0 .911 0 r
F P
0 g
s
.44349 .45095 m .39697 .42368 L .4076 .41669 L p 0 .911 0 r
F P
0 g
s
.58699 .36759 m .57553 .37471 L .57744 .42366 L p 0 .1 0 r
F P
0 g
s
.53152 .29847 m .53231 .3455 L .57553 .37471 L p 0 .666 0 r
F P
0 g
s
.53152 .29847 m .53231 .3455 L .57553 .37471 L p 0 .666 0 r
F P
0 g
s
.57553 .37471 m .58699 .36759 L .54379 .33802 L p 0 .907 0 r
F P
0 g
s
.54379 .33802 m .53231 .3455 L .57553 .37471 L p 0 .907 0 r
F P
0 g
s
.52098 .35289 m .53231 .3455 L .57553 .37471 L p 0 .907 0 r
F P
0 g
s
.53152 .29847 m .5427 .29089 L .54379 .33802 L p 0 .1 0 r
F P
0 g
s
.54379 .33802 m .53231 .3455 L .53152 .29847 L p 0 .1 0 r
F P
0 g
s
.52098 .35289 m .53231 .3455 L .53152 .29847 L p 0 .1 0 r
F P
0 g
s
.53231 .3455 m .53152 .29847 L .48722 .26737 L p 0 .666 0 r
F P
0 g
s
.5427 .29089 m .53152 .29847 L .53231 .3455 L p 0 .1 0 r
F P
0 g
s
.53152 .29847 m .5427 .29089 L .49841 .2594 L p 0 .903 0 r
F P
0 g
s
.49841 .2594 m .48722 .26737 L .53152 .29847 L p 0 .903 0 r
F P
0 g
s
.53231 .3455 m .53152 .29847 L .48722 .26737 L p 0 .666 0 r
F P
0 g
s
.56582 .43056 m .57744 .42366 L .57553 .37471 L p 0 .1 0 r
F P
0 g
s
.57744 .42366 m .57553 .37471 L .53231 .3455 L p 0 .666 0 r
F P
0 g
s
.57744 .42366 m .57553 .37471 L .53231 .3455 L p 0 .666 0 r
F P
0 g
s
.58699 .36759 m .57553 .37471 L .53231 .3455 L p 0 .907 0 r
F P
0 g
s
.61067 .35289 m .62256 .3455 L .61955 .29847 L p 0 .1 .423 r
F P
0 g
s
.62256 .3455 m .61955 .29847 L .57744 .26734 L p 0 .655 .342 r
F P
0 g
s
.63127 .29089 m .61955 .29847 L .62256 .3455 L p 0 .1 .423 r
F P
0 g
s
.61955 .29847 m .63127 .29089 L .58919 .25937 L p 0 .903 1 r
F P
0 g
s
.58919 .25937 m .57744 .26734 L .61955 .29847 L p 0 .903 1 r
F P
0 g
s
.62256 .3455 m .61955 .29847 L .57744 .26734 L p 0 .655 .342 r
F P
0 g
s
.44349 .2985 m .45413 .29092 L .45297 .33802 L p 0 .1 .365 r
F P
0 g
s
.45297 .33802 m .44206 .3455 L .44349 .2985 L p 0 .1 .365 r
F P
0 g
s
.80985 .3453 m .80224 .2983 L .80221 .29825 L p 0 .624 .261 r
F P
0 g
s
.80221 .29825 m .80224 .2983 L .81085 .29322 L p 0 .575 .884 r
F P
0 g
s
.80224 .2983 m .80985 .3453 L .81871 .34029 L p 0 .114 .472 r
F P
0 g
s
.81871 .34029 m .81085 .29322 L .80224 .2983 L p 0 .114 .472 r
F P
0 g
s
.80985 .3453 m .80224 .2983 L .80221 .29825 L p 0 .624 .261 r
F P
0 g
s
.80221 .29825 m .76472 .26713 L .75612 .27243 L p 0 .903 1 r
F P
0 g
s
.80221 .29825 m .76472 .26713 L p .80985 .3453 L 0 .624 .261 r
F P
0 g
s
.76472 .26713 m .80221 .29825 L .81082 .29317 L p 0 .903 1 r
F P
0 g
s
.81085 .29322 m .81082 .29317 L .80221 .29825 L p 0 .575 .884 r
F P
0 g
s
.80221 .29825 m .76472 .26713 L p .80985 .3453 L 0 .624 .261 r
F P
0 g
s
.57881 .68902 m .57879 .68905 L .59028 .68385 L p 0 .1 0 r
F P
0 g
s
.56915 .59532 m .5808 .58944 L .57882 .53632 L p 0 .1 .45 r
F P
0 g
s
.5808 .58944 m .57882 .53632 L .5356 .51114 L p 0 .675 .404 r
F P
0 g
s
.57882 .53632 m .59031 .53019 L .54711 .50469 L p 0 .914 1 r
F P
0 g
s
.54711 .50469 m .5356 .51114 L .57882 .53632 L p 0 .914 1 r
F P
0 g
s
.57882 .53632 m .5808 .58944 L .62291 .61269 L p 0 .675 .404 r
F P
0 g
s
.57882 .53632 m .5808 .58944 L .62291 .61269 L p 0 .675 .404 r
F P
0 g
s
.59031 .53019 m .57882 .53632 L .5808 .58944 L p 0 .1 .45 r
F P
0 g
s
.5808 .58944 m .57882 .53632 L .5356 .51114 L p 0 .675 .404 r
F P
0 g
s
.56915 .59532 m .5808 .58944 L .62291 .61269 L p 0 .916 1 r
F P
0 g
s
.63468 .60703 m .62291 .61269 L .5808 .58944 L p 0 .916 1 r
F P
0 g
s
.57882 .53632 m .59031 .53019 L .5926 .58348 L p 0 .1 .45 r
F P
0 g
s
.5926 .58348 m .5808 .58944 L .57882 .53632 L p 0 .1 .45 r
F P
0 g
s
.61407 .67309 m .62601 .66769 L .62291 .61269 L p 0 .114 .472 r
F P
0 g
s
.62601 .66769 m .62291 .61269 L .5808 .58944 L p 0 .675 .404 r
F P
0 g
s
.62291 .61269 m .63468 .60703 L .5926 .58348 L p 0 .916 1 r
F P
0 g
s
.5926 .58348 m .5808 .58944 L .62291 .61269 L p 0 .916 1 r
F P
0 g
s
.63468 .60703 m .62291 .61269 L .62601 .66769 L p 0 .114 .472 r
F P
0 g
s
.62601 .66769 m .62291 .61269 L .5808 .58944 L p 0 .675 .404 r
F P
0 g
s
.50162 .58348 m .54595 .60703 L .53472 .61269 L p 0 .916 0 r
F P
0 g
s
.53472 .61269 m .49039 .58944 L .50162 .58348 L p 0 .916 0 r
F P
0 g
s
.49039 .58944 m .53472 .61269 L .54595 .60703 L p 0 .916 0 r
F P
0 g
s
.54711 .66227 m .54595 .60703 L .53472 .61269 L p 0 .1 0 r
F P
0 g
s
.53472 .61269 m .5356 .66773 L .54711 .66227 L p 0 .1 0 r
F P
0 g
s
.53472 .61269 m .49039 .58944 L .4793 .59532 L p 0 .916 0 r
F P
0 g
s
.49015 .6453 m .49039 .58944 L .53472 .61269 L p 0 .683 0 r
F P
0 g
s
.53472 .61269 m .5356 .66773 L .52423 .67313 L p 0 .1 0 r
F P
0 g
s
.53472 .61269 m .5356 .66773 L .49015 .6453 L p 0 .683 0 r
F P
0 g
s
.49015 .6453 m .49039 .58944 L .53472 .61269 L p 0 .683 0 r
F P
0 g
s
.53472 .61269 m .5356 .66773 L .49015 .6453 L p 0 .683 0 r
F P
0 g
s
.5356 .66773 m .53472 .61269 L .54595 .60703 L p 0 .1 0 r
F P
0 g
s
.49039 .58944 m .49063 .53632 L .50158 .53019 L p 0 .1 0 r
F P
0 g
s
.49063 .53632 m .49039 .58944 L .4793 .59532 L p 0 .1 0 r
F P
0 g
s
.45613 .66227 m .50158 .68387 L .49063 .68906 L p 0 .916 1 r
F P
0 g
s
.49063 .68906 m .44519 .66773 L .45613 .66227 L p 0 .916 1 r
F P
0 g
s
.44519 .66773 m .44654 .61269 L .45722 .60703 L p 0 .1 .425 r
F P
0 g
s
.44654 .61269 m .44519 .66773 L .43438 .67313 L p 0 .1 .425 r
F P
0 g
s
.659 .59532 m .67121 .58944 L .667 .53636 L p 0 .114 0 r
F P
0 g
s
.667 .53636 m .66697 .5363 L .62601 .51114 L p 0 .666 0 r
F P
0 g
s
.67121 .58944 m .667 .53636 L p .62601 .51114 L 0 .666 0 r
F P
0 g
s
.66697 .5363 m .67901 .53017 L .63809 .50469 L p 0 .914 0 r
F P
0 g
s
.63809 .50469 m .62601 .51114 L .66697 .5363 L p 0 .914 0 r
F P
0 g
s
.67904 .53022 m .667 .53636 L .67121 .58944 L p 0 .114 0 r
F P
0 g
s
.667 .53636 m .67904 .53022 L .67901 .53017 L p 0 .562 0 r
F P
0 g
s
.67901 .53017 m .66697 .5363 L .667 .53636 L p 0 .562 0 r
F P
0 g
s
.667 .53636 m .66697 .5363 L .62601 .51114 L p 0 .666 0 r
F P
0 g
s
.67121 .58944 m .667 .53636 L p .62601 .51114 L 0 .666 0 r
F P
0 g
s
.54711 .66227 m .59028 .68385 L .57879 .68905 L p 0 .916 0 r
F P
0 g
s
.57879 .68905 m .5356 .66773 L .54711 .66227 L p 0 .916 0 r
F P
0 g
s
.32064 .52845 m .31077 .5346 L .31081 .53458 L p 0 .93 0 r
F P
0 g
s
.23179 .68238 m .22247 .68759 L .22244 .68754 L p 0 .525 0 r
F P
0 g
s
.22244 .68754 m .23176 .68232 L .23179 .68238 L p 0 .525 0 r
F P
0 g
s
.27051 .66065 m .26071 .66613 L .26661 .61107 L p 0 .1 .365 r
F P
0 g
s
.26661 .61107 m .2762 .60538 L .27051 .66065 L p 0 .1 .365 r
F P
0 g
s
.32064 .68236 m .31078 .68758 L .26074 .66619 L p 0 .916 1 r
F P
0 g
s
.25107 .6716 m .26074 .66619 L .31078 .68758 L p 0 .916 1 r
F P
0 g
s
.34104 .67158 m .35128 .66617 L .39912 .68758 L p 0 .916 0 r
F P
0 g
s
.36165 .66069 m .35128 .66617 L .35495 .61107 L p 0 .1 0 r
F P
0 g
s
.35495 .61107 m .36509 .60538 L .36165 .66069 L p 0 .1 0 r
F P
0 g
s
.29603 .59363 m .30599 .58773 L .35495 .61107 L p 0 .916 0 r
F P
0 g
s
.34104 .67158 m .35128 .66617 L .35495 .61107 L p 0 .1 0 r
F P
0 g
s
.40953 .68236 m .39912 .68758 L .35128 .66617 L p 0 .916 0 r
F P
0 g
s
.36509 .60538 m .35495 .61107 L .30599 .58773 L p 0 .916 0 r
F P
0 g
s
.31608 .58175 m .30599 .58773 L .35495 .61107 L p 0 .916 0 r
F P
0 g
s
.35495 .61107 m .36509 .60538 L .31608 .58175 L p 0 .916 0 r
F P
0 g
s
.36509 .60538 m .35495 .61107 L .35128 .66617 L p 0 .1 0 r
F P
0 g
s
.30097 .64361 m .30599 .58773 L .35495 .61107 L p 0 .694 0 r
F P
0 g
s
.301 .64367 m .30097 .64361 L p .35495 .61107 L 0 .694 0 r
F P
0 g
s
.35495 .61107 m .35128 .66617 L .301 .64367 L p 0 .694 0 r
F P
0 g
s
.30097 .64361 m .30599 .58773 L .35495 .61107 L p 0 .694 0 r
F P
0 g
s
.301 .64367 m .30097 .64361 L p .35495 .61107 L 0 .694 0 r
F P
0 g
s
.35495 .61107 m .35128 .66617 L .301 .64367 L p 0 .694 0 r
F P
0 g
s
.4528 .50282 m .44185 .50929 L .48746 .53456 L p 0 .914 0 r
F P
0 g
s
.48746 .53456 m .49841 .52841 L .4528 .50282 L p 0 .914 0 r
F P
0 g
s
.49841 .52841 m .48746 .53456 L .48714 .58773 L p 0 .1 0 r
F P
0 g
s
.44035 .56318 m .44185 .50929 L .48746 .53456 L p 0 .683 0 r
F P
0 g
s
.47605 .59363 m .48714 .58773 L .48746 .53456 L p 0 .1 0 r
F P
0 g
s
.48746 .53456 m .48714 .58773 L .44035 .56318 L p 0 .683 0 r
F P
0 g
s
.44035 .56318 m .44185 .50929 L .48746 .53456 L p 0 .683 0 r
F P
0 g
s
.48746 .53456 m .48714 .58773 L .44035 .56318 L p 0 .683 0 r
F P
0 g
s
.40723 .58175 m .39657 .58773 L .44329 .61107 L p 0 .916 1 r
F P
0 g
s
.44329 .61107 m .45397 .60538 L .40723 .58175 L p 0 .916 1 r
F P
0 g
s
.45397 .60538 m .44329 .61107 L .44185 .66617 L p 0 .1 .423 r
F P
0 g
s
.38604 .59363 m .39657 .58773 L .44329 .61107 L p 0 .916 1 r
F P
0 g
s
.39389 .64365 m .39657 .58773 L .44329 .61107 L p 0 .689 .454 r
F P
0 g
s
.43105 .67158 m .44185 .66617 L .44329 .61107 L p 0 .1 .423 r
F P
0 g
s
.44329 .61107 m .44185 .66617 L .39389 .64365 L p 0 .689 .454 r
F P
0 g
s
.39389 .64365 m .39657 .58773 L .44329 .61107 L p 0 .689 .454 r
F P
0 g
s
.44329 .61107 m .44185 .66617 L .39389 .64365 L p 0 .689 .454 r
F P
0 g
s
.45397 .60538 m .44329 .61107 L .39657 .58773 L p 0 .916 1 r
F P
0 g
s
.40723 .58175 m .39657 .58773 L .39912 .53456 L p 0 .1 .396 r
F P
0 g
s
.39912 .53456 m .40953 .52841 L .40723 .58175 L p 0 .1 .396 r
F P
0 g
s
.36169 .50284 m .35132 .50931 L .39912 .53456 L p 0 .914 1 r
F P
0 g
s
.39912 .53456 m .40953 .52841 L .36169 .50284 L p 0 .914 1 r
F P
0 g
s
.40953 .52841 m .39912 .53456 L .39657 .58773 L p 0 .1 .396 r
F P
0 g
s
.34107 .5157 m .35132 .50931 L .35128 .50933 L p 0 .93 .764 r
F P
0 g
s
.35128 .50933 m .35132 .50931 L .39912 .53456 L p 0 .689 .454 r
F P
0 g
s
.34743 .56318 m .35128 .50933 L p .39912 .53456 L 0 .689 .454 r
F P
0 g
s
.38604 .59363 m .39657 .58773 L .39912 .53456 L p 0 .1 .396 r
F P
0 g
s
.39912 .53456 m .39657 .58773 L .34743 .56318 L p 0 .689 .454 r
F P
0 g
s
.35128 .50933 m .35132 .50931 L .39912 .53456 L p 0 .689 .454 r
F P
0 g
s
.34743 .56318 m .35128 .50933 L p .39912 .53456 L 0 .689 .454 r
F P
0 g
s
.39912 .53456 m .39657 .58773 L .34743 .56318 L p 0 .689 .454 r
F P
0 g
s
.31608 .58175 m .30599 .58773 L .31077 .5346 L p 0 .1 0 r
F P
0 g
s
.31077 .5346 m .32064 .52845 L .31608 .58175 L p 0 .1 0 r
F P
0 g
s
.81871 .34029 m .81085 .29322 L .81082 .29317 L p 0 .621 .254 r
F P
0 g
s
.81082 .29317 m .81085 .29322 L .81953 .2881 L p 0 .575 .884 r
F P
0 g
s
.81085 .29322 m .81871 .34029 L .82764 .33524 L p 0 .114 .472 r
F P
0 g
s
.82764 .33524 m .81953 .2881 L .81085 .29322 L p 0 .114 .472 r
F P
0 g
s
.81871 .34029 m .81085 .29322 L .81082 .29317 L p 0 .621 .254 r
F P
0 g
s
.81082 .29317 m .77339 .26179 L .76472 .26713 L p 0 .903 1 r
F P
0 g
s
.81082 .29317 m .77339 .26179 L p .81871 .34029 L 0 .621 .254 r
F P
0 g
s
.77339 .26179 m .81082 .29317 L .8195 .28804 L p 0 .903 1 r
F P
0 g
s
.81953 .2881 m .8195 .28804 L .81082 .29317 L p 0 .575 .884 r
F P
0 g
s
.81082 .29317 m .77339 .26179 L p .81871 .34029 L 0 .621 .254 r
F P
0 g
s
.72261 .44618 m .72259 .4462 L .735 .43949 L p 0 .1 .1 r
F P
0 g
s
.72262 .29308 m .72825 .34018 L .76682 .36965 L p 0 .638 0 r
F P
0 g
s
.72262 .29308 m .72825 .34018 L .76682 .36965 L p 0 .638 0 r
F P
0 g
s
.72825 .34018 m .76682 .36965 L .77951 .36247 L p 0 .907 0 r
F P
0 g
s
.76682 .36965 m .77357 .41865 L .78662 .4116 L p 0 .114 0 r
F P
0 g
s
.78662 .4116 m .77951 .36247 L .76682 .36965 L p 0 .114 0 r
F P
0 g
s
.76682 .36965 m .72825 .34018 L .71564 .34764 L p 0 .907 0 r
F P
0 g
s
.77355 .41867 m .77357 .41865 L .76068 .42562 L p 0 .1 0 r
F P
0 g
s
.76682 .36965 m .72825 .34018 L p .77355 .41867 L 0 .638 0 r
F P
0 g
s
.77355 .41867 m .77357 .41865 L .76682 .36965 L p 0 .638 0 r
F P
0 g
s
.72825 .34018 m .72262 .29308 L .73503 .28543 L p 0 .1 0 r
F P
0 g
s
.68292 .26168 m .72262 .29308 L .73503 .28543 L p 0 .903 0 r
F P
0 g
s
.72262 .29308 m .72825 .34018 L .74101 .33264 L p 0 .1 0 r
F P
0 g
s
.74101 .33264 m .73503 .28543 L .72262 .29308 L p 0 .1 0 r
F P
0 g
s
.72262 .29308 m .68292 .26168 L .6706 .26962 L p 0 .903 0 r
F P
0 g
s
.72262 .29308 m .72825 .34018 L .71564 .34764 L p 0 .1 0 r
F P
0 g
s
.72825 .34018 m .72262 .29308 L .68292 .26168 L p 0 .638 0 r
F P
0 g
s
.76682 .36965 m .72825 .34018 L .74101 .33264 L p 0 .907 0 r
F P
0 g
s
.74101 .33264 m .77951 .36247 L .76682 .36965 L p 0 .907 0 r
F P
0 g
s
.72825 .34018 m .72262 .29308 L .68292 .26168 L p 0 .638 0 r
F P
0 g
s
.76682 .36965 m .72825 .34018 L p .77355 .41867 L 0 .638 0 r
F P
0 g
s
.77355 .41867 m .77357 .41865 L .76682 .36965 L p 0 .638 0 r
F P
0 g
s
.58999 .36965 m .59227 .41869 L .58051 .42565 L p 0 .1 0 r
F P
0 g
s
.58999 .36965 m .59227 .41869 L .6342 .44622 L p 0 .663 0 r
F P
0 g
s
.58999 .36965 m .59227 .41869 L .6342 .44622 L p 0 .663 0 r
F P
0 g
s
.6342 .44622 m .59227 .41869 L .60417 .41164 L p 0 .911 0 r
F P
0 g
s
.60417 .41164 m .64607 .43951 L .6342 .44622 L p 0 .911 0 r
F P
0 g
s
.59227 .41869 m .58999 .36965 L .60159 .36247 L p 0 .1 0 r
F P
0 g
s
.67841 .36965 m .68292 .41869 L .6706 .42565 L p 0 .1 .45 r
F P
0 g
s
.67841 .36965 m .68292 .41869 L .72259 .4462 L p 0 .652 .333 r
F P
0 g
s
.67841 .36965 m .68292 .41869 L .72259 .4462 L p 0 .652 .333 r
F P
0 g
s
.68292 .41869 m .67841 .36965 L .69055 .36247 L p 0 .1 .45 r
F P
0 g
s
.6342 .29308 m .6376 .34018 L .62556 .34764 L p 0 .1 .425 r
F P
0 g
s
.6342 .29308 m .6376 .34018 L .67841 .36965 L p 0 .652 .333 r
F P
0 g
s
.6342 .29308 m .6376 .34018 L .67841 .36965 L p 0 .652 .333 r
F P
0 g
s
.6376 .34018 m .6342 .29308 L .64607 .28543 L p 0 .1 .425 r
F P
0 g
s
.67841 .36965 m .6376 .34018 L .62556 .34764 L p 0 .907 1 r
F P
0 g
s
.68292 .41869 m .67841 .36965 L .6376 .34018 L p 0 .652 .333 r
F P
0 g
s
.6376 .34018 m .67841 .36965 L .69055 .36247 L p 0 .907 1 r
F P
0 g
s
.67841 .36965 m .68292 .41869 L .6954 .41164 L p 0 .1 .45 r
F P
0 g
s
.6954 .41164 m .69055 .36247 L .67841 .36965 L p 0 .1 .45 r
F P
0 g
s
.68292 .41869 m .67841 .36965 L .6376 .34018 L p 0 .652 .333 r
F P
0 g
s
.67841 .36965 m .6376 .34018 L .64979 .33264 L p 0 .907 1 r
F P
0 g
s
.64979 .33264 m .69055 .36247 L .67841 .36965 L p 0 .907 1 r
F P
0 g
s
.72259 .4462 m .68292 .41869 L .6954 .41164 L p 0 .911 1 r
F P
0 g
s
.6954 .41164 m .735 .43949 L .72259 .4462 L p 0 .911 1 r
F P
0 g
s
.45417 .29091 m .45413 .29092 L p .49842 .36759 L 0 .673 .397 r
F P
0 g
s
.45417 .29091 m .46494 .28323 L .46491 .28324 L p 0 1 .86 r
F P
0 g
s
.46491 .28324 m .45413 .29092 L .45417 .29091 L p 0 1 .86 r
F P
0 g
s
.45417 .29091 m .45413 .29092 L p .49842 .36759 L 0 .673 .397 r
F P
0 g
s
.37579 .43753 m .37583 .43759 L .3656 .44432 L p 0 .546 .889 r
F P
0 g
s
.3656 .44432 m .36556 .44426 L .37579 .43753 L p 0 .546 .889 r
F P
0 g
s
.49842 .36759 m .49838 .41667 L .5427 .4443 L p 0 .673 .397 r
F P
0 g
s
.49842 .36759 m .49838 .41667 L .5427 .4443 L p 0 .673 .397 r
F P
0 g
s
.49842 .36759 m .50947 .36039 L .50971 .40959 L p 0 .1 .396 r
F P
0 g
s
.50971 .40959 m .49838 .41667 L .49842 .36759 L p 0 .1 .396 r
F P
0 g
s
.48719 .42366 m .49838 .41667 L .49842 .36759 L p 0 .1 .396 r
F P
0 g
s
.44206 .3455 m .45297 .33802 L .49842 .36759 L p 0 .907 1 r
F P
0 g
s
.49838 .41667 m .49842 .36759 L .45297 .33802 L p 0 .673 .397 r
F P
0 g
s
.50947 .36039 m .49842 .36759 L .49838 .41667 L p 0 .1 .396 r
F P
0 g
s
.45413 .29092 m .45297 .33802 L .49842 .36759 L p 0 .673 .397 r
F P
0 g
s
.45413 .29092 m .45297 .33802 L .49842 .36759 L p 0 .673 .397 r
F P
0 g
s
.49842 .36759 m .50947 .36039 L .46402 .33045 L p 0 .907 1 r
F P
0 g
s
.46402 .33045 m .45297 .33802 L .49842 .36759 L p 0 .907 1 r
F P
0 g
s
.49838 .41667 m .49842 .36759 L .45297 .33802 L p 0 .673 .397 r
F P
0 g
s
.50947 .36039 m .49842 .36759 L .45297 .33802 L p 0 .907 1 r
F P
0 g
s
.48719 .42366 m .49838 .41667 L .5427 .4443 L p 0 .911 1 r
F P
0 g
s
.55403 .43757 m .5427 .4443 L .49838 .41667 L p 0 .911 1 r
F P
0 g
s
.40985 .36759 m .40756 .41663 L .39694 .42362 L p 0 .1 0 r
F P
0 g
s
.4076 .41669 m .40756 .41663 L .40985 .36759 L p 0 .681 0 r
F P
0 g
s
.40985 .36759 m .40756 .41663 L p .45413 .4443 L 0 .681 0 r
F P
0 g
s
.40985 .36759 m .42035 .36039 L .41832 .40956 L p 0 .1 0 r
F P
0 g
s
.41832 .40956 m .40756 .41663 L .40985 .36759 L p 0 .1 0 r
F P
0 g
s
.40756 .41663 m .4076 .41669 L .45413 .4443 L p 0 .681 0 r
F P
0 g
s
.46491 .43757 m .45413 .4443 L .4076 .41669 L p 0 .911 0 r
F P
0 g
s
.5427 .29089 m .54379 .33802 L .58699 .36759 L p 0 .663 0 r
F P
0 g
s
.5427 .29089 m .54379 .33802 L .58699 .36759 L p 0 .663 0 r
F P
0 g
s
.5427 .29089 m .55403 .28321 L .55541 .33045 L p 0 .1 0 r
F P
0 g
s
.55541 .33045 m .54379 .33802 L .5427 .29089 L p 0 .1 0 r
F P
0 g
s
.53231 .3455 m .54379 .33802 L .5427 .29089 L p 0 .1 0 r
F P
0 g
s
.54379 .33802 m .5427 .29089 L .49841 .2594 L p 0 .663 0 r
F P
0 g
s
.55403 .28321 m .5427 .29089 L .54379 .33802 L p 0 .1 0 r
F P
0 g
s
.5427 .29089 m .55403 .28321 L .50974 .25132 L p 0 .903 0 r
F P
0 g
s
.50974 .25132 m .49841 .2594 L .5427 .29089 L p 0 .903 0 r
F P
0 g
s
.54379 .33802 m .5427 .29089 L .49841 .2594 L p 0 .663 0 r
F P
0 g
s
.57744 .42366 m .58919 .41667 L .58699 .36759 L p 0 .1 0 r
F P
0 g
s
.53231 .3455 m .54379 .33802 L .58699 .36759 L p 0 .907 0 r
F P
0 g
s
.58919 .41667 m .58699 .36759 L .54379 .33802 L p 0 .663 0 r
F P
0 g
s
.59859 .36039 m .58699 .36759 L .58919 .41667 L p 0 .1 0 r
F P
0 g
s
.58699 .36759 m .59859 .36039 L .55541 .33045 L p 0 .907 0 r
F P
0 g
s
.55541 .33045 m .54379 .33802 L .58699 .36759 L p 0 .907 0 r
F P
0 g
s
.58919 .41667 m .58699 .36759 L .54379 .33802 L p 0 .663 0 r
F P
0 g
s
.59859 .36039 m .58699 .36759 L .54379 .33802 L p 0 .907 0 r
F P
0 g
s
.62256 .3455 m .6346 .33802 L .63127 .29089 L p 0 .1 .423 r
F P
0 g
s
.6346 .33802 m .63127 .29089 L .58919 .25937 L p 0 .652 .333 r
F P
0 g
s
.64315 .28321 m .63127 .29089 L .6346 .33802 L p 0 .1 .423 r
F P
0 g
s
.63127 .29089 m .64315 .28321 L .6011 .2513 L p 0 .903 1 r
F P
0 g
s
.6011 .2513 m .58919 .25937 L .63127 .29089 L p 0 .903 1 r
F P
0 g
s
.6346 .33802 m .63127 .29089 L .58919 .25937 L p 0 .652 .333 r
F P
0 g
s
.45413 .29092 m .46491 .28324 L .46402 .33045 L p 0 .1 .365 r
F P
0 g
s
.46402 .33045 m .45297 .33802 L .45413 .29092 L p 0 .1 .365 r
F P
0 g
s
.60195 .67857 m .59031 .68383 L .59028 .68385 L p 0 .1 0 r
F P
0 g
s
.59028 .68385 m .59031 .68383 L p .54595 .60703 L 0 .681 0 r
F P
0 g
s
.5808 .58944 m .5926 .58348 L .59031 .53019 L p 0 .1 .45 r
F P
0 g
s
.5926 .58348 m .59031 .53019 L .54711 .50469 L p 0 .673 .397 r
F P
0 g
s
.5926 .58348 m .59031 .53019 L .54711 .50469 L p 0 .673 .397 r
F P
0 g
s
.5808 .58944 m .5926 .58348 L .63468 .60703 L p 0 .916 1 r
F P
0 g
s
.59031 .53019 m .5926 .58348 L .63468 .60703 L p 0 .673 .397 r
F P
0 g
s
.59031 .53019 m .5926 .58348 L .63468 .60703 L p 0 .673 .397 r
F P
0 g
s
.59031 .53019 m .60195 .52398 L .55878 .49816 L p 0 .914 1 r
F P
0 g
s
.55878 .49816 m .54711 .50469 L .59031 .53019 L p 0 .914 1 r
F P
0 g
s
.60195 .52398 m .59031 .53019 L .5926 .58348 L p 0 .1 .45 r
F P
0 g
s
.64659 .60129 m .63468 .60703 L .5926 .58348 L p 0 .916 1 r
F P
0 g
s
.62601 .66769 m .63809 .66223 L .63468 .60703 L p 0 .114 .472 r
F P
0 g
s
.63809 .66223 m .63468 .60703 L .5926 .58348 L p 0 .673 .397 r
F P
0 g
s
.63468 .60703 m .64659 .60129 L .60455 .57745 L p 0 .916 1 r
F P
0 g
s
.60455 .57745 m .5926 .58348 L .63468 .60703 L p 0 .916 1 r
F P
0 g
s
.64659 .60129 m .63468 .60703 L .63809 .66223 L p 0 .114 .472 r
F P
0 g
s
.63809 .66223 m .63468 .60703 L .5926 .58348 L p 0 .673 .397 r
F P
0 g
s
.59031 .53019 m .60195 .52398 L .60455 .57745 L p 0 .1 .45 r
F P
0 g
s
.60455 .57745 m .5926 .58348 L .59031 .53019 L p 0 .1 .45 r
F P
0 g
s
.54595 .60703 m .50162 .58348 L .49039 .58944 L p 0 .916 0 r
F P
0 g
s
.50167 .63955 m .50162 .58348 L .54595 .60703 L p 0 .681 0 r
F P
0 g
s
.54595 .60703 m .54711 .66227 L .5356 .66773 L p 0 .1 0 r
F P
0 g
s
.54595 .60703 m .54711 .66227 L .50167 .63955 L p 0 .681 0 r
F P
0 g
s
.50158 .53019 m .50162 .58348 L .49039 .58944 L p 0 .1 0 r
F P
0 g
s
.50158 .53019 m .50162 .58348 L .54595 .60703 L p 0 .681 0 r
F P
0 g
s
.55731 .60129 m .54595 .60703 L .50162 .58348 L p 0 .916 0 r
F P
0 g
s
.54595 .60703 m .55731 .60129 L .513 .57745 L p 0 .916 0 r
F P
0 g
s
.513 .57745 m .50162 .58348 L .54595 .60703 L p 0 .916 0 r
F P
0 g
s
.54595 .60703 m .54711 .66227 L .59028 .68385 L p 0 .681 0 r
F P
0 g
s
.55731 .60129 m .54595 .60703 L .54711 .66227 L p 0 .1 0 r
F P
0 g
s
.54711 .66227 m .54595 .60703 L .50162 .58348 L p 0 .681 0 r
F P
0 g
s
.54595 .60703 m .55731 .60129 L .55878 .65674 L p 0 .1 0 r
F P
0 g
s
.55878 .65674 m .54711 .66227 L .54595 .60703 L p 0 .1 0 r
F P
0 g
s
.50158 .53019 m .51267 .52398 L .513 .57745 L p 0 .1 0 r
F P
0 g
s
.513 .57745 m .50162 .58348 L .50158 .53019 L p 0 .1 0 r
F P
0 g
s
.46722 .65674 m .51267 .67861 L .50158 .68387 L p 0 .916 1 r
F P
0 g
s
.50158 .68387 m .45613 .66227 L .46722 .65674 L p 0 .916 1 r
F P
0 g
s
.45722 .60703 m .45613 .66227 L .44519 .66773 L p 0 .1 .425 r
F P
0 g
s
.45613 .66227 m .45722 .60703 L .46804 .60129 L p 0 .1 .425 r
F P
0 g
s
.67121 .58944 m .68358 .58348 L .67904 .53022 L p 0 .114 0 r
F P
0 g
s
.67904 .53022 m .67901 .53017 L .63809 .50469 L p 0 .663 0 r
F P
0 g
s
.68358 .58348 m .67904 .53022 L p .63809 .50469 L 0 .663 0 r
F P
0 g
s
.67901 .53017 m .6912 .52396 L .65033 .49816 L p 0 .914 0 r
F P
0 g
s
.65033 .49816 m .63809 .50469 L .67901 .53017 L p 0 .914 0 r
F P
0 g
s
.69123 .52401 m .67904 .53022 L .68358 .58348 L p 0 .114 0 r
F P
0 g
s
.67904 .53022 m .69123 .52401 L .6912 .52396 L p 0 .562 0 r
F P
0 g
s
.6912 .52396 m .67901 .53017 L .67904 .53022 L p 0 .562 0 r
F P
0 g
s
.67904 .53022 m .67901 .53017 L .63809 .50469 L p 0 .663 0 r
F P
0 g
s
.68358 .58348 m .67904 .53022 L p .63809 .50469 L 0 .663 0 r
F P
0 g
s
.59028 .68385 m .60192 .67859 L .60195 .67857 L p 0 .1 0 r
F P
0 g
s
.60192 .67859 m .59028 .68385 L .54711 .66227 L p 0 .916 0 r
F P
0 g
s
.82764 .33524 m .81953 .2881 L .8195 .28804 L p 0 .618 .247 r
F P
0 g
s
.8195 .28804 m .78213 .2564 L .77339 .26179 L p 0 .903 1 r
F P
0 g
s
.8195 .28804 m .78213 .2564 L p .82764 .33524 L 0 .618 .247 r
F P
0 g
s
.33063 .52221 m .32064 .52845 L .32068 .52843 L p 0 .93 0 r
F P
0 g
s
.24123 .6771 m .23179 .68238 L .23176 .68232 L p 0 .525 0 r
F P
0 g
s
.23176 .68232 m .2412 .67704 L .24123 .6771 L p 0 .525 0 r
F P
0 g
s
.28044 .6551 m .27051 .66065 L .2762 .60538 L p 0 .1 .365 r
F P
0 g
s
.2762 .60538 m .28591 .59963 L .28044 .6551 L p 0 .1 .365 r
F P
0 g
s
.33063 .67708 m .32064 .68236 L .27055 .6607 L p 0 .916 1 r
F P
0 g
s
.26074 .66619 m .27055 .6607 L .32064 .68236 L p 0 .916 1 r
F P
0 g
s
.37216 .65514 m .36165 .66069 L .36509 .60538 L p 0 .1 0 r
F P
0 g
s
.36509 .60538 m .37535 .59963 L .37216 .65514 L p 0 .1 0 r
F P
0 g
s
.42007 .67708 m .40953 .68236 L .36165 .66069 L p 0 .916 0 r
F P
0 g
s
.3263 .5757 m .31608 .58175 L .36509 .60538 L p 0 .916 0 r
F P
0 g
s
.36509 .60538 m .37535 .59963 L .3263 .5757 L p 0 .916 0 r
F P
0 g
s
.37535 .59963 m .36509 .60538 L .36165 .66069 L p 0 .1 0 r
F P
0 g
s
.30599 .58773 m .31608 .58175 L .36509 .60538 L p 0 .916 0 r
F P
0 g
s
.31129 .63784 m .31608 .58175 L .36509 .60538 L p 0 .693 0 r
F P
0 g
s
.31132 .6379 m .31129 .63784 L p .36509 .60538 L 0 .693 0 r
F P
0 g
s
.35128 .66617 m .36165 .66069 L .36509 .60538 L p 0 .1 0 r
F P
0 g
s
.36509 .60538 m .36165 .66069 L .31132 .6379 L p 0 .693 0 r
F P
0 g
s
.31129 .63784 m .31608 .58175 L .36509 .60538 L p 0 .693 0 r
F P
0 g
s
.31132 .6379 m .31129 .63784 L p .36509 .60538 L 0 .693 0 r
F P
0 g
s
.36509 .60538 m .36165 .66069 L .31132 .6379 L p 0 .693 0 r
F P
0 g
s
.37535 .59963 m .36509 .60538 L .31608 .58175 L p 0 .916 0 r
F P
0 g
s
.35128 .66617 m .36165 .66069 L .40953 .68236 L p 0 .916 0 r
F P
0 g
s
.48714 .58773 m .49837 .58175 L .49841 .52841 L p 0 .1 0 r
F P
0 g
s
.45157 .55689 m .4528 .50282 L .49841 .52841 L p 0 .681 0 r
F P
0 g
s
.49841 .52841 m .49837 .58175 L .45157 .55689 L p 0 .681 0 r
F P
0 g
s
.4528 .50282 m .49841 .52841 L .5095 .52218 L p 0 .914 0 r
F P
0 g
s
.49841 .52841 m .49837 .58175 L .50975 .5757 L p 0 .1 0 r
F P
0 g
s
.50975 .5757 m .5095 .52218 L .49841 .52841 L p 0 .1 0 r
F P
0 g
s
.49837 .58175 m .49841 .52841 L .4528 .50282 L p 0 .681 0 r
F P
0 g
s
.44185 .66617 m .4528 .66069 L .45397 .60538 L p 0 .1 .423 r
F P
0 g
s
.39657 .58773 m .40723 .58175 L .45397 .60538 L p 0 .916 1 r
F P
0 g
s
.41802 .5757 m .40723 .58175 L .45397 .60538 L p 0 .916 1 r
F P
0 g
s
.45397 .60538 m .46478 .59963 L .41802 .5757 L p 0 .916 1 r
F P
0 g
s
.46478 .59963 m .45397 .60538 L .4528 .66069 L p 0 .1 .423 r
F P
0 g
s
.40481 .63788 m .40723 .58175 L .45397 .60538 L p 0 .687 .449 r
F P
0 g
s
.45397 .60538 m .4528 .66069 L .40481 .63788 L p 0 .687 .449 r
F P
0 g
s
.40481 .63788 m .40723 .58175 L .45397 .60538 L p 0 .687 .449 r
F P
0 g
s
.45397 .60538 m .4528 .66069 L .40481 .63788 L p 0 .687 .449 r
F P
0 g
s
.39657 .58773 m .40723 .58175 L .40953 .52841 L p 0 .1 .396 r
F P
0 g
s
.46478 .59963 m .45397 .60538 L .40723 .58175 L p 0 .916 1 r
F P
0 g
s
.41802 .5757 m .40723 .58175 L .40953 .52841 L p 0 .1 .396 r
F P
0 g
s
.40953 .52841 m .42007 .52218 L .41802 .5757 L p 0 .1 .396 r
F P
0 g
s
.37219 .49628 m .36169 .50284 L .40953 .52841 L p 0 .914 1 r
F P
0 g
s
.40953 .52841 m .42007 .52218 L .37219 .49628 L p 0 .914 1 r
F P
0 g
s
.42007 .52218 m .40953 .52841 L .40723 .58175 L p 0 .1 .396 r
F P
0 g
s
.35132 .50931 m .36169 .50284 L .36165 .50286 L p 0 .93 .764 r
F P
0 g
s
.36165 .50286 m .36169 .50284 L .40953 .52841 L p 0 .687 .449 r
F P
0 g
s
.35804 .55689 m .36165 .50286 L p .40953 .52841 L 0 .687 .449 r
F P
0 g
s
.40953 .52841 m .40723 .58175 L .35804 .55689 L p 0 .687 .449 r
F P
0 g
s
.36165 .50286 m .36169 .50284 L .40953 .52841 L p 0 .687 .449 r
F P
0 g
s
.35804 .55689 m .36165 .50286 L p .40953 .52841 L 0 .687 .449 r
F P
0 g
s
.40953 .52841 m .40723 .58175 L .35804 .55689 L p 0 .687 .449 r
F P
0 g
s
.3263 .5757 m .31608 .58175 L .32064 .52845 L p 0 .1 0 r
F P
0 g
s
.32064 .52845 m .33063 .52221 L .3263 .5757 L p 0 .1 0 r
F P
0 g
s
.73502 .43948 m .735 .43949 L .74757 .4327 L p 0 .1 .1 r
F P
0 g
s
.73503 .28543 m .74101 .33264 L .72825 .34018 L p 0 .1 0 r
F P
0 g
s
.73503 .28543 m .74101 .33264 L .77951 .36247 L p 0 .634 0 r
F P
0 g
s
.73503 .28543 m .74101 .33264 L .77951 .36247 L p 0 .634 0 r
F P
0 g
s
.74101 .33264 m .73503 .28543 L .74759 .27769 L p 0 .1 0 r
F P
0 g
s
.73503 .28543 m .6954 .25363 L .68292 .26168 L p 0 .903 0 r
F P
0 g
s
.74101 .33264 m .73503 .28543 L .6954 .25363 L p 0 .634 0 r
F P
0 g
s
.6954 .25363 m .73503 .28543 L .74759 .27769 L p 0 .903 0 r
F P
0 g
s
.73503 .28543 m .74101 .33264 L .75394 .32499 L p 0 .1 0 r
F P
0 g
s
.75394 .32499 m .74759 .27769 L .73503 .28543 L p 0 .1 0 r
F P
0 g
s
.74101 .33264 m .73503 .28543 L .6954 .25363 L p 0 .634 0 r
F P
0 g
s
.74759 .27769 m .75394 .32499 L .74101 .33264 L p 0 .1 0 r
F P
0 g
s
.74759 .27769 m .70803 .24549 L .6954 .25363 L p 0 .903 0 r
F P
0 g
s
.75394 .32499 m .74759 .27769 L .70803 .24549 L p 0 .63 .275 r
F P
0 g
s
.77951 .36247 m .74101 .33264 L .72825 .34018 L p 0 .907 0 r
F P
0 g
s
.7866 .41162 m .78662 .4116 L .77357 .41865 L p 0 .1 0 r
F P
0 g
s
.77951 .36247 m .74101 .33264 L p .7866 .41162 L 0 .634 0 r
F P
0 g
s
.7866 .41162 m .78662 .4116 L .77951 .36247 L p 0 .634 0 r
F P
0 g
s
.74101 .33264 m .77951 .36247 L .79235 .35521 L p 0 .907 0 r
F P
0 g
s
.77951 .36247 m .78662 .4116 L .79983 .40446 L p 0 .114 0 r
F P
0 g
s
.79983 .40446 m .79235 .35521 L .77951 .36247 L p 0 .114 0 r
F P
0 g
s
.79981 .40448 m .79983 .40446 L .78662 .4116 L p 0 .1 0 r
F P
0 g
s
.79981 .40448 m .79983 .40446 L .79235 .35521 L p 0 .63 .275 r
F P
0 g
s
.77951 .36247 m .74101 .33264 L p .7866 .41162 L 0 .634 0 r
F P
0 g
s
.7866 .41162 m .78662 .4116 L .77951 .36247 L p 0 .634 0 r
F P
0 g
s
.77951 .36247 m .74101 .33264 L .75394 .32499 L p 0 .907 0 r
F P
0 g
s
.75394 .32499 m .79235 .35521 L .77951 .36247 L p 0 .907 0 r
F P
0 g
s
.79235 .35521 m .75394 .32499 L .74101 .33264 L p 0 .907 0 r
F P
0 g
s
.79235 .35521 m .75394 .32499 L p .79981 .40448 L 0 .63 .275 r
F P
0 g
s
.60159 .36247 m .60417 .41164 L .64607 .43951 L p 0 .661 0 r
F P
0 g
s
.60159 .36247 m .60417 .41164 L .64607 .43951 L p 0 .661 0 r
F P
0 g
s
.64607 .43951 m .60417 .41164 L .61623 .4045 L p 0 .911 0 r
F P
0 g
s
.61623 .4045 m .65808 .43272 L .64607 .43951 L p 0 .911 0 r
F P
0 g
s
.60159 .36247 m .60417 .41164 L .59227 .41869 L p 0 .1 0 r
F P
0 g
s
.60417 .41164 m .60159 .36247 L .61333 .35521 L p 0 .1 0 r
F P
0 g
s
.64607 .28543 m .64979 .33264 L .6376 .34018 L p 0 .1 .425 r
F P
0 g
s
.64607 .28543 m .64979 .33264 L .69055 .36247 L p 0 .648 .324 r
F P
0 g
s
.64607 .28543 m .64979 .33264 L .69055 .36247 L p 0 .648 .324 r
F P
0 g
s
.64979 .33264 m .64607 .28543 L .65808 .27769 L p 0 .1 .425 r
F P
0 g
s
.69055 .36247 m .6954 .41164 L .68292 .41869 L p 0 .1 .45 r
F P
0 g
s
.69055 .36247 m .6954 .41164 L .735 .43949 L p 0 .648 .324 r
F P
0 g
s
.69055 .36247 m .6954 .41164 L .735 .43949 L p 0 .648 .324 r
F P
0 g
s
.6954 .41164 m .69055 .36247 L .70284 .35521 L p 0 .1 .45 r
F P
0 g
s
.69055 .36247 m .64979 .33264 L .6376 .34018 L p 0 .907 1 r
F P
0 g
s
.6954 .41164 m .69055 .36247 L .64979 .33264 L p 0 .648 .324 r
F P
0 g
s
.64979 .33264 m .69055 .36247 L .70284 .35521 L p 0 .907 1 r
F P
0 g
s
.69055 .36247 m .6954 .41164 L .70803 .4045 L p 0 .1 .45 r
F P
0 g
s
.70803 .4045 m .70284 .35521 L .69055 .36247 L p 0 .1 .45 r
F P
0 g
s
.6954 .41164 m .69055 .36247 L .64979 .33264 L p 0 .648 .324 r
F P
0 g
s
.69055 .36247 m .64979 .33264 L .66213 .32499 L p 0 .907 1 r
F P
0 g
s
.66213 .32499 m .70284 .35521 L .69055 .36247 L p 0 .907 1 r
F P
0 g
s
.735 .43949 m .6954 .41164 L .70803 .4045 L p 0 .911 1 r
F P
0 g
s
.70803 .4045 m .74757 .4327 L .735 .43949 L p 0 .911 1 r
F P
0 g
s
.46494 .28323 m .46491 .28324 L p .50947 .36039 L 0 .671 .39 r
F P
0 g
s
.46494 .28323 m .47585 .27546 L .47582 .27547 L p 0 1 .86 r
F P
0 g
s
.47582 .27547 m .46491 .28324 L .46494 .28323 L p 0 1 .86 r
F P
0 g
s
.46494 .28323 m .46491 .28324 L p .50947 .36039 L 0 .671 .39 r
F P
0 g
s
.38615 .43072 m .38618 .43078 L .37583 .43759 L p 0 .546 .889 r
F P
0 g
s
.37583 .43759 m .37579 .43753 L .38615 .43072 L p 0 .546 .889 r
F P
0 g
s
.50947 .36039 m .50971 .40959 L .55403 .43757 L p 0 .671 .39 r
F P
0 g
s
.50947 .36039 m .50971 .40959 L .55403 .43757 L p 0 .671 .39 r
F P
0 g
s
.50947 .36039 m .52066 .3531 L .52119 .40243 L p 0 .1 .396 r
F P
0 g
s
.52119 .40243 m .50971 .40959 L .50947 .36039 L p 0 .1 .396 r
F P
0 g
s
.52066 .3531 m .50947 .36039 L .50971 .40959 L p 0 .1 .396 r
F P
0 g
s
.46491 .28324 m .46402 .33045 L .50947 .36039 L p 0 .671 .39 r
F P
0 g
s
.46491 .28324 m .46402 .33045 L .50947 .36039 L p 0 .671 .39 r
F P
0 g
s
.50947 .36039 m .52066 .3531 L .4752 .32278 L p 0 .907 1 r
F P
0 g
s
.4752 .32278 m .46402 .33045 L .50947 .36039 L p 0 .907 1 r
F P
0 g
s
.56549 .43076 m .55403 .43757 L .50971 .40959 L p 0 .911 1 r
F P
0 g
s
.49838 .41667 m .50971 .40959 L .50947 .36039 L p 0 .1 .396 r
F P
0 g
s
.45297 .33802 m .46402 .33045 L .50947 .36039 L p 0 .907 1 r
F P
0 g
s
.50971 .40959 m .50947 .36039 L .46402 .33045 L p 0 .671 .39 r
F P
0 g
s
.50971 .40959 m .50947 .36039 L .46402 .33045 L p 0 .671 .39 r
F P
0 g
s
.52066 .3531 m .50947 .36039 L .46402 .33045 L p 0 .907 1 r
F P
0 g
s
.49838 .41667 m .50971 .40959 L .55403 .43757 L p 0 .911 1 r
F P
0 g
s
.42035 .36039 m .41832 .40956 L p .46491 .43757 L 0 .679 0 r
F P
0 g
s
.42035 .36039 m .41832 .40956 L p .46491 .43757 L 0 .679 0 r
F P
0 g
s
.42035 .36039 m .43099 .3531 L .42922 .40239 L p 0 .1 0 r
F P
0 g
s
.42922 .40239 m .41832 .40956 L .42035 .36039 L p 0 .1 0 r
F P
0 g
s
.4076 .41669 m .41835 .40961 L .46491 .43757 L p 0 .911 0 r
F P
0 g
s
.41832 .40956 m .41835 .40961 L .46491 .43757 L p 0 .679 0 r
F P
0 g
s
.41832 .40956 m .41835 .40961 L .46491 .43757 L p 0 .679 0 r
F P
0 g
s
.47582 .43076 m .46491 .43757 L .41835 .40961 L p 0 .911 0 r
F P
0 g
s
.55403 .28321 m .55541 .33045 L .59859 .36039 L p 0 .661 0 r
F P
0 g
s
.55403 .28321 m .55541 .33045 L .59859 .36039 L p 0 .661 0 r
F P
0 g
s
.54379 .33802 m .55541 .33045 L .55403 .28321 L p 0 .1 0 r
F P
0 g
s
.55541 .33045 m .55403 .28321 L .50974 .25132 L p 0 .661 0 r
F P
0 g
s
.55541 .33045 m .55403 .28321 L .50974 .25132 L p 0 .661 0 r
F P
0 g
s
.54379 .33802 m .55541 .33045 L .59859 .36039 L p 0 .907 0 r
F P
0 g
s
.61033 .3531 m .59859 .36039 L .55541 .33045 L p 0 .907 0 r
F P
0 g
s
.55403 .28321 m .56549 .27544 L .56717 .32278 L p 0 .1 0 r
F P
0 g
s
.56717 .32278 m .55541 .33045 L .55403 .28321 L p 0 .1 0 r
F P
0 g
s
.56549 .27544 m .55403 .28321 L .55541 .33045 L p 0 .1 0 r
F P
0 g
s
.55403 .28321 m .56549 .27544 L .52122 .24315 L p 0 .903 0 r
F P
0 g
s
.52122 .24315 m .50974 .25132 L .55403 .28321 L p 0 .903 0 r
F P
0 g
s
.58919 .41667 m .6011 .40959 L .59859 .36039 L p 0 .1 0 r
F P
0 g
s
.6011 .40959 m .59859 .36039 L .55541 .33045 L p 0 .661 0 r
F P
0 g
s
.61033 .3531 m .59859 .36039 L .6011 .40959 L p 0 .1 0 r
F P
0 g
s
.59859 .36039 m .61033 .3531 L .56717 .32278 L p 0 .907 0 r
F P
0 g
s
.56717 .32278 m .55541 .33045 L .59859 .36039 L p 0 .907 0 r
F P
0 g
s
.6011 .40959 m .59859 .36039 L .55541 .33045 L p 0 .661 0 r
F P
0 g
s
.6346 .33802 m .6468 .33045 L .64315 .28321 L p 0 .1 .423 r
F P
0 g
s
.6468 .33045 m .64315 .28321 L .6011 .2513 L p 0 .648 .324 r
F P
0 g
s
.65516 .27544 m .64315 .28321 L .6468 .33045 L p 0 .1 .423 r
F P
0 g
s
.64315 .28321 m .65516 .27544 L .61316 .24313 L p 0 .903 1 r
F P
0 g
s
.61316 .24313 m .6011 .2513 L .64315 .28321 L p 0 .903 1 r
F P
0 g
s
.6468 .33045 m .64315 .28321 L .6011 .2513 L p 0 .648 .324 r
F P
0 g
s
.46491 .28324 m .47582 .27547 L .4752 .32278 L p 0 .1 .365 r
F P
0 g
s
.4752 .32278 m .46402 .33045 L .46491 .28324 L p 0 .1 .365 r
F P
0 g
s
.60192 .67859 m .60195 .67857 L p .55731 .60129 L 0 .679 0 r
F P
0 g
s
.61373 .67324 m .60195 .67857 L .60192 .67859 L p 0 .1 0 r
F P
0 g
s
.60192 .67859 m .60195 .67857 L p .55731 .60129 L 0 .679 0 r
F P
0 g
s
.60195 .52398 m .61373 .51769 L .57059 .49155 L p 0 .914 1 r
F P
0 g
s
.57059 .49155 m .55878 .49816 L .60195 .52398 L p 0 .914 1 r
F P
0 g
s
.60195 .52398 m .60455 .57745 L .64659 .60129 L p 0 .671 .39 r
F P
0 g
s
.60195 .52398 m .60455 .57745 L .64659 .60129 L p 0 .671 .39 r
F P
0 g
s
.61373 .51769 m .60195 .52398 L .60455 .57745 L p 0 .1 .45 r
F P
0 g
s
.65865 .59549 m .64659 .60129 L .60455 .57745 L p 0 .916 1 r
F P
0 g
s
.5926 .58348 m .60455 .57745 L .60195 .52398 L p 0 .1 .45 r
F P
0 g
s
.60455 .57745 m .60195 .52398 L .55878 .49816 L p 0 .671 .39 r
F P
0 g
s
.60455 .57745 m .60195 .52398 L .55878 .49816 L p 0 .671 .39 r
F P
0 g
s
.60195 .52398 m .61373 .51769 L .61666 .57134 L p 0 .1 .45 r
F P
0 g
s
.61666 .57134 m .60455 .57745 L .60195 .52398 L p 0 .1 .45 r
F P
0 g
s
.5926 .58348 m .60455 .57745 L .64659 .60129 L p 0 .916 1 r
F P
0 g
s
.63809 .66223 m .65033 .6567 L .64659 .60129 L p 0 .114 .472 r
F P
0 g
s
.65033 .6567 m .64659 .60129 L .60455 .57745 L p 0 .671 .39 r
F P
0 g
s
.64659 .60129 m .65865 .59549 L .61666 .57134 L p 0 .916 1 r
F P
0 g
s
.61666 .57134 m .60455 .57745 L .64659 .60129 L p 0 .916 1 r
F P
0 g
s
.65865 .59549 m .64659 .60129 L .65033 .6567 L p 0 .114 .472 r
F P
0 g
s
.65033 .6567 m .64659 .60129 L .60455 .57745 L p 0 .671 .39 r
F P
0 g
s
.51267 .52398 m .513 .57745 L .55731 .60129 L p 0 .679 0 r
F P
0 g
s
.51267 .52398 m .513 .57745 L .55731 .60129 L p 0 .679 0 r
F P
0 g
s
.56882 .59549 m .55731 .60129 L .513 .57745 L p 0 .916 0 r
F P
0 g
s
.50162 .58348 m .513 .57745 L .55731 .60129 L p 0 .916 0 r
F P
0 g
s
.54711 .66227 m .55878 .65674 L .55731 .60129 L p 0 .1 0 r
F P
0 g
s
.55878 .65674 m .55731 .60129 L .513 .57745 L p 0 .679 0 r
F P
0 g
s
.55731 .60129 m .56882 .59549 L .52452 .57134 L p 0 .916 0 r
F P
0 g
s
.52452 .57134 m .513 .57745 L .55731 .60129 L p 0 .916 0 r
F P
0 g
s
.55731 .60129 m .55878 .65674 L .60192 .67859 L p 0 .679 0 r
F P
0 g
s
.55731 .60129 m .55878 .65674 L .60192 .67859 L p 0 .679 0 r
F P
0 g
s
.56882 .59549 m .55731 .60129 L .55878 .65674 L p 0 .1 0 r
F P
0 g
s
.55878 .65674 m .55731 .60129 L .513 .57745 L p 0 .679 0 r
F P
0 g
s
.55731 .60129 m .56882 .59549 L .57059 .65114 L p 0 .1 0 r
F P
0 g
s
.57059 .65114 m .55878 .65674 L .55731 .60129 L p 0 .1 0 r
F P
0 g
s
.51267 .52398 m .5239 .51769 L .52452 .57134 L p 0 .1 0 r
F P
0 g
s
.52452 .57134 m .513 .57745 L .51267 .52398 L p 0 .1 0 r
F P
0 g
s
.47845 .65114 m .5239 .67328 L .51267 .67861 L p 0 .916 1 r
F P
0 g
s
.51267 .67861 m .46722 .65674 L .47845 .65114 L p 0 .916 1 r
F P
0 g
s
.46722 .65674 m .46804 .60129 L .47899 .59549 L p 0 .1 .425 r
F P
0 g
s
.46804 .60129 m .46722 .65674 L .45613 .66227 L p 0 .1 .425 r
F P
0 g
s
.68358 .58348 m .69611 .57745 L .69123 .52401 L p 0 .114 0 r
F P
0 g
s
.69123 .52401 m .6912 .52396 L .65033 .49816 L p 0 .661 0 r
F P
0 g
s
.69611 .57745 m .69123 .52401 L p .65033 .49816 L 0 .661 0 r
F P
0 g
s
.69123 .52401 m .6912 .52396 L .65033 .49816 L p 0 .661 0 r
F P
0 g
s
.69611 .57745 m .69123 .52401 L p .65033 .49816 L 0 .661 0 r
F P
0 g
s
.6912 .52396 m .70354 .51767 L .66273 .49155 L p 0 .914 0 r
F P
0 g
s
.66273 .49155 m .65033 .49816 L .6912 .52396 L p 0 .914 0 r
F P
0 g
s
.70357 .51773 m .69123 .52401 L .69611 .57745 L p 0 .114 0 r
F P
0 g
s
.69123 .52401 m .70357 .51773 L .70354 .51767 L p 0 .562 0 r
F P
0 g
s
.70354 .51767 m .6912 .52396 L .69123 .52401 L p 0 .562 0 r
F P
0 g
s
.54711 .66227 m .55878 .65674 L .60192 .67859 L p 0 .916 0 r
F P
0 g
s
.60192 .67859 m .6137 .67327 L .61373 .67324 L p 0 .1 0 r
F P
0 g
s
.6137 .67327 m .60192 .67859 L .55878 .65674 L p 0 .916 0 r
F P
0 g
s
.34074 .5159 m .33063 .52221 L .33067 .52219 L p 0 .93 0 r
F P
0 g
s
.25079 .67175 m .24123 .6771 L .2412 .67704 L p 0 .525 0 r
F P
0 g
s
.2412 .67704 m .25076 .6717 L .25079 .67175 L p 0 .525 0 r
F P
0 g
s
.29049 .64947 m .28044 .6551 L .28591 .59963 L p 0 .1 .365 r
F P
0 g
s
.28591 .59963 m .29575 .5938 L .29049 .64947 L p 0 .1 .365 r
F P
0 g
s
.34074 .67174 m .33063 .67708 L .28047 .65515 L p 0 .916 1 r
F P
0 g
s
.27055 .6607 m .28047 .65515 L .33063 .67708 L p 0 .916 1 r
F P
0 g
s
.43074 .67174 m .42007 .67708 L .37216 .65514 L p 0 .916 0 r
F P
0 g
s
.3828 .64951 m .37216 .65514 L .37535 .59963 L p 0 .1 0 r
F P
0 g
s
.37535 .59963 m .38574 .5938 L .3828 .64951 L p 0 .1 0 r
F P
0 g
s
.36165 .66069 m .37216 .65514 L .42007 .67708 L p 0 .916 0 r
F P
0 g
s
.38574 .5938 m .37535 .59963 L .3263 .5757 L p 0 .916 0 r
F P
0 g
s
.31608 .58175 m .3263 .5757 L .37535 .59963 L p 0 .916 0 r
F P
0 g
s
.33664 .56957 m .3263 .5757 L .37535 .59963 L p 0 .916 0 r
F P
0 g
s
.37535 .59963 m .38574 .5938 L .33664 .56957 L p 0 .916 0 r
F P
0 g
s
.38574 .5938 m .37535 .59963 L .37216 .65514 L p 0 .1 0 r
F P
0 g
s
.32174 .632 m .3263 .5757 L .37535 .59963 L p 0 .692 0 r
F P
0 g
s
.32177 .63205 m .32174 .632 L p .37535 .59963 L 0 .692 0 r
F P
0 g
s
.36165 .66069 m .37216 .65514 L .37535 .59963 L p 0 .1 0 r
F P
0 g
s
.37535 .59963 m .37216 .65514 L .32177 .63205 L p 0 .692 0 r
F P
0 g
s
.32174 .632 m .3263 .5757 L .37535 .59963 L p 0 .692 0 r
F P
0 g
s
.32177 .63205 m .32174 .632 L p .37535 .59963 L 0 .692 0 r
F P
0 g
s
.37535 .59963 m .37216 .65514 L .32177 .63205 L p 0 .692 0 r
F P
0 g
s
.46388 .49626 m .5095 .52218 L .52073 .51587 L p 0 .914 0 r
F P
0 g
s
.5095 .52218 m .50975 .5757 L .52126 .56957 L p 0 .1 0 r
F P
0 g
s
.52126 .56957 m .52073 .51587 L .5095 .52218 L p 0 .1 0 r
F P
0 g
s
.5095 .52218 m .46388 .49626 L .4528 .50282 L p 0 .914 0 r
F P
0 g
s
.50975 .5757 m .5095 .52218 L .46388 .49626 L p 0 .679 0 r
F P
0 g
s
.50975 .5757 m .5095 .52218 L .46388 .49626 L p 0 .679 0 r
F P
0 g
s
.42895 .56957 m .41802 .5757 L .46478 .59963 L p 0 .916 1 r
F P
0 g
s
.46478 .59963 m .47573 .5938 L .42895 .56957 L p 0 .916 1 r
F P
0 g
s
.47573 .5938 m .46478 .59963 L .46388 .65514 L p 0 .1 .423 r
F P
0 g
s
.40723 .58175 m .41802 .5757 L .46478 .59963 L p 0 .916 1 r
F P
0 g
s
.41587 .63204 m .41802 .5757 L .46478 .59963 L p 0 .686 .443 r
F P
0 g
s
.4528 .66069 m .46388 .65514 L .46478 .59963 L p 0 .1 .423 r
F P
0 g
s
.46478 .59963 m .46388 .65514 L .41587 .63204 L p 0 .686 .443 r
F P
0 g
s
.41587 .63204 m .41802 .5757 L .46478 .59963 L p 0 .686 .443 r
F P
0 g
s
.46478 .59963 m .46388 .65514 L .41587 .63204 L p 0 .686 .443 r
F P
0 g
s
.47573 .5938 m .46478 .59963 L .41802 .5757 L p 0 .916 1 r
F P
0 g
s
.42895 .56957 m .41802 .5757 L .42007 .52218 L p 0 .1 .396 r
F P
0 g
s
.42007 .52218 m .43074 .51587 L .42895 .56957 L p 0 .1 .396 r
F P
0 g
s
.38283 .48965 m .37219 .49628 L .42007 .52218 L p 0 .914 1 r
F P
0 g
s
.42007 .52218 m .43074 .51587 L .38283 .48965 L p 0 .914 1 r
F P
0 g
s
.43074 .51587 m .42007 .52218 L .41802 .5757 L p 0 .1 .396 r
F P
0 g
s
.36169 .50284 m .37219 .49628 L .37216 .4963 L p 0 .93 .764 r
F P
0 g
s
.37216 .4963 m .37219 .49628 L .42007 .52218 L p 0 .686 .443 r
F P
0 g
s
.3688 .55051 m .37216 .4963 L p .42007 .52218 L 0 .686 .443 r
F P
0 g
s
.40723 .58175 m .41802 .5757 L .42007 .52218 L p 0 .1 .396 r
F P
0 g
s
.42007 .52218 m .41802 .5757 L .3688 .55051 L p 0 .686 .443 r
F P
0 g
s
.37216 .4963 m .37219 .49628 L .42007 .52218 L p 0 .686 .443 r
F P
0 g
s
.3688 .55051 m .37216 .4963 L p .42007 .52218 L 0 .686 .443 r
F P
0 g
s
.42007 .52218 m .41802 .5757 L .3688 .55051 L p 0 .686 .443 r
F P
0 g
s
.33664 .56957 m .3263 .5757 L .33063 .52221 L p 0 .1 0 r
F P
0 g
s
.33063 .52221 m .34074 .5159 L .33664 .56957 L p 0 .1 0 r
F P
0 g
s
.83645 .27804 m .83648 .27809 L .84962 .27034 L p 0 .575 0 r
F P
0 g
s
.83648 .27809 m .84509 .32536 L .85862 .31771 L p 0 .114 0 r
F P
0 g
s
.85862 .31771 m .84962 .27034 L .83648 .27809 L p 0 .114 0 r
F P
0 g
s
.84509 .32536 m .83648 .27809 L .83645 .27804 L p 0 .612 0 r
F P
0 g
s
.7992 .24588 m .83645 .27804 L .84959 .27028 L p 0 .903 0 r
F P
0 g
s
.84962 .27034 m .84959 .27028 L .83645 .27804 L p 0 .575 0 r
F P
0 g
s
.83645 .27804 m .7992 .24588 L p .84509 .32536 L 0 .612 0 r
F P
0 g
s
.79235 .35521 m .75394 .32499 L p .79981 .40448 L 0 .63 0 r
F P
0 g
s
.74759 .27769 m .75394 .32499 L .79235 .35521 L p 0 .63 .275 r
F P
0 g
s
.74759 .27769 m .75394 .32499 L .79235 .35521 L p 0 .63 0 r
F P
0 g
s
.74759 .27769 m .75394 .32499 L .76271 .31981 L p 0 .1 .45 r
F P
0 g
s
.75394 .32499 m .79235 .35521 L .80106 .35028 L p 0 .907 1 r
F P
0 g
s
.79235 .35521 m .75394 .32499 L .76271 .31981 L p 0 .907 1 r
F P
0 g
s
.80106 .35028 m .76271 .31981 L .75394 .32499 L p 0 .907 1 r
F P
0 g
s
.70284 .35521 m .70803 .4045 L .74757 .4327 L p 0 .645 .315 r
F P
0 g
s
.70319 .355 m .7084 .40429 L .74793 .43251 L p 0 .645 0 r
F P
0 g
s
.71564 .34764 m .7212 .39706 L .76066 .42563 L p 0 .641 0 r
F P
0 g
s
.71564 .34764 m .7212 .39706 L .76066 .42563 L p 0 .641 0 r
F P
0 g
s
.72825 .34018 m .73417 .38973 L .77355 .41867 L p 0 .638 0 r
F P
0 g
s
.72825 .34018 m .73417 .38973 L .77355 .41867 L p 0 .638 0 r
F P
0 g
s
.74101 .33264 m .74731 .38231 L .7866 .41162 L p 0 .634 0 r
F P
0 g
s
.74101 .33264 m .74731 .38231 L .7866 .41162 L p 0 .634 0 r
F P
0 g
s
.75394 .32499 m .76061 .37479 L .79981 .40448 L p 0 .63 .275 r
F P
0 g
s
.75394 .32499 m .76061 .37479 L .79981 .40448 L p 0 .63 0 r
F P
0 g
s
.75394 .32499 m .76061 .37479 L .76965 .36969 L p 0 .1 .45 r
F P
0 g
s
.76965 .36969 m .76271 .31981 L .75394 .32499 L p 0 .1 .45 r
F P
0 g
s
.79981 .40448 m .79983 .40446 L .79235 .35521 L p 0 .63 0 r
F P
0 g
s
.75394 .32499 m .74759 .27769 L .70803 .24549 L p 0 .63 0 r
F P
0 g
s
.79235 .35521 m .79983 .40446 L .8088 .39962 L p 0 .114 .472 r
F P
0 g
s
.8088 .39962 m .80106 .35028 L .79235 .35521 L p 0 .114 .472 r
F P
0 g
s
.70803 .24549 m .74759 .27769 L .75612 .27243 L p 0 .903 1 r
F P
0 g
s
.76271 .31981 m .75612 .27243 L .74759 .27769 L p 0 .1 .45 r
F P
0 g
s
.75394 .32499 m .74759 .27769 L .75612 .27243 L p 0 .1 .45 r
F P
0 g
s
.76271 .31981 m .80106 .35028 L .79235 .35521 L p 0 .907 1 r
F P
0 g
s
.61333 .35521 m .61623 .4045 L .60417 .41164 L p 0 .1 0 r
F P
0 g
s
.61333 .35521 m .61623 .4045 L .65808 .43272 L p 0 .658 0 r
F P
0 g
s
.70284 .35521 m .70803 .4045 L .6954 .41164 L p 0 .1 .45 r
F P
0 g
s
.65808 .27769 m .66213 .32499 L .64979 .33264 L p 0 .1 .425 r
F P
0 g
s
.65808 .27769 m .66213 .32499 L .70284 .35521 L p 0 .645 .315 r
F P
0 g
s
.70284 .35521 m .66213 .32499 L .64979 .33264 L p 0 .907 1 r
F P
0 g
s
.70803 .4045 m .70284 .35521 L .66213 .32499 L p 0 .645 .315 r
F P
0 g
s
.74795 .43249 m .74793 .43251 L .76066 .42563 L p 0 .1 0 r
F P
0 g
s
.65843 .27746 m .66249 .32477 L .70319 .355 L p 0 .645 0 r
F P
0 g
s
.66249 .32477 m .65843 .27746 L .6706 .26962 L p 0 .1 0 r
F P
0 g
s
.66249 .32477 m .70319 .355 L .71564 .34764 L p 0 .907 0 r
F P
0 g
s
.70319 .355 m .7084 .40429 L .7212 .39706 L p 0 .1 0 r
F P
0 g
s
.7212 .39706 m .71564 .34764 L .70319 .355 L p 0 .1 0 r
F P
0 g
s
.7084 .40429 m .70319 .355 L .66249 .32477 L p 0 .645 0 r
F P
0 g
s
.70319 .355 m .66249 .32477 L .675 .31703 L p 0 .907 0 r
F P
0 g
s
.675 .31703 m .71564 .34764 L .70319 .355 L p 0 .907 0 r
F P
0 g
s
.7084 .40429 m .70319 .355 L .71564 .34764 L p 0 .1 0 r
F P
0 g
s
.61367 .355 m .61658 .40429 L .65843 .43253 L p 0 .658 .35 r
F P
0 g
s
.65843 .43253 m .61658 .40429 L .62879 .39706 L p 0 .911 1 r
F P
0 g
s
.62879 .39706 m .6706 .42565 L .65843 .43253 L p 0 .911 1 r
F P
0 g
s
.61658 .40429 m .61367 .355 L .62556 .34764 L p 0 .1 .425 r
F P
0 g
s
.74793 .43251 m .7084 .40429 L .7212 .39706 L p 0 .911 0 r
F P
0 g
s
.7212 .39706 m .76066 .42563 L .74793 .43251 L p 0 .911 0 r
F P
0 g
s
.47585 .27546 m .47582 .27547 L p .52066 .3531 L 0 .668 .382 r
F P
0 g
s
.43099 .3531 m .42922 .40239 L p .47582 .43076 L 0 .677 0 r
F P
0 g
s
.41835 .40961 m .42925 .40245 L .47582 .43076 L p 0 .911 0 r
F P
0 g
s
.42922 .40239 m .42925 .40245 L .47582 .43076 L p 0 .677 0 r
F P
0 g
s
.50971 .40959 m .52119 .40243 L .52066 .3531 L p 0 .1 .396 r
F P
0 g
s
.46402 .33045 m .4752 .32278 L .52066 .3531 L p 0 .907 1 r
F P
0 g
s
.52119 .40243 m .52066 .3531 L .4752 .32278 L p 0 .668 .382 r
F P
0 g
s
.52066 .3531 m .52119 .40243 L .56549 .43076 L p 0 .668 .382 r
F P
0 g
s
.47582 .27547 m .4752 .32278 L .52066 .3531 L p 0 .668 .382 r
F P
0 g
s
.50971 .40959 m .52119 .40243 L .56549 .43076 L p 0 .911 1 r
F P
0 g
s
.55541 .33045 m .56717 .32278 L .61033 .3531 L p 0 .907 0 r
F P
0 g
s
.56549 .27544 m .56717 .32278 L .61033 .3531 L p 0 .658 0 r
F P
0 g
s
.55541 .33045 m .56717 .32278 L .56549 .27544 L p 0 .1 0 r
F P
0 g
s
.56717 .32278 m .56549 .27544 L .52122 .24315 L p 0 .658 0 r
F P
0 g
s
.6011 .40959 m .61316 .40243 L .61033 .3531 L p 0 .1 0 r
F P
0 g
s
.61316 .40243 m .61033 .3531 L .56717 .32278 L p 0 .658 0 r
F P
0 g
s
.6468 .33045 m .65915 .32278 L .65516 .27544 L p 0 .1 .423 r
F P
0 g
s
.65915 .32278 m .65516 .27544 L .61316 .24313 L p 0 .645 .315 r
F P
0 g
s
.39694 .42362 m .39697 .42368 L .38648 .43058 L p 0 .546 0 r
F P
0 g
s
.38648 .43058 m .38645 .43052 L .39694 .42362 L p 0 .546 0 r
F P
0 g
s
.47617 .27524 m .48722 .26737 L .48719 .26738 L p 0 1 0 r
F P
0 g
s
.48719 .26738 m .47614 .27525 L .47617 .27524 L p 0 1 0 r
F P
0 g
s
.47617 .27524 m .47614 .27525 L p .52098 .35289 L 0 .668 0 r
F P
0 g
s
.43129 .35289 m .42953 .40218 L p .47614 .43056 L 0 .677 .411 r
F P
0 g
s
.43129 .35289 m .44206 .3455 L .44057 .39492 L p 0 .1 .365 r
F P
0 g
s
.44057 .39492 m .42953 .40218 L .43129 .35289 L p 0 .1 .365 r
F P
0 g
s
.42953 .40218 m .42956 .40224 L .47614 .43056 L p 0 .677 .411 r
F P
0 g
s
.48719 .42366 m .47614 .43056 L .42956 .40224 L p 0 .911 1 r
F P
0 g
s
.52098 .35289 m .52152 .40222 L .56582 .43056 L p 0 .668 0 r
F P
0 g
s
.52152 .40222 m .52098 .35289 L .47552 .32256 L p 0 .668 0 r
F P
0 g
s
.47614 .27525 m .47552 .32256 L .52098 .35289 L p 0 .668 0 r
F P
0 g
s
.57744 .42366 m .56582 .43056 L .52152 .40222 L p 0 .911 0 r
F P
0 g
s
.52098 .35289 m .53231 .3455 L .53315 .39496 L p 0 .1 0 r
F P
0 g
s
.53315 .39496 m .52152 .40222 L .52098 .35289 L p 0 .1 0 r
F P
0 g
s
.53231 .3455 m .52098 .35289 L .52152 .40222 L p 0 .1 0 r
F P
0 g
s
.52098 .35289 m .53231 .3455 L .48686 .31478 L p 0 .907 0 r
F P
0 g
s
.48686 .31478 m .47552 .32256 L .52098 .35289 L p 0 .907 0 r
F P
0 g
s
.53231 .3455 m .52098 .35289 L .47552 .32256 L p 0 .907 0 r
F P
0 g
s
.66768 .26734 m .65551 .27522 L .6595 .32256 L p 0 .1 0 r
F P
0 g
s
.65551 .27522 m .66768 .26734 L .62573 .23461 L p 0 .903 0 r
F P
0 g
s
.62573 .23461 m .61351 .24289 L .65551 .27522 L p 0 .903 0 r
F P
0 g
s
.6595 .32256 m .65551 .27522 L .61351 .24289 L p 0 .645 0 r
F P
0 g
s
.56582 .27522 m .56751 .32256 L .61067 .35289 L p 0 .658 .35 r
F P
0 g
s
.56582 .27522 m .57744 .26734 L .57944 .31478 L p 0 .1 .396 r
F P
0 g
s
.57944 .31478 m .56751 .32256 L .56582 .27522 L p 0 .1 .396 r
F P
0 g
s
.56751 .32256 m .56582 .27522 L .52155 .24291 L p 0 .658 .35 r
F P
0 g
s
.62256 .3455 m .61067 .35289 L .61351 .40222 L p 0 .1 .423 r
F P
0 g
s
.61067 .35289 m .62256 .3455 L .57944 .31478 L p 0 .907 1 r
F P
0 g
s
.57944 .31478 m .56751 .32256 L .61067 .35289 L p 0 .907 1 r
F P
0 g
s
.61351 .40222 m .61067 .35289 L .56751 .32256 L p 0 .658 .35 r
F P
0 g
s
.62256 .3455 m .61067 .35289 L .56751 .32256 L p 0 .907 1 r
F P
0 g
s
.57744 .26734 m .56582 .27522 L .56751 .32256 L p 0 .1 .396 r
F P
0 g
s
.56582 .27522 m .57744 .26734 L .53318 .23463 L p 0 .903 1 r
F P
0 g
s
.53318 .23463 m .52155 .24291 L .56582 .27522 L p 0 .903 1 r
F P
0 g
s
.47614 .27525 m .48719 .26738 L .48686 .31478 L p 0 .1 0 r
F P
0 g
s
.48686 .31478 m .47552 .32256 L .47614 .27525 L p 0 .1 0 r
F P
0 g
s
.6137 .67327 m .61373 .67324 L p .56882 .59549 L 0 .677 0 r
F P
0 g
s
.60455 .57745 m .61666 .57134 L .61373 .51769 L p 0 .1 .45 r
F P
0 g
s
.61666 .57134 m .61373 .51769 L .57059 .49155 L p 0 .668 .382 r
F P
0 g
s
.60455 .57745 m .61666 .57134 L .65865 .59549 L p 0 .916 1 r
F P
0 g
s
.61373 .51769 m .61666 .57134 L .65865 .59549 L p 0 .668 .382 r
F P
0 g
s
.65033 .6567 m .66273 .6511 L .65865 .59549 L p 0 .114 .472 r
F P
0 g
s
.66273 .6511 m .65865 .59549 L .61666 .57134 L p 0 .668 .382 r
F P
0 g
s
.513 .57745 m .52452 .57134 L .56882 .59549 L p 0 .916 0 r
F P
0 g
s
.5239 .51769 m .52452 .57134 L .56882 .59549 L p 0 .677 0 r
F P
0 g
s
.55878 .65674 m .57059 .65114 L .56882 .59549 L p 0 .1 0 r
F P
0 g
s
.57059 .65114 m .56882 .59549 L .52452 .57134 L p 0 .677 0 r
F P
0 g
s
.56882 .59549 m .57059 .65114 L .6137 .67327 L p 0 .677 0 r
F P
0 g
s
.47899 .59549 m .47845 .65114 L .46722 .65674 L p 0 .1 .425 r
F P
0 g
s
.55878 .65674 m .57059 .65114 L .6137 .67327 L p 0 .916 0 r
F P
0 g
s
.69611 .57745 m .7088 .57134 L .70357 .51773 L p 0 .114 0 r
F P
0 g
s
.70357 .51773 m .70354 .51767 L .66273 .49155 L p 0 .658 0 r
F P
0 g
s
.7088 .57134 m .70357 .51773 L p .66273 .49155 L 0 .658 0 r
F P
0 g
s
.62601 .66769 m .61407 .67309 L .61404 .67311 L p 0 .1 .1 r
F P
0 g
s
.61404 .67311 m .61407 .67309 L p .56915 .59532 L 0 .677 .411 r
F P
0 g
s
.52423 .51751 m .52485 .57117 L .56915 .59532 L p 0 .677 .411 r
F P
0 g
s
.5808 .58944 m .56915 .59532 L .52485 .57117 L p 0 .916 1 r
F P
0 g
s
.57093 .65098 m .56915 .59532 L .52485 .57117 L p 0 .677 .411 r
F P
0 g
s
.56915 .59532 m .57093 .65098 L .61404 .67311 L p 0 .677 .411 r
F P
0 g
s
.56915 .59532 m .5808 .58944 L .53652 .56498 L p 0 .916 1 r
F P
0 g
s
.53652 .56498 m .52485 .57117 L .56915 .59532 L p 0 .916 1 r
F P
0 g
s
.5808 .58944 m .56915 .59532 L .57093 .65098 L p 0 .1 .45 r
F P
0 g
s
.56915 .59532 m .5808 .58944 L .5829 .6453 L p 0 .1 .45 r
F P
0 g
s
.5829 .6453 m .57093 .65098 L .56915 .59532 L p 0 .1 .45 r
F P
0 g
s
.52423 .51751 m .5356 .51114 L .53652 .56498 L p 0 .1 .425 r
F P
0 g
s
.53652 .56498 m .52485 .57117 L .52423 .51751 L p 0 .1 .425 r
F P
0 g
s
.66308 .65094 m .659 .59532 L .61701 .57117 L p 0 .668 0 r
F P
0 g
s
.61407 .51751 m .61701 .57117 L .659 .59532 L p 0 .668 0 r
F P
0 g
s
.659 .59532 m .67121 .58944 L .62927 .56498 L p 0 .916 0 r
F P
0 g
s
.62927 .56498 m .61701 .57117 L .659 .59532 L p 0 .916 0 r
F P
0 g
s
.67121 .58944 m .659 .59532 L .66308 .65094 L p 0 .114 0 r
F P
0 g
s
.61407 .51751 m .62601 .51114 L .5829 .48465 L p 0 .914 0 r
F P
0 g
s
.5829 .48465 m .57093 .49135 L .61407 .51751 L p 0 .914 0 r
F P
0 g
s
.62601 .51114 m .61407 .51751 L .61701 .57117 L p 0 .1 0 r
F P
0 g
s
.61701 .57117 m .61407 .51751 L .57093 .49135 L p 0 .668 0 r
F P
0 g
s
.61407 .51751 m .62601 .51114 L .62927 .56498 L p 0 .1 0 r
F P
0 g
s
.62927 .56498 m .61701 .57117 L .61407 .51751 L p 0 .1 0 r
F P
0 g
s
.67121 .58944 m .659 .59532 L .61701 .57117 L p 0 .916 0 r
F P
0 g
s
.49015 .6453 m .5356 .66773 L .52423 .67313 L p 0 .916 0 r
F P
0 g
s
.52423 .67313 m .47877 .65098 L .49015 .6453 L p 0 .916 0 r
F P
0 g
s
.47877 .65098 m .4793 .59532 L .49039 .58944 L p 0 .1 0 r
F P
0 g
s
.61404 .67311 m .62598 .66772 L .62601 .66769 L p 0 .1 .1 r
F P
0 g
s
.62598 .66772 m .61404 .67311 L .57093 .65098 L p 0 .916 1 r
F P
0 g
s
.70389 .51749 m .71639 .51112 L .67565 .48465 L p 0 .914 1 r
F P
0 g
s
.67565 .48465 m .66309 .49135 L .70389 .51749 L p 0 .914 1 r
F P
0 g
s
.71642 .51118 m .70393 .51754 L .70917 .57117 L p 0 .114 .472 r
F P
0 g
s
.70393 .51754 m .71642 .51118 L .71639 .51112 L p 0 .562 .887 r
F P
0 g
s
.71639 .51112 m .70389 .51749 L .70393 .51754 L p 0 .562 .887 r
F P
0 g
s
.70393 .51754 m .70389 .51749 L .66309 .49135 L p 0 .658 .35 r
F P
0 g
s
.70917 .57117 m .70393 .51754 L p .66309 .49135 L 0 .658 .35 r
F P
0 g
s
.75612 .27243 m .76271 .31981 L .80106 .35028 L p 0 .627 .269 r
F P
0 g
s
.75612 .27243 m .76271 .31981 L .80106 .35028 L p 0 .627 .269 r
F P
0 g
s
.76271 .31981 m .75612 .27243 L .76472 .26713 L p 0 .1 .45 r
F P
0 g
s
.80878 .39963 m .8088 .39962 L .79983 .40446 L p 0 .1 .1 r
F P
0 g
s
.80106 .35028 m .76271 .31981 L p .80878 .39963 L 0 .627 .269 r
F P
0 g
s
.80878 .39963 m .8088 .39962 L .80106 .35028 L p 0 .627 .269 r
F P
0 g
s
.76271 .31981 m .80106 .35028 L .80985 .3453 L p 0 .907 1 r
F P
0 g
s
.80106 .35028 m .8088 .39962 L .81785 .39473 L p 0 .114 .472 r
F P
0 g
s
.81785 .39473 m .80985 .3453 L .80106 .35028 L p 0 .114 .472 r
F P
0 g
s
.80106 .35028 m .76271 .31981 L p .80878 .39963 L 0 .627 .269 r
F P
0 g
s
.80878 .39963 m .8088 .39962 L .80106 .35028 L p 0 .627 .269 r
F P
0 g
s
.80106 .35028 m .76271 .31981 L .77156 .31458 L p 0 .907 1 r
F P
0 g
s
.77156 .31458 m .80985 .3453 L .80106 .35028 L p 0 .907 1 r
F P
0 g
s
.71661 .23996 m .75612 .27243 L .76472 .26713 L p 0 .903 1 r
F P
0 g
s
.75612 .27243 m .76271 .31981 L .77156 .31458 L p 0 .1 .45 r
F P
0 g
s
.77156 .31458 m .76472 .26713 L .75612 .27243 L p 0 .1 .45 r
F P
0 g
s
.75612 .27243 m .71661 .23996 L .70803 .24549 L p 0 .903 1 r
F P
0 g
s
.75612 .27243 m .76271 .31981 L .75394 .32499 L p 0 .1 .45 r
F P
0 g
s
.76271 .31981 m .75612 .27243 L .71661 .23996 L p 0 .627 .269 r
F P
0 g
s
.76271 .31981 m .75612 .27243 L .71661 .23996 L p 0 .627 .269 r
F P
0 g
s
.28047 .65515 m .29052 .64953 L .34074 .67174 L p 0 .916 1 r
F P
0 g
s
.52073 .51587 m .47511 .48963 L .46388 .49626 L p 0 .914 0 r
F P
0 g
s
.52126 .56957 m .52073 .51587 L .47511 .48963 L p 0 .677 0 r
F P
0 g
s
.37216 .65514 m .3828 .64951 L .43074 .67174 L p 0 .916 0 r
F P
0 g
s
.3263 .5757 m .33664 .56957 L .38574 .5938 L p 0 .916 0 r
F P
0 g
s
.37216 .65514 m .3828 .64951 L .38574 .5938 L p 0 .1 0 r
F P
0 g
s
.33233 .62607 m .33664 .56957 L .38574 .5938 L p 0 .69 0 r
F P
0 g
s
.33236 .62613 m .33233 .62607 L p .38574 .5938 L 0 .69 0 r
F P
0 g
s
.38574 .5938 m .3828 .64951 L .33236 .62613 L p 0 .69 0 r
F P
0 g
s
.46388 .65514 m .47511 .64951 L .47573 .5938 L p 0 .1 .423 r
F P
0 g
s
.41802 .5757 m .42895 .56957 L .47573 .5938 L p 0 .916 1 r
F P
0 g
s
.42708 .62611 m .42895 .56957 L .47573 .5938 L p 0 .684 .437 r
F P
0 g
s
.47573 .5938 m .47511 .64951 L .42708 .62611 L p 0 .684 .437 r
F P
0 g
s
.41802 .5757 m .42895 .56957 L .43074 .51587 L p 0 .1 .396 r
F P
0 g
s
.37219 .49628 m .38283 .48965 L .3828 .48966 L p 0 .93 .764 r
F P
0 g
s
.3828 .48966 m .38283 .48965 L .43074 .51587 L p 0 .684 .437 r
F P
0 g
s
.3797 .54406 m .3828 .48966 L p .43074 .51587 L 0 .684 .437 r
F P
0 g
s
.43074 .51587 m .42895 .56957 L .3797 .54406 L p 0 .684 .437 r
F P
0 g
s
.26074 .66619 m .25107 .6716 L .25103 .67154 L p 0 .525 .891 r
F P
0 g
s
.25103 .67154 m .26071 .66613 L .26074 .66619 L p 0 .525 .891 r
F P
0 g
s
.35128 .50933 m .34103 .51572 L .34107 .5157 L p 0 .93 .764 r
F P
0 g
s
.47543 .48943 m .52106 .51568 L .53243 .50929 L p 0 .914 1 r
F P
0 g
s
.52106 .51568 m .5216 .56939 L .53327 .56318 L p 0 .1 .423 r
F P
0 g
s
.53327 .56318 m .53243 .50929 L .52106 .51568 L p 0 .1 .423 r
F P
0 g
s
.5216 .56939 m .52106 .51568 L .47543 .48943 L p 0 .677 .411 r
F P
0 g
s
.30097 .64361 m .29078 .64931 L .29603 .59363 L p 0 .1 0 r
F P
0 g
s
.29603 .59363 m .30599 .58773 L .30097 .64361 L p 0 .1 0 r
F P
0 g
s
.35128 .66617 m .34104 .67158 L .29082 .64937 L p 0 .916 0 r
F P
0 g
s
.44185 .66617 m .43105 .67158 L .38311 .64935 L p 0 .916 1 r
F P
0 g
s
.39389 .64365 m .38311 .64935 L .38604 .59363 L p 0 .1 .396 r
F P
0 g
s
.38604 .59363 m .39657 .58773 L .39389 .64365 L p 0 .1 .396 r
F P
0 g
s
.34743 .56318 m .33694 .56939 L .38604 .59363 L p 0 .916 1 r
F P
0 g
s
.38604 .59363 m .39657 .58773 L .34743 .56318 L p 0 .916 1 r
F P
0 g
s
.39657 .58773 m .38604 .59363 L .38311 .64935 L p 0 .1 .396 r
F P
0 g
s
.33263 .6259 m .33694 .56939 L .38604 .59363 L p 0 .69 .46 r
F P
0 g
s
.33267 .62596 m .33263 .6259 L p .38604 .59363 L 0 .69 .46 r
F P
0 g
s
.38604 .59363 m .38311 .64935 L .33267 .62596 L p 0 .69 .46 r
F P
0 g
s
.39657 .58773 m .38604 .59363 L .33694 .56939 L p 0 .916 1 r
F P
0 g
s
.44035 .56318 m .42927 .56939 L .47605 .59363 L p 0 .916 0 r
F P
0 g
s
.47605 .59363 m .48714 .58773 L .44035 .56318 L p 0 .916 0 r
F P
0 g
s
.48714 .58773 m .47605 .59363 L .47543 .64935 L p 0 .1 0 r
F P
0 g
s
.4274 .62594 m .42927 .56939 L .47605 .59363 L p 0 .684 0 r
F P
0 g
s
.47605 .59363 m .47543 .64935 L .4274 .62594 L p 0 .684 0 r
F P
0 g
s
.48714 .58773 m .47605 .59363 L .42927 .56939 L p 0 .916 0 r
F P
0 g
s
.44035 .56318 m .42927 .56939 L .43105 .51568 L p 0 .1 0 r
F P
0 g
s
.43105 .51568 m .44185 .50929 L .44035 .56318 L p 0 .1 0 r
F P
0 g
s
.39392 .48273 m .38314 .48945 L .43105 .51568 L p 0 .914 0 r
F P
0 g
s
.43105 .51568 m .44185 .50929 L .39392 .48273 L p 0 .914 0 r
F P
0 g
s
.44185 .50929 m .43105 .51568 L .42927 .56939 L p 0 .1 0 r
F P
0 g
s
.3831 .48947 m .38314 .48945 L .43105 .51568 L p 0 .684 0 r
F P
0 g
s
.38002 .54387 m .3831 .48947 L p .43105 .51568 L 0 .684 0 r
F P
0 g
s
.43105 .51568 m .42927 .56939 L .38002 .54387 L p 0 .684 0 r
F P
0 g
s
.34743 .56318 m .33694 .56939 L .34103 .51572 L p 0 .1 .365 r
F P
0 g
s
.34103 .51572 m .35128 .50933 L .34743 .56318 L p 0 .1 .365 r
F P
0 g
s
.85862 .31771 m .84962 .27034 L .84959 .27028 L p 0 .607 0 r
F P
0 g
s
.84959 .27028 m .84962 .27034 L .86292 .26248 L p 0 .575 0 r
F P
0 g
s
.84962 .27034 m .85862 .31771 L .87233 .30995 L p 0 .114 0 r
F P
0 g
s
.87233 .30995 m .86292 .26248 L .84962 .27034 L p 0 .114 0 r
F P
0 g
s
.85862 .31771 m .84962 .27034 L .84959 .27028 L p 0 .607 0 r
F P
0 g
s
.84959 .27028 m .81244 .23772 L .7992 .24588 L p 0 .903 0 r
F P
0 g
s
.84959 .27028 m .81244 .23772 L p .85862 .31771 L 0 .607 0 r
F P
0 g
s
.81244 .23772 m .84959 .27028 L .86289 .26243 L p 0 .903 0 r
F P
0 g
s
.86292 .26248 m .86289 .26243 L .84959 .27028 L p 0 .575 0 r
F P
0 g
s
.84959 .27028 m .81244 .23772 L p .85862 .31771 L 0 .607 0 r
F P
0 g
s
.76068 .42562 m .76066 .42563 L .77355 .41867 L p 0 .1 0 r
F P
0 g
s
.71564 .34764 m .675 .31703 L .66249 .32477 L p 0 .907 0 r
F P
0 g
s
.71564 .34764 m .7212 .39706 L .7084 .40429 L p 0 .1 0 r
F P
0 g
s
.7212 .39706 m .71564 .34764 L .675 .31703 L p 0 .641 0 r
F P
0 g
s
.6706 .26962 m .675 .31703 L .71564 .34764 L p 0 .641 0 r
F P
0 g
s
.6706 .26962 m .675 .31703 L .71564 .34764 L p 0 .641 0 r
F P
0 g
s
.675 .31703 m .71564 .34764 L .72825 .34018 L p 0 .907 0 r
F P
0 g
s
.71564 .34764 m .7212 .39706 L .73417 .38973 L p 0 .1 0 r
F P
0 g
s
.73417 .38973 m .72825 .34018 L .71564 .34764 L p 0 .1 0 r
F P
0 g
s
.7212 .39706 m .71564 .34764 L .675 .31703 L p 0 .641 0 r
F P
0 g
s
.6706 .26962 m .675 .31703 L .66249 .32477 L p 0 .1 0 r
F P
0 g
s
.71564 .34764 m .675 .31703 L .68767 .30919 L p 0 .907 0 r
F P
0 g
s
.68767 .30919 m .72825 .34018 L .71564 .34764 L p 0 .907 0 r
F P
0 g
s
.675 .31703 m .6706 .26962 L .68292 .26168 L p 0 .1 0 r
F P
0 g
s
.7212 .39706 m .71564 .34764 L .72825 .34018 L p 0 .1 0 r
F P
0 g
s
.62556 .34764 m .62879 .39706 L .61658 .40429 L p 0 .1 .425 r
F P
0 g
s
.62556 .34764 m .62879 .39706 L .6706 .42565 L p 0 .655 .342 r
F P
0 g
s
.62556 .34764 m .62879 .39706 L .6706 .42565 L p 0 .655 .342 r
F P
0 g
s
.62879 .39706 m .62556 .34764 L .6376 .34018 L p 0 .1 .425 r
F P
0 g
s
.6706 .42565 m .62879 .39706 L .64117 .38973 L p 0 .911 1 r
F P
0 g
s
.64117 .38973 m .68292 .41869 L .6706 .42565 L p 0 .911 1 r
F P
0 g
s
.76066 .42563 m .7212 .39706 L .73417 .38973 L p 0 .911 0 r
F P
0 g
s
.73417 .38973 m .77355 .41867 L .76066 .42563 L p 0 .911 0 r
F P
0 g
s
.40756 .41663 m .4076 .41669 L .39697 .42368 L p 0 .546 0 r
F P
0 g
s
.39697 .42368 m .39694 .42362 L .40756 .41663 L p 0 .546 0 r
F P
0 g
s
.48722 .26737 m .48719 .26738 L p .53231 .3455 L 0 .666 0 r
F P
0 g
s
.48722 .26737 m .49841 .2594 L .49838 .25941 L p 0 1 0 r
F P
0 g
s
.49838 .25941 m .48719 .26738 L .48722 .26737 L p 0 1 0 r
F P
0 g
s
.48722 .26737 m .48719 .26738 L p .53231 .3455 L 0 .666 0 r
F P
0 g
s
.44206 .3455 m .44057 .39492 L p .48719 .42366 L 0 .675 .404 r
F P
0 g
s
.44206 .3455 m .44057 .39492 L p .48719 .42366 L 0 .675 .404 r
F P
0 g
s
.44206 .3455 m .45297 .33802 L .45175 .38757 L p 0 .1 .365 r
F P
0 g
s
.45175 .38757 m .44057 .39492 L .44206 .3455 L p 0 .1 .365 r
F P
0 g
s
.42956 .40224 m .4406 .39498 L .48719 .42366 L p 0 .911 1 r
F P
0 g
s
.44057 .39492 m .4406 .39498 L .48719 .42366 L p 0 .675 .404 r
F P
0 g
s
.44057 .39492 m .4406 .39498 L .48719 .42366 L p 0 .675 .404 r
F P
0 g
s
.49838 .41667 m .48719 .42366 L .4406 .39498 L p 0 .911 1 r
F P
0 g
s
.6595 .32256 m .67202 .31478 L .66768 .26734 L p 0 .1 0 r
F P
0 g
s
.67202 .31478 m .66768 .26734 L .62573 .23461 L p 0 .641 0 r
F P
0 g
s
.68001 .25937 m .66768 .26734 L .67202 .31478 L p 0 .1 0 r
F P
0 g
s
.66768 .26734 m .68001 .25937 L .6381 .22622 L p 0 .903 0 r
F P
0 g
s
.6381 .22622 m .62573 .23461 L .66768 .26734 L p 0 .903 0 r
F P
0 g
s
.67202 .31478 m .66768 .26734 L .62573 .23461 L p 0 .641 0 r
F P
0 g
s
.53231 .3455 m .53315 .39496 L .57744 .42366 L p 0 .666 0 r
F P
0 g
s
.53231 .3455 m .53315 .39496 L .57744 .42366 L p 0 .666 0 r
F P
0 g
s
.58919 .41667 m .57744 .42366 L .53315 .39496 L p 0 .911 0 r
F P
0 g
s
.53231 .3455 m .54379 .33802 L .54492 .38761 L p 0 .1 0 r
F P
0 g
s
.54492 .38761 m .53315 .39496 L .53231 .3455 L p 0 .1 0 r
F P
0 g
s
.52152 .40222 m .53315 .39496 L .53231 .3455 L p 0 .1 0 r
F P
0 g
s
.47552 .32256 m .48686 .31478 L .53231 .3455 L p 0 .907 0 r
F P
0 g
s
.53315 .39496 m .53231 .3455 L .48686 .31478 L p 0 .666 0 r
F P
0 g
s
.54379 .33802 m .53231 .3455 L .53315 .39496 L p 0 .1 0 r
F P
0 g
s
.48719 .26738 m .48686 .31478 L .53231 .3455 L p 0 .666 0 r
F P
0 g
s
.48719 .26738 m .48686 .31478 L .53231 .3455 L p 0 .666 0 r
F P
0 g
s
.53231 .3455 m .54379 .33802 L .49834 .30691 L p 0 .907 0 r
F P
0 g
s
.49834 .30691 m .48686 .31478 L .53231 .3455 L p 0 .907 0 r
F P
0 g
s
.53315 .39496 m .53231 .3455 L .48686 .31478 L p 0 .666 0 r
F P
0 g
s
.54379 .33802 m .53231 .3455 L .48686 .31478 L p 0 .907 0 r
F P
0 g
s
.52152 .40222 m .53315 .39496 L .57744 .42366 L p 0 .911 0 r
F P
0 g
s
.57744 .26734 m .57944 .31478 L .62256 .3455 L p 0 .655 .342 r
F P
0 g
s
.57744 .26734 m .57944 .31478 L .62256 .3455 L p 0 .655 .342 r
F P
0 g
s
.57744 .26734 m .58919 .25937 L .59151 .30691 L p 0 .1 .396 r
F P
0 g
s
.59151 .30691 m .57944 .31478 L .57744 .26734 L p 0 .1 .396 r
F P
0 g
s
.61351 .40222 m .62573 .39496 L .62256 .3455 L p 0 .1 .423 r
F P
0 g
s
.56751 .32256 m .57944 .31478 L .62256 .3455 L p 0 .907 1 r
F P
0 g
s
.62573 .39496 m .62256 .3455 L .57944 .31478 L p 0 .655 .342 r
F P
0 g
s
.62573 .39496 m .62256 .3455 L .57944 .31478 L p 0 .655 .342 r
F P
0 g
s
.6346 .33802 m .62256 .3455 L .62573 .39496 L p 0 .1 .423 r
F P
0 g
s
.62256 .3455 m .6346 .33802 L .59151 .30691 L p 0 .907 1 r
F P
0 g
s
.59151 .30691 m .57944 .31478 L .62256 .3455 L p 0 .907 1 r
F P
0 g
s
.6346 .33802 m .62256 .3455 L .57944 .31478 L p 0 .907 1 r
F P
0 g
s
.56751 .32256 m .57944 .31478 L .57744 .26734 L p 0 .1 .396 r
F P
0 g
s
.57944 .31478 m .57744 .26734 L .53318 .23463 L p 0 .655 .342 r
F P
0 g
s
.58919 .25937 m .57744 .26734 L .57944 .31478 L p 0 .1 .396 r
F P
0 g
s
.57744 .26734 m .58919 .25937 L .54496 .22624 L p 0 .903 1 r
F P
0 g
s
.54496 .22624 m .53318 .23463 L .57744 .26734 L p 0 .903 1 r
F P
0 g
s
.57944 .31478 m .57744 .26734 L .53318 .23463 L p 0 .655 .342 r
F P
0 g
s
.48719 .26738 m .49838 .25941 L .49834 .30691 L p 0 .1 0 r
F P
0 g
s
.49834 .30691 m .48686 .31478 L .48719 .26738 L p 0 .1 0 r
F P
0 g
s
.76472 .26713 m .77156 .31458 L .76271 .31981 L p 0 .1 .45 r
F P
0 g
s
.76472 .26713 m .77156 .31458 L .80985 .3453 L p 0 .624 .261 r
F P
0 g
s
.76472 .26713 m .77156 .31458 L .80985 .3453 L p 0 .624 .261 r
F P
0 g
s
.77156 .31458 m .76472 .26713 L .77339 .26179 L p 0 .1 .45 r
F P
0 g
s
.80985 .3453 m .77156 .31458 L .76271 .31981 L p 0 .907 1 r
F P
0 g
s
.81783 .39475 m .81785 .39473 L .8088 .39962 L p 0 .1 .1 r
F P
0 g
s
.80985 .3453 m .77156 .31458 L p .81783 .39475 L 0 .624 .261 r
F P
0 g
s
.81783 .39475 m .81785 .39473 L .80985 .3453 L p 0 .624 .261 r
F P
0 g
s
.77156 .31458 m .80985 .3453 L .81871 .34029 L p 0 .907 1 r
F P
0 g
s
.80985 .3453 m .81785 .39473 L .82697 .3898 L p 0 .114 .472 r
F P
0 g
s
.82697 .3898 m .81871 .34029 L .80985 .3453 L p 0 .114 .472 r
F P
0 g
s
.80985 .3453 m .77156 .31458 L p .81783 .39475 L 0 .624 .261 r
F P
0 g
s
.81783 .39475 m .81785 .39473 L .80985 .3453 L p 0 .624 .261 r
F P
0 g
s
.80985 .3453 m .77156 .31458 L .78048 .3093 L p 0 .907 1 r
F P
0 g
s
.78048 .3093 m .81871 .34029 L .80985 .3453 L p 0 .907 1 r
F P
0 g
s
.76472 .26713 m .72526 .23439 L .71661 .23996 L p 0 .903 1 r
F P
0 g
s
.77156 .31458 m .76472 .26713 L .72526 .23439 L p 0 .624 .261 r
F P
0 g
s
.72526 .23439 m .76472 .26713 L .77339 .26179 L p 0 .903 1 r
F P
0 g
s
.76472 .26713 m .77156 .31458 L .78048 .3093 L p 0 .1 .45 r
F P
0 g
s
.78048 .3093 m .77339 .26179 L .76472 .26713 L p 0 .1 .45 r
F P
0 g
s
.77156 .31458 m .76472 .26713 L .72526 .23439 L p 0 .624 .261 r
F P
0 g
s
.62598 .66772 m .62601 .66769 L p .5808 .58944 L 0 .675 .404 r
F P
0 g
s
.63809 .66223 m .62601 .66769 L .62598 .66772 L p 0 .1 .1 r
F P
0 g
s
.62598 .66772 m .62601 .66769 L p .5808 .58944 L 0 .675 .404 r
F P
0 g
s
.52485 .57117 m .53652 .56498 L .5808 .58944 L p 0 .916 1 r
F P
0 g
s
.5356 .51114 m .53652 .56498 L .5808 .58944 L p 0 .675 .404 r
F P
0 g
s
.5356 .51114 m .53652 .56498 L .5808 .58944 L p 0 .675 .404 r
F P
0 g
s
.5926 .58348 m .5808 .58944 L .53652 .56498 L p 0 .916 1 r
F P
0 g
s
.57093 .65098 m .5829 .6453 L .5808 .58944 L p 0 .1 .45 r
F P
0 g
s
.5829 .6453 m .5808 .58944 L .53652 .56498 L p 0 .675 .404 r
F P
0 g
s
.5808 .58944 m .5926 .58348 L .54834 .55871 L p 0 .916 1 r
F P
0 g
s
.54834 .55871 m .53652 .56498 L .5808 .58944 L p 0 .916 1 r
F P
0 g
s
.5808 .58944 m .5829 .6453 L .62598 .66772 L p 0 .675 .404 r
F P
0 g
s
.5808 .58944 m .5829 .6453 L .62598 .66772 L p 0 .675 .404 r
F P
0 g
s
.5926 .58348 m .5808 .58944 L .5829 .6453 L p 0 .1 .45 r
F P
0 g
s
.5829 .6453 m .5808 .58944 L .53652 .56498 L p 0 .675 .404 r
F P
0 g
s
.5808 .58944 m .5926 .58348 L .59502 .63955 L p 0 .1 .45 r
F P
0 g
s
.59502 .63955 m .5829 .6453 L .5808 .58944 L p 0 .1 .45 r
F P
0 g
s
.5356 .51114 m .54711 .50469 L .54834 .55871 L p 0 .1 .425 r
F P
0 g
s
.54834 .55871 m .53652 .56498 L .5356 .51114 L p 0 .1 .425 r
F P
0 g
s
.66308 .65094 m .67564 .64526 L .67121 .58944 L p 0 .114 0 r
F P
0 g
s
.61701 .57117 m .62927 .56498 L .67121 .58944 L p 0 .916 0 r
F P
0 g
s
.67564 .64526 m .67121 .58944 L .62927 .56498 L p 0 .666 0 r
F P
0 g
s
.62601 .51114 m .62927 .56498 L .67121 .58944 L p 0 .666 0 r
F P
0 g
s
.62601 .51114 m .62927 .56498 L .67121 .58944 L p 0 .666 0 r
F P
0 g
s
.67121 .58944 m .68358 .58348 L .64169 .55871 L p 0 .916 0 r
F P
0 g
s
.64169 .55871 m .62927 .56498 L .67121 .58944 L p 0 .916 0 r
F P
0 g
s
.68358 .58348 m .67121 .58944 L .67564 .64526 L p 0 .114 0 r
F P
0 g
s
.67564 .64526 m .67121 .58944 L .62927 .56498 L p 0 .666 0 r
F P
0 g
s
.62601 .51114 m .63809 .50469 L .59502 .47786 L p 0 .914 0 r
F P
0 g
s
.59502 .47786 m .5829 .48465 L .62601 .51114 L p 0 .914 0 r
F P
0 g
s
.63809 .50469 m .62601 .51114 L .62927 .56498 L p 0 .1 0 r
F P
0 g
s
.62601 .51114 m .63809 .50469 L .64169 .55871 L p 0 .1 0 r
F P
0 g
s
.64169 .55871 m .62927 .56498 L .62601 .51114 L p 0 .1 0 r
F P
0 g
s
.68358 .58348 m .67121 .58944 L .62927 .56498 L p 0 .916 0 r
F P
0 g
s
.61701 .57117 m .62927 .56498 L .62601 .51114 L p 0 .1 0 r
F P
0 g
s
.62927 .56498 m .62601 .51114 L .5829 .48465 L p 0 .666 0 r
F P
0 g
s
.62927 .56498 m .62601 .51114 L .5829 .48465 L p 0 .666 0 r
F P
0 g
s
.50167 .63955 m .54711 .66227 L .5356 .66773 L p 0 .916 0 r
F P
0 g
s
.5356 .66773 m .49015 .6453 L .50167 .63955 L p 0 .916 0 r
F P
0 g
s
.49015 .6453 m .49039 .58944 L .50162 .58348 L p 0 .1 0 r
F P
0 g
s
.49039 .58944 m .49015 .6453 L .47877 .65098 L p 0 .1 0 r
F P
0 g
s
.57093 .65098 m .5829 .6453 L .62598 .66772 L p 0 .916 1 r
F P
0 g
s
.62598 .66772 m .63806 .66226 L .63809 .66223 L p 0 .1 .1 r
F P
0 g
s
.63806 .66226 m .62598 .66772 L .5829 .6453 L p 0 .916 1 r
F P
0 g
s
.70917 .57117 m .72202 .56498 L .71642 .51118 L p 0 .114 .472 r
F P
0 g
s
.71642 .51118 m .71639 .51112 L .67565 .48465 L p 0 .655 .342 r
F P
0 g
s
.72202 .56498 m .71642 .51118 L p .67565 .48465 L 0 .655 .342 r
F P
0 g
s
.71642 .51118 m .71639 .51112 L .67565 .48465 L p 0 .655 .342 r
F P
0 g
s
.72202 .56498 m .71642 .51118 L p .67565 .48465 L 0 .655 .342 r
F P
0 g
s
.71639 .51112 m .72905 .50467 L .68837 .47786 L p 0 .914 1 r
F P
0 g
s
.68837 .47786 m .67565 .48465 L .71639 .51112 L p 0 .914 1 r
F P
0 g
s
.72905 .50467 m .71639 .51112 L .71642 .51118 L p 0 .562 .887 r
F P
0 g
s
.72908 .50473 m .71642 .51118 L .72202 .56498 L p 0 .114 .472 r
F P
0 g
s
.71642 .51118 m .72908 .50473 L .72905 .50467 L p 0 .562 .887 r
F P
0 g
s
.27055 .6607 m .26074 .66619 L .26071 .66613 L p 0 .525 .891 r
F P
0 g
s
.26071 .66613 m .27051 .66065 L .27055 .6607 L p 0 .525 .891 r
F P
0 g
s
.36165 .50286 m .35128 .50933 L .35132 .50931 L p 0 .93 .764 r
F P
0 g
s
.53243 .50929 m .48681 .48271 L .47543 .48943 L p 0 .914 1 r
F P
0 g
s
.53327 .56318 m .53243 .50929 L .48681 .48271 L p 0 .675 .404 r
F P
0 g
s
.48681 .48271 m .53243 .50929 L .54395 .50282 L p 0 .914 1 r
F P
0 g
s
.53243 .50929 m .53327 .56318 L .54509 .55689 L p 0 .1 .423 r
F P
0 g
s
.54509 .55689 m .54395 .50282 L .53243 .50929 L p 0 .1 .423 r
F P
0 g
s
.53327 .56318 m .53243 .50929 L .48681 .48271 L p 0 .675 .404 r
F P
0 g
s
.31129 .63784 m .30097 .64361 L .30599 .58773 L p 0 .1 0 r
F P
0 g
s
.30599 .58773 m .31608 .58175 L .31129 .63784 L p 0 .1 0 r
F P
0 g
s
.29082 .64937 m .301 .64367 L .35128 .66617 L p 0 .916 0 r
F P
0 g
s
.36165 .66069 m .35128 .66617 L .301 .64367 L p 0 .916 0 r
F P
0 g
s
.45157 .55689 m .44035 .56318 L .48714 .58773 L p 0 .916 0 r
F P
0 g
s
.48714 .58773 m .49837 .58175 L .45157 .55689 L p 0 .916 0 r
F P
0 g
s
.49837 .58175 m .48714 .58773 L .48681 .64365 L p 0 .1 0 r
F P
0 g
s
.42927 .56939 m .44035 .56318 L .48714 .58773 L p 0 .916 0 r
F P
0 g
s
.43876 .61994 m .44035 .56318 L .48714 .58773 L p 0 .683 0 r
F P
0 g
s
.47543 .64935 m .48681 .64365 L .48714 .58773 L p 0 .1 0 r
F P
0 g
s
.48714 .58773 m .48681 .64365 L .43876 .61994 L p 0 .683 0 r
F P
0 g
s
.43876 .61994 m .44035 .56318 L .48714 .58773 L p 0 .683 0 r
F P
0 g
s
.48714 .58773 m .48681 .64365 L .43876 .61994 L p 0 .683 0 r
F P
0 g
s
.49837 .58175 m .48714 .58773 L .44035 .56318 L p 0 .916 0 r
F P
0 g
s
.45157 .55689 m .44035 .56318 L .44185 .50929 L p 0 .1 0 r
F P
0 g
s
.44185 .50929 m .4528 .50282 L .45157 .55689 L p 0 .1 0 r
F P
0 g
s
.40484 .47591 m .39392 .48273 L .44185 .50929 L p 0 .914 0 r
F P
0 g
s
.44185 .50929 m .4528 .50282 L .40484 .47591 L p 0 .914 0 r
F P
0 g
s
.4528 .50282 m .44185 .50929 L .44035 .56318 L p 0 .1 0 r
F P
0 g
s
.38314 .48945 m .39392 .48273 L .39388 .48275 L p 0 .93 0 r
F P
0 g
s
.39388 .48275 m .39392 .48273 L .44185 .50929 L p 0 .683 0 r
F P
0 g
s
.39106 .53732 m .39388 .48275 L p .44185 .50929 L 0 .683 0 r
F P
0 g
s
.42927 .56939 m .44035 .56318 L .44185 .50929 L p 0 .1 0 r
F P
0 g
s
.44185 .50929 m .44035 .56318 L .39106 .53732 L p 0 .683 0 r
F P
0 g
s
.39388 .48275 m .39392 .48273 L .44185 .50929 L p 0 .683 0 r
F P
0 g
s
.39106 .53732 m .39388 .48275 L p .44185 .50929 L 0 .683 0 r
F P
0 g
s
.44185 .50929 m .44035 .56318 L .39106 .53732 L p 0 .683 0 r
F P
0 g
s
.4528 .66069 m .44185 .66617 L .39389 .64365 L p 0 .916 1 r
F P
0 g
s
.38311 .64935 m .39389 .64365 L .44185 .66617 L p 0 .916 1 r
F P
0 g
s
.40481 .63788 m .39389 .64365 L .39657 .58773 L p 0 .1 .396 r
F P
0 g
s
.39657 .58773 m .40723 .58175 L .40481 .63788 L p 0 .1 .396 r
F P
0 g
s
.40723 .58175 m .39657 .58773 L .34743 .56318 L p 0 .916 1 r
F P
0 g
s
.35804 .55689 m .34743 .56318 L .39657 .58773 L p 0 .916 1 r
F P
0 g
s
.39657 .58773 m .40723 .58175 L .35804 .55689 L p 0 .916 1 r
F P
0 g
s
.40723 .58175 m .39657 .58773 L .39389 .64365 L p 0 .1 .396 r
F P
0 g
s
.33694 .56939 m .34743 .56318 L .39657 .58773 L p 0 .916 1 r
F P
0 g
s
.34337 .6199 m .34743 .56318 L .39657 .58773 L p 0 .689 .454 r
F P
0 g
s
.3434 .61996 m .34337 .6199 L p .39657 .58773 L 0 .689 .454 r
F P
0 g
s
.38311 .64935 m .39389 .64365 L .39657 .58773 L p 0 .1 .396 r
F P
0 g
s
.39657 .58773 m .39389 .64365 L .3434 .61996 L p 0 .689 .454 r
F P
0 g
s
.34337 .6199 m .34743 .56318 L .39657 .58773 L p 0 .689 .454 r
F P
0 g
s
.3434 .61996 m .34337 .6199 L p .39657 .58773 L 0 .689 .454 r
F P
0 g
s
.39657 .58773 m .39389 .64365 L .3434 .61996 L p 0 .689 .454 r
F P
0 g
s
.35804 .55689 m .34743 .56318 L .35128 .50933 L p 0 .1 .365 r
F P
0 g
s
.35128 .50933 m .36165 .50286 L .35804 .55689 L p 0 .1 .365 r
F P
0 g
s
.87233 .30995 m .86292 .26248 L .86289 .26243 L p 0 .601 0 r
F P
0 g
s
.86289 .26243 m .82585 .22946 L .81244 .23772 L p 0 .903 0 r
F P
0 g
s
.86289 .26243 m .82585 .22946 L p .87233 .30995 L 0 .601 0 r
F P
0 g
s
.77339 .26179 m .73398 .22877 L .72526 .23439 L p 0 .903 1 r
F P
0 g
s
.77339 .26179 m .78048 .3093 L .77156 .31458 L p 0 .1 .45 r
F P
0 g
s
.78048 .3093 m .77339 .26179 L .73398 .22877 L p 0 .621 .254 r
F P
0 g
s
.73398 .22877 m .77339 .26179 L .78213 .2564 L p 0 .903 1 r
F P
0 g
s
.77339 .26179 m .78048 .3093 L .81871 .34029 L p 0 .621 .254 r
F P
0 g
s
.77339 .26179 m .78048 .3093 L .81871 .34029 L p 0 .621 .254 r
F P
0 g
s
.77339 .26179 m .78048 .3093 L .78948 .30398 L p 0 .1 .45 r
F P
0 g
s
.78948 .30398 m .78213 .2564 L .77339 .26179 L p 0 .1 .45 r
F P
0 g
s
.78048 .3093 m .77339 .26179 L .73398 .22877 L p 0 .621 .254 r
F P
0 g
s
.81871 .34029 m .78048 .3093 L .77156 .31458 L p 0 .907 1 r
F P
0 g
s
.82695 .38982 m .82697 .3898 L .81785 .39473 L p 0 .1 .1 r
F P
0 g
s
.81871 .34029 m .78048 .3093 L p .82695 .38982 L 0 .621 .254 r
F P
0 g
s
.82695 .38982 m .82697 .3898 L .81871 .34029 L p 0 .621 .254 r
F P
0 g
s
.78048 .3093 m .81871 .34029 L .82764 .33524 L p 0 .907 1 r
F P
0 g
s
.81871 .34029 m .82697 .3898 L .83618 .38483 L p 0 .114 .472 r
F P
0 g
s
.83618 .38483 m .82764 .33524 L .81871 .34029 L p 0 .114 .472 r
F P
0 g
s
.81871 .34029 m .78048 .3093 L p .82695 .38982 L 0 .621 .254 r
F P
0 g
s
.82695 .38982 m .82697 .3898 L .81871 .34029 L p 0 .621 .254 r
F P
0 g
s
.78048 .3093 m .77339 .26179 L .78213 .2564 L p 0 .1 .45 r
F P
0 g
s
.81871 .34029 m .78048 .3093 L .78948 .30398 L p 0 .907 1 r
F P
0 g
s
.78948 .30398 m .82764 .33524 L .81871 .34029 L p 0 .907 1 r
F P
0 g
s
.77357 .41865 m .77355 .41867 L .7866 .41162 L p 0 .1 0 r
F P
0 g
s
.68292 .26168 m .68767 .30919 L .72825 .34018 L p 0 .638 0 r
F P
0 g
s
.68292 .26168 m .68767 .30919 L .72825 .34018 L p 0 .638 0 r
F P
0 g
s
.68767 .30919 m .72825 .34018 L .74101 .33264 L p 0 .907 0 r
F P
0 g
s
.72825 .34018 m .73417 .38973 L .74731 .38231 L p 0 .1 0 r
F P
0 g
s
.74731 .38231 m .74101 .33264 L .72825 .34018 L p 0 .1 0 r
F P
0 g
s
.72825 .34018 m .68767 .30919 L .675 .31703 L p 0 .907 0 r
F P
0 g
s
.72825 .34018 m .73417 .38973 L .7212 .39706 L p 0 .1 0 r
F P
0 g
s
.73417 .38973 m .72825 .34018 L .68767 .30919 L p 0 .638 0 r
F P
0 g
s
.73417 .38973 m .72825 .34018 L .74101 .33264 L p 0 .1 0 r
F P
0 g
s
.68767 .30919 m .68292 .26168 L .6954 .25363 L p 0 .1 0 r
F P
0 g
s
.72825 .34018 m .68767 .30919 L .7005 .30124 L p 0 .907 0 r
F P
0 g
s
.7005 .30124 m .74101 .33264 L .72825 .34018 L p 0 .907 0 r
F P
0 g
s
.73417 .38973 m .72825 .34018 L .68767 .30919 L p 0 .638 0 r
F P
0 g
s
.68292 .26168 m .68767 .30919 L .675 .31703 L p 0 .1 0 r
F P
0 g
s
.6376 .34018 m .64117 .38973 L .62879 .39706 L p 0 .1 .425 r
F P
0 g
s
.6376 .34018 m .64117 .38973 L .68292 .41869 L p 0 .652 .333 r
F P
0 g
s
.6376 .34018 m .64117 .38973 L .68292 .41869 L p 0 .652 .333 r
F P
0 g
s
.64117 .38973 m .6376 .34018 L .64979 .33264 L p 0 .1 .425 r
F P
0 g
s
.68292 .41869 m .64117 .38973 L .6537 .38231 L p 0 .911 1 r
F P
0 g
s
.6537 .38231 m .6954 .41164 L .68292 .41869 L p 0 .911 1 r
F P
0 g
s
.77355 .41867 m .73417 .38973 L .74731 .38231 L p 0 .911 0 r
F P
0 g
s
.74731 .38231 m .7866 .41162 L .77355 .41867 L p 0 .911 0 r
F P
0 g
s
.40756 .41663 m .41832 .40956 L .41835 .40961 L p 0 .546 0 r
F P
0 g
s
.41835 .40961 m .4076 .41669 L .40756 .41663 L p 0 .546 0 r
F P
0 g
s
.49841 .2594 m .49838 .25941 L p .54379 .33802 L 0 .663 0 r
F P
0 g
s
.49841 .2594 m .50974 .25132 L .50971 .25133 L p 0 1 0 r
F P
0 g
s
.50971 .25133 m .49838 .25941 L .49841 .2594 L p 0 1 0 r
F P
0 g
s
.49841 .2594 m .49838 .25941 L p .54379 .33802 L 0 .663 0 r
F P
0 g
s
.69249 .2513 m .68001 .25937 L .68469 .30691 L p 0 .1 0 r
F P
0 g
s
.68001 .25937 m .69249 .2513 L .65064 .21772 L p 0 .903 0 r
F P
0 g
s
.65064 .21772 m .6381 .22622 L .68001 .25937 L p 0 .903 0 r
F P
0 g
s
.67202 .31478 m .68469 .30691 L .68001 .25937 L p 0 .1 0 r
F P
0 g
s
.68469 .30691 m .68001 .25937 L .6381 .22622 L p 0 .638 0 r
F P
0 g
s
.45297 .33802 m .45175 .38757 L p .49838 .41667 L 0 .673 .397 r
F P
0 g
s
.45297 .33802 m .45175 .38757 L p .49838 .41667 L 0 .673 .397 r
F P
0 g
s
.45297 .33802 m .46402 .33045 L .46307 .38012 L p 0 .1 .365 r
F P
0 g
s
.46307 .38012 m .45175 .38757 L .45297 .33802 L p 0 .1 .365 r
F P
0 g
s
.4406 .39498 m .45178 .38763 L .49838 .41667 L p 0 .911 1 r
F P
0 g
s
.45175 .38757 m .45178 .38763 L .49838 .41667 L p 0 .673 .397 r
F P
0 g
s
.45175 .38757 m .45178 .38763 L .49838 .41667 L p 0 .673 .397 r
F P
0 g
s
.50971 .40959 m .49838 .41667 L .45178 .38763 L p 0 .911 1 r
F P
0 g
s
.68469 .30691 m .68001 .25937 L .6381 .22622 L p 0 .638 0 r
F P
0 g
s
.54379 .33802 m .54492 .38761 L .58919 .41667 L p 0 .663 0 r
F P
0 g
s
.54379 .33802 m .54492 .38761 L .58919 .41667 L p 0 .663 0 r
F P
0 g
s
.54379 .33802 m .55541 .33045 L .55686 .38016 L p 0 .1 0 r
F P
0 g
s
.55686 .38016 m .54492 .38761 L .54379 .33802 L p 0 .1 0 r
F P
0 g
s
.53315 .39496 m .54492 .38761 L .54379 .33802 L p 0 .1 0 r
F P
0 g
s
.48686 .31478 m .49834 .30691 L .54379 .33802 L p 0 .907 0 r
F P
0 g
s
.54492 .38761 m .54379 .33802 L .49834 .30691 L p 0 .663 0 r
F P
0 g
s
.55541 .33045 m .54379 .33802 L .54492 .38761 L p 0 .1 0 r
F P
0 g
s
.49838 .25941 m .49834 .30691 L .54379 .33802 L p 0 .663 0 r
F P
0 g
s
.49838 .25941 m .49834 .30691 L .54379 .33802 L p 0 .663 0 r
F P
0 g
s
.54379 .33802 m .55541 .33045 L .50996 .29894 L p 0 .907 0 r
F P
0 g
s
.50996 .29894 m .49834 .30691 L .54379 .33802 L p 0 .907 0 r
F P
0 g
s
.54492 .38761 m .54379 .33802 L .49834 .30691 L p 0 .663 0 r
F P
0 g
s
.55541 .33045 m .54379 .33802 L .49834 .30691 L p 0 .907 0 r
F P
0 g
s
.53315 .39496 m .54492 .38761 L .58919 .41667 L p 0 .911 0 r
F P
0 g
s
.6011 .40959 m .58919 .41667 L .54492 .38761 L p 0 .911 0 r
F P
0 g
s
.58919 .25937 m .59151 .30691 L .6346 .33802 L p 0 .652 .333 r
F P
0 g
s
.58919 .25937 m .59151 .30691 L .6346 .33802 L p 0 .652 .333 r
F P
0 g
s
.58919 .25937 m .6011 .2513 L .60375 .29894 L p 0 .1 .396 r
F P
0 g
s
.60375 .29894 m .59151 .30691 L .58919 .25937 L p 0 .1 .396 r
F P
0 g
s
.62573 .39496 m .6381 .38761 L .6346 .33802 L p 0 .1 .423 r
F P
0 g
s
.57944 .31478 m .59151 .30691 L .6346 .33802 L p 0 .907 1 r
F P
0 g
s
.6381 .38761 m .6346 .33802 L .59151 .30691 L p 0 .652 .333 r
F P
0 g
s
.6468 .33045 m .6346 .33802 L .6381 .38761 L p 0 .1 .423 r
F P
0 g
s
.6346 .33802 m .6468 .33045 L .60375 .29894 L p 0 .907 1 r
F P
0 g
s
.60375 .29894 m .59151 .30691 L .6346 .33802 L p 0 .907 1 r
F P
0 g
s
.6381 .38761 m .6346 .33802 L .59151 .30691 L p 0 .652 .333 r
F P
0 g
s
.6468 .33045 m .6346 .33802 L .59151 .30691 L p 0 .907 1 r
F P
0 g
s
.57944 .31478 m .59151 .30691 L .58919 .25937 L p 0 .1 .396 r
F P
0 g
s
.59151 .30691 m .58919 .25937 L .54496 .22624 L p 0 .652 .333 r
F P
0 g
s
.6011 .2513 m .58919 .25937 L .59151 .30691 L p 0 .1 .396 r
F P
0 g
s
.58919 .25937 m .6011 .2513 L .55689 .21775 L p 0 .903 1 r
F P
0 g
s
.55689 .21775 m .54496 .22624 L .58919 .25937 L p 0 .903 1 r
F P
0 g
s
.59151 .30691 m .58919 .25937 L .54496 .22624 L p 0 .652 .333 r
F P
0 g
s
.49838 .25941 m .50971 .25133 L .50996 .29894 L p 0 .1 0 r
F P
0 g
s
.50996 .29894 m .49834 .30691 L .49838 .25941 L p 0 .1 0 r
F P
0 g
s
.83175 .22582 m .86874 .25897 L .88012 .25226 L p 0 .903 1 r
F P
0 g
s
.86874 .25897 m .86877 .25903 L .88015 .25231 L p 0 .575 .884 r
F P
0 g
s
.88015 .25231 m .88012 .25226 L .86874 .25897 L p 0 .575 .884 r
F P
0 g
s
.86877 .25903 m .87836 .30654 L .89008 .2999 L p 0 .114 .472 r
F P
0 g
s
.89008 .2999 m .88015 .25231 L .86877 .25903 L p 0 .114 .472 r
F P
0 g
s
.86874 .25897 m .83175 .22582 L p .87836 .30654 L 0 .599 .205 r
F P
0 g
s
.87836 .30654 m .86877 .25903 L .86874 .25897 L p 0 .599 .205 r
F P
0 g
s
.63806 .66226 m .63809 .66223 L p .5926 .58348 L 0 .673 .397 r
F P
0 g
s
.65033 .6567 m .63809 .66223 L .63806 .66226 L p 0 .1 .1 r
F P
0 g
s
.63806 .66226 m .63809 .66223 L p .5926 .58348 L 0 .673 .397 r
F P
0 g
s
.53652 .56498 m .54834 .55871 L .5926 .58348 L p 0 .916 1 r
F P
0 g
s
.54711 .50469 m .54834 .55871 L .5926 .58348 L p 0 .673 .397 r
F P
0 g
s
.54711 .50469 m .54834 .55871 L .5926 .58348 L p 0 .673 .397 r
F P
0 g
s
.60455 .57745 m .5926 .58348 L .54834 .55871 L p 0 .916 1 r
F P
0 g
s
.5829 .6453 m .59502 .63955 L .5926 .58348 L p 0 .1 .45 r
F P
0 g
s
.59502 .63955 m .5926 .58348 L .54834 .55871 L p 0 .673 .397 r
F P
0 g
s
.5926 .58348 m .60455 .57745 L .56032 .55236 L p 0 .916 1 r
F P
0 g
s
.56032 .55236 m .54834 .55871 L .5926 .58348 L p 0 .916 1 r
F P
0 g
s
.5926 .58348 m .59502 .63955 L .63806 .66226 L p 0 .673 .397 r
F P
0 g
s
.5926 .58348 m .59502 .63955 L .63806 .66226 L p 0 .673 .397 r
F P
0 g
s
.60455 .57745 m .5926 .58348 L .59502 .63955 L p 0 .1 .45 r
F P
0 g
s
.59502 .63955 m .5926 .58348 L .54834 .55871 L p 0 .673 .397 r
F P
0 g
s
.5926 .58348 m .60455 .57745 L .6073 .63373 L p 0 .1 .45 r
F P
0 g
s
.6073 .63373 m .59502 .63955 L .5926 .58348 L p 0 .1 .45 r
F P
0 g
s
.54711 .50469 m .55878 .49816 L .56032 .55236 L p 0 .1 .425 r
F P
0 g
s
.56032 .55236 m .54834 .55871 L .54711 .50469 L p 0 .1 .425 r
F P
0 g
s
.63809 .50469 m .64169 .55871 L .68358 .58348 L p 0 .663 0 r
F P
0 g
s
.63809 .50469 m .64169 .55871 L .68358 .58348 L p 0 .663 0 r
F P
0 g
s
.68358 .58348 m .69611 .57745 L .65427 .55236 L p 0 .916 0 r
F P
0 g
s
.65427 .55236 m .64169 .55871 L .68358 .58348 L p 0 .916 0 r
F P
0 g
s
.69611 .57745 m .68358 .58348 L .68836 .63951 L p 0 .114 0 r
F P
0 g
s
.62927 .56498 m .64169 .55871 L .68358 .58348 L p 0 .916 0 r
F P
0 g
s
.69611 .57745 m .68358 .58348 L .64169 .55871 L p 0 .916 0 r
F P
0 g
s
.67564 .64526 m .68836 .63951 L .68358 .58348 L p 0 .114 0 r
F P
0 g
s
.68836 .63951 m .68358 .58348 L .64169 .55871 L p 0 .663 0 r
F P
0 g
s
.68836 .63951 m .68358 .58348 L .64169 .55871 L p 0 .663 0 r
F P
0 g
s
.62927 .56498 m .64169 .55871 L .63809 .50469 L p 0 .1 0 r
F P
0 g
s
.64169 .55871 m .63809 .50469 L .59502 .47786 L p 0 .663 0 r
F P
0 g
s
.64169 .55871 m .63809 .50469 L .59502 .47786 L p 0 .663 0 r
F P
0 g
s
.63809 .50469 m .65033 .49816 L .6073 .47099 L p 0 .914 0 r
F P
0 g
s
.6073 .47099 m .59502 .47786 L .63809 .50469 L p 0 .914 0 r
F P
0 g
s
.65033 .49816 m .63809 .50469 L .64169 .55871 L p 0 .1 0 r
F P
0 g
s
.63809 .50469 m .65033 .49816 L .65427 .55236 L p 0 .1 0 r
F P
0 g
s
.65427 .55236 m .64169 .55871 L .63809 .50469 L p 0 .1 0 r
F P
0 g
s
.50162 .58348 m .50167 .63955 L .49015 .6453 L p 0 .1 0 r
F P
0 g
s
.50162 .58348 m .50167 .63955 L .54711 .66227 L p 0 .681 0 r
F P
0 g
s
.55878 .65674 m .54711 .66227 L .50167 .63955 L p 0 .916 0 r
F P
0 g
s
.50162 .58348 m .513 .57745 L .51334 .63373 L p 0 .1 0 r
F P
0 g
s
.51334 .63373 m .50167 .63955 L .50162 .58348 L p 0 .1 0 r
F P
0 g
s
.5829 .6453 m .59502 .63955 L .63806 .66226 L p 0 .916 1 r
F P
0 g
s
.63806 .66226 m .6503 .65672 L .65033 .6567 L p 0 .1 .1 r
F P
0 g
s
.6503 .65672 m .63806 .66226 L .59502 .63955 L p 0 .916 1 r
F P
0 g
s
.72202 .56498 m .73504 .55871 L .72908 .50473 L p 0 .114 .472 r
F P
0 g
s
.72908 .50473 m .72905 .50467 L .68837 .47786 L p 0 .652 .333 r
F P
0 g
s
.73504 .55871 m .72908 .50473 L p .68837 .47786 L 0 .652 .333 r
F P
0 g
s
.72905 .50467 m .74186 .49814 L .70125 .47099 L p 0 .914 1 r
F P
0 g
s
.70125 .47099 m .68837 .47786 L .72905 .50467 L p 0 .914 1 r
F P
0 g
s
.74189 .4982 m .72908 .50473 L .73504 .55871 L p 0 .114 .472 r
F P
0 g
s
.72908 .50473 m .74189 .4982 L .74186 .49814 L p 0 .562 .887 r
F P
0 g
s
.74186 .49814 m .72905 .50467 L .72908 .50473 L p 0 .562 .887 r
F P
0 g
s
.72908 .50473 m .72905 .50467 L .68837 .47786 L p 0 .652 .333 r
F P
0 g
s
.73504 .55871 m .72908 .50473 L p .68837 .47786 L 0 .652 .333 r
F P
0 g
s
.78213 .2564 m .74278 .22309 L .73398 .22877 L p 0 .903 1 r
F P
0 g
s
.78213 .2564 m .78948 .30398 L .78048 .3093 L p 0 .1 .45 r
F P
0 g
s
.78948 .30398 m .78213 .2564 L .74278 .22309 L p 0 .618 .247 r
F P
0 g
s
.82764 .33524 m .78948 .30398 L .78048 .3093 L p 0 .907 1 r
F P
0 g
s
.83615 .38484 m .83618 .38483 L .82697 .3898 L p 0 .1 .1 r
F P
0 g
s
.82764 .33524 m .78948 .30398 L p .83615 .38484 L 0 .618 .247 r
F P
0 g
s
.83615 .38484 m .83618 .38483 L .82764 .33524 L p 0 .618 .247 r
F P
0 g
s
.78213 .2564 m .78948 .30398 L .82764 .33524 L p 0 .618 .247 r
F P
0 g
s
.28047 .65515 m .27055 .6607 L .27051 .66065 L p 0 .525 .891 r
F P
0 g
s
.27051 .66065 m .28044 .6551 L .28047 .65515 L p 0 .525 .891 r
F P
0 g
s
.37216 .4963 m .36165 .50286 L .36169 .50284 L p 0 .93 .764 r
F P
0 g
s
.54395 .50282 m .49833 .47589 L .48681 .48271 L p 0 .914 1 r
F P
0 g
s
.54509 .55689 m .54395 .50282 L .49833 .47589 L p 0 .673 .397 r
F P
0 g
s
.49833 .47589 m .54395 .50282 L .55561 .49626 L p 0 .914 1 r
F P
0 g
s
.54395 .50282 m .54509 .55689 L .55707 .55051 L p 0 .1 .423 r
F P
0 g
s
.55707 .55051 m .55561 .49626 L .54395 .50282 L p 0 .1 .423 r
F P
0 g
s
.54509 .55689 m .54395 .50282 L .49833 .47589 L p 0 .673 .397 r
F P
0 g
s
.32174 .632 m .31129 .63784 L .31608 .58175 L p 0 .1 0 r
F P
0 g
s
.31608 .58175 m .3263 .5757 L .32174 .632 L p 0 .1 0 r
F P
0 g
s
.37216 .65514 m .36165 .66069 L .31132 .6379 L p 0 .916 0 r
F P
0 g
s
.301 .64367 m .31132 .6379 L .36165 .66069 L p 0 .916 0 r
F P
0 g
s
.44035 .56318 m .45157 .55689 L .49837 .58175 L p 0 .916 0 r
F P
0 g
s
.48681 .64365 m .49833 .63788 L .49837 .58175 L p 0 .1 0 r
F P
0 g
s
.45027 .61386 m .45157 .55689 L .49837 .58175 L p 0 .681 0 r
F P
0 g
s
.49837 .58175 m .49833 .63788 L .45027 .61386 L p 0 .681 0 r
F P
0 g
s
.44035 .56318 m .45157 .55689 L .4528 .50282 L p 0 .1 0 r
F P
0 g
s
.39392 .48273 m .40484 .47591 L .4048 .47593 L p 0 .93 0 r
F P
0 g
s
.4048 .47593 m .40484 .47591 L .4528 .50282 L p 0 .681 0 r
F P
0 g
s
.40226 .53069 m .4048 .47593 L p .4528 .50282 L 0 .681 0 r
F P
0 g
s
.4528 .50282 m .45157 .55689 L .40226 .53069 L p 0 .681 0 r
F P
0 g
s
.4528 .50282 m .45157 .55689 L .49837 .58175 L p 0 .681 0 r
F P
0 g
s
.45157 .55689 m .49837 .58175 L .50975 .5757 L p 0 .916 0 r
F P
0 g
s
.49837 .58175 m .49833 .63788 L .51 .63204 L p 0 .1 0 r
F P
0 g
s
.51 .63204 m .50975 .5757 L .49837 .58175 L p 0 .1 0 r
F P
0 g
s
.49833 .63788 m .49837 .58175 L .45157 .55689 L p 0 .681 0 r
F P
0 g
s
.49837 .58175 m .45157 .55689 L .46293 .55051 L p 0 .916 0 r
F P
0 g
s
.46293 .55051 m .50975 .5757 L .49837 .58175 L p 0 .916 0 r
F P
0 g
s
.45157 .55689 m .4528 .50282 L .46388 .49626 L p 0 .1 0 r
F P
0 g
s
.40484 .47591 m .4528 .50282 L .46388 .49626 L p 0 .914 0 r
F P
0 g
s
.4528 .50282 m .45157 .55689 L .46293 .55051 L p 0 .1 0 r
F P
0 g
s
.46293 .55051 m .46388 .49626 L .4528 .50282 L p 0 .1 0 r
F P
0 g
s
.45157 .55689 m .4528 .50282 L .40484 .47591 L p 0 .681 0 r
F P
0 g
s
.46388 .65514 m .4528 .66069 L .40481 .63788 L p 0 .916 1 r
F P
0 g
s
.41587 .63204 m .40481 .63788 L .40723 .58175 L p 0 .1 .396 r
F P
0 g
s
.40723 .58175 m .41802 .5757 L .41587 .63204 L p 0 .1 .396 r
F P
0 g
s
.41802 .5757 m .40723 .58175 L .35804 .55689 L p 0 .916 1 r
F P
0 g
s
.34743 .56318 m .35804 .55689 L .40723 .58175 L p 0 .916 1 r
F P
0 g
s
.3688 .55051 m .35804 .55689 L .40723 .58175 L p 0 .916 1 r
F P
0 g
s
.40723 .58175 m .41802 .5757 L .3688 .55051 L p 0 .916 1 r
F P
0 g
s
.41802 .5757 m .40723 .58175 L .40481 .63788 L p 0 .1 .396 r
F P
0 g
s
.35424 .61381 m .35804 .55689 L .40723 .58175 L p 0 .687 .449 r
F P
0 g
s
.35428 .61387 m .35424 .61381 L p .40723 .58175 L 0 .687 .449 r
F P
0 g
s
.39389 .64365 m .40481 .63788 L .40723 .58175 L p 0 .1 .396 r
F P
0 g
s
.40723 .58175 m .40481 .63788 L .35428 .61387 L p 0 .687 .449 r
F P
0 g
s
.35424 .61381 m .35804 .55689 L .40723 .58175 L p 0 .687 .449 r
F P
0 g
s
.35428 .61387 m .35424 .61381 L p .40723 .58175 L 0 .687 .449 r
F P
0 g
s
.40723 .58175 m .40481 .63788 L .35428 .61387 L p 0 .687 .449 r
F P
0 g
s
.39389 .64365 m .40481 .63788 L .4528 .66069 L p 0 .916 1 r
F P
0 g
s
.3688 .55051 m .35804 .55689 L .36165 .50286 L p 0 .1 .365 r
F P
0 g
s
.36165 .50286 m .37216 .4963 L .3688 .55051 L p 0 .1 .365 r
F P
0 g
s
.78662 .4116 m .7866 .41162 L .79981 .40448 L p 0 .1 0 r
F P
0 g
s
.74101 .33264 m .7005 .30124 L .68767 .30919 L p 0 .907 0 r
F P
0 g
s
.74101 .33264 m .74731 .38231 L .73417 .38973 L p 0 .1 0 r
F P
0 g
s
.74731 .38231 m .74101 .33264 L .7005 .30124 L p 0 .634 0 r
F P
0 g
s
.6954 .25363 m .7005 .30124 L .74101 .33264 L p 0 .634 0 r
F P
0 g
s
.6954 .25363 m .7005 .30124 L .74101 .33264 L p 0 .634 0 r
F P
0 g
s
.7005 .30124 m .74101 .33264 L .75394 .32499 L p 0 .907 0 r
F P
0 g
s
.74101 .33264 m .74731 .38231 L .76061 .37479 L p 0 .1 0 r
F P
0 g
s
.76061 .37479 m .75394 .32499 L .74101 .33264 L p 0 .1 0 r
F P
0 g
s
.74731 .38231 m .74101 .33264 L .7005 .30124 L p 0 .634 0 r
F P
0 g
s
.74731 .38231 m .74101 .33264 L .75394 .32499 L p 0 .1 0 r
F P
0 g
s
.74101 .33264 m .7005 .30124 L .7135 .2932 L p 0 .907 0 r
F P
0 g
s
.7135 .2932 m .75394 .32499 L .74101 .33264 L p 0 .907 0 r
F P
0 g
s
.75394 .32499 m .7135 .2932 L .7005 .30124 L p 0 .907 0 r
F P
0 g
s
.75394 .32499 m .76061 .37479 L .74731 .38231 L p 0 .1 0 r
F P
0 g
s
.76061 .37479 m .75394 .32499 L .7135 .2932 L p 0 .63 .275 r
F P
0 g
s
.6954 .25363 m .7005 .30124 L .68767 .30919 L p 0 .1 0 r
F P
0 g
s
.7005 .30124 m .6954 .25363 L .70803 .24549 L p 0 .1 0 r
F P
0 g
s
.64979 .33264 m .6537 .38231 L .64117 .38973 L p 0 .1 .425 r
F P
0 g
s
.64979 .33264 m .6537 .38231 L .6954 .41164 L p 0 .648 .324 r
F P
0 g
s
.64979 .33264 m .6537 .38231 L .6954 .41164 L p 0 .648 .324 r
F P
0 g
s
.6537 .38231 m .64979 .33264 L .66213 .32499 L p 0 .1 .425 r
F P
0 g
s
.6954 .41164 m .6537 .38231 L .6664 .37479 L p 0 .911 1 r
F P
0 g
s
.6664 .37479 m .70803 .4045 L .6954 .41164 L p 0 .911 1 r
F P
0 g
s
.7866 .41162 m .74731 .38231 L .76061 .37479 L p 0 .911 0 r
F P
0 g
s
.76061 .37479 m .79981 .40448 L .7866 .41162 L p 0 .911 0 r
F P
0 g
s
.88012 .25226 m .84323 .21875 L .83175 .22582 L p 0 .903 1 r
F P
0 g
s
.88012 .25226 m .84323 .21875 L p .89008 .2999 L 0 .594 .194 r
F P
0 g
s
.89008 .2999 m .88015 .25231 L .88012 .25226 L p 0 .594 .194 r
F P
0 g
s
.84323 .21875 m .88012 .25226 L .89162 .24547 L p 0 .903 1 r
F P
0 g
s
.88012 .25226 m .88015 .25231 L .89165 .24552 L p 0 .575 .884 r
F P
0 g
s
.89165 .24552 m .89162 .24547 L .88012 .25226 L p 0 .575 .884 r
F P
0 g
s
.88015 .25231 m .89008 .2999 L .90194 .2932 L p 0 .114 .472 r
F P
0 g
s
.90194 .2932 m .89165 .24552 L .88015 .25231 L p 0 .114 .472 r
F P
0 g
s
.88012 .25226 m .84323 .21875 L p .89008 .2999 L 0 .594 .194 r
F P
0 g
s
.89008 .2999 m .88015 .25231 L .88012 .25226 L p 0 .594 .194 r
F P
0 g
s
.41832 .40956 m .42922 .40239 L .42925 .40245 L p 0 .546 0 r
F P
0 g
s
.42925 .40245 m .41835 .40961 L .41832 .40956 L p 0 .546 0 r
F P
0 g
s
.50974 .25132 m .52122 .24315 L .52119 .24316 L p 0 1 0 r
F P
0 g
s
.52119 .24316 m .50971 .25133 L .50974 .25132 L p 0 1 0 r
F P
0 g
s
.50974 .25132 m .50971 .25133 L p .55541 .33045 L 0 .661 0 r
F P
0 g
s
.50974 .25132 m .50971 .25133 L p .55541 .33045 L 0 .661 0 r
F P
0 g
s
.68469 .30691 m .69753 .29894 L .69249 .2513 L p 0 .1 0 r
F P
0 g
s
.69753 .29894 m .69249 .2513 L .65064 .21772 L p 0 .634 0 r
F P
0 g
s
.70513 .24313 m .69249 .2513 L .69753 .29894 L p 0 .1 0 r
F P
0 g
s
.69249 .2513 m .70513 .24313 L .66334 .20911 L p 0 .903 0 r
F P
0 g
s
.66334 .20911 m .65064 .21772 L .69249 .2513 L p 0 .903 0 r
F P
0 g
s
.69753 .29894 m .69249 .2513 L .65064 .21772 L p 0 .634 0 r
F P
0 g
s
.46402 .33045 m .46307 .38012 L p .50971 .40959 L 0 .671 .39 r
F P
0 g
s
.46402 .33045 m .46307 .38012 L p .50971 .40959 L 0 .671 .39 r
F P
0 g
s
.46402 .33045 m .4752 .32278 L .47455 .37257 L p 0 .1 .365 r
F P
0 g
s
.47455 .37257 m .46307 .38012 L .46402 .33045 L p 0 .1 .365 r
F P
0 g
s
.45178 .38763 m .46311 .38018 L .50971 .40959 L p 0 .911 1 r
F P
0 g
s
.46307 .38012 m .46311 .38018 L .50971 .40959 L p 0 .671 .39 r
F P
0 g
s
.46307 .38012 m .46311 .38018 L .50971 .40959 L p 0 .671 .39 r
F P
0 g
s
.52119 .40243 m .50971 .40959 L .46311 .38018 L p 0 .911 1 r
F P
0 g
s
.55541 .33045 m .55686 .38016 L .6011 .40959 L p 0 .661 0 r
F P
0 g
s
.55541 .33045 m .55686 .38016 L .6011 .40959 L p 0 .661 0 r
F P
0 g
s
.54492 .38761 m .55686 .38016 L .55541 .33045 L p 0 .1 0 r
F P
0 g
s
.49834 .30691 m .50996 .29894 L .55541 .33045 L p 0 .907 0 r
F P
0 g
s
.55686 .38016 m .55541 .33045 L .50996 .29894 L p 0 .661 0 r
F P
0 g
s
.55686 .38016 m .55541 .33045 L .50996 .29894 L p 0 .661 0 r
F P
0 g
s
.50971 .25133 m .50996 .29894 L .55541 .33045 L p 0 .661 0 r
F P
0 g
s
.50971 .25133 m .50996 .29894 L .55541 .33045 L p 0 .661 0 r
F P
0 g
s
.54492 .38761 m .55686 .38016 L .6011 .40959 L p 0 .911 0 r
F P
0 g
s
.61316 .40243 m .6011 .40959 L .55686 .38016 L p 0 .911 0 r
F P
0 g
s
.55541 .33045 m .56717 .32278 L .56894 .37261 L p 0 .1 0 r
F P
0 g
s
.56894 .37261 m .55686 .38016 L .55541 .33045 L p 0 .1 0 r
F P
0 g
s
.56717 .32278 m .55541 .33045 L .55686 .38016 L p 0 .1 0 r
F P
0 g
s
.55541 .33045 m .56717 .32278 L .52174 .29086 L p 0 .907 0 r
F P
0 g
s
.52174 .29086 m .50996 .29894 L .55541 .33045 L p 0 .907 0 r
F P
0 g
s
.56717 .32278 m .55541 .33045 L .50996 .29894 L p 0 .907 0 r
F P
0 g
s
.6011 .2513 m .60375 .29894 L .6468 .33045 L p 0 .648 .324 r
F P
0 g
s
.6011 .2513 m .60375 .29894 L .6468 .33045 L p 0 .648 .324 r
F P
0 g
s
.6011 .2513 m .61316 .24313 L .61614 .29086 L p 0 .1 .396 r
F P
0 g
s
.61614 .29086 m .60375 .29894 L .6011 .2513 L p 0 .1 .396 r
F P
0 g
s
.59151 .30691 m .60375 .29894 L .6468 .33045 L p 0 .907 1 r
F P
0 g
s
.65915 .32278 m .6468 .33045 L .60375 .29894 L p 0 .907 1 r
F P
0 g
s
.6381 .38761 m .65064 .38016 L .6468 .33045 L p 0 .1 .423 r
F P
0 g
s
.65064 .38016 m .6468 .33045 L .60375 .29894 L p 0 .648 .324 r
F P
0 g
s
.65915 .32278 m .6468 .33045 L .65064 .38016 L p 0 .1 .423 r
F P
0 g
s
.6468 .33045 m .65915 .32278 L .61614 .29086 L p 0 .907 1 r
F P
0 g
s
.61614 .29086 m .60375 .29894 L .6468 .33045 L p 0 .907 1 r
F P
0 g
s
.65064 .38016 m .6468 .33045 L .60375 .29894 L p 0 .648 .324 r
F P
0 g
s
.59151 .30691 m .60375 .29894 L .6011 .2513 L p 0 .1 .396 r
F P
0 g
s
.60375 .29894 m .6011 .2513 L .55689 .21775 L p 0 .648 .324 r
F P
0 g
s
.61316 .24313 m .6011 .2513 L .60375 .29894 L p 0 .1 .396 r
F P
0 g
s
.6011 .2513 m .61316 .24313 L .56897 .20914 L p 0 .903 1 r
F P
0 g
s
.56897 .20914 m .55689 .21775 L .6011 .2513 L p 0 .903 1 r
F P
0 g
s
.60375 .29894 m .6011 .2513 L .55689 .21775 L p 0 .648 .324 r
F P
0 g
s
.50971 .25133 m .52119 .24316 L .52174 .29086 L p 0 .1 0 r
F P
0 g
s
.52174 .29086 m .50996 .29894 L .50971 .25133 L p 0 .1 0 r
F P
0 g
s
.6503 .65672 m .65033 .6567 L p .60455 .57745 L 0 .671 .39 r
F P
0 g
s
.66273 .6511 m .65033 .6567 L .6503 .65672 L p 0 .1 .1 r
F P
0 g
s
.6503 .65672 m .65033 .6567 L p .60455 .57745 L 0 .671 .39 r
F P
0 g
s
.55878 .49816 m .56032 .55236 L .60455 .57745 L p 0 .671 .39 r
F P
0 g
s
.55878 .49816 m .56032 .55236 L .60455 .57745 L p 0 .671 .39 r
F P
0 g
s
.61666 .57134 m .60455 .57745 L .56032 .55236 L p 0 .916 1 r
F P
0 g
s
.54834 .55871 m .56032 .55236 L .60455 .57745 L p 0 .916 1 r
F P
0 g
s
.55878 .49816 m .57059 .49155 L .57245 .54592 L p 0 .1 .425 r
F P
0 g
s
.57245 .54592 m .56032 .55236 L .55878 .49816 L p 0 .1 .425 r
F P
0 g
s
.59502 .63955 m .6073 .63373 L .60455 .57745 L p 0 .1 .45 r
F P
0 g
s
.6073 .63373 m .60455 .57745 L .56032 .55236 L p 0 .671 .39 r
F P
0 g
s
.60455 .57745 m .61666 .57134 L .57245 .54592 L p 0 .916 1 r
F P
0 g
s
.57245 .54592 m .56032 .55236 L .60455 .57745 L p 0 .916 1 r
F P
0 g
s
.60455 .57745 m .6073 .63373 L .6503 .65672 L p 0 .671 .39 r
F P
0 g
s
.60455 .57745 m .6073 .63373 L .6503 .65672 L p 0 .671 .39 r
F P
0 g
s
.61666 .57134 m .60455 .57745 L .6073 .63373 L p 0 .1 .45 r
F P
0 g
s
.6073 .63373 m .60455 .57745 L .56032 .55236 L p 0 .671 .39 r
F P
0 g
s
.60455 .57745 m .61666 .57134 L .61974 .62783 L p 0 .1 .45 r
F P
0 g
s
.61974 .62783 m .6073 .63373 L .60455 .57745 L p 0 .1 .45 r
F P
0 g
s
.68836 .63951 m .70125 .63369 L .69611 .57745 L p 0 .114 0 r
F P
0 g
s
.64169 .55871 m .65427 .55236 L .69611 .57745 L p 0 .916 0 r
F P
0 g
s
.70125 .63369 m .69611 .57745 L .65427 .55236 L p 0 .661 0 r
F P
0 g
s
.70125 .63369 m .69611 .57745 L .65427 .55236 L p 0 .661 0 r
F P
0 g
s
.64169 .55871 m .65427 .55236 L .65033 .49816 L p 0 .1 0 r
F P
0 g
s
.65427 .55236 m .65033 .49816 L .6073 .47099 L p 0 .661 0 r
F P
0 g
s
.65033 .49816 m .66273 .49155 L .61974 .46402 L p 0 .914 0 r
F P
0 g
s
.61974 .46402 m .6073 .47099 L .65033 .49816 L p 0 .914 0 r
F P
0 g
s
.65033 .49816 m .65427 .55236 L .69611 .57745 L p 0 .661 0 r
F P
0 g
s
.65033 .49816 m .65427 .55236 L .69611 .57745 L p 0 .661 0 r
F P
0 g
s
.66273 .49155 m .65033 .49816 L .65427 .55236 L p 0 .1 0 r
F P
0 g
s
.65427 .55236 m .65033 .49816 L .6073 .47099 L p 0 .661 0 r
F P
0 g
s
.69611 .57745 m .7088 .57134 L .66702 .54592 L p 0 .916 0 r
F P
0 g
s
.66702 .54592 m .65427 .55236 L .69611 .57745 L p 0 .916 0 r
F P
0 g
s
.7088 .57134 m .69611 .57745 L .70125 .63369 L p 0 .114 0 r
F P
0 g
s
.65033 .49816 m .66273 .49155 L .66702 .54592 L p 0 .1 0 r
F P
0 g
s
.66702 .54592 m .65427 .55236 L .65033 .49816 L p 0 .1 0 r
F P
0 g
s
.7088 .57134 m .69611 .57745 L .65427 .55236 L p 0 .916 0 r
F P
0 g
s
.50167 .63955 m .51334 .63373 L .55878 .65674 L p 0 .916 0 r
F P
0 g
s
.513 .57745 m .51334 .63373 L .55878 .65674 L p 0 .679 0 r
F P
0 g
s
.513 .57745 m .51334 .63373 L .55878 .65674 L p 0 .679 0 r
F P
0 g
s
.513 .57745 m .52452 .57134 L .52516 .62783 L p 0 .1 0 r
F P
0 g
s
.52516 .62783 m .51334 .63373 L .513 .57745 L p 0 .1 0 r
F P
0 g
s
.57059 .65114 m .55878 .65674 L .51334 .63373 L p 0 .916 0 r
F P
0 g
s
.59502 .63955 m .6073 .63373 L .6503 .65672 L p 0 .916 1 r
F P
0 g
s
.6503 .65672 m .6627 .65112 L .66273 .6511 L p 0 .1 .1 r
F P
0 g
s
.6627 .65112 m .6503 .65672 L .6073 .63373 L p 0 .916 1 r
F P
0 g
s
.73504 .55871 m .74823 .55236 L .74189 .4982 L p 0 .114 .472 r
F P
0 g
s
.74189 .4982 m .74186 .49814 L .70125 .47099 L p 0 .648 .324 r
F P
0 g
s
.74823 .55236 m .74189 .4982 L p .70125 .47099 L 0 .648 .324 r
F P
0 g
s
.74186 .49814 m .75484 .49153 L .71431 .46402 L p 0 .914 1 r
F P
0 g
s
.71431 .46402 m .70125 .47099 L .74186 .49814 L p 0 .914 1 r
F P
0 g
s
.75487 .49158 m .74189 .4982 L .74823 .55236 L p 0 .114 .472 r
F P
0 g
s
.74189 .4982 m .75487 .49158 L .75484 .49153 L p 0 .562 .887 r
F P
0 g
s
.75484 .49153 m .74186 .49814 L .74189 .4982 L p 0 .562 .887 r
F P
0 g
s
.74189 .4982 m .74186 .49814 L .70125 .47099 L p 0 .648 .324 r
F P
0 g
s
.74823 .55236 m .74189 .4982 L p .70125 .47099 L 0 .648 .324 r
F P
0 g
s
.29052 .64953 m .28047 .65515 L .28044 .6551 L p 0 .525 .891 r
F P
0 g
s
.28044 .6551 m .29049 .64947 L .29052 .64953 L p 0 .525 .891 r
F P
0 g
s
.3828 .48966 m .37216 .4963 L .37219 .49628 L p 0 .93 .764 r
F P
0 g
s
.51 .46899 m .55561 .49626 L .56742 .48963 L p 0 .914 1 r
F P
0 g
s
.55561 .49626 m .55707 .55051 L .5692 .54406 L p 0 .1 .423 r
F P
0 g
s
.5692 .54406 m .56742 .48963 L .55561 .49626 L p 0 .1 .423 r
F P
0 g
s
.55561 .49626 m .51 .46899 L .49833 .47589 L p 0 .914 1 r
F P
0 g
s
.55707 .55051 m .55561 .49626 L .51 .46899 L p 0 .671 .39 r
F P
0 g
s
.55707 .55051 m .55561 .49626 L .51 .46899 L p 0 .671 .39 r
F P
0 g
s
.3828 .64951 m .37216 .65514 L .32177 .63205 L p 0 .916 0 r
F P
0 g
s
.33233 .62607 m .32174 .632 L .3263 .5757 L p 0 .1 0 r
F P
0 g
s
.3263 .5757 m .33664 .56957 L .33233 .62607 L p 0 .1 0 r
F P
0 g
s
.31132 .6379 m .32177 .63205 L .37216 .65514 L p 0 .916 0 r
F P
0 g
s
.46388 .49626 m .46293 .55051 L .45157 .55689 L p 0 .1 0 r
F P
0 g
s
.46388 .49626 m .46293 .55051 L .50975 .5757 L p 0 .679 0 r
F P
0 g
s
.46388 .49626 m .46293 .55051 L .50975 .5757 L p 0 .679 0 r
F P
0 g
s
.50975 .5757 m .46293 .55051 L .47445 .54406 L p 0 .916 0 r
F P
0 g
s
.47445 .54406 m .52126 .56957 L .50975 .5757 L p 0 .916 0 r
F P
0 g
s
.46293 .55051 m .46388 .49626 L .47511 .48963 L p 0 .1 0 r
F P
0 g
s
.50975 .5757 m .46293 .55051 L .45157 .55689 L p 0 .916 0 r
F P
0 g
s
.51 .63204 m .50975 .5757 L .46293 .55051 L p 0 .679 0 r
F P
0 g
s
.46293 .55051 m .50975 .5757 L .52126 .56957 L p 0 .916 0 r
F P
0 g
s
.50975 .5757 m .51 .63204 L .52183 .62611 L p 0 .1 0 r
F P
0 g
s
.52183 .62611 m .52126 .56957 L .50975 .5757 L p 0 .1 0 r
F P
0 g
s
.51 .63204 m .50975 .5757 L .46293 .55051 L p 0 .679 0 r
F P
0 g
s
.46388 .49626 m .4159 .46901 L .40484 .47591 L p 0 .914 0 r
F P
0 g
s
.46293 .55051 m .46388 .49626 L .4159 .46901 L p 0 .679 0 r
F P
0 g
s
.4159 .46901 m .46388 .49626 L .47511 .48963 L p 0 .914 0 r
F P
0 g
s
.46388 .49626 m .46293 .55051 L .47445 .54406 L p 0 .1 0 r
F P
0 g
s
.47445 .54406 m .47511 .48963 L .46388 .49626 L p 0 .1 0 r
F P
0 g
s
.46293 .55051 m .46388 .49626 L .4159 .46901 L p 0 .679 0 r
F P
0 g
s
.47511 .64951 m .46388 .65514 L .41587 .63204 L p 0 .916 1 r
F P
0 g
s
.42708 .62611 m .41587 .63204 L .41802 .5757 L p 0 .1 .396 r
F P
0 g
s
.41802 .5757 m .42895 .56957 L .42708 .62611 L p 0 .1 .396 r
F P
0 g
s
.40481 .63788 m .41587 .63204 L .46388 .65514 L p 0 .916 1 r
F P
0 g
s
.42895 .56957 m .41802 .5757 L .3688 .55051 L p 0 .916 1 r
F P
0 g
s
.35804 .55689 m .3688 .55051 L .41802 .5757 L p 0 .916 1 r
F P
0 g
s
.3797 .54406 m .3688 .55051 L .41802 .5757 L p 0 .916 1 r
F P
0 g
s
.41802 .5757 m .42895 .56957 L .3797 .54406 L p 0 .916 1 r
F P
0 g
s
.42895 .56957 m .41802 .5757 L .41587 .63204 L p 0 .1 .396 r
F P
0 g
s
.36526 .60765 m .3688 .55051 L .41802 .5757 L p 0 .686 .443 r
F P
0 g
s
.3653 .60771 m .36526 .60765 L p .41802 .5757 L 0 .686 .443 r
F P
0 g
s
.40481 .63788 m .41587 .63204 L .41802 .5757 L p 0 .1 .396 r
F P
0 g
s
.41802 .5757 m .41587 .63204 L .3653 .60771 L p 0 .686 .443 r
F P
0 g
s
.36526 .60765 m .3688 .55051 L .41802 .5757 L p 0 .686 .443 r
F P
0 g
s
.3653 .60771 m .36526 .60765 L p .41802 .5757 L 0 .686 .443 r
F P
0 g
s
.41802 .5757 m .41587 .63204 L .3653 .60771 L p 0 .686 .443 r
F P
0 g
s
.3797 .54406 m .3688 .55051 L .37216 .4963 L p 0 .1 .365 r
F P
0 g
s
.37216 .4963 m .3828 .48966 L .3797 .54406 L p 0 .1 .365 r
F P
0 g
s
.75997 .21201 m .7992 .24588 L .81244 .23772 L p 0 .903 0 r
F P
0 g
s
.7992 .24588 m .80706 .29358 L .84509 .32536 L p 0 .612 0 r
F P
0 g
s
.7992 .24588 m .80706 .29358 L .82071 .28552 L p 0 .1 0 r
F P
0 g
s
.82071 .28552 m .81244 .23772 L .7992 .24588 L p 0 .1 0 r
F P
0 g
s
.80706 .29358 m .7992 .24588 L .75997 .21201 L p 0 .612 0 r
F P
0 g
s
.80706 .29358 m .7992 .24588 L .81244 .23772 L p 0 .1 0 r
F P
0 g
s
.80706 .29358 m .84509 .32536 L .85862 .31771 L p 0 .907 0 r
F P
0 g
s
.84509 .32536 m .85415 .37512 L .8681 .36758 L p 0 .114 0 r
F P
0 g
s
.8681 .36758 m .85862 .31771 L .84509 .32536 L p 0 .114 0 r
F P
0 g
s
.84509 .32536 m .80706 .29358 L p .85413 .37513 L 0 .612 0 r
F P
0 g
s
.85413 .37513 m .85415 .37512 L .84509 .32536 L p 0 .612 0 r
F P
0 g
s
.84509 .32536 m .80706 .29358 L .82071 .28552 L p 0 .907 0 r
F P
0 g
s
.82071 .28552 m .85862 .31771 L .84509 .32536 L p 0 .907 0 r
F P
0 g
s
.79983 .40446 m .79981 .40448 L .80878 .39963 L p 0 .1 .1 r
F P
0 g
s
.76061 .37479 m .75394 .32499 L .7135 .2932 L p 0 .63 0 r
F P
0 g
s
.70803 .24549 m .7135 .2932 L .7005 .30124 L p 0 .1 0 r
F P
0 g
s
.70803 .24549 m .7135 .2932 L .75394 .32499 L p 0 .63 .275 r
F P
0 g
s
.70803 .24549 m .7135 .2932 L .75394 .32499 L p 0 .63 0 r
F P
0 g
s
.7135 .2932 m .70803 .24549 L .71661 .23996 L p 0 .1 .425 r
F P
0 g
s
.7135 .2932 m .75394 .32499 L .76271 .31981 L p 0 .907 1 r
F P
0 g
s
.76061 .37479 m .75394 .32499 L .76271 .31981 L p 0 .1 .45 r
F P
0 g
s
.75394 .32499 m .7135 .2932 L .72233 .28773 L p 0 .907 1 r
F P
0 g
s
.72233 .28773 m .76271 .31981 L .75394 .32499 L p 0 .907 1 r
F P
0 g
s
.66213 .32499 m .6664 .37479 L .6537 .38231 L p 0 .1 .425 r
F P
0 g
s
.66213 .32499 m .6664 .37479 L .70803 .4045 L p 0 .645 .315 r
F P
0 g
s
.89162 .24547 m .85483 .2116 L .84323 .21875 L p 0 .903 1 r
F P
0 g
s
.89162 .24547 m .85483 .2116 L p .90194 .2932 L 0 .59 .184 r
F P
0 g
s
.90194 .2932 m .89165 .24552 L .89162 .24547 L p 0 .59 .184 r
F P
0 g
s
.79981 .40448 m .76061 .37479 L .76965 .36969 L p 0 .911 1 r
F P
0 g
s
.76965 .36969 m .80878 .39963 L .79981 .40448 L p 0 .911 1 r
F P
0 g
s
.66249 .32477 m .66676 .37457 L .7084 .40429 L p 0 .645 0 r
F P
0 g
s
.7084 .40429 m .66676 .37457 L .67963 .36695 L p 0 .911 0 r
F P
0 g
s
.67963 .36695 m .7212 .39706 L .7084 .40429 L p 0 .911 0 r
F P
0 g
s
.66676 .37457 m .66249 .32477 L .675 .31703 L p 0 .1 0 r
F P
0 g
s
.52122 .24315 m .52119 .24316 L p .56717 .32278 L 0 .658 0 r
F P
0 g
s
.69753 .29894 m .71053 .29086 L .70513 .24313 L p 0 .1 0 r
F P
0 g
s
.71053 .29086 m .70513 .24313 L .66334 .20911 L p 0 .63 .275 r
F P
0 g
s
.71053 .29086 m .70513 .24313 L .66334 .20911 L p 0 .63 0 r
F P
0 g
s
.4752 .32278 m .47455 .37257 L p .52119 .40243 L 0 .668 .382 r
F P
0 g
s
.46311 .38018 m .47458 .37263 L .52119 .40243 L p 0 .911 1 r
F P
0 g
s
.47455 .37257 m .47458 .37263 L .52119 .40243 L p 0 .668 .382 r
F P
0 g
s
.71371 .23758 m .70513 .24313 L .71053 .29086 L p 0 .1 .423 r
F P
0 g
s
.70513 .24313 m .71371 .23758 L .67196 .20327 L p 0 .903 1 r
F P
0 g
s
.67196 .20327 m .66334 .20911 L .70513 .24313 L p 0 .903 1 r
F P
0 g
s
.55686 .38016 m .56894 .37261 L .61316 .40243 L p 0 .911 0 r
F P
0 g
s
.56717 .32278 m .56894 .37261 L .61316 .40243 L p 0 .658 0 r
F P
0 g
s
.55686 .38016 m .56894 .37261 L .56717 .32278 L p 0 .1 0 r
F P
0 g
s
.50996 .29894 m .52174 .29086 L .56717 .32278 L p 0 .907 0 r
F P
0 g
s
.56894 .37261 m .56717 .32278 L .52174 .29086 L p 0 .658 0 r
F P
0 g
s
.52119 .24316 m .52174 .29086 L .56717 .32278 L p 0 .658 0 r
F P
0 g
s
.61316 .24313 m .61614 .29086 L .65915 .32278 L p 0 .645 .315 r
F P
0 g
s
.65064 .38016 m .66334 .37261 L .65915 .32278 L p 0 .1 .423 r
F P
0 g
s
.60375 .29894 m .61614 .29086 L .65915 .32278 L p 0 .907 1 r
F P
0 g
s
.66334 .37261 m .65915 .32278 L .61614 .29086 L p 0 .645 .315 r
F P
0 g
s
.60375 .29894 m .61614 .29086 L .61316 .24313 L p 0 .1 .396 r
F P
0 g
s
.61614 .29086 m .61316 .24313 L .56897 .20914 L p 0 .645 .315 r
F P
0 g
s
.42953 .40218 m .44057 .39492 L .4406 .39498 L p 0 .546 .889 r
F P
0 g
s
.4406 .39498 m .42956 .40224 L .42953 .40218 L p 0 .546 .889 r
F P
0 g
s
.52155 .24291 m .53318 .23463 L .53315 .23464 L p 0 1 .86 r
F P
0 g
s
.53315 .23464 m .52152 .24292 L .52155 .24291 L p 0 1 .86 r
F P
0 g
s
.52155 .24291 m .52152 .24292 L p .56751 .32256 L 0 .658 .35 r
F P
0 g
s
.47552 .32256 m .47488 .37235 L p .52152 .40222 L 0 .668 0 r
F P
0 g
s
.47552 .32256 m .48686 .31478 L .48651 .3647 L p 0 .1 0 r
F P
0 g
s
.48651 .3647 m .47488 .37235 L .47552 .32256 L p 0 .1 0 r
F P
0 g
s
.47488 .37235 m .47491 .37241 L .52152 .40222 L p 0 .668 0 r
F P
0 g
s
.53315 .39496 m .52152 .40222 L .47491 .37241 L p 0 .911 0 r
F P
0 g
s
.67202 .31478 m .6595 .32256 L .6637 .37239 L p 0 .1 0 r
F P
0 g
s
.61351 .24289 m .6165 .29063 L .6595 .32256 L p 0 .645 0 r
F P
0 g
s
.6595 .32256 m .67202 .31478 L .62906 .28244 L p 0 .907 0 r
F P
0 g
s
.62906 .28244 m .6165 .29063 L .6595 .32256 L p 0 .907 0 r
F P
0 g
s
.6637 .37239 m .6595 .32256 L .6165 .29063 L p 0 .645 0 r
F P
0 g
s
.67202 .31478 m .6595 .32256 L .6165 .29063 L p 0 .907 0 r
F P
0 g
s
.61351 .24289 m .62573 .23461 L .62906 .28244 L p 0 .1 0 r
F P
0 g
s
.62906 .28244 m .6165 .29063 L .61351 .24289 L p 0 .1 0 r
F P
0 g
s
.62573 .23461 m .61351 .24289 L .6165 .29063 L p 0 .1 0 r
F P
0 g
s
.61351 .24289 m .62573 .23461 L .58158 .20016 L p 0 .903 0 r
F P
0 g
s
.58158 .20016 m .56932 .20889 L .61351 .24289 L p 0 .903 0 r
F P
0 g
s
.6165 .29063 m .61351 .24289 L .56932 .20889 L p 0 .645 0 r
F P
0 g
s
.56751 .32256 m .56929 .37239 L .61351 .40222 L p 0 .658 .35 r
F P
0 g
s
.62573 .39496 m .61351 .40222 L .56929 .37239 L p 0 .911 1 r
F P
0 g
s
.57944 .31478 m .56751 .32256 L .56929 .37239 L p 0 .1 .396 r
F P
0 g
s
.52152 .24292 m .52209 .29063 L .56751 .32256 L p 0 .658 .35 r
F P
0 g
s
.56751 .32256 m .57944 .31478 L .53403 .28244 L p 0 .907 1 r
F P
0 g
s
.53403 .28244 m .52209 .29063 L .56751 .32256 L p 0 .907 1 r
F P
0 g
s
.56929 .37239 m .56751 .32256 L .52209 .29063 L p 0 .658 .35 r
F P
0 g
s
.56751 .32256 m .57944 .31478 L .58154 .36474 L p 0 .1 .396 r
F P
0 g
s
.58154 .36474 m .56929 .37239 L .56751 .32256 L p 0 .1 .396 r
F P
0 g
s
.57944 .31478 m .56751 .32256 L .52209 .29063 L p 0 .907 1 r
F P
0 g
s
.52152 .24292 m .53315 .23464 L .53403 .28244 L p 0 .1 .365 r
F P
0 g
s
.53403 .28244 m .52209 .29063 L .52152 .24292 L p 0 .1 .365 r
F P
0 g
s
.6627 .65112 m .66273 .6511 L p .61666 .57134 L 0 .668 .382 r
F P
0 g
s
.56032 .55236 m .57245 .54592 L .61666 .57134 L p 0 .916 1 r
F P
0 g
s
.57059 .49155 m .57245 .54592 L .61666 .57134 L p 0 .668 .382 r
F P
0 g
s
.6073 .63373 m .61974 .62783 L .61666 .57134 L p 0 .1 .45 r
F P
0 g
s
.61974 .62783 m .61666 .57134 L .57245 .54592 L p 0 .668 .382 r
F P
0 g
s
.61666 .57134 m .61974 .62783 L .6627 .65112 L p 0 .668 .382 r
F P
0 g
s
.51334 .63373 m .52516 .62783 L .57059 .65114 L p 0 .916 0 r
F P
0 g
s
.52452 .57134 m .52516 .62783 L .57059 .65114 L p 0 .677 0 r
F P
0 g
s
.65427 .55236 m .66702 .54592 L .66273 .49155 L p 0 .1 0 r
F P
0 g
s
.66702 .54592 m .66273 .49155 L .61974 .46402 L p 0 .658 0 r
F P
0 g
s
.70125 .63369 m .7143 .62778 L .7088 .57134 L p 0 .114 0 r
F P
0 g
s
.65427 .55236 m .66702 .54592 L .7088 .57134 L p 0 .916 0 r
F P
0 g
s
.7143 .62778 m .7088 .57134 L .66702 .54592 L p 0 .658 0 r
F P
0 g
s
.66273 .49155 m .66702 .54592 L .7088 .57134 L p 0 .658 0 r
F P
0 g
s
.6073 .63373 m .61974 .62783 L .6627 .65112 L p 0 .916 1 r
F P
0 g
s
.75487 .49158 m .75484 .49153 L .71431 .46402 L p 0 .645 .315 r
F P
0 g
s
.74823 .55236 m .7616 .54592 L .75487 .49158 L p 0 .114 .472 r
F P
0 g
s
.7616 .54592 m .75487 .49158 L p .71431 .46402 L 0 .645 .315 r
F P
0 g
s
.66306 .65096 m .66308 .65094 L p .61701 .57117 L 0 .668 0 r
F P
0 g
s
.67564 .64526 m .66308 .65094 L .66306 .65096 L p 0 .1 0 r
F P
0 g
s
.52485 .57117 m .52551 .62766 L .57093 .65098 L p 0 .677 .411 r
F P
0 g
s
.5829 .6453 m .57093 .65098 L .52551 .62766 L p 0 .916 1 r
F P
0 g
s
.52485 .57117 m .53652 .56498 L .53749 .62167 L p 0 .1 .425 r
F P
0 g
s
.53749 .62167 m .52551 .62766 L .52485 .57117 L p 0 .1 .425 r
F P
0 g
s
.66309 .49135 m .67565 .48465 L .63271 .45676 L p 0 .914 1 r
F P
0 g
s
.63271 .45676 m .6201 .46382 L .66309 .49135 L p 0 .914 1 r
F P
0 g
s
.66309 .49135 m .66739 .54574 L .70917 .57117 L p 0 .658 .35 r
F P
0 g
s
.67565 .48465 m .66309 .49135 L .66739 .54574 L p 0 .1 .45 r
F P
0 g
s
.66739 .54574 m .66309 .49135 L .6201 .46382 L p 0 .658 .35 r
F P
0 g
s
.66309 .49135 m .67565 .48465 L .68031 .53922 L p 0 .1 .45 r
F P
0 g
s
.68031 .53922 m .66739 .54574 L .66309 .49135 L p 0 .1 .45 r
F P
0 g
s
.72202 .56498 m .70917 .57117 L .66739 .54574 L p 0 .916 1 r
F P
0 g
s
.71468 .62761 m .70917 .57117 L .66739 .54574 L p 0 .658 .35 r
F P
0 g
s
.70917 .57117 m .72202 .56498 L .68031 .53922 L p 0 .916 1 r
F P
0 g
s
.68031 .53922 m .66739 .54574 L .70917 .57117 L p 0 .916 1 r
F P
0 g
s
.72202 .56498 m .70917 .57117 L .71468 .62761 L p 0 .114 .472 r
F P
0 g
s
.57093 .49135 m .5728 .54574 L .61701 .57117 L p 0 .668 0 r
F P
0 g
s
.61701 .57117 m .6201 .62766 L .66306 .65096 L p 0 .668 0 r
F P
0 g
s
.62927 .56498 m .61701 .57117 L .5728 .54574 L p 0 .916 0 r
F P
0 g
s
.6201 .62766 m .61701 .57117 L .5728 .54574 L p 0 .668 0 r
F P
0 g
s
.61701 .57117 m .62927 .56498 L .63271 .62167 L p 0 .1 0 r
F P
0 g
s
.63271 .62167 m .6201 .62766 L .61701 .57117 L p 0 .1 0 r
F P
0 g
s
.57093 .49135 m .5829 .48465 L .5851 .53922 L p 0 .1 0 r
F P
0 g
s
.5851 .53922 m .5728 .54574 L .57093 .49135 L p 0 .1 0 r
F P
0 g
s
.61701 .57117 m .62927 .56498 L .5851 .53922 L p 0 .916 0 r
F P
0 g
s
.5851 .53922 m .5728 .54574 L .61701 .57117 L p 0 .916 0 r
F P
0 g
s
.62927 .56498 m .61701 .57117 L .6201 .62766 L p 0 .1 0 r
F P
0 g
s
.66306 .65096 m .67562 .64528 L .67564 .64526 L p 0 .1 0 r
F P
0 g
s
.67562 .64528 m .66306 .65096 L .6201 .62766 L p 0 .916 0 r
F P
0 g
s
.75522 .49133 m .76837 .48463 L .72792 .45676 L p 0 .914 0 r
F P
0 g
s
.72792 .45676 m .71469 .46382 L .75522 .49133 L p 0 .914 0 r
F P
0 g
s
.7684 .48469 m .75525 .49139 L .76198 .54574 L p 0 .114 0 r
F P
0 g
s
.75525 .49139 m .7684 .48469 L .76837 .48463 L p 0 .562 0 r
F P
0 g
s
.76837 .48463 m .75522 .49133 L .75525 .49139 L p 0 .562 0 r
F P
0 g
s
.75525 .49139 m .75522 .49133 L .71469 .46382 L p 0 .645 0 r
F P
0 g
s
.76198 .54574 m .75525 .49139 L p .71469 .46382 L 0 .645 0 r
F P
0 g
s
.8088 .39962 m .80878 .39963 L .81783 .39475 L p 0 .1 .1 r
F P
0 g
s
.76271 .31981 m .72233 .28773 L .7135 .2932 L p 0 .907 1 r
F P
0 g
s
.76271 .31981 m .76965 .36969 L .76061 .37479 L p 0 .1 .45 r
F P
0 g
s
.76965 .36969 m .76271 .31981 L .72233 .28773 L p 0 .627 .269 r
F P
0 g
s
.71661 .23996 m .72233 .28773 L .76271 .31981 L p 0 .627 .269 r
F P
0 g
s
.71661 .23996 m .72233 .28773 L .76271 .31981 L p 0 .627 .269 r
F P
0 g
s
.72233 .28773 m .76271 .31981 L .77156 .31458 L p 0 .907 1 r
F P
0 g
s
.76271 .31981 m .76965 .36969 L .80878 .39963 L p 0 .627 .269 r
F P
0 g
s
.76271 .31981 m .76965 .36969 L .80878 .39963 L p 0 .627 .269 r
F P
0 g
s
.76271 .31981 m .76965 .36969 L .77876 .36454 L p 0 .1 .45 r
F P
0 g
s
.77876 .36454 m .77156 .31458 L .76271 .31981 L p 0 .1 .45 r
F P
0 g
s
.76965 .36969 m .76271 .31981 L .72233 .28773 L p 0 .627 .269 r
F P
0 g
s
.76965 .36969 m .76271 .31981 L .77156 .31458 L p 0 .1 .45 r
F P
0 g
s
.72233 .28773 m .71661 .23996 L .72526 .23439 L p 0 .1 .425 r
F P
0 g
s
.76271 .31981 m .72233 .28773 L .73123 .28222 L p 0 .907 1 r
F P
0 g
s
.73123 .28222 m .77156 .31458 L .76271 .31981 L p 0 .907 1 r
F P
0 g
s
.71661 .23996 m .72233 .28773 L .7135 .2932 L p 0 .1 .425 r
F P
0 g
s
.80878 .39963 m .76965 .36969 L .77876 .36454 L p 0 .911 1 r
F P
0 g
s
.77876 .36454 m .81783 .39475 L .80878 .39963 L p 0 .911 1 r
F P
0 g
s
.56742 .48963 m .52183 .462 L .51 .46899 L p 0 .914 1 r
F P
0 g
s
.5692 .54406 m .56742 .48963 L .52183 .462 L p 0 .668 .382 r
F P
0 g
s
.47511 .48963 m .47445 .54406 L .46293 .55051 L p 0 .1 0 r
F P
0 g
s
.47511 .48963 m .47445 .54406 L .52126 .56957 L p 0 .677 0 r
F P
0 g
s
.52126 .56957 m .47445 .54406 L .46293 .55051 L p 0 .916 0 r
F P
0 g
s
.52183 .62611 m .52126 .56957 L .47445 .54406 L p 0 .677 0 r
F P
0 g
s
.47511 .48963 m .42711 .46202 L .4159 .46901 L p 0 .914 0 r
F P
0 g
s
.47445 .54406 m .47511 .48963 L .42711 .46202 L p 0 .677 0 r
F P
0 g
s
.32177 .63205 m .33236 .62613 L .3828 .64951 L p 0 .916 0 r
F P
0 g
s
.41587 .63204 m .42708 .62611 L .47511 .64951 L p 0 .916 1 r
F P
0 g
s
.3688 .55051 m .3797 .54406 L .42895 .56957 L p 0 .916 1 r
F P
0 g
s
.41587 .63204 m .42708 .62611 L .42895 .56957 L p 0 .1 .396 r
F P
0 g
s
.37644 .6014 m .3797 .54406 L .42895 .56957 L p 0 .684 .437 r
F P
0 g
s
.37647 .60146 m .37644 .6014 L p .42895 .56957 L 0 .684 .437 r
F P
0 g
s
.42895 .56957 m .42708 .62611 L .37647 .60146 L p 0 .684 .437 r
F P
0 g
s
.301 .64367 m .29082 .64937 L .29078 .64931 L p 0 .525 0 r
F P
0 g
s
.29078 .64931 m .30097 .64361 L .301 .64367 L p 0 .525 0 r
F P
0 g
s
.39388 .48275 m .3831 .48947 L .38314 .48945 L p 0 .93 0 r
F P
0 g
s
.47543 .48943 m .47478 .54387 L .5216 .56939 L p 0 .677 .411 r
F P
0 g
s
.5216 .56939 m .47478 .54387 L .48646 .53732 L p 0 .916 1 r
F P
0 g
s
.48646 .53732 m .53327 .56318 L .5216 .56939 L p 0 .916 1 r
F P
0 g
s
.47478 .54387 m .47543 .48943 L .48681 .48271 L p 0 .1 .396 r
F P
0 g
s
.47478 .54387 m .5216 .56939 L .53327 .56318 L p 0 .916 1 r
F P
0 g
s
.5216 .56939 m .52217 .62594 L .53415 .61994 L p 0 .1 .423 r
F P
0 g
s
.53415 .61994 m .53327 .56318 L .5216 .56939 L p 0 .1 .423 r
F P
0 g
s
.52217 .62594 m .5216 .56939 L .47478 .54387 L p 0 .677 .411 r
F P
0 g
s
.42744 .46182 m .47543 .48943 L .48681 .48271 L p 0 .914 1 r
F P
0 g
s
.47543 .48943 m .47478 .54387 L .48646 .53732 L p 0 .1 .396 r
F P
0 g
s
.48646 .53732 m .48681 .48271 L .47543 .48943 L p 0 .1 .396 r
F P
0 g
s
.47478 .54387 m .47543 .48943 L .42744 .46182 L p 0 .677 .411 r
F P
0 g
s
.52217 .4618 m .56776 .48943 L .57973 .48271 L p 0 .914 0 r
F P
0 g
s
.56776 .48943 m .56955 .54387 L .58185 .53732 L p 0 .1 0 r
F P
0 g
s
.58185 .53732 m .57973 .48271 L .56776 .48943 L p 0 .1 0 r
F P
0 g
s
.56955 .54387 m .56776 .48943 L .52217 .4618 L p 0 .668 0 r
F P
0 g
s
.34337 .6199 m .33263 .6259 L .33694 .56939 L p 0 .1 .365 r
F P
0 g
s
.33694 .56939 m .34743 .56318 L .34337 .6199 L p 0 .1 .365 r
F P
0 g
s
.39389 .64365 m .38311 .64935 L .33267 .62596 L p 0 .916 1 r
F P
0 g
s
.48681 .64365 m .47543 .64935 L .4274 .62594 L p 0 .916 0 r
F P
0 g
s
.43876 .61994 m .4274 .62594 L .42927 .56939 L p 0 .1 0 r
F P
0 g
s
.42927 .56939 m .44035 .56318 L .43876 .61994 L p 0 .1 0 r
F P
0 g
s
.44035 .56318 m .42927 .56939 L .38002 .54387 L p 0 .916 0 r
F P
0 g
s
.39106 .53732 m .38002 .54387 L .42927 .56939 L p 0 .916 0 r
F P
0 g
s
.42927 .56939 m .44035 .56318 L .39106 .53732 L p 0 .916 0 r
F P
0 g
s
.44035 .56318 m .42927 .56939 L .4274 .62594 L p 0 .1 0 r
F P
0 g
s
.37676 .60122 m .38002 .54387 L .42927 .56939 L p 0 .684 0 r
F P
0 g
s
.37679 .60128 m .37676 .60122 L p .42927 .56939 L 0 .684 0 r
F P
0 g
s
.42927 .56939 m .4274 .62594 L .37679 .60128 L p 0 .684 0 r
F P
0 g
s
.39106 .53732 m .38002 .54387 L .3831 .48947 L p 0 .1 0 r
F P
0 g
s
.3831 .48947 m .39388 .48275 L .39106 .53732 L p 0 .1 0 r
F P
0 g
s
.81244 .23772 m .77331 .20342 L .75997 .21201 L p 0 .903 0 r
F P
0 g
s
.81244 .23772 m .82071 .28552 L .80706 .29358 L p 0 .1 0 r
F P
0 g
s
.82071 .28552 m .81244 .23772 L .77331 .20342 L p 0 .607 0 r
F P
0 g
s
.77331 .20342 m .81244 .23772 L .82585 .22946 L p 0 .903 0 r
F P
0 g
s
.81244 .23772 m .82071 .28552 L .85862 .31771 L p 0 .607 0 r
F P
0 g
s
.81244 .23772 m .82071 .28552 L .85862 .31771 L p 0 .607 0 r
F P
0 g
s
.81244 .23772 m .82071 .28552 L .83453 .27735 L p 0 .1 0 r
F P
0 g
s
.83453 .27735 m .82585 .22946 L .81244 .23772 L p 0 .1 0 r
F P
0 g
s
.82071 .28552 m .81244 .23772 L .77331 .20342 L p 0 .607 0 r
F P
0 g
s
.82071 .28552 m .81244 .23772 L .82585 .22946 L p 0 .1 0 r
F P
0 g
s
.85862 .31771 m .82071 .28552 L .80706 .29358 L p 0 .907 0 r
F P
0 g
s
.86808 .3676 m .8681 .36758 L .85415 .37512 L p 0 .1 0 r
F P
0 g
s
.85862 .31771 m .82071 .28552 L p .86808 .3676 L 0 .607 0 r
F P
0 g
s
.86808 .3676 m .8681 .36758 L .85862 .31771 L p 0 .607 0 r
F P
0 g
s
.82071 .28552 m .85862 .31771 L .87233 .30995 L p 0 .907 0 r
F P
0 g
s
.85862 .31771 m .8681 .36758 L .88223 .35995 L p 0 .114 0 r
F P
0 g
s
.88223 .35995 m .87233 .30995 L .85862 .31771 L p 0 .114 0 r
F P
0 g
s
.85862 .31771 m .82071 .28552 L p .86808 .3676 L 0 .607 0 r
F P
0 g
s
.86808 .3676 m .8681 .36758 L .85862 .31771 L p 0 .607 0 r
F P
0 g
s
.85862 .31771 m .82071 .28552 L .83453 .27735 L p 0 .907 0 r
F P
0 g
s
.83453 .27735 m .87233 .30995 L .85862 .31771 L p 0 .907 0 r
F P
0 g
s
.72236 .23198 m .71371 .23758 L .71936 .28538 L p 0 .1 .423 r
F P
0 g
s
.71371 .23758 m .72236 .23198 L .68066 .19737 L p 0 .903 1 r
F P
0 g
s
.68066 .19737 m .67196 .20327 L .71371 .23758 L p 0 .903 1 r
F P
0 g
s
.71053 .29086 m .71936 .28538 L .71371 .23758 L p 0 .1 .423 r
F P
0 g
s
.71936 .28538 m .71371 .23758 L .67196 .20327 L p 0 .627 .269 r
F P
0 g
s
.71936 .28538 m .71371 .23758 L .67196 .20327 L p 0 .627 .269 r
F P
0 g
s
.675 .31703 m .67963 .36695 L .66676 .37457 L p 0 .1 0 r
F P
0 g
s
.675 .31703 m .67963 .36695 L .7212 .39706 L p 0 .641 0 r
F P
0 g
s
.675 .31703 m .67963 .36695 L .7212 .39706 L p 0 .641 0 r
F P
0 g
s
.67963 .36695 m .675 .31703 L .68767 .30919 L p 0 .1 0 r
F P
0 g
s
.7212 .39706 m .67963 .36695 L .69267 .35923 L p 0 .911 0 r
F P
0 g
s
.69267 .35923 m .73417 .38973 L .7212 .39706 L p 0 .911 0 r
F P
0 g
s
.44057 .39492 m .45175 .38757 L .45178 .38763 L p 0 .546 .889 r
F P
0 g
s
.45178 .38763 m .4406 .39498 L .44057 .39492 L p 0 .546 .889 r
F P
0 g
s
.53318 .23463 m .53315 .23464 L p .57944 .31478 L 0 .655 .342 r
F P
0 g
s
.53318 .23463 m .54496 .22624 L .54493 .22625 L p 0 1 .86 r
F P
0 g
s
.54493 .22625 m .53315 .23464 L .53318 .23463 L p 0 1 .86 r
F P
0 g
s
.53318 .23463 m .53315 .23464 L p .57944 .31478 L 0 .655 .342 r
F P
0 g
s
.6637 .37239 m .67658 .36474 L .67202 .31478 L p 0 .1 0 r
F P
0 g
s
.6165 .29063 m .62906 .28244 L .67202 .31478 L p 0 .907 0 r
F P
0 g
s
.67658 .36474 m .67202 .31478 L .62906 .28244 L p 0 .641 0 r
F P
0 g
s
.68469 .30691 m .67202 .31478 L .67658 .36474 L p 0 .1 0 r
F P
0 g
s
.62573 .23461 m .62906 .28244 L .67202 .31478 L p 0 .641 0 r
F P
0 g
s
.62573 .23461 m .62906 .28244 L .67202 .31478 L p 0 .641 0 r
F P
0 g
s
.67202 .31478 m .68469 .30691 L .64179 .27414 L p 0 .907 0 r
F P
0 g
s
.64179 .27414 m .62906 .28244 L .67202 .31478 L p 0 .907 0 r
F P
0 g
s
.67658 .36474 m .67202 .31478 L .62906 .28244 L p 0 .641 0 r
F P
0 g
s
.68469 .30691 m .67202 .31478 L .62906 .28244 L p 0 .907 0 r
F P
0 g
s
.62573 .23461 m .6381 .22622 L .64179 .27414 L p 0 .1 0 r
F P
0 g
s
.64179 .27414 m .62906 .28244 L .62573 .23461 L p 0 .1 0 r
F P
0 g
s
.6165 .29063 m .62906 .28244 L .62573 .23461 L p 0 .1 0 r
F P
0 g
s
.62906 .28244 m .62573 .23461 L .58158 .20016 L p 0 .641 0 r
F P
0 g
s
.6381 .22622 m .62573 .23461 L .62906 .28244 L p 0 .1 0 r
F P
0 g
s
.62573 .23461 m .6381 .22622 L .59399 .19132 L p 0 .903 0 r
F P
0 g
s
.59399 .19132 m .58158 .20016 L .62573 .23461 L p 0 .903 0 r
F P
0 g
s
.62906 .28244 m .62573 .23461 L .58158 .20016 L p 0 .641 0 r
F P
0 g
s
.48686 .31478 m .48651 .3647 L p .53315 .39496 L 0 .666 0 r
F P
0 g
s
.48686 .31478 m .48651 .3647 L p .53315 .39496 L 0 .666 0 r
F P
0 g
s
.48686 .31478 m .49834 .30691 L .49829 .35695 L p 0 .1 0 r
F P
0 g
s
.49829 .35695 m .48651 .3647 L .48686 .31478 L p 0 .1 0 r
F P
0 g
s
.47491 .37241 m .48654 .36476 L .53315 .39496 L p 0 .911 0 r
F P
0 g
s
.48651 .3647 m .48654 .36476 L .53315 .39496 L p 0 .666 0 r
F P
0 g
s
.48651 .3647 m .48654 .36476 L .53315 .39496 L p 0 .666 0 r
F P
0 g
s
.54492 .38761 m .53315 .39496 L .48654 .36476 L p 0 .911 0 r
F P
0 g
s
.56929 .37239 m .58154 .36474 L .62573 .39496 L p 0 .911 1 r
F P
0 g
s
.57944 .31478 m .58154 .36474 L .62573 .39496 L p 0 .655 .342 r
F P
0 g
s
.57944 .31478 m .58154 .36474 L .62573 .39496 L p 0 .655 .342 r
F P
0 g
s
.56929 .37239 m .58154 .36474 L .57944 .31478 L p 0 .1 .396 r
F P
0 g
s
.52209 .29063 m .53403 .28244 L .57944 .31478 L p 0 .907 1 r
F P
0 g
s
.58154 .36474 m .57944 .31478 L .53403 .28244 L p 0 .655 .342 r
F P
0 g
s
.58154 .36474 m .57944 .31478 L .53403 .28244 L p 0 .655 .342 r
F P
0 g
s
.6381 .38761 m .62573 .39496 L .58154 .36474 L p 0 .911 1 r
F P
0 g
s
.59151 .30691 m .57944 .31478 L .58154 .36474 L p 0 .1 .396 r
F P
0 g
s
.53315 .23464 m .53403 .28244 L .57944 .31478 L p 0 .655 .342 r
F P
0 g
s
.53315 .23464 m .53403 .28244 L .57944 .31478 L p 0 .655 .342 r
F P
0 g
s
.57944 .31478 m .59151 .30691 L .54612 .27414 L p 0 .907 1 r
F P
0 g
s
.54612 .27414 m .53403 .28244 L .57944 .31478 L p 0 .907 1 r
F P
0 g
s
.57944 .31478 m .59151 .30691 L .59396 .35699 L p 0 .1 .396 r
F P
0 g
s
.59396 .35699 m .58154 .36474 L .57944 .31478 L p 0 .1 .396 r
F P
0 g
s
.59151 .30691 m .57944 .31478 L .53403 .28244 L p 0 .907 1 r
F P
0 g
s
.53315 .23464 m .54493 .22625 L .54612 .27414 L p 0 .1 .365 r
F P
0 g
s
.54612 .27414 m .53403 .28244 L .53315 .23464 L p 0 .1 .365 r
F P
0 g
s
.81785 .39473 m .81783 .39475 L .82695 .38982 L p 0 .1 .1 r
F P
0 g
s
.77156 .31458 m .73123 .28222 L .72233 .28773 L p 0 .907 1 r
F P
0 g
s
.77156 .31458 m .77876 .36454 L .76965 .36969 L p 0 .1 .45 r
F P
0 g
s
.77876 .36454 m .77156 .31458 L .73123 .28222 L p 0 .624 .261 r
F P
0 g
s
.72526 .23439 m .73123 .28222 L .77156 .31458 L p 0 .624 .261 r
F P
0 g
s
.72526 .23439 m .73123 .28222 L .77156 .31458 L p 0 .624 .261 r
F P
0 g
s
.73123 .28222 m .77156 .31458 L .78048 .3093 L p 0 .907 1 r
F P
0 g
s
.77156 .31458 m .77876 .36454 L .81783 .39475 L p 0 .624 .261 r
F P
0 g
s
.77156 .31458 m .77876 .36454 L .81783 .39475 L p 0 .624 .261 r
F P
0 g
s
.77156 .31458 m .77876 .36454 L .78795 .35934 L p 0 .1 .45 r
F P
0 g
s
.78795 .35934 m .78048 .3093 L .77156 .31458 L p 0 .1 .45 r
F P
0 g
s
.77876 .36454 m .77156 .31458 L .73123 .28222 L p 0 .624 .261 r
F P
0 g
s
.77876 .36454 m .77156 .31458 L .78048 .3093 L p 0 .1 .45 r
F P
0 g
s
.72526 .23439 m .73123 .28222 L .72233 .28773 L p 0 .1 .425 r
F P
0 g
s
.73123 .28222 m .72526 .23439 L .73398 .22877 L p 0 .1 .425 r
F P
0 g
s
.77156 .31458 m .73123 .28222 L .74022 .27666 L p 0 .907 1 r
F P
0 g
s
.74022 .27666 m .78048 .3093 L .77156 .31458 L p 0 .907 1 r
F P
0 g
s
.81783 .39475 m .77876 .36454 L .78795 .35934 L p 0 .911 1 r
F P
0 g
s
.78795 .35934 m .82695 .38982 L .81783 .39475 L p 0 .911 1 r
F P
0 g
s
.67562 .64528 m .67564 .64526 L p .62927 .56498 L 0 .666 0 r
F P
0 g
s
.68836 .63951 m .67564 .64526 L .67562 .64528 L p 0 .1 0 r
F P
0 g
s
.67562 .64528 m .67564 .64526 L p .62927 .56498 L 0 .666 0 r
F P
0 g
s
.52551 .62766 m .53749 .62167 L .5829 .6453 L p 0 .916 1 r
F P
0 g
s
.53652 .56498 m .53749 .62167 L .5829 .6453 L p 0 .675 .404 r
F P
0 g
s
.53652 .56498 m .53749 .62167 L .5829 .6453 L p 0 .675 .404 r
F P
0 g
s
.59502 .63955 m .5829 .6453 L .53749 .62167 L p 0 .916 1 r
F P
0 g
s
.53652 .56498 m .54834 .55871 L .54963 .61561 L p 0 .1 .425 r
F P
0 g
s
.54963 .61561 m .53749 .62167 L .53652 .56498 L p 0 .1 .425 r
F P
0 g
s
.66739 .54574 m .68031 .53922 L .67565 .48465 L p 0 .1 .45 r
F P
0 g
s
.68031 .53922 m .67565 .48465 L .63271 .45676 L p 0 .655 .342 r
F P
0 g
s
.68031 .53922 m .67565 .48465 L .63271 .45676 L p 0 .655 .342 r
F P
0 g
s
.66739 .54574 m .68031 .53922 L .72202 .56498 L p 0 .916 1 r
F P
0 g
s
.67565 .48465 m .68031 .53922 L .72202 .56498 L p 0 .655 .342 r
F P
0 g
s
.67565 .48465 m .68031 .53922 L .72202 .56498 L p 0 .655 .342 r
F P
0 g
s
.73504 .55871 m .72202 .56498 L .68031 .53922 L p 0 .916 1 r
F P
0 g
s
.71468 .62761 m .72792 .62163 L .72202 .56498 L p 0 .114 .472 r
F P
0 g
s
.72792 .62163 m .72202 .56498 L .68031 .53922 L p 0 .655 .342 r
F P
0 g
s
.72202 .56498 m .73504 .55871 L .6934 .53261 L p 0 .916 1 r
F P
0 g
s
.6934 .53261 m .68031 .53922 L .72202 .56498 L p 0 .916 1 r
F P
0 g
s
.73504 .55871 m .72202 .56498 L .72792 .62163 L p 0 .114 .472 r
F P
0 g
s
.72792 .62163 m .72202 .56498 L .68031 .53922 L p 0 .655 .342 r
F P
0 g
s
.67565 .48465 m .68837 .47786 L .64548 .4496 L p 0 .914 1 r
F P
0 g
s
.64548 .4496 m .63271 .45676 L .67565 .48465 L p 0 .914 1 r
F P
0 g
s
.68837 .47786 m .67565 .48465 L .68031 .53922 L p 0 .1 .45 r
F P
0 g
s
.67565 .48465 m .68837 .47786 L .6934 .53261 L p 0 .1 .45 r
F P
0 g
s
.6934 .53261 m .68031 .53922 L .67565 .48465 L p 0 .1 .45 r
F P
0 g
s
.5728 .54574 m .5851 .53922 L .62927 .56498 L p 0 .916 0 r
F P
0 g
s
.5829 .48465 m .5851 .53922 L .62927 .56498 L p 0 .666 0 r
F P
0 g
s
.5829 .48465 m .5851 .53922 L .62927 .56498 L p 0 .666 0 r
F P
0 g
s
.64169 .55871 m .62927 .56498 L .5851 .53922 L p 0 .916 0 r
F P
0 g
s
.62927 .56498 m .63271 .62167 L .67562 .64528 L p 0 .666 0 r
F P
0 g
s
.62927 .56498 m .63271 .62167 L .67562 .64528 L p 0 .666 0 r
F P
0 g
s
.62927 .56498 m .64169 .55871 L .64548 .61561 L p 0 .1 0 r
F P
0 g
s
.64548 .61561 m .63271 .62167 L .62927 .56498 L p 0 .1 0 r
F P
0 g
s
.5829 .48465 m .59502 .47786 L .59756 .53261 L p 0 .1 0 r
F P
0 g
s
.59756 .53261 m .5851 .53922 L .5829 .48465 L p 0 .1 0 r
F P
0 g
s
.6201 .62766 m .63271 .62167 L .62927 .56498 L p 0 .1 0 r
F P
0 g
s
.63271 .62167 m .62927 .56498 L .5851 .53922 L p 0 .666 0 r
F P
0 g
s
.62927 .56498 m .64169 .55871 L .59756 .53261 L p 0 .916 0 r
F P
0 g
s
.59756 .53261 m .5851 .53922 L .62927 .56498 L p 0 .916 0 r
F P
0 g
s
.64169 .55871 m .62927 .56498 L .63271 .62167 L p 0 .1 0 r
F P
0 g
s
.63271 .62167 m .62927 .56498 L .5851 .53922 L p 0 .666 0 r
F P
0 g
s
.6201 .62766 m .63271 .62167 L .67562 .64528 L p 0 .916 0 r
F P
0 g
s
.67562 .64528 m .68834 .63953 L .68836 .63951 L p 0 .1 0 r
F P
0 g
s
.68834 .63953 m .67562 .64528 L .63271 .62167 L p 0 .916 0 r
F P
0 g
s
.76198 .54574 m .77553 .53922 L .7684 .48469 L p 0 .114 0 r
F P
0 g
s
.7684 .48469 m .76837 .48463 L .72792 .45676 L p 0 .641 0 r
F P
0 g
s
.77553 .53922 m .7684 .48469 L p .72792 .45676 L 0 .641 0 r
F P
0 g
s
.76837 .48463 m .78169 .47784 L .74133 .4496 L p 0 .914 0 r
F P
0 g
s
.7684 .48469 m .78172 .4779 L .78169 .47784 L p 0 .562 0 r
F P
0 g
s
.78169 .47784 m .76837 .48463 L .7684 .48469 L p 0 .562 0 r
F P
0 g
s
.78172 .4779 m .78169 .47784 L .74133 .4496 L p 0 .638 0 r
F P
0 g
s
.74133 .4496 m .72792 .45676 L .76837 .48463 L p 0 .914 0 r
F P
0 g
s
.78172 .4779 m .7684 .48469 L .77553 .53922 L p 0 .114 0 r
F P
0 g
s
.7684 .48469 m .76837 .48463 L .72792 .45676 L p 0 .641 0 r
F P
0 g
s
.77553 .53922 m .7684 .48469 L p .72792 .45676 L 0 .641 0 r
F P
0 g
s
.77553 .53922 m .78925 .53261 L .78172 .4779 L p 0 .114 0 r
F P
0 g
s
.78925 .53261 m .78172 .4779 L p .74133 .4496 L 0 .638 0 r
F P
0 g
s
.71936 .28538 m .72827 .27984 L .72236 .23198 L p 0 .1 .423 r
F P
0 g
s
.72827 .27984 m .72236 .23198 L .68066 .19737 L p 0 .624 .261 r
F P
0 g
s
.73109 .22634 m .72236 .23198 L .72827 .27984 L p 0 .1 .423 r
F P
0 g
s
.72236 .23198 m .73109 .22634 L .68943 .19142 L p 0 .903 1 r
F P
0 g
s
.68943 .19142 m .68066 .19737 L .72236 .23198 L p 0 .903 1 r
F P
0 g
s
.72827 .27984 m .72236 .23198 L .68066 .19737 L p 0 .624 .261 r
F P
0 g
s
.31132 .6379 m .301 .64367 L .30097 .64361 L p 0 .525 0 r
F P
0 g
s
.30097 .64361 m .31129 .63784 L .31132 .6379 L p 0 .525 0 r
F P
0 g
s
.4048 .47593 m .39388 .48275 L .39392 .48273 L p 0 .93 0 r
F P
0 g
s
.48681 .48271 m .48646 .53732 L .47478 .54387 L p 0 .1 .396 r
F P
0 g
s
.48681 .48271 m .48646 .53732 L .53327 .56318 L p 0 .675 .404 r
F P
0 g
s
.48681 .48271 m .48646 .53732 L .53327 .56318 L p 0 .675 .404 r
F P
0 g
s
.53327 .56318 m .48646 .53732 L .49829 .53069 L p 0 .916 1 r
F P
0 g
s
.49829 .53069 m .54509 .55689 L .53327 .56318 L p 0 .916 1 r
F P
0 g
s
.48646 .53732 m .48681 .48271 L .49833 .47589 L p 0 .1 .396 r
F P
0 g
s
.53327 .56318 m .48646 .53732 L .47478 .54387 L p 0 .916 1 r
F P
0 g
s
.53415 .61994 m .53327 .56318 L .48646 .53732 L p 0 .675 .404 r
F P
0 g
s
.48646 .53732 m .53327 .56318 L .54509 .55689 L p 0 .916 1 r
F P
0 g
s
.53327 .56318 m .53415 .61994 L .5463 .61386 L p 0 .1 .423 r
F P
0 g
s
.5463 .61386 m .54509 .55689 L .53327 .56318 L p 0 .1 .423 r
F P
0 g
s
.53415 .61994 m .53327 .56318 L .48646 .53732 L p 0 .675 .404 r
F P
0 g
s
.48681 .48271 m .43879 .45473 L .42744 .46182 L p 0 .914 1 r
F P
0 g
s
.48646 .53732 m .48681 .48271 L .43879 .45473 L p 0 .675 .404 r
F P
0 g
s
.43879 .45473 m .48681 .48271 L .49833 .47589 L p 0 .914 1 r
F P
0 g
s
.48681 .48271 m .48646 .53732 L .49829 .53069 L p 0 .1 .396 r
F P
0 g
s
.49829 .53069 m .49833 .47589 L .48681 .48271 L p 0 .1 .396 r
F P
0 g
s
.48646 .53732 m .48681 .48271 L .43879 .45473 L p 0 .675 .404 r
F P
0 g
s
.57973 .48271 m .53415 .45471 L .52217 .4618 L p 0 .914 0 r
F P
0 g
s
.58185 .53732 m .57973 .48271 L .53415 .45471 L p 0 .666 0 r
F P
0 g
s
.53415 .45471 m .57973 .48271 L .59185 .47589 L p 0 .914 0 r
F P
0 g
s
.57973 .48271 m .58185 .53732 L .59432 .53069 L p 0 .1 0 r
F P
0 g
s
.59432 .53069 m .59185 .47589 L .57973 .48271 L p 0 .1 0 r
F P
0 g
s
.58185 .53732 m .57973 .48271 L .53415 .45471 L p 0 .666 0 r
F P
0 g
s
.49833 .63788 m .48681 .64365 L .43876 .61994 L p 0 .916 0 r
F P
0 g
s
.45027 .61386 m .43876 .61994 L .44035 .56318 L p 0 .1 0 r
F P
0 g
s
.44035 .56318 m .45157 .55689 L .45027 .61386 L p 0 .1 0 r
F P
0 g
s
.4274 .62594 m .43876 .61994 L .48681 .64365 L p 0 .916 0 r
F P
0 g
s
.45157 .55689 m .44035 .56318 L .39106 .53732 L p 0 .916 0 r
F P
0 g
s
.38002 .54387 m .39106 .53732 L .44035 .56318 L p 0 .916 0 r
F P
0 g
s
.40226 .53069 m .39106 .53732 L .44035 .56318 L p 0 .916 0 r
F P
0 g
s
.44035 .56318 m .45157 .55689 L .40226 .53069 L p 0 .916 0 r
F P
0 g
s
.45157 .55689 m .44035 .56318 L .43876 .61994 L p 0 .1 0 r
F P
0 g
s
.38808 .59489 m .39106 .53732 L .44035 .56318 L p 0 .683 0 r
F P
0 g
s
.38812 .59495 m .38808 .59489 L p .44035 .56318 L 0 .683 0 r
F P
0 g
s
.4274 .62594 m .43876 .61994 L .44035 .56318 L p 0 .1 0 r
F P
0 g
s
.44035 .56318 m .43876 .61994 L .38812 .59495 L p 0 .683 0 r
F P
0 g
s
.38808 .59489 m .39106 .53732 L .44035 .56318 L p 0 .683 0 r
F P
0 g
s
.38812 .59495 m .38808 .59489 L p .44035 .56318 L 0 .683 0 r
F P
0 g
s
.44035 .56318 m .43876 .61994 L .38812 .59495 L p 0 .683 0 r
F P
0 g
s
.35424 .61381 m .34337 .6199 L .34743 .56318 L p 0 .1 .365 r
F P
0 g
s
.34743 .56318 m .35804 .55689 L .35424 .61381 L p 0 .1 .365 r
F P
0 g
s
.40481 .63788 m .39389 .64365 L .3434 .61996 L p 0 .916 1 r
F P
0 g
s
.33267 .62596 m .3434 .61996 L .39389 .64365 L p 0 .916 1 r
F P
0 g
s
.40226 .53069 m .39106 .53732 L .39388 .48275 L p 0 .1 0 r
F P
0 g
s
.39388 .48275 m .4048 .47593 L .40226 .53069 L p 0 .1 0 r
F P
0 g
s
.82585 .22946 m .78682 .19471 L .77331 .20342 L p 0 .903 0 r
F P
0 g
s
.82585 .22946 m .83453 .27735 L .82071 .28552 L p 0 .1 0 r
F P
0 g
s
.83453 .27735 m .82585 .22946 L .78682 .19471 L p 0 .601 0 r
F P
0 g
s
.82585 .22946 m .83453 .27735 L .87233 .30995 L p 0 .601 0 r
F P
0 g
s
.87233 .30995 m .83453 .27735 L .82071 .28552 L p 0 .907 0 r
F P
0 g
s
.88221 .35996 m .88223 .35995 L .8681 .36758 L p 0 .1 0 r
F P
0 g
s
.87233 .30995 m .83453 .27735 L p .88221 .35996 L 0 .601 0 r
F P
0 g
s
.88221 .35996 m .88223 .35995 L .87233 .30995 L p 0 .601 0 r
F P
0 g
s
.82697 .3898 m .82695 .38982 L .83615 .38484 L p 0 .1 .1 r
F P
0 g
s
.73398 .22877 m .74022 .27666 L .73123 .28222 L p 0 .1 .425 r
F P
0 g
s
.73398 .22877 m .74022 .27666 L .78048 .3093 L p 0 .621 .254 r
F P
0 g
s
.73398 .22877 m .74022 .27666 L .78048 .3093 L p 0 .621 .254 r
F P
0 g
s
.74022 .27666 m .73398 .22877 L .74278 .22309 L p 0 .1 .425 r
F P
0 g
s
.78048 .3093 m .74022 .27666 L .73123 .28222 L p 0 .907 1 r
F P
0 g
s
.78048 .3093 m .78795 .35934 L .77876 .36454 L p 0 .1 .45 r
F P
0 g
s
.78795 .35934 m .78048 .3093 L .74022 .27666 L p 0 .621 .254 r
F P
0 g
s
.74022 .27666 m .78048 .3093 L .78948 .30398 L p 0 .907 1 r
F P
0 g
s
.78048 .3093 m .78795 .35934 L .82695 .38982 L p 0 .621 .254 r
F P
0 g
s
.78048 .3093 m .78795 .35934 L .82695 .38982 L p 0 .621 .254 r
F P
0 g
s
.78048 .3093 m .78795 .35934 L .79723 .3541 L p 0 .1 .45 r
F P
0 g
s
.79723 .3541 m .78948 .30398 L .78048 .3093 L p 0 .1 .45 r
F P
0 g
s
.78795 .35934 m .78048 .3093 L .74022 .27666 L p 0 .621 .254 r
F P
0 g
s
.78048 .3093 m .74022 .27666 L .74928 .27105 L p 0 .907 1 r
F P
0 g
s
.74928 .27105 m .78948 .30398 L .78048 .3093 L p 0 .907 1 r
F P
0 g
s
.78795 .35934 m .78048 .3093 L .78948 .30398 L p 0 .1 .45 r
F P
0 g
s
.82695 .38982 m .78795 .35934 L .79723 .3541 L p 0 .911 1 r
F P
0 g
s
.79723 .3541 m .83615 .38484 L .82695 .38982 L p 0 .911 1 r
F P
0 g
s
.68767 .30919 m .69267 .35923 L .73417 .38973 L p 0 .638 0 r
F P
0 g
s
.68767 .30919 m .69267 .35923 L .73417 .38973 L p 0 .638 0 r
F P
0 g
s
.69267 .35923 m .68767 .30919 L .7005 .30124 L p 0 .1 0 r
F P
0 g
s
.73417 .38973 m .69267 .35923 L .70588 .35141 L p 0 .911 0 r
F P
0 g
s
.70588 .35141 m .74731 .38231 L .73417 .38973 L p 0 .911 0 r
F P
0 g
s
.68767 .30919 m .69267 .35923 L .67963 .36695 L p 0 .1 0 r
F P
0 g
s
.72827 .27984 m .73726 .27426 L .73109 .22634 L p 0 .1 .423 r
F P
0 g
s
.73726 .27426 m .73109 .22634 L .68943 .19142 L p 0 .621 .254 r
F P
0 g
s
.73989 .22065 m .73109 .22634 L .73726 .27426 L p 0 .1 .423 r
F P
0 g
s
.73109 .22634 m .73989 .22065 L .69828 .18542 L p 0 .903 1 r
F P
0 g
s
.69828 .18542 m .68943 .19142 L .73109 .22634 L p 0 .903 1 r
F P
0 g
s
.73726 .27426 m .73109 .22634 L .68943 .19142 L p 0 .621 .254 r
F P
0 g
s
.45175 .38757 m .46307 .38012 L .46311 .38018 L p 0 .546 .889 r
F P
0 g
s
.46311 .38018 m .45178 .38763 L .45175 .38757 L p 0 .546 .889 r
F P
0 g
s
.54496 .22624 m .54493 .22625 L p .59151 .30691 L 0 .652 .333 r
F P
0 g
s
.54496 .22624 m .55689 .21775 L .55686 .21775 L p 0 1 .86 r
F P
0 g
s
.55686 .21775 m .54493 .22625 L .54496 .22624 L p 0 1 .86 r
F P
0 g
s
.54496 .22624 m .54493 .22625 L p .59151 .30691 L 0 .652 .333 r
F P
0 g
s
.69753 .29894 m .68469 .30691 L .68962 .35699 L p 0 .1 0 r
F P
0 g
s
.6381 .22622 m .64179 .27414 L .68469 .30691 L p 0 .638 0 r
F P
0 g
s
.6381 .22622 m .64179 .27414 L .68469 .30691 L p 0 .638 0 r
F P
0 g
s
.68469 .30691 m .69753 .29894 L .65468 .26574 L p 0 .907 0 r
F P
0 g
s
.65468 .26574 m .64179 .27414 L .68469 .30691 L p 0 .907 0 r
F P
0 g
s
.67658 .36474 m .68962 .35699 L .68469 .30691 L p 0 .1 0 r
F P
0 g
s
.62906 .28244 m .64179 .27414 L .68469 .30691 L p 0 .907 0 r
F P
0 g
s
.68962 .35699 m .68469 .30691 L .64179 .27414 L p 0 .638 0 r
F P
0 g
s
.6381 .22622 m .65064 .21772 L .65468 .26574 L p 0 .1 0 r
F P
0 g
s
.65468 .26574 m .64179 .27414 L .6381 .22622 L p 0 .1 0 r
F P
0 g
s
.69753 .29894 m .68469 .30691 L .64179 .27414 L p 0 .907 0 r
F P
0 g
s
.65064 .21772 m .6381 .22622 L .64179 .27414 L p 0 .1 0 r
F P
0 g
s
.6381 .22622 m .65064 .21772 L .60657 .18236 L p 0 .903 0 r
F P
0 g
s
.60657 .18236 m .59399 .19132 L .6381 .22622 L p 0 .903 0 r
F P
0 g
s
.62906 .28244 m .64179 .27414 L .6381 .22622 L p 0 .1 0 r
F P
0 g
s
.64179 .27414 m .6381 .22622 L .59399 .19132 L p 0 .638 0 r
F P
0 g
s
.68962 .35699 m .68469 .30691 L .64179 .27414 L p 0 .638 0 r
F P
0 g
s
.64179 .27414 m .6381 .22622 L .59399 .19132 L p 0 .638 0 r
F P
0 g
s
.49834 .30691 m .49829 .35695 L p .54492 .38761 L 0 .663 0 r
F P
0 g
s
.49834 .30691 m .49829 .35695 L p .54492 .38761 L 0 .663 0 r
F P
0 g
s
.49834 .30691 m .50996 .29894 L .51023 .3491 L p 0 .1 0 r
F P
0 g
s
.51023 .3491 m .49829 .35695 L .49834 .30691 L p 0 .1 0 r
F P
0 g
s
.48654 .36476 m .49833 .35701 L .54492 .38761 L p 0 .911 0 r
F P
0 g
s
.49829 .35695 m .49833 .35701 L .54492 .38761 L p 0 .663 0 r
F P
0 g
s
.49829 .35695 m .49833 .35701 L .54492 .38761 L p 0 .663 0 r
F P
0 g
s
.55686 .38016 m .54492 .38761 L .49833 .35701 L p 0 .911 0 r
F P
0 g
s
.58154 .36474 m .59396 .35699 L .6381 .38761 L p 0 .911 1 r
F P
0 g
s
.59151 .30691 m .59396 .35699 L .6381 .38761 L p 0 .652 .333 r
F P
0 g
s
.59151 .30691 m .59396 .35699 L .6381 .38761 L p 0 .652 .333 r
F P
0 g
s
.65064 .38016 m .6381 .38761 L .59396 .35699 L p 0 .911 1 r
F P
0 g
s
.58154 .36474 m .59396 .35699 L .59151 .30691 L p 0 .1 .396 r
F P
0 g
s
.53403 .28244 m .54612 .27414 L .59151 .30691 L p 0 .907 1 r
F P
0 g
s
.59396 .35699 m .59151 .30691 L .54612 .27414 L p 0 .652 .333 r
F P
0 g
s
.60375 .29894 m .59151 .30691 L .59396 .35699 L p 0 .1 .396 r
F P
0 g
s
.54493 .22625 m .54612 .27414 L .59151 .30691 L p 0 .652 .333 r
F P
0 g
s
.54493 .22625 m .54612 .27414 L .59151 .30691 L p 0 .652 .333 r
F P
0 g
s
.59151 .30691 m .60375 .29894 L .55838 .26574 L p 0 .907 1 r
F P
0 g
s
.55838 .26574 m .54612 .27414 L .59151 .30691 L p 0 .907 1 r
F P
0 g
s
.59396 .35699 m .59151 .30691 L .54612 .27414 L p 0 .652 .333 r
F P
0 g
s
.59151 .30691 m .60375 .29894 L .60653 .34914 L p 0 .1 .396 r
F P
0 g
s
.60653 .34914 m .59396 .35699 L .59151 .30691 L p 0 .1 .396 r
F P
0 g
s
.60375 .29894 m .59151 .30691 L .54612 .27414 L p 0 .907 1 r
F P
0 g
s
.54493 .22625 m .55686 .21775 L .55838 .26574 L p 0 .1 .365 r
F P
0 g
s
.55838 .26574 m .54612 .27414 L .54493 .22625 L p 0 .1 .365 r
F P
0 g
s
.79277 .19088 m .83175 .22582 L .84323 .21875 L p 0 .903 1 r
F P
0 g
s
.83175 .22582 m .84061 .27375 L .87836 .30654 L p 0 .599 .205 r
F P
0 g
s
.83175 .22582 m .84061 .27375 L .85245 .26675 L p 0 .1 .45 r
F P
0 g
s
.85245 .26675 m .84323 .21875 L .83175 .22582 L p 0 .1 .45 r
F P
0 g
s
.84061 .27375 m .83175 .22582 L .79277 .19088 L p 0 .599 .205 r
F P
0 g
s
.84061 .27375 m .83175 .22582 L .84323 .21875 L p 0 .1 .45 r
F P
0 g
s
.84061 .27375 m .87836 .30654 L .89008 .2999 L p 0 .907 1 r
F P
0 g
s
.87836 .30654 m .88845 .35659 L .90055 .35005 L p 0 .114 .472 r
F P
0 g
s
.90055 .35005 m .89008 .2999 L .87836 .30654 L p 0 .114 .472 r
F P
0 g
s
.87836 .30654 m .84061 .27375 L p .88843 .3566 L 0 .599 .205 r
F P
0 g
s
.88843 .3566 m .88845 .35659 L .87836 .30654 L p 0 .599 .205 r
F P
0 g
s
.87836 .30654 m .84061 .27375 L .85245 .26675 L p 0 .907 1 r
F P
0 g
s
.85245 .26675 m .89008 .2999 L .87836 .30654 L p 0 .907 1 r
F P
0 g
s
.70125 .63369 m .68836 .63951 L .68834 .63953 L p 0 .1 0 r
F P
0 g
s
.68834 .63953 m .68836 .63951 L p .64169 .55871 L 0 .663 0 r
F P
0 g
s
.68834 .63953 m .68836 .63951 L p .64169 .55871 L 0 .663 0 r
F P
0 g
s
.53749 .62167 m .54963 .61561 L .59502 .63955 L p 0 .916 1 r
F P
0 g
s
.54834 .55871 m .54963 .61561 L .59502 .63955 L p 0 .673 .397 r
F P
0 g
s
.54834 .55871 m .54963 .61561 L .59502 .63955 L p 0 .673 .397 r
F P
0 g
s
.6073 .63373 m .59502 .63955 L .54963 .61561 L p 0 .916 1 r
F P
0 g
s
.54834 .55871 m .56032 .55236 L .56194 .60947 L p 0 .1 .425 r
F P
0 g
s
.56194 .60947 m .54963 .61561 L .54834 .55871 L p 0 .1 .425 r
F P
0 g
s
.68031 .53922 m .6934 .53261 L .68837 .47786 L p 0 .1 .45 r
F P
0 g
s
.6934 .53261 m .68837 .47786 L .64548 .4496 L p 0 .652 .333 r
F P
0 g
s
.68837 .47786 m .70125 .47099 L .65843 .44235 L p 0 .914 1 r
F P
0 g
s
.65843 .44235 m .64548 .4496 L .68837 .47786 L p 0 .914 1 r
F P
0 g
s
.68837 .47786 m .6934 .53261 L .73504 .55871 L p 0 .652 .333 r
F P
0 g
s
.68837 .47786 m .6934 .53261 L .73504 .55871 L p 0 .652 .333 r
F P
0 g
s
.70125 .47099 m .68837 .47786 L .6934 .53261 L p 0 .1 .45 r
F P
0 g
s
.6934 .53261 m .68837 .47786 L .64548 .4496 L p 0 .652 .333 r
F P
0 g
s
.68031 .53922 m .6934 .53261 L .73504 .55871 L p 0 .916 1 r
F P
0 g
s
.68837 .47786 m .70125 .47099 L .70667 .52591 L p 0 .1 .45 r
F P
0 g
s
.70667 .52591 m .6934 .53261 L .68837 .47786 L p 0 .1 .45 r
F P
0 g
s
.74823 .55236 m .73504 .55871 L .6934 .53261 L p 0 .916 1 r
F P
0 g
s
.72792 .62163 m .74132 .61557 L .73504 .55871 L p 0 .114 .472 r
F P
0 g
s
.74132 .61557 m .73504 .55871 L .6934 .53261 L p 0 .652 .333 r
F P
0 g
s
.73504 .55871 m .74823 .55236 L .70667 .52591 L p 0 .916 1 r
F P
0 g
s
.70667 .52591 m .6934 .53261 L .73504 .55871 L p 0 .916 1 r
F P
0 g
s
.74823 .55236 m .73504 .55871 L .74132 .61557 L p 0 .114 .472 r
F P
0 g
s
.74132 .61557 m .73504 .55871 L .6934 .53261 L p 0 .652 .333 r
F P
0 g
s
.5851 .53922 m .59756 .53261 L .64169 .55871 L p 0 .916 0 r
F P
0 g
s
.59502 .47786 m .59756 .53261 L .64169 .55871 L p 0 .663 0 r
F P
0 g
s
.59502 .47786 m .59756 .53261 L .64169 .55871 L p 0 .663 0 r
F P
0 g
s
.65427 .55236 m .64169 .55871 L .59756 .53261 L p 0 .916 0 r
F P
0 g
s
.64169 .55871 m .64548 .61561 L .68834 .63953 L p 0 .663 0 r
F P
0 g
s
.64169 .55871 m .64548 .61561 L .68834 .63953 L p 0 .663 0 r
F P
0 g
s
.64169 .55871 m .65427 .55236 L .65843 .60947 L p 0 .1 0 r
F P
0 g
s
.65843 .60947 m .64548 .61561 L .64169 .55871 L p 0 .1 0 r
F P
0 g
s
.63271 .62167 m .64548 .61561 L .64169 .55871 L p 0 .1 0 r
F P
0 g
s
.64548 .61561 m .64169 .55871 L .59756 .53261 L p 0 .663 0 r
F P
0 g
s
.64169 .55871 m .65427 .55236 L .61018 .52591 L p 0 .916 0 r
F P
0 g
s
.61018 .52591 m .59756 .53261 L .64169 .55871 L p 0 .916 0 r
F P
0 g
s
.65427 .55236 m .64169 .55871 L .64548 .61561 L p 0 .1 0 r
F P
0 g
s
.64548 .61561 m .64169 .55871 L .59756 .53261 L p 0 .663 0 r
F P
0 g
s
.59502 .47786 m .6073 .47099 L .61018 .52591 L p 0 .1 0 r
F P
0 g
s
.61018 .52591 m .59756 .53261 L .59502 .47786 L p 0 .1 0 r
F P
0 g
s
.78169 .47784 m .79518 .47097 L .75492 .44235 L p 0 .914 0 r
F P
0 g
s
.75492 .44235 m .74133 .4496 L .78169 .47784 L p 0 .914 0 r
F P
0 g
s
.79522 .47103 m .78172 .4779 L .78925 .53261 L p 0 .114 0 r
F P
0 g
s
.78172 .4779 m .79522 .47103 L .79518 .47097 L p 0 .562 0 r
F P
0 g
s
.79518 .47097 m .78169 .47784 L .78172 .4779 L p 0 .562 0 r
F P
0 g
s
.68834 .63953 m .70122 .63371 L .70125 .63369 L p 0 .1 0 r
F P
0 g
s
.70122 .63371 m .68834 .63953 L .64548 .61561 L p 0 .916 0 r
F P
0 g
s
.63271 .62167 m .64548 .61561 L .68834 .63953 L p 0 .916 0 r
F P
0 g
s
.78172 .4779 m .78169 .47784 L .74133 .4496 L p 0 .638 0 r
F P
0 g
s
.78925 .53261 m .78172 .4779 L p .74133 .4496 L 0 .638 0 r
F P
0 g
s
.78925 .53261 m .80316 .52591 L .79522 .47103 L p 0 .114 0 r
F P
0 g
s
.70125 .47099 m .70667 .52591 L .74823 .55236 L p 0 .648 .324 r
F P
0 g
s
.70125 .47099 m .70667 .52591 L .74823 .55236 L p 0 .648 .324 r
F P
0 g
s
.71431 .46402 m .72012 .51913 L .7616 .54592 L p 0 .645 .315 r
F P
0 g
s
.71469 .46382 m .72051 .51893 L .76198 .54574 L p 0 .645 0 r
F P
0 g
s
.72792 .45676 m .73414 .51205 L .77553 .53922 L p 0 .641 0 r
F P
0 g
s
.72792 .45676 m .73414 .51205 L .77553 .53922 L p 0 .641 0 r
F P
0 g
s
.74133 .4496 m .74796 .50508 L .78925 .53261 L p 0 .638 0 r
F P
0 g
s
.74133 .4496 m .74796 .50508 L .78925 .53261 L p 0 .638 0 r
F P
0 g
s
.76197 .49801 m .74796 .50508 L .78925 .53261 L p 0 .916 0 r
F P
0 g
s
.78925 .53261 m .80316 .52591 L .76197 .49801 L p 0 .916 0 r
F P
0 g
s
.74278 .22309 m .74928 .27105 L .74022 .27666 L p 0 .1 .425 r
F P
0 g
s
.74278 .22309 m .74928 .27105 L .78948 .30398 L p 0 .618 .247 r
F P
0 g
s
.78948 .30398 m .74928 .27105 L .74022 .27666 L p 0 .907 1 r
F P
0 g
s
.78948 .30398 m .79723 .3541 L .78795 .35934 L p 0 .1 .45 r
F P
0 g
s
.79723 .3541 m .78948 .30398 L .74928 .27105 L p 0 .618 .247 r
F P
0 g
s
.78948 .30398 m .79723 .3541 L .83615 .38484 L p 0 .618 .247 r
F P
0 g
s
.32177 .63205 m .31132 .6379 L .31129 .63784 L p 0 .525 0 r
F P
0 g
s
.31129 .63784 m .32174 .632 L .32177 .63205 L p 0 .525 0 r
F P
0 g
s
.4048 .47593 m .40484 .47591 L .4159 .46901 L p 0 .93 0 r
F P
0 g
s
.40226 .53069 m .45157 .55689 L p .40484 .47591 L 0 .681 0 r
F P
0 g
s
.40484 .47591 m .4048 .47593 L .40226 .53069 L p 0 .681 0 r
F P
0 g
s
.49833 .47589 m .49829 .53069 L .48646 .53732 L p 0 .1 .396 r
F P
0 g
s
.49833 .47589 m .49829 .53069 L .54509 .55689 L p 0 .673 .397 r
F P
0 g
s
.49833 .47589 m .49829 .53069 L .54509 .55689 L p 0 .673 .397 r
F P
0 g
s
.49829 .53069 m .49833 .47589 L .51 .46899 L p 0 .1 .396 r
F P
0 g
s
.54509 .55689 m .49829 .53069 L .48646 .53732 L p 0 .916 1 r
F P
0 g
s
.5463 .61386 m .54509 .55689 L .49829 .53069 L p 0 .673 .397 r
F P
0 g
s
.49829 .53069 m .54509 .55689 L .55707 .55051 L p 0 .916 1 r
F P
0 g
s
.54509 .55689 m .5463 .61386 L .55861 .60769 L p 0 .1 .423 r
F P
0 g
s
.55861 .60769 m .55707 .55051 L .54509 .55689 L p 0 .1 .423 r
F P
0 g
s
.5463 .61386 m .54509 .55689 L .49829 .53069 L p 0 .673 .397 r
F P
0 g
s
.49833 .47589 m .45031 .44755 L .43879 .45473 L p 0 .914 1 r
F P
0 g
s
.49829 .53069 m .49833 .47589 L .45031 .44755 L p 0 .673 .397 r
F P
0 g
s
.45031 .44755 m .49833 .47589 L .51 .46899 L p 0 .914 1 r
F P
0 g
s
.49833 .47589 m .49829 .53069 L .51027 .52397 L p 0 .1 .396 r
F P
0 g
s
.51027 .52397 m .51 .46899 L .49833 .47589 L p 0 .1 .396 r
F P
0 g
s
.49829 .53069 m .49833 .47589 L .45031 .44755 L p 0 .673 .397 r
F P
0 g
s
.54509 .55689 m .49829 .53069 L .51027 .52397 L p 0 .916 1 r
F P
0 g
s
.51027 .52397 m .55707 .55051 L .54509 .55689 L p 0 .916 1 r
F P
0 g
s
.59185 .47589 m .5463 .44753 L .53415 .45471 L p 0 .914 0 r
F P
0 g
s
.59432 .53069 m .59185 .47589 L .5463 .44753 L p 0 .663 0 r
F P
0 g
s
.59432 .53069 m .59185 .47589 L .5463 .44753 L p 0 .663 0 r
F P
0 g
s
.5463 .44753 m .59185 .47589 L .60414 .46899 L p 0 .914 0 r
F P
0 g
s
.59185 .47589 m .59432 .53069 L .60694 .52397 L p 0 .1 0 r
F P
0 g
s
.60694 .52397 m .60414 .46899 L .59185 .47589 L p 0 .1 0 r
F P
0 g
s
.43876 .61994 m .45027 .61386 L .49833 .63788 L p 0 .916 0 r
F P
0 g
s
.39106 .53732 m .40226 .53069 L .45157 .55689 L p 0 .916 0 r
F P
0 g
s
.43876 .61994 m .45027 .61386 L .45157 .55689 L p 0 .1 0 r
F P
0 g
s
.39957 .58846 m .40226 .53069 L .45157 .55689 L p 0 .681 0 r
F P
0 g
s
.3996 .58852 m .39957 .58846 L p .45157 .55689 L 0 .681 0 r
F P
0 g
s
.45157 .55689 m .45027 .61386 L .3996 .58852 L p 0 .681 0 r
F P
0 g
s
.45157 .55689 m .45027 .61386 L .49833 .63788 L p 0 .681 0 r
F P
0 g
s
.49833 .63788 m .45027 .61386 L .46194 .60769 L p 0 .916 0 r
F P
0 g
s
.46194 .60769 m .51 .63204 L .49833 .63788 L p 0 .916 0 r
F P
0 g
s
.45027 .61386 m .45157 .55689 L .46293 .55051 L p 0 .1 0 r
F P
0 g
s
.45157 .55689 m .40226 .53069 L .4136 .52397 L p 0 .916 0 r
F P
0 g
s
.4136 .52397 m .46293 .55051 L .45157 .55689 L p 0 .916 0 r
F P
0 g
s
.40226 .53069 m .45157 .55689 L .46293 .55051 L p 0 .916 0 r
F P
0 g
s
.45157 .55689 m .45027 .61386 L .46194 .60769 L p 0 .1 0 r
F P
0 g
s
.46194 .60769 m .46293 .55051 L .45157 .55689 L p 0 .1 0 r
F P
0 g
s
.45027 .61386 m .45157 .55689 L .40226 .53069 L p 0 .681 0 r
F P
0 g
s
.36526 .60765 m .35424 .61381 L .35804 .55689 L p 0 .1 .365 r
F P
0 g
s
.35804 .55689 m .3688 .55051 L .36526 .60765 L p 0 .1 .365 r
F P
0 g
s
.41587 .63204 m .40481 .63788 L .35428 .61387 L p 0 .916 1 r
F P
0 g
s
.3434 .61996 m .35428 .61387 L .40481 .63788 L p 0 .916 1 r
F P
0 g
s
.4159 .46901 m .41587 .46903 L .4048 .47593 L p 0 .93 0 r
F P
0 g
s
.40226 .53069 m .4048 .47593 L .41587 .46903 L p 0 .1 0 r
F P
0 g
s
.73726 .27426 m .74632 .26863 L .73989 .22065 L p 0 .1 .423 r
F P
0 g
s
.74632 .26863 m .73989 .22065 L .69828 .18542 L p 0 .618 .247 r
F P
0 g
s
.7005 .30124 m .70588 .35141 L .69267 .35923 L p 0 .1 0 r
F P
0 g
s
.7005 .30124 m .70588 .35141 L .74731 .38231 L p 0 .634 0 r
F P
0 g
s
.7005 .30124 m .70588 .35141 L .74731 .38231 L p 0 .634 0 r
F P
0 g
s
.74731 .38231 m .70588 .35141 L .71927 .34348 L p 0 .911 0 r
F P
0 g
s
.71927 .34348 m .76061 .37479 L .74731 .38231 L p 0 .911 0 r
F P
0 g
s
.70588 .35141 m .7005 .30124 L .7135 .2932 L p 0 .1 0 r
F P
0 g
s
.84323 .21875 m .80433 .18342 L .79277 .19088 L p 0 .903 1 r
F P
0 g
s
.84323 .21875 m .85245 .26675 L .84061 .27375 L p 0 .1 .45 r
F P
0 g
s
.85245 .26675 m .84323 .21875 L .80433 .18342 L p 0 .594 .194 r
F P
0 g
s
.80433 .18342 m .84323 .21875 L .85483 .2116 L p 0 .903 1 r
F P
0 g
s
.84323 .21875 m .85245 .26675 L .89008 .2999 L p 0 .594 .194 r
F P
0 g
s
.84323 .21875 m .85245 .26675 L .89008 .2999 L p 0 .594 .194 r
F P
0 g
s
.84323 .21875 m .85245 .26675 L .86441 .25968 L p 0 .1 .45 r
F P
0 g
s
.86441 .25968 m .85483 .2116 L .84323 .21875 L p 0 .1 .45 r
F P
0 g
s
.85245 .26675 m .84323 .21875 L .80433 .18342 L p 0 .594 .194 r
F P
0 g
s
.85245 .26675 m .84323 .21875 L .85483 .2116 L p 0 .1 .45 r
F P
0 g
s
.89008 .2999 m .85245 .26675 L .84061 .27375 L p 0 .907 1 r
F P
0 g
s
.90053 .35006 m .90055 .35005 L .88845 .35659 L p 0 .1 .1 r
F P
0 g
s
.89008 .2999 m .85245 .26675 L p .90053 .35006 L 0 .594 .194 r
F P
0 g
s
.90053 .35006 m .90055 .35005 L .89008 .2999 L p 0 .594 .194 r
F P
0 g
s
.85245 .26675 m .89008 .2999 L .90194 .2932 L p 0 .907 1 r
F P
0 g
s
.89008 .2999 m .90055 .35005 L .91278 .34344 L p 0 .114 .472 r
F P
0 g
s
.91278 .34344 m .90194 .2932 L .89008 .2999 L p 0 .114 .472 r
F P
0 g
s
.89008 .2999 m .85245 .26675 L p .90053 .35006 L 0 .594 .194 r
F P
0 g
s
.90053 .35006 m .90055 .35005 L .89008 .2999 L p 0 .594 .194 r
F P
0 g
s
.89008 .2999 m .85245 .26675 L .86441 .25968 L p 0 .907 1 r
F P
0 g
s
.86441 .25968 m .90194 .2932 L .89008 .2999 L p 0 .907 1 r
F P
0 g
s
.46307 .38012 m .47455 .37257 L .47458 .37263 L p 0 .546 .889 r
F P
0 g
s
.47458 .37263 m .46311 .38018 L .46307 .38012 L p 0 .546 .889 r
F P
0 g
s
.55689 .21775 m .55686 .21775 L p .60375 .29894 L 0 .648 .324 r
F P
0 g
s
.55689 .21775 m .56897 .20914 L .56894 .20915 L p 0 1 .86 r
F P
0 g
s
.56894 .20915 m .55686 .21775 L .55689 .21775 L p 0 1 .86 r
F P
0 g
s
.55689 .21775 m .55686 .21775 L p .60375 .29894 L 0 .648 .324 r
F P
0 g
s
.64179 .27414 m .65468 .26574 L .69753 .29894 L p 0 .907 0 r
F P
0 g
s
.65064 .21772 m .65468 .26574 L .69753 .29894 L p 0 .634 0 r
F P
0 g
s
.65064 .21772 m .65468 .26574 L .69753 .29894 L p 0 .634 0 r
F P
0 g
s
.71053 .29086 m .69753 .29894 L .65468 .26574 L p 0 .907 0 r
F P
0 g
s
.68962 .35699 m .70284 .34914 L .69753 .29894 L p 0 .1 0 r
F P
0 g
s
.70284 .34914 m .69753 .29894 L .65468 .26574 L p 0 .634 0 r
F P
0 g
s
.71053 .29086 m .69753 .29894 L .70284 .34914 L p 0 .1 0 r
F P
0 g
s
.69753 .29894 m .71053 .29086 L .66776 .25722 L p 0 .907 0 r
F P
0 g
s
.66776 .25722 m .65468 .26574 L .69753 .29894 L p 0 .907 0 r
F P
0 g
s
.70284 .34914 m .69753 .29894 L .65468 .26574 L p 0 .634 0 r
F P
0 g
s
.65064 .21772 m .66334 .20911 L .66776 .25722 L p 0 .1 0 r
F P
0 g
s
.66776 .25722 m .65468 .26574 L .65064 .21772 L p 0 .1 0 r
F P
0 g
s
.64179 .27414 m .65468 .26574 L .65064 .21772 L p 0 .1 0 r
F P
0 g
s
.65468 .26574 m .65064 .21772 L .60657 .18236 L p 0 .634 0 r
F P
0 g
s
.66334 .20911 m .65064 .21772 L .65468 .26574 L p 0 .1 0 r
F P
0 g
s
.65064 .21772 m .66334 .20911 L .61931 .17328 L p 0 .903 0 r
F P
0 g
s
.61931 .17328 m .60657 .18236 L .65064 .21772 L p 0 .903 0 r
F P
0 g
s
.65468 .26574 m .65064 .21772 L .60657 .18236 L p 0 .634 0 r
F P
0 g
s
.50996 .29894 m .51023 .3491 L p .55686 .38016 L 0 .661 0 r
F P
0 g
s
.50996 .29894 m .51023 .3491 L p .55686 .38016 L 0 .661 0 r
F P
0 g
s
.49833 .35701 m .51027 .34916 L .55686 .38016 L p 0 .911 0 r
F P
0 g
s
.51023 .3491 m .51027 .34916 L .55686 .38016 L p 0 .661 0 r
F P
0 g
s
.51023 .3491 m .51027 .34916 L .55686 .38016 L p 0 .661 0 r
F P
0 g
s
.56894 .37261 m .55686 .38016 L .51027 .34916 L p 0 .911 0 r
F P
0 g
s
.50996 .29894 m .52174 .29086 L .52233 .34114 L p 0 .1 0 r
F P
0 g
s
.52233 .34114 m .51023 .3491 L .50996 .29894 L p 0 .1 0 r
F P
0 g
s
.59396 .35699 m .60653 .34914 L .65064 .38016 L p 0 .911 1 r
F P
0 g
s
.60375 .29894 m .60653 .34914 L .65064 .38016 L p 0 .648 .324 r
F P
0 g
s
.60375 .29894 m .60653 .34914 L .65064 .38016 L p 0 .648 .324 r
F P
0 g
s
.66334 .37261 m .65064 .38016 L .60653 .34914 L p 0 .911 1 r
F P
0 g
s
.59396 .35699 m .60653 .34914 L .60375 .29894 L p 0 .1 .396 r
F P
0 g
s
.54612 .27414 m .55838 .26574 L .60375 .29894 L p 0 .907 1 r
F P
0 g
s
.60653 .34914 m .60375 .29894 L .55838 .26574 L p 0 .648 .324 r
F P
0 g
s
.61614 .29086 m .60375 .29894 L .60653 .34914 L p 0 .1 .396 r
F P
0 g
s
.55686 .21775 m .55838 .26574 L .60375 .29894 L p 0 .648 .324 r
F P
0 g
s
.55686 .21775 m .55838 .26574 L .60375 .29894 L p 0 .648 .324 r
F P
0 g
s
.60375 .29894 m .61614 .29086 L .57081 .25722 L p 0 .907 1 r
F P
0 g
s
.57081 .25722 m .55838 .26574 L .60375 .29894 L p 0 .907 1 r
F P
0 g
s
.60653 .34914 m .60375 .29894 L .55838 .26574 L p 0 .648 .324 r
F P
0 g
s
.60375 .29894 m .61614 .29086 L .61928 .34118 L p 0 .1 .396 r
F P
0 g
s
.61928 .34118 m .60653 .34914 L .60375 .29894 L p 0 .1 .396 r
F P
0 g
s
.61614 .29086 m .60375 .29894 L .55838 .26574 L p 0 .907 1 r
F P
0 g
s
.55686 .21775 m .56894 .20915 L .57081 .25722 L p 0 .1 .365 r
F P
0 g
s
.57081 .25722 m .55838 .26574 L .55686 .21775 L p 0 .1 .365 r
F P
0 g
s
.7143 .62778 m .70125 .63369 L .70122 .63371 L p 0 .1 0 r
F P
0 g
s
.70122 .63371 m .70125 .63369 L p .65427 .55236 L 0 .661 0 r
F P
0 g
s
.70122 .63371 m .70125 .63369 L p .65427 .55236 L 0 .661 0 r
F P
0 g
s
.54963 .61561 m .56194 .60947 L .6073 .63373 L p 0 .916 1 r
F P
0 g
s
.56032 .55236 m .56194 .60947 L .6073 .63373 L p 0 .671 .39 r
F P
0 g
s
.56032 .55236 m .56194 .60947 L .6073 .63373 L p 0 .671 .39 r
F P
0 g
s
.61974 .62783 m .6073 .63373 L .56194 .60947 L p 0 .916 1 r
F P
0 g
s
.56032 .55236 m .57245 .54592 L .57441 .60325 L p 0 .1 .425 r
F P
0 g
s
.57441 .60325 m .56194 .60947 L .56032 .55236 L p 0 .1 .425 r
F P
0 g
s
.6934 .53261 m .70667 .52591 L .70125 .47099 L p 0 .1 .45 r
F P
0 g
s
.70667 .52591 m .70125 .47099 L .65843 .44235 L p 0 .648 .324 r
F P
0 g
s
.70125 .47099 m .71431 .46402 L .67155 .43501 L p 0 .914 1 r
F P
0 g
s
.67155 .43501 m .65843 .44235 L .70125 .47099 L p 0 .914 1 r
F P
0 g
s
.71431 .46402 m .70125 .47099 L .70667 .52591 L p 0 .1 .45 r
F P
0 g
s
.70667 .52591 m .70125 .47099 L .65843 .44235 L p 0 .648 .324 r
F P
0 g
s
.6934 .53261 m .70667 .52591 L .74823 .55236 L p 0 .916 1 r
F P
0 g
s
.70125 .47099 m .71431 .46402 L .72012 .51913 L p 0 .1 .45 r
F P
0 g
s
.72012 .51913 m .70667 .52591 L .70125 .47099 L p 0 .1 .45 r
F P
0 g
s
.7616 .54592 m .74823 .55236 L .70667 .52591 L p 0 .916 1 r
F P
0 g
s
.74132 .61557 m .75491 .60943 L .74823 .55236 L p 0 .114 .472 r
F P
0 g
s
.75491 .60943 m .74823 .55236 L .70667 .52591 L p 0 .648 .324 r
F P
0 g
s
.74823 .55236 m .7616 .54592 L .72012 .51913 L p 0 .916 1 r
F P
0 g
s
.72012 .51913 m .70667 .52591 L .74823 .55236 L p 0 .916 1 r
F P
0 g
s
.7616 .54592 m .74823 .55236 L .75491 .60943 L p 0 .114 .472 r
F P
0 g
s
.75491 .60943 m .74823 .55236 L .70667 .52591 L p 0 .648 .324 r
F P
0 g
s
.59756 .53261 m .61018 .52591 L .65427 .55236 L p 0 .916 0 r
F P
0 g
s
.6073 .47099 m .61018 .52591 L .65427 .55236 L p 0 .661 0 r
F P
0 g
s
.6073 .47099 m .61018 .52591 L .65427 .55236 L p 0 .661 0 r
F P
0 g
s
.64548 .61561 m .65843 .60947 L .65427 .55236 L p 0 .1 0 r
F P
0 g
s
.65843 .60947 m .65427 .55236 L .61018 .52591 L p 0 .661 0 r
F P
0 g
s
.65843 .60947 m .65427 .55236 L .61018 .52591 L p 0 .661 0 r
F P
0 g
s
.65427 .55236 m .65843 .60947 L .70122 .63371 L p 0 .661 0 r
F P
0 g
s
.65427 .55236 m .65843 .60947 L .70122 .63371 L p 0 .661 0 r
F P
0 g
s
.66702 .54592 m .65427 .55236 L .61018 .52591 L p 0 .916 0 r
F P
0 g
s
.65427 .55236 m .66702 .54592 L .67155 .60325 L p 0 .1 0 r
F P
0 g
s
.67155 .60325 m .65843 .60947 L .65427 .55236 L p 0 .1 0 r
F P
0 g
s
.65427 .55236 m .66702 .54592 L .62298 .51913 L p 0 .916 0 r
F P
0 g
s
.62298 .51913 m .61018 .52591 L .65427 .55236 L p 0 .916 0 r
F P
0 g
s
.66702 .54592 m .65427 .55236 L .65843 .60947 L p 0 .1 0 r
F P
0 g
s
.6073 .47099 m .61974 .46402 L .62298 .51913 L p 0 .1 0 r
F P
0 g
s
.62298 .51913 m .61018 .52591 L .6073 .47099 L p 0 .1 0 r
F P
0 g
s
.79522 .47103 m .79518 .47097 L .75492 .44235 L p 0 .634 0 r
F P
0 g
s
.80316 .52591 m .79522 .47103 L p .75492 .44235 L 0 .634 0 r
F P
0 g
s
.79518 .47097 m .80885 .464 L .76869 .43501 L p 0 .914 0 r
F P
0 g
s
.79522 .47103 m .80889 .46406 L .80885 .464 L p 0 .562 0 r
F P
0 g
s
.80885 .464 m .79518 .47097 L .79522 .47103 L p 0 .562 0 r
F P
0 g
s
.76869 .43501 m .75492 .44235 L .79518 .47097 L p 0 .914 0 r
F P
0 g
s
.80889 .46406 m .79522 .47103 L .80316 .52591 L p 0 .114 0 r
F P
0 g
s
.79522 .47103 m .79518 .47097 L .75492 .44235 L p 0 .634 0 r
F P
0 g
s
.80316 .52591 m .79522 .47103 L p .75492 .44235 L 0 .634 0 r
F P
0 g
s
.80316 .52591 m .81725 .51913 L .80889 .46406 L p 0 .114 0 r
F P
0 g
s
.75492 .44235 m .76197 .49801 L .80316 .52591 L p 0 .634 0 r
F P
0 g
s
.75492 .44235 m .76197 .49801 L .80316 .52591 L p 0 .634 0 r
F P
0 g
s
.76869 .43501 m .77617 .49084 L .81725 .51913 L p 0 .63 .275 r
F P
0 g
s
.81725 .51913 m .80889 .46406 L p .76869 .43501 L 0 .63 .275 r
F P
0 g
s
.81817 .45933 m .80889 .46406 L .81725 .51913 L p 0 .114 .472 r
F P
0 g
s
.81725 .51913 m .80889 .46406 L p .76869 .43501 L 0 .63 0 r
F P
0 g
s
.80889 .46406 m .80885 .464 L .76869 .43501 L p 0 .63 .275 r
F P
0 g
s
.77804 .43002 m .76869 .43501 L .80885 .464 L p 0 .914 1 r
F P
0 g
s
.80889 .46406 m .80885 .464 L .76869 .43501 L p 0 .63 0 r
F P
0 g
s
.76869 .43501 m .77617 .49084 L .81725 .51913 L p 0 .63 0 r
F P
0 g
s
.81725 .51913 m .82682 .51452 L .81817 .45933 L p 0 .114 .472 r
F P
0 g
s
.81725 .51913 m .82682 .51452 L .78582 .48597 L p 0 .916 1 r
F P
0 g
s
.78582 .48597 m .77617 .49084 L .76869 .43501 L p 0 .1 .45 r
F P
0 g
s
.76869 .43501 m .77804 .43002 L .78582 .48597 L p 0 .1 .45 r
F P
0 g
s
.77804 .43002 m .76869 .43501 L .77617 .49084 L p 0 .1 .45 r
F P
0 g
s
.82682 .51452 m .81725 .51913 L .77617 .49084 L p 0 .916 1 r
F P
0 g
s
.70122 .63371 m .71428 .62781 L .7143 .62778 L p 0 .1 0 r
F P
0 g
s
.71428 .62781 m .70122 .63371 L .65843 .60947 L p 0 .916 0 r
F P
0 g
s
.64548 .61561 m .65843 .60947 L .70122 .63371 L p 0 .916 0 r
F P
0 g
s
.33236 .62613 m .32177 .63205 L .32174 .632 L p 0 .525 0 r
F P
0 g
s
.32174 .632 m .33233 .62607 L .33236 .62613 L p 0 .525 0 r
F P
0 g
s
.4136 .52397 m .46293 .55051 L p .4159 .46901 L 0 .679 0 r
F P
0 g
s
.4159 .46901 m .41587 .46903 L .4136 .52397 L p 0 .679 0 r
F P
0 g
s
.41587 .46903 m .4159 .46901 L .42711 .46202 L p 0 .93 0 r
F P
0 g
s
.4136 .52397 m .46293 .55051 L p .4159 .46901 L 0 .679 0 r
F P
0 g
s
.4159 .46901 m .41587 .46903 L .4136 .52397 L p 0 .679 0 r
F P
0 g
s
.51 .46899 m .51027 .52397 L .49829 .53069 L p 0 .1 .396 r
F P
0 g
s
.51 .46899 m .51027 .52397 L .55707 .55051 L p 0 .671 .39 r
F P
0 g
s
.51 .46899 m .51027 .52397 L .55707 .55051 L p 0 .671 .39 r
F P
0 g
s
.55707 .55051 m .51027 .52397 L .52242 .51716 L p 0 .916 1 r
F P
0 g
s
.52242 .51716 m .5692 .54406 L .55707 .55051 L p 0 .916 1 r
F P
0 g
s
.51027 .52397 m .51 .46899 L .52183 .462 L p 0 .1 .396 r
F P
0 g
s
.55707 .55051 m .51027 .52397 L .49829 .53069 L p 0 .916 1 r
F P
0 g
s
.55861 .60769 m .55707 .55051 L .51027 .52397 L p 0 .671 .39 r
F P
0 g
s
.51027 .52397 m .55707 .55051 L .5692 .54406 L p 0 .916 1 r
F P
0 g
s
.55707 .55051 m .55861 .60769 L .57108 .60144 L p 0 .1 .423 r
F P
0 g
s
.57108 .60144 m .5692 .54406 L .55707 .55051 L p 0 .1 .423 r
F P
0 g
s
.55861 .60769 m .55707 .55051 L .51027 .52397 L p 0 .671 .39 r
F P
0 g
s
.51 .46899 m .46197 .44027 L .45031 .44755 L p 0 .914 1 r
F P
0 g
s
.51027 .52397 m .51 .46899 L .46197 .44027 L p 0 .671 .39 r
F P
0 g
s
.46197 .44027 m .51 .46899 L .52183 .462 L p 0 .914 1 r
F P
0 g
s
.51 .46899 m .51027 .52397 L .52242 .51716 L p 0 .1 .396 r
F P
0 g
s
.52242 .51716 m .52183 .462 L .51 .46899 L p 0 .1 .396 r
F P
0 g
s
.51027 .52397 m .51 .46899 L .46197 .44027 L p 0 .671 .39 r
F P
0 g
s
.60414 .46899 m .55861 .44025 L .5463 .44753 L p 0 .914 0 r
F P
0 g
s
.60694 .52397 m .60414 .46899 L .55861 .44025 L p 0 .661 0 r
F P
0 g
s
.55861 .44025 m .60414 .46899 L .61658 .462 L p 0 .914 0 r
F P
0 g
s
.60414 .46899 m .60694 .52397 L .61974 .51716 L p 0 .1 0 r
F P
0 g
s
.61974 .51716 m .61658 .462 L .60414 .46899 L p 0 .1 0 r
F P
0 g
s
.60694 .52397 m .60414 .46899 L .55861 .44025 L p 0 .661 0 r
F P
0 g
s
.46293 .55051 m .4136 .52397 L .42509 .51716 L p 0 .916 0 r
F P
0 g
s
.42509 .51716 m .47445 .54406 L .46293 .55051 L p 0 .916 0 r
F P
0 g
s
.46293 .55051 m .46194 .60769 L .45027 .61386 L p 0 .1 0 r
F P
0 g
s
.46293 .55051 m .46194 .60769 L .51 .63204 L p 0 .679 0 r
F P
0 g
s
.46293 .55051 m .46194 .60769 L .51 .63204 L p 0 .679 0 r
F P
0 g
s
.51 .63204 m .46194 .60769 L .47376 .60144 L p 0 .916 0 r
F P
0 g
s
.47376 .60144 m .52183 .62611 L .51 .63204 L p 0 .916 0 r
F P
0 g
s
.46194 .60769 m .46293 .55051 L .47445 .54406 L p 0 .1 0 r
F P
0 g
s
.46293 .55051 m .4136 .52397 L .40226 .53069 L p 0 .916 0 r
F P
0 g
s
.46194 .60769 m .46293 .55051 L .4136 .52397 L p 0 .679 0 r
F P
0 g
s
.4136 .52397 m .46293 .55051 L .47445 .54406 L p 0 .916 0 r
F P
0 g
s
.46293 .55051 m .46194 .60769 L .47376 .60144 L p 0 .1 0 r
F P
0 g
s
.47376 .60144 m .47445 .54406 L .46293 .55051 L p 0 .1 0 r
F P
0 g
s
.46194 .60769 m .46293 .55051 L .4136 .52397 L p 0 .679 0 r
F P
0 g
s
.37644 .6014 m .36526 .60765 L .3688 .55051 L p 0 .1 .365 r
F P
0 g
s
.3688 .55051 m .3797 .54406 L .37644 .6014 L p 0 .1 .365 r
F P
0 g
s
.42708 .62611 m .41587 .63204 L .3653 .60771 L p 0 .916 1 r
F P
0 g
s
.35428 .61387 m .3653 .60771 L .41587 .63204 L p 0 .916 1 r
F P
0 g
s
.41587 .46903 m .4136 .52397 L .40226 .53069 L p 0 .1 0 r
F P
0 g
s
.42711 .46202 m .42707 .46204 L .41587 .46903 L p 0 .93 0 r
F P
0 g
s
.4136 .52397 m .41587 .46903 L .42707 .46204 L p 0 .1 0 r
F P
0 g
s
.85415 .37512 m .85413 .37513 L .86808 .3676 L p 0 .1 0 r
F P
0 g
s
.75997 .21201 m .76699 .26009 L .80706 .29358 L p 0 .612 0 r
F P
0 g
s
.76699 .26009 m .80706 .29358 L .82071 .28552 L p 0 .907 0 r
F P
0 g
s
.80706 .29358 m .81535 .34386 L .85413 .37513 L p 0 .612 0 r
F P
0 g
s
.80706 .29358 m .81535 .34386 L .82942 .33591 L p 0 .1 0 r
F P
0 g
s
.82942 .33591 m .82071 .28552 L .80706 .29358 L p 0 .1 0 r
F P
0 g
s
.81535 .34386 m .80706 .29358 L .76699 .26009 L p 0 .612 0 r
F P
0 g
s
.80706 .29358 m .76699 .26009 L .78073 .25158 L p 0 .907 0 r
F P
0 g
s
.78073 .25158 m .82071 .28552 L .80706 .29358 L p 0 .907 0 r
F P
0 g
s
.76699 .26009 m .75997 .21201 L .77331 .20342 L p 0 .1 0 r
F P
0 g
s
.81535 .34386 m .80706 .29358 L .82071 .28552 L p 0 .1 0 r
F P
0 g
s
.85413 .37513 m .81535 .34386 L .82942 .33591 L p 0 .911 0 r
F P
0 g
s
.82942 .33591 m .86808 .3676 L .85413 .37513 L p 0 .911 0 r
F P
0 g
s
.7135 .2932 m .71927 .34348 L .70588 .35141 L p 0 .1 0 r
F P
0 g
s
.7135 .2932 m .71927 .34348 L .76061 .37479 L p 0 .63 .275 r
F P
0 g
s
.7135 .2932 m .71927 .34348 L .76061 .37479 L p 0 .63 0 r
F P
0 g
s
.71927 .34348 m .7135 .2932 L .72233 .28773 L p 0 .1 .425 r
F P
0 g
s
.85483 .2116 m .81603 .17588 L .80433 .18342 L p 0 .903 1 r
F P
0 g
s
.85483 .2116 m .86441 .25968 L .85245 .26675 L p 0 .1 .45 r
F P
0 g
s
.86441 .25968 m .85483 .2116 L .81603 .17588 L p 0 .59 .184 r
F P
0 g
s
.85483 .2116 m .86441 .25968 L .90194 .2932 L p 0 .59 .184 r
F P
0 g
s
.90194 .2932 m .86441 .25968 L .85245 .26675 L p 0 .907 1 r
F P
0 g
s
.91276 .34345 m .91278 .34344 L .90055 .35005 L p 0 .1 .1 r
F P
0 g
s
.90194 .2932 m .86441 .25968 L p .91276 .34345 L 0 .59 .184 r
F P
0 g
s
.91276 .34345 m .91278 .34344 L .90194 .2932 L p 0 .59 .184 r
F P
0 g
s
.76061 .37479 m .71927 .34348 L .72836 .33809 L p 0 .911 1 r
F P
0 g
s
.72836 .33809 m .76965 .36969 L .76061 .37479 L p 0 .911 1 r
F P
0 g
s
.77043 .2009 m .75709 .20953 L .76404 .25763 L p 0 .1 0 r
F P
0 g
s
.75709 .20953 m .77043 .2009 L .72901 .16459 L p 0 .903 0 r
F P
0 g
s
.72901 .16459 m .71558 .17369 L .75709 .20953 L p 0 .903 0 r
F P
0 g
s
.76404 .25763 m .75709 .20953 L .71558 .17369 L p 0 .612 0 r
F P
0 g
s
.56897 .20914 m .56894 .20915 L p .61614 .29086 L 0 .645 .315 r
F P
0 g
s
.70284 .34914 m .71623 .34118 L .71053 .29086 L p 0 .1 0 r
F P
0 g
s
.65468 .26574 m .66776 .25722 L .71053 .29086 L p 0 .907 0 r
F P
0 g
s
.71623 .34118 m .71053 .29086 L .66776 .25722 L p 0 .63 .275 r
F P
0 g
s
.71623 .34118 m .71053 .29086 L .66776 .25722 L p 0 .63 0 r
F P
0 g
s
.66334 .20911 m .66776 .25722 L .71053 .29086 L p 0 .63 .275 r
F P
0 g
s
.66334 .20911 m .66776 .25722 L .71053 .29086 L p 0 .63 0 r
F P
0 g
s
.65468 .26574 m .66776 .25722 L .66334 .20911 L p 0 .1 0 r
F P
0 g
s
.66776 .25722 m .66334 .20911 L .61931 .17328 L p 0 .63 .275 r
F P
0 g
s
.66776 .25722 m .66334 .20911 L .61931 .17328 L p 0 .63 0 r
F P
0 g
s
.71936 .28538 m .71053 .29086 L .71623 .34118 L p 0 .1 .423 r
F P
0 g
s
.71053 .29086 m .71936 .28538 L .67663 .25143 L p 0 .907 1 r
F P
0 g
s
.67663 .25143 m .66776 .25722 L .71053 .29086 L p 0 .907 1 r
F P
0 g
s
.71936 .28538 m .71053 .29086 L .66776 .25722 L p 0 .907 1 r
F P
0 g
s
.66334 .20911 m .67196 .20327 L .67663 .25143 L p 0 .1 .396 r
F P
0 g
s
.67663 .25143 m .66776 .25722 L .66334 .20911 L p 0 .1 .396 r
F P
0 g
s
.67196 .20327 m .66334 .20911 L .66776 .25722 L p 0 .1 .396 r
F P
0 g
s
.66334 .20911 m .67196 .20327 L .62797 .16712 L p 0 .903 1 r
F P
0 g
s
.62797 .16712 m .61931 .17328 L .66334 .20911 L p 0 .903 1 r
F P
0 g
s
.52174 .29086 m .52233 .34114 L p .56894 .37261 L 0 .658 0 r
F P
0 g
s
.51027 .34916 m .52237 .3412 L .56894 .37261 L p 0 .911 0 r
F P
0 g
s
.52233 .34114 m .52237 .3412 L .56894 .37261 L p 0 .658 0 r
F P
0 g
s
.60653 .34914 m .61928 .34118 L .66334 .37261 L p 0 .911 1 r
F P
0 g
s
.61614 .29086 m .61928 .34118 L .66334 .37261 L p 0 .645 .315 r
F P
0 g
s
.60653 .34914 m .61928 .34118 L .61614 .29086 L p 0 .1 .396 r
F P
0 g
s
.55838 .26574 m .57081 .25722 L .61614 .29086 L p 0 .907 1 r
F P
0 g
s
.61928 .34118 m .61614 .29086 L .57081 .25722 L p 0 .645 .315 r
F P
0 g
s
.56894 .20915 m .57081 .25722 L .61614 .29086 L p 0 .645 .315 r
F P
0 g
s
.47488 .37235 m .48651 .3647 L .48654 .36476 L p 0 .546 0 r
F P
0 g
s
.48654 .36476 m .47491 .37241 L .47488 .37235 L p 0 .546 0 r
F P
0 g
s
.56932 .20889 m .58158 .20016 L .58154 .20017 L p 0 1 0 r
F P
0 g
s
.58154 .20017 m .56929 .2089 L .56932 .20889 L p 0 1 0 r
F P
0 g
s
.56932 .20889 m .56929 .2089 L p .6165 .29063 L 0 .645 0 r
F P
0 g
s
.6165 .29063 m .61965 .34095 L .6637 .37239 L p 0 .645 0 r
F P
0 g
s
.67658 .36474 m .6637 .37239 L .61965 .34095 L p 0 .911 0 r
F P
0 g
s
.6165 .29063 m .62906 .28244 L .63258 .33288 L p 0 .1 0 r
F P
0 g
s
.63258 .33288 m .61965 .34095 L .6165 .29063 L p 0 .1 0 r
F P
0 g
s
.62906 .28244 m .6165 .29063 L .61965 .34095 L p 0 .1 0 r
F P
0 g
s
.56929 .2089 m .57117 .25697 L .6165 .29063 L p 0 .645 0 r
F P
0 g
s
.6165 .29063 m .62906 .28244 L .58376 .24833 L p 0 .907 0 r
F P
0 g
s
.58376 .24833 m .57117 .25697 L .6165 .29063 L p 0 .907 0 r
F P
0 g
s
.61965 .34095 m .6165 .29063 L .57117 .25697 L p 0 .645 0 r
F P
0 g
s
.62906 .28244 m .6165 .29063 L .57117 .25697 L p 0 .907 0 r
F P
0 g
s
.52209 .29063 m .52268 .34091 L p .56929 .37239 L 0 .658 .35 r
F P
0 g
s
.52209 .29063 m .53403 .28244 L .53495 .33284 L p 0 .1 .365 r
F P
0 g
s
.53495 .33284 m .52268 .34091 L .52209 .29063 L p 0 .1 .365 r
F P
0 g
s
.52268 .34091 m .52272 .34097 L .56929 .37239 L p 0 .658 .35 r
F P
0 g
s
.58154 .36474 m .56929 .37239 L .52272 .34097 L p 0 .911 1 r
F P
0 g
s
.56929 .2089 m .58154 .20017 L .58376 .24833 L p 0 .1 0 r
F P
0 g
s
.58376 .24833 m .57117 .25697 L .56929 .2089 L p 0 .1 0 r
F P
0 g
s
.71428 .62781 m .7143 .62778 L p .66702 .54592 L 0 .658 0 r
F P
0 g
s
.56194 .60947 m .57441 .60325 L .61974 .62783 L p 0 .916 1 r
F P
0 g
s
.57245 .54592 m .57441 .60325 L .61974 .62783 L p 0 .668 .382 r
F P
0 g
s
.70667 .52591 m .72012 .51913 L .71431 .46402 L p 0 .1 .45 r
F P
0 g
s
.72012 .51913 m .71431 .46402 L .67155 .43501 L p 0 .645 .315 r
F P
0 g
s
.70667 .52591 m .72012 .51913 L .7616 .54592 L p 0 .916 1 r
F P
0 g
s
.75491 .60943 m .76868 .60321 L .7616 .54592 L p 0 .114 .472 r
F P
0 g
s
.76868 .60321 m .7616 .54592 L .72012 .51913 L p 0 .645 .315 r
F P
0 g
s
.61018 .52591 m .62298 .51913 L .66702 .54592 L p 0 .916 0 r
F P
0 g
s
.61974 .46402 m .62298 .51913 L .66702 .54592 L p 0 .658 0 r
F P
0 g
s
.66702 .54592 m .67155 .60325 L .71428 .62781 L p 0 .658 0 r
F P
0 g
s
.65843 .60947 m .67155 .60325 L .66702 .54592 L p 0 .1 0 r
F P
0 g
s
.67155 .60325 m .66702 .54592 L .62298 .51913 L p 0 .658 0 r
F P
0 g
s
.80885 .464 m .81813 .45927 L .77804 .43002 L p 0 .914 1 r
F P
0 g
s
.80889 .46406 m .81817 .45933 L .81813 .45927 L p 0 .562 .887 r
F P
0 g
s
.81813 .45927 m .80885 .464 L .80889 .46406 L p 0 .562 .887 r
F P
0 g
s
.65843 .60947 m .67155 .60325 L .71428 .62781 L p 0 .916 0 r
F P
0 g
s
.71466 .62764 m .71468 .62761 L p .66739 .54574 L 0 .658 .35 r
F P
0 g
s
.72792 .62163 m .71468 .62761 L .71466 .62764 L p 0 .1 .1 r
F P
0 g
s
.6201 .46382 m .62335 .51893 L .66739 .54574 L p 0 .658 .35 r
F P
0 g
s
.68031 .53922 m .66739 .54574 L .62335 .51893 L p 0 .916 1 r
F P
0 g
s
.66739 .54574 m .67193 .60307 L .71466 .62764 L p 0 .658 .35 r
F P
0 g
s
.67193 .60307 m .66739 .54574 L .62335 .51893 L p 0 .658 .35 r
F P
0 g
s
.6201 .46382 m .63271 .45676 L .63633 .51205 L p 0 .1 .425 r
F P
0 g
s
.63633 .51205 m .62335 .51893 L .6201 .46382 L p 0 .1 .425 r
F P
0 g
s
.66739 .54574 m .68031 .53922 L .63633 .51205 L p 0 .916 1 r
F P
0 g
s
.63633 .51205 m .62335 .51893 L .66739 .54574 L p 0 .916 1 r
F P
0 g
s
.68031 .53922 m .66739 .54574 L .67193 .60307 L p 0 .1 .45 r
F P
0 g
s
.66739 .54574 m .68031 .53922 L .68523 .59676 L p 0 .1 .45 r
F P
0 g
s
.68523 .59676 m .67193 .60307 L .66739 .54574 L p 0 .1 .45 r
F P
0 g
s
.5728 .54574 m .57477 .60307 L .6201 .62766 L p 0 .668 0 r
F P
0 g
s
.63271 .62167 m .6201 .62766 L .57477 .60307 L p 0 .916 0 r
F P
0 g
s
.5728 .54574 m .5851 .53922 L .58742 .59676 L p 0 .1 0 r
F P
0 g
s
.58742 .59676 m .57477 .60307 L .5728 .54574 L p 0 .1 0 r
F P
0 g
s
.71469 .46382 m .72792 .45676 L .68523 .42734 L p 0 .914 0 r
F P
0 g
s
.68523 .42734 m .67193 .43479 L .71469 .46382 L p 0 .914 0 r
F P
0 g
s
.72792 .45676 m .71469 .46382 L .72051 .51893 L p 0 .1 0 r
F P
0 g
s
.72051 .51893 m .71469 .46382 L .67193 .43479 L p 0 .645 0 r
F P
0 g
s
.71469 .46382 m .72792 .45676 L .73414 .51205 L p 0 .1 0 r
F P
0 g
s
.73414 .51205 m .72051 .51893 L .71469 .46382 L p 0 .1 0 r
F P
0 g
s
.77553 .53922 m .76198 .54574 L .72051 .51893 L p 0 .916 0 r
F P
0 g
s
.76198 .54574 m .77553 .53922 L .73414 .51205 L p 0 .916 0 r
F P
0 g
s
.73414 .51205 m .72051 .51893 L .76198 .54574 L p 0 .916 0 r
F P
0 g
s
.77553 .53922 m .76198 .54574 L .76908 .60303 L p 0 .114 0 r
F P
0 g
s
.76908 .60303 m .76198 .54574 L .72051 .51893 L p 0 .645 0 r
F P
0 g
s
.71466 .62764 m .72789 .62166 L .72792 .62163 L p 0 .1 .1 r
F P
0 g
s
.72789 .62166 m .71466 .62764 L .67193 .60307 L p 0 .916 1 r
F P
0 g
s
.72233 .28773 m .72836 .33809 L .71927 .34348 L p 0 .1 .425 r
F P
0 g
s
.72233 .28773 m .72836 .33809 L .76965 .36969 L p 0 .627 .269 r
F P
0 g
s
.72233 .28773 m .72836 .33809 L .76965 .36969 L p 0 .627 .269 r
F P
0 g
s
.72836 .33809 m .72233 .28773 L .73123 .28222 L p 0 .1 .425 r
F P
0 g
s
.76965 .36969 m .72836 .33809 L .73753 .33266 L p 0 .911 1 r
F P
0 g
s
.73753 .33266 m .77876 .36454 L .76965 .36969 L p 0 .911 1 r
F P
0 g
s
.42509 .51716 m .47445 .54406 L p .42711 .46202 L 0 .677 0 r
F P
0 g
s
.42711 .46202 m .42707 .46204 L .42509 .51716 L p 0 .677 0 r
F P
0 g
s
.52183 .462 m .52242 .51716 L .51027 .52397 L p 0 .1 .396 r
F P
0 g
s
.52183 .462 m .52242 .51716 L .5692 .54406 L p 0 .668 .382 r
F P
0 g
s
.52183 .462 m .47379 .43289 L .46197 .44027 L p 0 .914 1 r
F P
0 g
s
.52242 .51716 m .52183 .462 L .47379 .43289 L p 0 .668 .382 r
F P
0 g
s
.5692 .54406 m .52242 .51716 L .51027 .52397 L p 0 .916 1 r
F P
0 g
s
.57108 .60144 m .5692 .54406 L .52242 .51716 L p 0 .668 .382 r
F P
0 g
s
.47445 .54406 m .47376 .60144 L .46194 .60769 L p 0 .1 0 r
F P
0 g
s
.47445 .54406 m .47376 .60144 L .52183 .62611 L p 0 .677 0 r
F P
0 g
s
.47445 .54406 m .42509 .51716 L .4136 .52397 L p 0 .916 0 r
F P
0 g
s
.47376 .60144 m .47445 .54406 L .42509 .51716 L p 0 .677 0 r
F P
0 g
s
.61658 .462 m .57108 .43287 L .55861 .44025 L p 0 .914 0 r
F P
0 g
s
.61974 .51716 m .61658 .462 L .57108 .43287 L p 0 .658 0 r
F P
0 g
s
.3653 .60771 m .37647 .60146 L .42708 .62611 L p 0 .916 1 r
F P
0 g
s
.42707 .46204 m .42509 .51716 L .4136 .52397 L p 0 .1 0 r
F P
0 g
s
.4274 .46184 m .42744 .46182 L .43879 .45473 L p 0 .93 .764 r
F P
0 g
s
.42543 .51696 m .47478 .54387 L p .42744 .46182 L 0 .677 .411 r
F P
0 g
s
.42744 .46182 m .4274 .46184 L .42543 .51696 L p 0 .677 .411 r
F P
0 g
s
.3434 .61996 m .33267 .62596 L .33263 .6259 L p 0 .525 .891 r
F P
0 g
s
.33263 .6259 m .34337 .6199 L .3434 .61996 L p 0 .525 .891 r
F P
0 g
s
.47478 .54387 m .4741 .60126 L .52217 .62594 L p 0 .677 .411 r
F P
0 g
s
.47478 .54387 m .42543 .51696 L .43708 .51005 L p 0 .916 1 r
F P
0 g
s
.43708 .51005 m .48646 .53732 L .47478 .54387 L p 0 .916 1 r
F P
0 g
s
.4741 .60126 m .47478 .54387 L .42543 .51696 L p 0 .677 .411 r
F P
0 g
s
.52217 .62594 m .4741 .60126 L .48609 .59493 L p 0 .916 1 r
F P
0 g
s
.48609 .59493 m .53415 .61994 L .52217 .62594 L p 0 .916 1 r
F P
0 g
s
.4741 .60126 m .47478 .54387 L .48646 .53732 L p 0 .1 .396 r
F P
0 g
s
.42543 .51696 m .47478 .54387 L .48646 .53732 L p 0 .916 1 r
F P
0 g
s
.47478 .54387 m .4741 .60126 L .48609 .59493 L p 0 .1 .396 r
F P
0 g
s
.48609 .59493 m .48646 .53732 L .47478 .54387 L p 0 .1 .396 r
F P
0 g
s
.57144 .43266 m .61694 .4618 L .62955 .45471 L p 0 .914 1 r
F P
0 g
s
.61694 .4618 m .62011 .51696 L .63309 .51005 L p 0 .1 .423 r
F P
0 g
s
.63309 .51005 m .62955 .45471 L .61694 .4618 L p 0 .1 .423 r
F P
0 g
s
.62011 .51696 m .61694 .4618 L .57144 .43266 L p 0 .658 .35 r
F P
0 g
s
.52217 .4618 m .52277 .51696 L .56955 .54387 L p 0 .668 0 r
F P
0 g
s
.56955 .54387 m .52277 .51696 L .53509 .51005 L p 0 .916 0 r
F P
0 g
s
.53509 .51005 m .58185 .53732 L .56955 .54387 L p 0 .916 0 r
F P
0 g
s
.52277 .51696 m .56955 .54387 L .58185 .53732 L p 0 .916 0 r
F P
0 g
s
.56955 .54387 m .57144 .60126 L .58409 .59493 L p 0 .1 0 r
F P
0 g
s
.58409 .59493 m .58185 .53732 L .56955 .54387 L p 0 .1 0 r
F P
0 g
s
.57144 .60126 m .56955 .54387 L .52277 .51696 L p 0 .668 0 r
F P
0 g
s
.52277 .51696 m .52217 .4618 L .53415 .45471 L p 0 .1 0 r
F P
0 g
s
.47413 .43268 m .52217 .4618 L .53415 .45471 L p 0 .914 0 r
F P
0 g
s
.52217 .4618 m .52277 .51696 L .53509 .51005 L p 0 .1 0 r
F P
0 g
s
.53509 .51005 m .53415 .45471 L .52217 .4618 L p 0 .1 0 r
F P
0 g
s
.52277 .51696 m .52217 .4618 L .47413 .43268 L p 0 .668 0 r
F P
0 g
s
.43876 .61994 m .4274 .62594 L .37679 .60128 L p 0 .916 0 r
F P
0 g
s
.38808 .59489 m .37676 .60122 L .38002 .54387 L p 0 .1 0 r
F P
0 g
s
.38002 .54387 m .39106 .53732 L .38808 .59489 L p 0 .1 0 r
F P
0 g
s
.43879 .45473 m .43876 .45475 L .4274 .46184 L p 0 .93 .764 r
F P
0 g
s
.42543 .51696 m .4274 .46184 L .43876 .45475 L p 0 .1 .365 r
F P
0 g
s
.8681 .36758 m .86808 .3676 L .88221 .35996 L p 0 .1 0 r
F P
0 g
s
.82071 .28552 m .78073 .25158 L .76699 .26009 L p 0 .907 0 r
F P
0 g
s
.82071 .28552 m .82942 .33591 L .81535 .34386 L p 0 .1 0 r
F P
0 g
s
.82942 .33591 m .82071 .28552 L .78073 .25158 L p 0 .607 0 r
F P
0 g
s
.77331 .20342 m .78073 .25158 L .82071 .28552 L p 0 .607 0 r
F P
0 g
s
.77331 .20342 m .78073 .25158 L .82071 .28552 L p 0 .607 0 r
F P
0 g
s
.78073 .25158 m .82071 .28552 L .83453 .27735 L p 0 .907 0 r
F P
0 g
s
.82071 .28552 m .82942 .33591 L .86808 .3676 L p 0 .607 0 r
F P
0 g
s
.82071 .28552 m .82942 .33591 L .86808 .3676 L p 0 .607 0 r
F P
0 g
s
.82071 .28552 m .82942 .33591 L .84368 .32785 L p 0 .1 0 r
F P
0 g
s
.84368 .32785 m .83453 .27735 L .82071 .28552 L p 0 .1 0 r
F P
0 g
s
.82942 .33591 m .82071 .28552 L .78073 .25158 L p 0 .607 0 r
F P
0 g
s
.82071 .28552 m .78073 .25158 L .79466 .24296 L p 0 .907 0 r
F P
0 g
s
.79466 .24296 m .83453 .27735 L .82071 .28552 L p 0 .907 0 r
F P
0 g
s
.82942 .33591 m .82071 .28552 L .83453 .27735 L p 0 .1 0 r
F P
0 g
s
.77331 .20342 m .78073 .25158 L .76699 .26009 L p 0 .1 0 r
F P
0 g
s
.78073 .25158 m .77331 .20342 L .78682 .19471 L p 0 .1 0 r
F P
0 g
s
.86808 .3676 m .82942 .33591 L .84368 .32785 L p 0 .911 0 r
F P
0 g
s
.84368 .32785 m .88221 .35996 L .86808 .3676 L p 0 .911 0 r
F P
0 g
s
.71623 .34118 m .72532 .33577 L .71936 .28538 L p 0 .1 .423 r
F P
0 g
s
.66776 .25722 m .67663 .25143 L .71936 .28538 L p 0 .907 1 r
F P
0 g
s
.72532 .33577 m .71936 .28538 L .67663 .25143 L p 0 .627 .269 r
F P
0 g
s
.72827 .27984 m .71936 .28538 L .72532 .33577 L p 0 .1 .423 r
F P
0 g
s
.67196 .20327 m .67663 .25143 L .71936 .28538 L p 0 .627 .269 r
F P
0 g
s
.67196 .20327 m .67663 .25143 L .71936 .28538 L p 0 .627 .269 r
F P
0 g
s
.71936 .28538 m .72827 .27984 L .68559 .24559 L p 0 .907 1 r
F P
0 g
s
.68559 .24559 m .67663 .25143 L .71936 .28538 L p 0 .907 1 r
F P
0 g
s
.72532 .33577 m .71936 .28538 L .67663 .25143 L p 0 .627 .269 r
F P
0 g
s
.72827 .27984 m .71936 .28538 L .67663 .25143 L p 0 .907 1 r
F P
0 g
s
.67196 .20327 m .68066 .19737 L .68559 .24559 L p 0 .1 .396 r
F P
0 g
s
.68559 .24559 m .67663 .25143 L .67196 .20327 L p 0 .1 .396 r
F P
0 g
s
.68066 .19737 m .67196 .20327 L .67663 .25143 L p 0 .1 .396 r
F P
0 g
s
.67196 .20327 m .68066 .19737 L .6367 .1609 L p 0 .903 1 r
F P
0 g
s
.6367 .1609 m .62797 .16712 L .67196 .20327 L p 0 .903 1 r
F P
0 g
s
.66776 .25722 m .67663 .25143 L .67196 .20327 L p 0 .1 .396 r
F P
0 g
s
.67663 .25143 m .67196 .20327 L .62797 .16712 L p 0 .627 .269 r
F P
0 g
s
.67663 .25143 m .67196 .20327 L .62797 .16712 L p 0 .627 .269 r
F P
0 g
s
.76404 .25763 m .77779 .24909 L .77043 .2009 L p 0 .1 0 r
F P
0 g
s
.77779 .24909 m .77043 .2009 L .72901 .16459 L p 0 .607 0 r
F P
0 g
s
.78395 .19216 m .77043 .2009 L .77779 .24909 L p 0 .1 0 r
F P
0 g
s
.77043 .2009 m .78395 .19216 L .74262 .15537 L p 0 .903 0 r
F P
0 g
s
.74262 .15537 m .72901 .16459 L .77043 .2009 L p 0 .903 0 r
F P
0 g
s
.77779 .24909 m .77043 .2009 L .72901 .16459 L p 0 .607 0 r
F P
0 g
s
.81817 .45933 m .81813 .45927 L .77804 .43002 L p 0 .627 .269 r
F P
0 g
s
.82682 .51452 m .81817 .45933 L p .77804 .43002 L 0 .627 .269 r
F P
0 g
s
.81813 .45927 m .8275 .4545 L .78747 .42498 L p 0 .914 1 r
F P
0 g
s
.78747 .42498 m .77804 .43002 L .81813 .45927 L p 0 .914 1 r
F P
0 g
s
.82753 .45456 m .81817 .45933 L .82682 .51452 L p 0 .114 .472 r
F P
0 g
s
.81817 .45933 m .82753 .45456 L .8275 .4545 L p 0 .562 .887 r
F P
0 g
s
.8275 .4545 m .81813 .45927 L .81817 .45933 L p 0 .562 .887 r
F P
0 g
s
.81817 .45933 m .81813 .45927 L .77804 .43002 L p 0 .627 .269 r
F P
0 g
s
.82682 .51452 m .81817 .45933 L p .77804 .43002 L 0 .627 .269 r
F P
0 g
s
.58158 .20016 m .58154 .20017 L p .62906 .28244 L 0 .641 0 r
F P
0 g
s
.58158 .20016 m .59399 .19132 L .59396 .19133 L p 0 1 0 r
F P
0 g
s
.59396 .19133 m .58154 .20017 L .58158 .20016 L p 0 1 0 r
F P
0 g
s
.58158 .20016 m .58154 .20017 L p .62906 .28244 L 0 .641 0 r
F P
0 g
s
.48651 .3647 m .49829 .35695 L .49833 .35701 L p 0 .546 0 r
F P
0 g
s
.49833 .35701 m .48654 .36476 L .48651 .3647 L p 0 .546 0 r
F P
0 g
s
.61965 .34095 m .63258 .33288 L .67658 .36474 L p 0 .911 0 r
F P
0 g
s
.62906 .28244 m .63258 .33288 L .67658 .36474 L p 0 .641 0 r
F P
0 g
s
.62906 .28244 m .63258 .33288 L .67658 .36474 L p 0 .641 0 r
F P
0 g
s
.68962 .35699 m .67658 .36474 L .63258 .33288 L p 0 .911 0 r
F P
0 g
s
.62906 .28244 m .64179 .27414 L .64568 .32469 L p 0 .1 0 r
F P
0 g
s
.64568 .32469 m .63258 .33288 L .62906 .28244 L p 0 .1 0 r
F P
0 g
s
.61965 .34095 m .63258 .33288 L .62906 .28244 L p 0 .1 0 r
F P
0 g
s
.57117 .25697 m .58376 .24833 L .62906 .28244 L p 0 .907 0 r
F P
0 g
s
.63258 .33288 m .62906 .28244 L .58376 .24833 L p 0 .641 0 r
F P
0 g
s
.64179 .27414 m .62906 .28244 L .63258 .33288 L p 0 .1 0 r
F P
0 g
s
.58154 .20017 m .58376 .24833 L .62906 .28244 L p 0 .641 0 r
F P
0 g
s
.58154 .20017 m .58376 .24833 L .62906 .28244 L p 0 .641 0 r
F P
0 g
s
.62906 .28244 m .64179 .27414 L .59653 .23958 L p 0 .907 0 r
F P
0 g
s
.59653 .23958 m .58376 .24833 L .62906 .28244 L p 0 .907 0 r
F P
0 g
s
.63258 .33288 m .62906 .28244 L .58376 .24833 L p 0 .641 0 r
F P
0 g
s
.64179 .27414 m .62906 .28244 L .58376 .24833 L p 0 .907 0 r
F P
0 g
s
.52272 .34097 m .53499 .3329 L .58154 .36474 L p 0 .911 1 r
F P
0 g
s
.53495 .33284 m .53499 .3329 L .58154 .36474 L p 0 .655 .342 r
F P
0 g
s
.53403 .28244 m .53495 .33284 L p .58154 .36474 L 0 .655 .342 r
F P
0 g
s
.53495 .33284 m .53499 .3329 L .58154 .36474 L p 0 .655 .342 r
F P
0 g
s
.53403 .28244 m .53495 .33284 L p .58154 .36474 L 0 .655 .342 r
F P
0 g
s
.59396 .35699 m .58154 .36474 L .53499 .3329 L p 0 .911 1 r
F P
0 g
s
.53403 .28244 m .54612 .27414 L .54739 .32466 L p 0 .1 .365 r
F P
0 g
s
.54739 .32466 m .53495 .33284 L .53403 .28244 L p 0 .1 .365 r
F P
0 g
s
.58154 .20017 m .59396 .19133 L .59653 .23958 L p 0 .1 0 r
F P
0 g
s
.59653 .23958 m .58376 .24833 L .58154 .20017 L p 0 .1 0 r
F P
0 g
s
.73123 .28222 m .73753 .33266 L .72836 .33809 L p 0 .1 .425 r
F P
0 g
s
.73123 .28222 m .73753 .33266 L .77876 .36454 L p 0 .624 .261 r
F P
0 g
s
.73123 .28222 m .73753 .33266 L .77876 .36454 L p 0 .624 .261 r
F P
0 g
s
.73753 .33266 m .73123 .28222 L .74022 .27666 L p 0 .1 .425 r
F P
0 g
s
.77876 .36454 m .73753 .33266 L .74679 .32718 L p 0 .911 1 r
F P
0 g
s
.74679 .32718 m .78795 .35934 L .77876 .36454 L p 0 .911 1 r
F P
0 g
s
.72789 .62166 m .72792 .62163 L p .68031 .53922 L 0 .655 .342 r
F P
0 g
s
.74132 .61557 m .72792 .62163 L .72789 .62166 L p 0 .1 .1 r
F P
0 g
s
.72789 .62166 m .72792 .62163 L p .68031 .53922 L 0 .655 .342 r
F P
0 g
s
.62335 .51893 m .63633 .51205 L .68031 .53922 L p 0 .916 1 r
F P
0 g
s
.63271 .45676 m .63633 .51205 L .68031 .53922 L p 0 .655 .342 r
F P
0 g
s
.63271 .45676 m .63633 .51205 L .68031 .53922 L p 0 .655 .342 r
F P
0 g
s
.6934 .53261 m .68031 .53922 L .63633 .51205 L p 0 .916 1 r
F P
0 g
s
.67193 .60307 m .68523 .59676 L .68031 .53922 L p 0 .1 .45 r
F P
0 g
s
.68523 .59676 m .68031 .53922 L .63633 .51205 L p 0 .655 .342 r
F P
0 g
s
.68031 .53922 m .6934 .53261 L .64948 .50508 L p 0 .916 1 r
F P
0 g
s
.64948 .50508 m .63633 .51205 L .68031 .53922 L p 0 .916 1 r
F P
0 g
s
.68031 .53922 m .68523 .59676 L .72789 .62166 L p 0 .655 .342 r
F P
0 g
s
.68031 .53922 m .68523 .59676 L .72789 .62166 L p 0 .655 .342 r
F P
0 g
s
.6934 .53261 m .68031 .53922 L .68523 .59676 L p 0 .1 .45 r
F P
0 g
s
.68523 .59676 m .68031 .53922 L .63633 .51205 L p 0 .655 .342 r
F P
0 g
s
.68031 .53922 m .6934 .53261 L .69872 .59036 L p 0 .1 .45 r
F P
0 g
s
.69872 .59036 m .68523 .59676 L .68031 .53922 L p 0 .1 .45 r
F P
0 g
s
.63271 .45676 m .64548 .4496 L .64948 .50508 L p 0 .1 .425 r
F P
0 g
s
.64948 .50508 m .63633 .51205 L .63271 .45676 L p 0 .1 .425 r
F P
0 g
s
.57477 .60307 m .58742 .59676 L .63271 .62167 L p 0 .916 0 r
F P
0 g
s
.5851 .53922 m .58742 .59676 L .63271 .62167 L p 0 .666 0 r
F P
0 g
s
.5851 .53922 m .58742 .59676 L .63271 .62167 L p 0 .666 0 r
F P
0 g
s
.64548 .61561 m .63271 .62167 L .58742 .59676 L p 0 .916 0 r
F P
0 g
s
.5851 .53922 m .59756 .53261 L .60024 .59036 L p 0 .1 0 r
F P
0 g
s
.60024 .59036 m .58742 .59676 L .5851 .53922 L p 0 .1 0 r
F P
0 g
s
.72051 .51893 m .73414 .51205 L .72792 .45676 L p 0 .1 0 r
F P
0 g
s
.73414 .51205 m .72792 .45676 L .68523 .42734 L p 0 .641 0 r
F P
0 g
s
.72792 .45676 m .74133 .4496 L .69872 .41979 L p 0 .914 0 r
F P
0 g
s
.69872 .41979 m .68523 .42734 L .72792 .45676 L p 0 .914 0 r
F P
0 g
s
.74133 .4496 m .72792 .45676 L .73414 .51205 L p 0 .1 0 r
F P
0 g
s
.73414 .51205 m .72792 .45676 L .68523 .42734 L p 0 .641 0 r
F P
0 g
s
.74796 .50508 m .73414 .51205 L .72792 .45676 L p 0 .1 0 r
F P
0 g
s
.73414 .51205 m .74796 .50508 L .74133 .4496 L p 0 .1 0 r
F P
0 g
s
.64548 .4496 m .64948 .50508 L .6934 .53261 L p 0 .652 .333 r
F P
0 g
s
.64548 .4496 m .64948 .50508 L .6934 .53261 L p 0 .652 .333 r
F P
0 g
s
.65843 .44235 m .66281 .49801 L .70667 .52591 L p 0 .648 .324 r
F P
0 g
s
.65843 .44235 m .66281 .49801 L .70667 .52591 L p 0 .648 .324 r
F P
0 g
s
.67155 .43501 m .67633 .49084 L .72012 .51913 L p 0 .645 .315 r
F P
0 g
s
.67193 .43479 m .67672 .49063 L .72051 .51893 L p 0 .645 0 r
F P
0 g
s
.68523 .42734 m .69043 .48336 L .73414 .51205 L p 0 .641 0 r
F P
0 g
s
.68523 .42734 m .69043 .48336 L .73414 .51205 L p 0 .641 0 r
F P
0 g
s
.69872 .41979 m .70433 .47599 L .74796 .50508 L p 0 .638 0 r
F P
0 g
s
.72792 .45676 m .74133 .4496 L .74796 .50508 L p 0 .1 0 r
F P
0 g
s
.74796 .50508 m .74133 .4496 L .69872 .41979 L p 0 .638 0 r
F P
0 g
s
.72051 .51893 m .73414 .51205 L .77553 .53922 L p 0 .916 0 r
F P
0 g
s
.78925 .53261 m .77553 .53922 L .73414 .51205 L p 0 .916 0 r
F P
0 g
s
.76908 .60303 m .78304 .59672 L .77553 .53922 L p 0 .114 0 r
F P
0 g
s
.78304 .59672 m .77553 .53922 L .73414 .51205 L p 0 .641 0 r
F P
0 g
s
.77553 .53922 m .78925 .53261 L .74796 .50508 L p 0 .916 0 r
F P
0 g
s
.74796 .50508 m .73414 .51205 L .77553 .53922 L p 0 .916 0 r
F P
0 g
s
.78925 .53261 m .77553 .53922 L .78304 .59672 L p 0 .114 0 r
F P
0 g
s
.78304 .59672 m .77553 .53922 L .73414 .51205 L p 0 .641 0 r
F P
0 g
s
.73414 .51205 m .74796 .50508 L .78925 .53261 L p 0 .916 0 r
F P
0 g
s
.73414 .51205 m .72051 .51893 L .67672 .49063 L p 0 .916 0 r
F P
0 g
s
.72051 .51893 m .73414 .51205 L .69043 .48336 L p 0 .916 0 r
F P
0 g
s
.75491 .60943 m .74132 .61557 L .7413 .6156 L p 0 .1 .1 r
F P
0 g
s
.7413 .6156 m .75489 .60946 L .75491 .60943 L p 0 .1 .1 r
F P
0 g
s
.75489 .60946 m .75491 .60943 L p .70667 .52591 L 0 .648 .324 r
F P
0 g
s
.75489 .60946 m .75491 .60943 L p .70667 .52591 L 0 .648 .324 r
F P
0 g
s
.72789 .62166 m .7413 .6156 L .74132 .61557 L p 0 .1 .1 r
F P
0 g
s
.7413 .6156 m .74132 .61557 L p .6934 .53261 L 0 .652 .333 r
F P
0 g
s
.7413 .6156 m .74132 .61557 L p .6934 .53261 L 0 .652 .333 r
F P
0 g
s
.6934 .53261 m .69872 .59036 L .7413 .6156 L p 0 .652 .333 r
F P
0 g
s
.6934 .53261 m .69872 .59036 L .7413 .6156 L p 0 .652 .333 r
F P
0 g
s
.70667 .52591 m .71239 .58388 L .75489 .60946 L p 0 .648 .324 r
F P
0 g
s
.70667 .52591 m .71239 .58388 L .75489 .60946 L p 0 .648 .324 r
F P
0 g
s
.76868 .60321 m .75491 .60943 L .75489 .60946 L p 0 .1 .1 r
F P
0 g
s
.75489 .60946 m .76866 .60323 L .76868 .60321 L p 0 .1 .1 r
F P
0 g
s
.76866 .60323 m .76868 .60321 L p .72012 .51913 L 0 .645 .315 r
F P
0 g
s
.72012 .51913 m .72625 .5773 L .76866 .60323 L p 0 .645 .315 r
F P
0 g
s
.76905 .60305 m .76908 .60303 L p .72051 .51893 L 0 .645 0 r
F P
0 g
s
.72051 .51893 m .72665 .57711 L .76905 .60305 L p 0 .645 0 r
F P
0 g
s
.73414 .51205 m .72051 .51893 L .72665 .57711 L p 0 .1 0 r
F P
0 g
s
.72051 .51893 m .73414 .51205 L .74071 .57045 L p 0 .1 0 r
F P
0 g
s
.78304 .59672 m .76908 .60303 L .76905 .60305 L p 0 .1 0 r
F P
0 g
s
.76905 .60305 m .78302 .59674 L .78304 .59672 L p 0 .1 0 r
F P
0 g
s
.78302 .59674 m .78304 .59672 L p .73414 .51205 L 0 .641 0 r
F P
0 g
s
.78302 .59674 m .78304 .59672 L p .73414 .51205 L 0 .641 0 r
F P
0 g
s
.67672 .49063 m .69043 .48336 L .73414 .51205 L p 0 .916 0 r
F P
0 g
s
.74796 .50508 m .73414 .51205 L .69043 .48336 L p 0 .916 0 r
F P
0 g
s
.72665 .57711 m .74071 .57045 L .73414 .51205 L p 0 .1 0 r
F P
0 g
s
.72012 .51913 m .70667 .52591 L .66281 .49801 L p 0 .916 1 r
F P
0 g
s
.70667 .52591 m .72012 .51913 L .67633 .49084 L p 0 .916 1 r
F P
0 g
s
.72012 .51913 m .70667 .52591 L .71239 .58388 L p 0 .1 .45 r
F P
0 g
s
.70667 .52591 m .72012 .51913 L .72625 .5773 L p 0 .1 .45 r
F P
0 g
s
.66281 .49801 m .67633 .49084 L .72012 .51913 L p 0 .916 1 r
F P
0 g
s
.71239 .58388 m .72625 .5773 L .72012 .51913 L p 0 .1 .45 r
F P
0 g
s
.70667 .52591 m .6934 .53261 L .64948 .50508 L p 0 .916 1 r
F P
0 g
s
.6934 .53261 m .70667 .52591 L .66281 .49801 L p 0 .916 1 r
F P
0 g
s
.70667 .52591 m .6934 .53261 L .69872 .59036 L p 0 .1 .45 r
F P
0 g
s
.6934 .53261 m .70667 .52591 L .71239 .58388 L p 0 .1 .45 r
F P
0 g
s
.64948 .50508 m .66281 .49801 L .70667 .52591 L p 0 .916 1 r
F P
0 g
s
.69872 .59036 m .71239 .58388 L .70667 .52591 L p 0 .1 .45 r
F P
0 g
s
.63633 .51205 m .64948 .50508 L .6934 .53261 L p 0 .916 1 r
F P
0 g
s
.68523 .59676 m .69872 .59036 L .6934 .53261 L p 0 .1 .45 r
F P
0 g
s
.69872 .59036 m .6934 .53261 L .64948 .50508 L p 0 .652 .333 r
F P
0 g
s
.66281 .49801 m .64948 .50508 L .6934 .53261 L p 0 .916 1 r
F P
0 g
s
.69872 .59036 m .6934 .53261 L .64948 .50508 L p 0 .652 .333 r
F P
0 g
s
.71239 .58388 m .69872 .59036 L .6934 .53261 L p 0 .1 .45 r
F P
0 g
s
.71239 .58388 m .70667 .52591 L .66281 .49801 L p 0 .648 .324 r
F P
0 g
s
.67633 .49084 m .66281 .49801 L .70667 .52591 L p 0 .916 1 r
F P
0 g
s
.71239 .58388 m .70667 .52591 L .66281 .49801 L p 0 .648 .324 r
F P
0 g
s
.72625 .5773 m .71239 .58388 L .70667 .52591 L p 0 .1 .45 r
F P
0 g
s
.72625 .5773 m .72012 .51913 L .67633 .49084 L p 0 .645 .315 r
F P
0 g
s
.69043 .48336 m .67672 .49063 L .72051 .51893 L p 0 .916 0 r
F P
0 g
s
.72665 .57711 m .72051 .51893 L .67672 .49063 L p 0 .645 0 r
F P
0 g
s
.74071 .57045 m .72665 .57711 L .72051 .51893 L p 0 .1 0 r
F P
0 g
s
.74071 .57045 m .73414 .51205 L .69043 .48336 L p 0 .641 0 r
F P
0 g
s
.73414 .51205 m .74796 .50508 L .70433 .47599 L p 0 .916 0 r
F P
0 g
s
.70433 .47599 m .69043 .48336 L .73414 .51205 L p 0 .916 0 r
F P
0 g
s
.73414 .51205 m .74071 .57045 L .78302 .59674 L p 0 .641 0 r
F P
0 g
s
.73414 .51205 m .74071 .57045 L .78302 .59674 L p 0 .641 0 r
F P
0 g
s
.74796 .50508 m .73414 .51205 L .74071 .57045 L p 0 .1 0 r
F P
0 g
s
.74071 .57045 m .73414 .51205 L .69043 .48336 L p 0 .641 0 r
F P
0 g
s
.75497 .56368 m .74071 .57045 L .73414 .51205 L p 0 .1 0 r
F P
0 g
s
.69043 .48336 m .70433 .47599 L .74796 .50508 L p 0 .916 0 r
F P
0 g
s
.74071 .57045 m .75497 .56368 L .74796 .50508 L p 0 .1 0 r
F P
0 g
s
.59756 .53261 m .60024 .59036 L .64548 .61561 L p 0 .663 0 r
F P
0 g
s
.59756 .53261 m .60024 .59036 L .64548 .61561 L p 0 .663 0 r
F P
0 g
s
.61018 .52591 m .61323 .58388 L .65843 .60947 L p 0 .661 0 r
F P
0 g
s
.61018 .52591 m .61323 .58388 L .65843 .60947 L p 0 .661 0 r
F P
0 g
s
.62298 .51913 m .62641 .5773 L .67155 .60325 L p 0 .658 0 r
F P
0 g
s
.62335 .51893 m .62679 .57711 L .67193 .60307 L p 0 .658 .35 r
F P
0 g
s
.63633 .51205 m .64015 .57045 L .68523 .59676 L p 0 .655 .342 r
F P
0 g
s
.63633 .51205 m .64015 .57045 L .68523 .59676 L p 0 .655 .342 r
F P
0 g
s
.64948 .50508 m .6537 .56368 L .69872 .59036 L p 0 .652 .333 r
F P
0 g
s
.64948 .50508 m .6537 .56368 L .69872 .59036 L p 0 .652 .333 r
F P
0 g
s
.66281 .49801 m .66744 .55683 L .71239 .58388 L p 0 .648 .324 r
F P
0 g
s
.66281 .49801 m .66744 .55683 L .71239 .58388 L p 0 .648 .324 r
F P
0 g
s
.67633 .49084 m .68138 .54987 L .72625 .5773 L p 0 .645 .315 r
F P
0 g
s
.67672 .49063 m .68179 .54967 L .72665 .57711 L p 0 .645 0 r
F P
0 g
s
.69043 .48336 m .69593 .54261 L .74071 .57045 L p 0 .641 0 r
F P
0 g
s
.69043 .48336 m .69593 .54261 L .74071 .57045 L p 0 .641 0 r
F P
0 g
s
.70433 .47599 m .71028 .53545 L .75497 .56368 L p 0 .638 0 r
F P
0 g
s
.73414 .51205 m .74796 .50508 L .75497 .56368 L p 0 .1 0 r
F P
0 g
s
.75497 .56368 m .74796 .50508 L .70433 .47599 L p 0 .638 0 r
F P
0 g
s
.78304 .59672 m .79719 .59032 L .78925 .53261 L p 0 .114 0 r
F P
0 g
s
.79719 .59032 m .78304 .59672 L .78302 .59674 L p 0 .1 0 r
F P
0 g
s
.78302 .59674 m .79717 .59034 L .79719 .59032 L p 0 .1 0 r
F P
0 g
s
.79717 .59034 m .79719 .59032 L p .74796 .50508 L 0 .638 0 r
F P
0 g
s
.79719 .59032 m .78925 .53261 L .74796 .50508 L p 0 .638 0 r
F P
0 g
s
.67193 .60307 m .68523 .59676 L .72789 .62166 L p 0 .916 1 r
F P
0 g
s
.7413 .6156 m .72789 .62166 L .68523 .59676 L p 0 .916 1 r
F P
0 g
s
.72532 .33577 m .7345 .33032 L .72827 .27984 L p 0 .1 .423 r
F P
0 g
s
.67663 .25143 m .68559 .24559 L .72827 .27984 L p 0 .907 1 r
F P
0 g
s
.7345 .33032 m .72827 .27984 L .68559 .24559 L p 0 .624 .261 r
F P
0 g
s
.73726 .27426 m .72827 .27984 L .7345 .33032 L p 0 .1 .423 r
F P
0 g
s
.68066 .19737 m .68559 .24559 L .72827 .27984 L p 0 .624 .261 r
F P
0 g
s
.68066 .19737 m .68559 .24559 L .72827 .27984 L p 0 .624 .261 r
F P
0 g
s
.72827 .27984 m .73726 .27426 L .69462 .2397 L p 0 .907 1 r
F P
0 g
s
.69462 .2397 m .68559 .24559 L .72827 .27984 L p 0 .907 1 r
F P
0 g
s
.7345 .33032 m .72827 .27984 L .68559 .24559 L p 0 .624 .261 r
F P
0 g
s
.73726 .27426 m .72827 .27984 L .68559 .24559 L p 0 .907 1 r
F P
0 g
s
.68066 .19737 m .68943 .19142 L .69462 .2397 L p 0 .1 .396 r
F P
0 g
s
.69462 .2397 m .68559 .24559 L .68066 .19737 L p 0 .1 .396 r
F P
0 g
s
.67663 .25143 m .68559 .24559 L .68066 .19737 L p 0 .1 .396 r
F P
0 g
s
.68559 .24559 m .68066 .19737 L .6367 .1609 L p 0 .624 .261 r
F P
0 g
s
.68943 .19142 m .68066 .19737 L .68559 .24559 L p 0 .1 .396 r
F P
0 g
s
.68066 .19737 m .68943 .19142 L .64552 .15462 L p 0 .903 1 r
F P
0 g
s
.64552 .15462 m .6367 .1609 L .68066 .19737 L p 0 .903 1 r
F P
0 g
s
.68559 .24559 m .68066 .19737 L .6367 .1609 L p 0 .624 .261 r
F P
0 g
s
.43708 .51005 m .48646 .53732 L p .43879 .45473 L 0 .675 .404 r
F P
0 g
s
.43879 .45473 m .43876 .45475 L .43708 .51005 L p 0 .675 .404 r
F P
0 g
s
.43876 .45475 m .43879 .45473 L .45031 .44755 L p 0 .93 .764 r
F P
0 g
s
.43708 .51005 m .48646 .53732 L p .43879 .45473 L 0 .675 .404 r
F P
0 g
s
.43879 .45473 m .43876 .45475 L .43708 .51005 L p 0 .675 .404 r
F P
0 g
s
.35428 .61387 m .3434 .61996 L .34337 .6199 L p 0 .525 .891 r
F P
0 g
s
.34337 .6199 m .35424 .61381 L .35428 .61387 L p 0 .525 .891 r
F P
0 g
s
.48646 .53732 m .48609 .59493 L .4741 .60126 L p 0 .1 .396 r
F P
0 g
s
.48646 .53732 m .48609 .59493 L .53415 .61994 L p 0 .675 .404 r
F P
0 g
s
.48646 .53732 m .48609 .59493 L .53415 .61994 L p 0 .675 .404 r
F P
0 g
s
.48609 .59493 m .48646 .53732 L .49829 .53069 L p 0 .1 .396 r
F P
0 g
s
.48646 .53732 m .43708 .51005 L .4489 .50305 L p 0 .916 1 r
F P
0 g
s
.4489 .50305 m .49829 .53069 L .48646 .53732 L p 0 .916 1 r
F P
0 g
s
.48646 .53732 m .43708 .51005 L .42543 .51696 L p 0 .916 1 r
F P
0 g
s
.48609 .59493 m .48646 .53732 L .43708 .51005 L p 0 .675 .404 r
F P
0 g
s
.43708 .51005 m .48646 .53732 L .49829 .53069 L p 0 .916 1 r
F P
0 g
s
.48646 .53732 m .48609 .59493 L .49824 .58851 L p 0 .1 .396 r
F P
0 g
s
.49824 .58851 m .49829 .53069 L .48646 .53732 L p 0 .1 .396 r
F P
0 g
s
.48609 .59493 m .48646 .53732 L .43708 .51005 L p 0 .675 .404 r
F P
0 g
s
.53415 .61994 m .48609 .59493 L .49824 .58851 L p 0 .916 1 r
F P
0 g
s
.49824 .58851 m .5463 .61386 L .53415 .61994 L p 0 .916 1 r
F P
0 g
s
.62955 .45471 m .58409 .42518 L .57144 .43266 L p 0 .914 1 r
F P
0 g
s
.63309 .51005 m .62955 .45471 L .58409 .42518 L p 0 .655 .342 r
F P
0 g
s
.63309 .51005 m .62955 .45471 L .58409 .42518 L p 0 .655 .342 r
F P
0 g
s
.58409 .42518 m .62955 .45471 L .64233 .44753 L p 0 .914 1 r
F P
0 g
s
.62955 .45471 m .63309 .51005 L .64625 .50305 L p 0 .1 .423 r
F P
0 g
s
.64625 .50305 m .64233 .44753 L .62955 .45471 L p 0 .1 .423 r
F P
0 g
s
.53415 .45471 m .53509 .51005 L .52277 .51696 L p 0 .1 0 r
F P
0 g
s
.53415 .45471 m .53509 .51005 L .58185 .53732 L p 0 .666 0 r
F P
0 g
s
.53415 .45471 m .53509 .51005 L .58185 .53732 L p 0 .666 0 r
F P
0 g
s
.58185 .53732 m .53509 .51005 L .54757 .50305 L p 0 .916 0 r
F P
0 g
s
.54757 .50305 m .59432 .53069 L .58185 .53732 L p 0 .916 0 r
F P
0 g
s
.53509 .51005 m .53415 .45471 L .5463 .44753 L p 0 .1 0 r
F P
0 g
s
.58185 .53732 m .53509 .51005 L .52277 .51696 L p 0 .916 0 r
F P
0 g
s
.58409 .59493 m .58185 .53732 L .53509 .51005 L p 0 .666 0 r
F P
0 g
s
.58409 .59493 m .58185 .53732 L .53509 .51005 L p 0 .666 0 r
F P
0 g
s
.53415 .45471 m .48612 .4252 L .47413 .43268 L p 0 .914 0 r
F P
0 g
s
.53509 .51005 m .53415 .45471 L .48612 .4252 L p 0 .666 0 r
F P
0 g
s
.48612 .4252 m .53415 .45471 L .5463 .44753 L p 0 .914 0 r
F P
0 g
s
.53415 .45471 m .53509 .51005 L .54757 .50305 L p 0 .1 0 r
F P
0 g
s
.54757 .50305 m .5463 .44753 L .53415 .45471 L p 0 .1 0 r
F P
0 g
s
.53509 .51005 m .53415 .45471 L .48612 .4252 L p 0 .666 0 r
F P
0 g
s
.53509 .51005 m .58185 .53732 L .59432 .53069 L p 0 .916 0 r
F P
0 g
s
.58185 .53732 m .58409 .59493 L .59691 .58851 L p 0 .1 0 r
F P
0 g
s
.59691 .58851 m .59432 .53069 L .58185 .53732 L p 0 .1 0 r
F P
0 g
s
.45027 .61386 m .43876 .61994 L .38812 .59495 L p 0 .916 0 r
F P
0 g
s
.39957 .58846 m .38808 .59489 L .39106 .53732 L p 0 .1 0 r
F P
0 g
s
.39106 .53732 m .40226 .53069 L .39957 .58846 L p 0 .1 0 r
F P
0 g
s
.37679 .60128 m .38812 .59495 L .43876 .61994 L p 0 .916 0 r
F P
0 g
s
.43876 .45475 m .43708 .51005 L .42543 .51696 L p 0 .1 .365 r
F P
0 g
s
.45031 .44755 m .45027 .44757 L .43876 .45475 L p 0 .93 .764 r
F P
0 g
s
.43708 .51005 m .43876 .45475 L .45027 .44757 L p 0 .1 .365 r
F P
0 g
s
.82682 .51452 m .83648 .50987 L .82753 .45456 L p 0 .114 .472 r
F P
0 g
s
.82753 .45456 m .8275 .4545 L .78747 .42498 L p 0 .624 .261 r
F P
0 g
s
.83648 .50987 m .82753 .45456 L p .78747 .42498 L 0 .624 .261 r
F P
0 g
s
.8275 .4545 m .83694 .44969 L .79699 .4199 L p 0 .914 1 r
F P
0 g
s
.79699 .4199 m .78747 .42498 L .8275 .4545 L p 0 .914 1 r
F P
0 g
s
.83698 .44975 m .82753 .45456 L .83648 .50987 L p 0 .114 .472 r
F P
0 g
s
.82753 .45456 m .83698 .44975 L .83694 .44969 L p 0 .562 .887 r
F P
0 g
s
.83694 .44969 m .8275 .4545 L .82753 .45456 L p 0 .562 .887 r
F P
0 g
s
.82753 .45456 m .8275 .4545 L .78747 .42498 L p 0 .624 .261 r
F P
0 g
s
.83648 .50987 m .82753 .45456 L p .78747 .42498 L 0 .624 .261 r
F P
0 g
s
.83453 .27735 m .79466 .24296 L .78073 .25158 L p 0 .907 0 r
F P
0 g
s
.83453 .27735 m .84368 .32785 L .82942 .33591 L p 0 .1 0 r
F P
0 g
s
.84368 .32785 m .83453 .27735 L .79466 .24296 L p 0 .601 0 r
F P
0 g
s
.78682 .19471 m .79466 .24296 L .83453 .27735 L p 0 .601 0 r
F P
0 g
s
.83453 .27735 m .84368 .32785 L .88221 .35996 L p 0 .601 0 r
F P
0 g
s
.78682 .19471 m .79466 .24296 L .78073 .25158 L p 0 .1 0 r
F P
0 g
s
.74022 .27666 m .74679 .32718 L .73753 .33266 L p 0 .1 .425 r
F P
0 g
s
.74022 .27666 m .74679 .32718 L .78795 .35934 L p 0 .621 .254 r
F P
0 g
s
.74022 .27666 m .74679 .32718 L .78795 .35934 L p 0 .621 .254 r
F P
0 g
s
.74679 .32718 m .74022 .27666 L .74928 .27105 L p 0 .1 .425 r
F P
0 g
s
.78795 .35934 m .74679 .32718 L .75613 .32165 L p 0 .911 1 r
F P
0 g
s
.75613 .32165 m .79723 .3541 L .78795 .35934 L p 0 .911 1 r
F P
0 g
s
.77779 .24909 m .79173 .24043 L .78395 .19216 L p 0 .1 0 r
F P
0 g
s
.79173 .24043 m .78395 .19216 L .74262 .15537 L p 0 .601 0 r
F P
0 g
s
.68559 .24559 m .69462 .2397 L .73726 .27426 L p 0 .907 1 r
F P
0 g
s
.68943 .19142 m .69462 .2397 L .73726 .27426 L p 0 .621 .254 r
F P
0 g
s
.68943 .19142 m .69462 .2397 L .73726 .27426 L p 0 .621 .254 r
F P
0 g
s
.7345 .33032 m .74376 .32481 L .73726 .27426 L p 0 .1 .423 r
F P
0 g
s
.74376 .32481 m .73726 .27426 L .69462 .2397 L p 0 .621 .254 r
F P
0 g
s
.74632 .26863 m .73726 .27426 L .74376 .32481 L p 0 .1 .423 r
F P
0 g
s
.73726 .27426 m .74632 .26863 L .70375 .23376 L p 0 .907 1 r
F P
0 g
s
.70375 .23376 m .69462 .2397 L .73726 .27426 L p 0 .907 1 r
F P
0 g
s
.74376 .32481 m .73726 .27426 L .69462 .2397 L p 0 .621 .254 r
F P
0 g
s
.74632 .26863 m .73726 .27426 L .69462 .2397 L p 0 .907 1 r
F P
0 g
s
.68943 .19142 m .69828 .18542 L .70375 .23376 L p 0 .1 .396 r
F P
0 g
s
.70375 .23376 m .69462 .2397 L .68943 .19142 L p 0 .1 .396 r
F P
0 g
s
.68559 .24559 m .69462 .2397 L .68943 .19142 L p 0 .1 .396 r
F P
0 g
s
.69462 .2397 m .68943 .19142 L .64552 .15462 L p 0 .621 .254 r
F P
0 g
s
.69828 .18542 m .68943 .19142 L .69462 .2397 L p 0 .1 .396 r
F P
0 g
s
.68943 .19142 m .69828 .18542 L .65441 .14828 L p 0 .903 1 r
F P
0 g
s
.65441 .14828 m .64552 .15462 L .68943 .19142 L p 0 .903 1 r
F P
0 g
s
.69462 .2397 m .68943 .19142 L .64552 .15462 L p 0 .621 .254 r
F P
0 g
s
.59399 .19132 m .60657 .18236 L .60654 .18237 L p 0 1 0 r
F P
0 g
s
.60654 .18237 m .59396 .19133 L .59399 .19132 L p 0 1 0 r
F P
0 g
s
.59399 .19132 m .59396 .19133 L p .64179 .27414 L 0 .638 0 r
F P
0 g
s
.59399 .19132 m .59396 .19133 L p .64179 .27414 L 0 .638 0 r
F P
0 g
s
.49829 .35695 m .51023 .3491 L .51027 .34916 L p 0 .546 0 r
F P
0 g
s
.51027 .34916 m .49833 .35701 L .49829 .35695 L p 0 .546 0 r
F P
0 g
s
.64179 .27414 m .64568 .32469 L .68962 .35699 L p 0 .638 0 r
F P
0 g
s
.64179 .27414 m .64568 .32469 L .68962 .35699 L p 0 .638 0 r
F P
0 g
s
.70284 .34914 m .68962 .35699 L .64568 .32469 L p 0 .911 0 r
F P
0 g
s
.64179 .27414 m .65468 .26574 L .65896 .3164 L p 0 .1 0 r
F P
0 g
s
.65896 .3164 m .64568 .32469 L .64179 .27414 L p 0 .1 0 r
F P
0 g
s
.65468 .26574 m .64179 .27414 L .64568 .32469 L p 0 .1 0 r
F P
0 g
s
.59396 .19133 m .59653 .23958 L .64179 .27414 L p 0 .638 0 r
F P
0 g
s
.59396 .19133 m .59653 .23958 L .64179 .27414 L p 0 .638 0 r
F P
0 g
s
.64179 .27414 m .65468 .26574 L .60948 .2307 L p 0 .907 0 r
F P
0 g
s
.60948 .2307 m .59653 .23958 L .64179 .27414 L p 0 .907 0 r
F P
0 g
s
.63258 .33288 m .64568 .32469 L .64179 .27414 L p 0 .1 0 r
F P
0 g
s
.58376 .24833 m .59653 .23958 L .64179 .27414 L p 0 .907 0 r
F P
0 g
s
.64568 .32469 m .64179 .27414 L .59653 .23958 L p 0 .638 0 r
F P
0 g
s
.65468 .26574 m .64179 .27414 L .59653 .23958 L p 0 .907 0 r
F P
0 g
s
.64568 .32469 m .64179 .27414 L .59653 .23958 L p 0 .638 0 r
F P
0 g
s
.63258 .33288 m .64568 .32469 L .68962 .35699 L p 0 .911 0 r
F P
0 g
s
.53499 .3329 m .54742 .32472 L .59396 .35699 L p 0 .911 1 r
F P
0 g
s
.54739 .32466 m .54742 .32472 L .59396 .35699 L p 0 .652 .333 r
F P
0 g
s
.54612 .27414 m .54739 .32466 L p .59396 .35699 L 0 .652 .333 r
F P
0 g
s
.54739 .32466 m .54742 .32472 L .59396 .35699 L p 0 .652 .333 r
F P
0 g
s
.54612 .27414 m .54739 .32466 L p .59396 .35699 L 0 .652 .333 r
F P
0 g
s
.60653 .34914 m .59396 .35699 L .54742 .32472 L p 0 .911 1 r
F P
0 g
s
.54612 .27414 m .55838 .26574 L .55999 .31637 L p 0 .1 .365 r
F P
0 g
s
.55999 .31637 m .54739 .32466 L .54612 .27414 L p 0 .1 .365 r
F P
0 g
s
.59396 .19133 m .60654 .18237 L .60948 .2307 L p 0 .1 0 r
F P
0 g
s
.60948 .2307 m .59653 .23958 L .59396 .19133 L p 0 .1 0 r
F P
0 g
s
.88845 .35659 m .88843 .3566 L .90053 .35006 L p 0 .1 .1 r
F P
0 g
s
.79277 .19088 m .8008 .23916 L .84061 .27375 L p 0 .599 .205 r
F P
0 g
s
.8008 .23916 m .84061 .27375 L .85245 .26675 L p 0 .907 1 r
F P
0 g
s
.84061 .27375 m .84996 .32431 L .88843 .3566 L p 0 .599 .205 r
F P
0 g
s
.84061 .27375 m .84996 .32431 L .86217 .31741 L p 0 .1 .45 r
F P
0 g
s
.86217 .31741 m .85245 .26675 L .84061 .27375 L p 0 .1 .45 r
F P
0 g
s
.84996 .32431 m .84061 .27375 L .8008 .23916 L p 0 .599 .205 r
F P
0 g
s
.84061 .27375 m .8008 .23916 L .81273 .23177 L p 0 .907 1 r
F P
0 g
s
.81273 .23177 m .85245 .26675 L .84061 .27375 L p 0 .907 1 r
F P
0 g
s
.8008 .23916 m .79277 .19088 L .80433 .18342 L p 0 .1 .425 r
F P
0 g
s
.84996 .32431 m .84061 .27375 L .85245 .26675 L p 0 .1 .45 r
F P
0 g
s
.88843 .3566 m .84996 .32431 L .86217 .31741 L p 0 .911 1 r
F P
0 g
s
.86217 .31741 m .90053 .35006 L .88843 .3566 L p 0 .911 1 r
F P
0 g
s
.83648 .50987 m .84623 .50518 L .83698 .44975 L p 0 .114 .472 r
F P
0 g
s
.83698 .44975 m .83694 .44969 L .79699 .4199 L p 0 .621 .254 r
F P
0 g
s
.84623 .50518 m .83698 .44975 L p .79699 .4199 L 0 .621 .254 r
F P
0 g
s
.83694 .44969 m .84647 .44483 L .8066 .41477 L p 0 .914 1 r
F P
0 g
s
.8066 .41477 m .79699 .4199 L .83694 .44969 L p 0 .914 1 r
F P
0 g
s
.84651 .44489 m .83698 .44975 L .84623 .50518 L p 0 .114 .472 r
F P
0 g
s
.83698 .44975 m .84651 .44489 L .84647 .44483 L p 0 .562 .887 r
F P
0 g
s
.84647 .44483 m .83694 .44969 L .83698 .44975 L p 0 .562 .887 r
F P
0 g
s
.83698 .44975 m .83694 .44969 L .79699 .4199 L p 0 .621 .254 r
F P
0 g
s
.84623 .50518 m .83698 .44975 L p .79699 .4199 L 0 .621 .254 r
F P
0 g
s
.64548 .4496 m .65843 .44235 L .66281 .49801 L p 0 .1 .425 r
F P
0 g
s
.66281 .49801 m .64948 .50508 L .64548 .4496 L p 0 .1 .425 r
F P
0 g
s
.80316 .52591 m .78925 .53261 L .79719 .59032 L p 0 .114 0 r
F P
0 g
s
.74133 .4496 m .75492 .44235 L .71239 .41213 L p 0 .914 0 r
F P
0 g
s
.71239 .41213 m .69872 .41979 L .74133 .4496 L p 0 .914 0 r
F P
0 g
s
.75492 .44235 m .74133 .4496 L .74796 .50508 L p 0 .1 0 r
F P
0 g
s
.74133 .4496 m .75492 .44235 L .76197 .49801 L p 0 .1 0 r
F P
0 g
s
.76197 .49801 m .74796 .50508 L .74133 .4496 L p 0 .1 0 r
F P
0 g
s
.80316 .52591 m .78925 .53261 L .74796 .50508 L p 0 .916 0 r
F P
0 g
s
.58742 .59676 m .60024 .59036 L .64548 .61561 L p 0 .916 0 r
F P
0 g
s
.65843 .60947 m .64548 .61561 L .60024 .59036 L p 0 .916 0 r
F P
0 g
s
.59756 .53261 m .61018 .52591 L .61323 .58388 L p 0 .1 0 r
F P
0 g
s
.61323 .58388 m .60024 .59036 L .59756 .53261 L p 0 .1 0 r
F P
0 g
s
.74796 .50508 m .74133 .4496 L .69872 .41979 L p 0 .638 0 r
F P
0 g
s
.74796 .50508 m .76197 .49801 L .75492 .44235 L p 0 .1 0 r
F P
0 g
s
.69872 .41979 m .70433 .47599 L .74796 .50508 L p 0 .638 0 r
F P
0 g
s
.74796 .50508 m .76197 .49801 L .71843 .46851 L p 0 .916 0 r
F P
0 g
s
.76197 .49801 m .74796 .50508 L .70433 .47599 L p 0 .916 0 r
F P
0 g
s
.79719 .59032 m .78925 .53261 L .74796 .50508 L p 0 .638 0 r
F P
0 g
s
.68523 .59676 m .69872 .59036 L .7413 .6156 L p 0 .916 1 r
F P
0 g
s
.75489 .60946 m .7413 .6156 L .69872 .59036 L p 0 .916 1 r
F P
0 g
s
.80147 .18082 m .7899 .18831 L .79787 .23662 L p 0 .1 .423 r
F P
0 g
s
.7899 .18831 m .80147 .18082 L .76027 .1434 L p 0 .903 1 r
F P
0 g
s
.76027 .1434 m .74861 .1513 L .7899 .18831 L p 0 .903 1 r
F P
0 g
s
.79787 .23662 m .7899 .18831 L .74861 .1513 L p 0 .599 .205 r
F P
0 g
s
.74928 .27105 m .75613 .32165 L .74679 .32718 L p 0 .1 .425 r
F P
0 g
s
.74928 .27105 m .75613 .32165 L .79723 .3541 L p 0 .618 .247 r
F P
0 g
s
.4489 .50305 m .49829 .53069 L p .45031 .44755 L 0 .673 .397 r
F P
0 g
s
.45031 .44755 m .45027 .44757 L .4489 .50305 L p 0 .673 .397 r
F P
0 g
s
.45027 .44757 m .45031 .44755 L .46197 .44027 L p 0 .93 .764 r
F P
0 g
s
.4489 .50305 m .49829 .53069 L p .45031 .44755 L 0 .673 .397 r
F P
0 g
s
.45031 .44755 m .45027 .44757 L .4489 .50305 L p 0 .673 .397 r
F P
0 g
s
.3653 .60771 m .35428 .61387 L .35424 .61381 L p 0 .525 .891 r
F P
0 g
s
.35424 .61381 m .36526 .60765 L .3653 .60771 L p 0 .525 .891 r
F P
0 g
s
.49829 .53069 m .49824 .58851 L .48609 .59493 L p 0 .1 .396 r
F P
0 g
s
.49829 .53069 m .49824 .58851 L .5463 .61386 L p 0 .673 .397 r
F P
0 g
s
.49829 .53069 m .49824 .58851 L .5463 .61386 L p 0 .673 .397 r
F P
0 g
s
.5463 .61386 m .49824 .58851 L .51056 .582 L p 0 .916 1 r
F P
0 g
s
.51056 .582 m .55861 .60769 L .5463 .61386 L p 0 .916 1 r
F P
0 g
s
.49824 .58851 m .49829 .53069 L .51027 .52397 L p 0 .1 .396 r
F P
0 g
s
.49829 .53069 m .4489 .50305 L .46088 .49595 L p 0 .916 1 r
F P
0 g
s
.46088 .49595 m .51027 .52397 L .49829 .53069 L p 0 .916 1 r
F P
0 g
s
.49829 .53069 m .4489 .50305 L .43708 .51005 L p 0 .916 1 r
F P
0 g
s
.49824 .58851 m .49829 .53069 L .4489 .50305 L p 0 .673 .397 r
F P
0 g
s
.4489 .50305 m .49829 .53069 L .51027 .52397 L p 0 .916 1 r
F P
0 g
s
.49829 .53069 m .49824 .58851 L .51056 .582 L p 0 .1 .396 r
F P
0 g
s
.51056 .582 m .51027 .52397 L .49829 .53069 L p 0 .1 .396 r
F P
0 g
s
.49824 .58851 m .49829 .53069 L .4489 .50305 L p 0 .673 .397 r
F P
0 g
s
.64233 .44753 m .59691 .4176 L .58409 .42518 L p 0 .914 1 r
F P
0 g
s
.64625 .50305 m .64233 .44753 L .59691 .4176 L p 0 .652 .333 r
F P
0 g
s
.59691 .4176 m .64233 .44753 L .65528 .44025 L p 0 .914 1 r
F P
0 g
s
.64233 .44753 m .64625 .50305 L .65959 .49595 L p 0 .1 .423 r
F P
0 g
s
.65959 .49595 m .65528 .44025 L .64233 .44753 L p 0 .1 .423 r
F P
0 g
s
.64625 .50305 m .64233 .44753 L .59691 .4176 L p 0 .652 .333 r
F P
0 g
s
.5463 .44753 m .54757 .50305 L .53509 .51005 L p 0 .1 0 r
F P
0 g
s
.5463 .44753 m .54757 .50305 L .59432 .53069 L p 0 .663 0 r
F P
0 g
s
.5463 .44753 m .54757 .50305 L .59432 .53069 L p 0 .663 0 r
F P
0 g
s
.59432 .53069 m .54757 .50305 L .56023 .49595 L p 0 .916 0 r
F P
0 g
s
.56023 .49595 m .60694 .52397 L .59432 .53069 L p 0 .916 0 r
F P
0 g
s
.54757 .50305 m .5463 .44753 L .55861 .44025 L p 0 .1 0 r
F P
0 g
s
.59432 .53069 m .54757 .50305 L .53509 .51005 L p 0 .916 0 r
F P
0 g
s
.59691 .58851 m .59432 .53069 L .54757 .50305 L p 0 .663 0 r
F P
0 g
s
.54757 .50305 m .59432 .53069 L .60694 .52397 L p 0 .916 0 r
F P
0 g
s
.59432 .53069 m .59691 .58851 L .60991 .582 L p 0 .1 0 r
F P
0 g
s
.60991 .582 m .60694 .52397 L .59432 .53069 L p 0 .1 0 r
F P
0 g
s
.59691 .58851 m .59432 .53069 L .54757 .50305 L p 0 .663 0 r
F P
0 g
s
.5463 .44753 m .49827 .41762 L .48612 .4252 L p 0 .914 0 r
F P
0 g
s
.54757 .50305 m .5463 .44753 L .49827 .41762 L p 0 .663 0 r
F P
0 g
s
.54757 .50305 m .5463 .44753 L .49827 .41762 L p 0 .663 0 r
F P
0 g
s
.49827 .41762 m .5463 .44753 L .55861 .44025 L p 0 .914 0 r
F P
0 g
s
.5463 .44753 m .54757 .50305 L .56023 .49595 L p 0 .1 0 r
F P
0 g
s
.56023 .49595 m .55861 .44025 L .5463 .44753 L p 0 .1 0 r
F P
0 g
s
.38812 .59495 m .3996 .58852 L .45027 .61386 L p 0 .916 0 r
F P
0 g
s
.3996 .58852 m .45027 .61386 L p .40226 .53069 L 0 .681 0 r
F P
0 g
s
.40226 .53069 m .39957 .58846 L .3996 .58852 L p 0 .681 0 r
F P
0 g
s
.39957 .58846 m .40226 .53069 L .4136 .52397 L p 0 .1 0 r
F P
0 g
s
.45027 .61386 m .3996 .58852 L .41124 .58201 L p 0 .916 0 r
F P
0 g
s
.41124 .58201 m .46194 .60769 L .45027 .61386 L p 0 .916 0 r
F P
0 g
s
.45027 .44757 m .4489 .50305 L .43708 .51005 L p 0 .1 .365 r
F P
0 g
s
.46197 .44027 m .46193 .44029 L .45027 .44757 L p 0 .93 .764 r
F P
0 g
s
.4489 .50305 m .45027 .44757 L .46193 .44029 L p 0 .1 .365 r
F P
0 g
s
.74376 .32481 m .75311 .31926 L .74632 .26863 L p 0 .1 .423 r
F P
0 g
s
.69462 .2397 m .70375 .23376 L .74632 .26863 L p 0 .907 1 r
F P
0 g
s
.75311 .31926 m .74632 .26863 L .70375 .23376 L p 0 .618 .247 r
F P
0 g
s
.69828 .18542 m .70375 .23376 L .74632 .26863 L p 0 .618 .247 r
F P
0 g
s
.69462 .2397 m .70375 .23376 L .69828 .18542 L p 0 .1 .396 r
F P
0 g
s
.70375 .23376 m .69828 .18542 L .65441 .14828 L p 0 .618 .247 r
F P
0 g
s
.90055 .35005 m .90053 .35006 L .91276 .34345 L p 0 .1 .1 r
F P
0 g
s
.85245 .26675 m .81273 .23177 L .8008 .23916 L p 0 .907 1 r
F P
0 g
s
.85245 .26675 m .86217 .31741 L .84996 .32431 L p 0 .1 .45 r
F P
0 g
s
.86217 .31741 m .85245 .26675 L .81273 .23177 L p 0 .594 .194 r
F P
0 g
s
.80433 .18342 m .81273 .23177 L .85245 .26675 L p 0 .594 .194 r
F P
0 g
s
.80433 .18342 m .81273 .23177 L .85245 .26675 L p 0 .594 .194 r
F P
0 g
s
.81273 .23177 m .85245 .26675 L .86441 .25968 L p 0 .907 1 r
F P
0 g
s
.85245 .26675 m .86217 .31741 L .90053 .35006 L p 0 .594 .194 r
F P
0 g
s
.85245 .26675 m .86217 .31741 L .90053 .35006 L p 0 .594 .194 r
F P
0 g
s
.85245 .26675 m .86217 .31741 L .87452 .31043 L p 0 .1 .45 r
F P
0 g
s
.87452 .31043 m .86441 .25968 L .85245 .26675 L p 0 .1 .45 r
F P
0 g
s
.86217 .31741 m .85245 .26675 L .81273 .23177 L p 0 .594 .194 r
F P
0 g
s
.85245 .26675 m .81273 .23177 L .8248 .2243 L p 0 .907 1 r
F P
0 g
s
.8248 .2243 m .86441 .25968 L .85245 .26675 L p 0 .907 1 r
F P
0 g
s
.86217 .31741 m .85245 .26675 L .86441 .25968 L p 0 .1 .45 r
F P
0 g
s
.80433 .18342 m .81273 .23177 L .8008 .23916 L p 0 .1 .425 r
F P
0 g
s
.81273 .23177 m .80433 .18342 L .81603 .17588 L p 0 .1 .425 r
F P
0 g
s
.90053 .35006 m .86217 .31741 L .87452 .31043 L p 0 .911 1 r
F P
0 g
s
.87452 .31043 m .91276 .34345 L .90053 .35006 L p 0 .911 1 r
F P
0 g
s
.84623 .50518 m .85607 .50044 L .84651 .44489 L p 0 .114 .472 r
F P
0 g
s
.84651 .44489 m .84647 .44483 L .8066 .41477 L p 0 .618 .247 r
F P
0 g
s
.85607 .50044 m .84651 .44489 L p .8066 .41477 L 0 .618 .247 r
F P
0 g
s
.60657 .18236 m .60654 .18237 L p .65468 .26574 L 0 .634 0 r
F P
0 g
s
.60657 .18236 m .61931 .17328 L .61928 .17329 L p 0 1 0 r
F P
0 g
s
.61928 .17329 m .60654 .18237 L .60657 .18236 L p 0 1 0 r
F P
0 g
s
.60657 .18236 m .60654 .18237 L p .65468 .26574 L 0 .634 0 r
F P
0 g
s
.51023 .3491 m .52233 .34114 L .52237 .3412 L p 0 .546 0 r
F P
0 g
s
.52237 .3412 m .51027 .34916 L .51023 .3491 L p 0 .546 0 r
F P
0 g
s
.64568 .32469 m .65896 .3164 L .70284 .34914 L p 0 .911 0 r
F P
0 g
s
.65468 .26574 m .65896 .3164 L .70284 .34914 L p 0 .634 0 r
F P
0 g
s
.65468 .26574 m .65896 .3164 L .70284 .34914 L p 0 .634 0 r
F P
0 g
s
.71623 .34118 m .70284 .34914 L .65896 .3164 L p 0 .911 0 r
F P
0 g
s
.65468 .26574 m .66776 .25722 L .67242 .308 L p 0 .1 0 r
F P
0 g
s
.67242 .308 m .65896 .3164 L .65468 .26574 L p 0 .1 0 r
F P
0 g
s
.64568 .32469 m .65896 .3164 L .65468 .26574 L p 0 .1 0 r
F P
0 g
s
.59653 .23958 m .60948 .2307 L .65468 .26574 L p 0 .907 0 r
F P
0 g
s
.65896 .3164 m .65468 .26574 L .60948 .2307 L p 0 .634 0 r
F P
0 g
s
.66776 .25722 m .65468 .26574 L .65896 .3164 L p 0 .1 0 r
F P
0 g
s
.60654 .18237 m .60948 .2307 L .65468 .26574 L p 0 .634 0 r
F P
0 g
s
.60654 .18237 m .60948 .2307 L .65468 .26574 L p 0 .634 0 r
F P
0 g
s
.65468 .26574 m .66776 .25722 L .6226 .2217 L p 0 .907 0 r
F P
0 g
s
.6226 .2217 m .60948 .2307 L .65468 .26574 L p 0 .907 0 r
F P
0 g
s
.65896 .3164 m .65468 .26574 L .60948 .2307 L p 0 .634 0 r
F P
0 g
s
.66776 .25722 m .65468 .26574 L .60948 .2307 L p 0 .907 0 r
F P
0 g
s
.54742 .32472 m .56003 .31643 L .60653 .34914 L p 0 .911 1 r
F P
0 g
s
.55999 .31637 m .56003 .31643 L .60653 .34914 L p 0 .648 .324 r
F P
0 g
s
.55838 .26574 m .55999 .31637 L p .60653 .34914 L 0 .648 .324 r
F P
0 g
s
.55999 .31637 m .56003 .31643 L .60653 .34914 L p 0 .648 .324 r
F P
0 g
s
.55838 .26574 m .55999 .31637 L p .60653 .34914 L 0 .648 .324 r
F P
0 g
s
.61928 .34118 m .60653 .34914 L .56003 .31643 L p 0 .911 1 r
F P
0 g
s
.55838 .26574 m .57081 .25722 L .57277 .30796 L p 0 .1 .365 r
F P
0 g
s
.57277 .30796 m .55999 .31637 L .55838 .26574 L p 0 .1 .365 r
F P
0 g
s
.60654 .18237 m .61928 .17329 L .6226 .2217 L p 0 .1 0 r
F P
0 g
s
.6226 .2217 m .60948 .2307 L .60654 .18237 L p 0 .1 0 r
F P
0 g
s
.79787 .23662 m .80981 .2292 L .80147 .18082 L p 0 .1 .423 r
F P
0 g
s
.80981 .2292 m .80147 .18082 L .76027 .1434 L p 0 .594 .194 r
F P
0 g
s
.81318 .17326 m .80147 .18082 L .80981 .2292 L p 0 .1 .423 r
F P
0 g
s
.80147 .18082 m .81318 .17326 L .77206 .13541 L p 0 .903 1 r
F P
0 g
s
.77206 .13541 m .76027 .1434 L .80147 .18082 L p 0 .903 1 r
F P
0 g
s
.80981 .2292 m .80147 .18082 L .76027 .1434 L p 0 .594 .194 r
F P
0 g
s
.65843 .44235 m .67155 .43501 L .67633 .49084 L p 0 .1 .425 r
F P
0 g
s
.67633 .49084 m .66281 .49801 L .65843 .44235 L p 0 .1 .425 r
F P
0 g
s
.76197 .49801 m .75492 .44235 L .71239 .41213 L p 0 .634 0 r
F P
0 g
s
.75492 .44235 m .76869 .43501 L .72625 .40437 L p 0 .914 0 r
F P
0 g
s
.72625 .40437 m .72299 .4062 L .75492 .44235 L p 0 .914 0 r
F P
0 g
s
.76869 .43501 m .75492 .44235 L .76197 .49801 L p 0 .1 0 r
F P
0 g
s
.76197 .49801 m .75492 .44235 L .71239 .41213 L p 0 .634 0 r
F P
0 g
s
.75492 .44235 m .76869 .43501 L .77617 .49084 L p 0 .1 0 r
F P
0 g
s
.77617 .49084 m .76197 .49801 L .75492 .44235 L p 0 .1 0 r
F P
0 g
s
.76197 .49801 m .77617 .49084 L .76869 .43501 L p 0 .1 0 r
F P
0 g
s
.74796 .50508 m .76197 .49801 L .80316 .52591 L p 0 .916 0 r
F P
0 g
s
.81725 .51913 m .80316 .52591 L .76197 .49801 L p 0 .916 0 r
F P
0 g
s
.79719 .59032 m .81154 .58384 L .80316 .52591 L p 0 .114 0 r
F P
0 g
s
.81154 .58384 m .80316 .52591 L .76197 .49801 L p 0 .634 0 r
F P
0 g
s
.80316 .52591 m .81725 .51913 L .77617 .49084 L p 0 .916 0 r
F P
0 g
s
.77617 .49084 m .76197 .49801 L .80316 .52591 L p 0 .916 0 r
F P
0 g
s
.76197 .49801 m .77617 .49084 L .81725 .51913 L p 0 .916 0 r
F P
0 g
s
.81154 .58384 m .80316 .52591 L .76197 .49801 L p 0 .634 0 r
F P
0 g
s
.81154 .58384 m .79719 .59032 L .79717 .59034 L p 0 .1 0 r
F P
0 g
s
.79717 .59034 m .81152 .58386 L .81154 .58384 L p 0 .1 0 r
F P
0 g
s
.81152 .58386 m .81154 .58384 L p .76197 .49801 L 0 .634 0 r
F P
0 g
s
.81152 .58386 m .81154 .58384 L p .76197 .49801 L 0 .634 0 r
F P
0 g
s
.79717 .59034 m .79719 .59032 L p .74796 .50508 L 0 .638 0 r
F P
0 g
s
.74796 .50508 m .75497 .56368 L .79717 .59034 L p 0 .638 0 r
F P
0 g
s
.74796 .50508 m .75497 .56368 L .79717 .59034 L p 0 .638 0 r
F P
0 g
s
.75497 .56368 m .76942 .55683 L .81152 .58386 L p 0 .916 0 r
F P
0 g
s
.81152 .58386 m .79717 .59034 L .75497 .56368 L p 0 .916 0 r
F P
0 g
s
.76197 .49801 m .76942 .55683 L .81152 .58386 L p 0 .634 0 r
F P
0 g
s
.76197 .49801 m .76942 .55683 L .81152 .58386 L p 0 .634 0 r
F P
0 g
s
.81725 .51913 m .80316 .52591 L .81154 .58384 L p 0 .114 0 r
F P
0 g
s
.81154 .58384 m .82609 .57726 L .81725 .51913 L p 0 .114 0 r
F P
0 g
s
.82609 .57726 m .81154 .58384 L .81152 .58386 L p 0 .1 0 r
F P
0 g
s
.81152 .58386 m .82606 .57729 L .82609 .57726 L p 0 .1 0 r
F P
0 g
s
.82606 .57729 m .82609 .57726 L p .77617 .49084 L 0 .63 .275 r
F P
0 g
s
.78977 .51438 m .82609 .57726 L .78759 .4987 L 0 .63 .275 r
F
.77617 .49084 m .78408 .54987 L .82606 .57729 L p F P
0 g
s
.77617 .49084 m .78408 .54987 L p .82606 .57729 L 0 .63 0 r
F P
0 g
s
.82609 .57726 m .81725 .51913 L .78759 .4987 L p 0 .63 .275 r
F P
0 g
s
.82682 .51452 m .81725 .51913 L .82609 .57726 L p 0 .114 .472 r
F P
0 g
s
.78759 .4987 m .77617 .49084 L p .78977 .51438 L 0 .63 .275 r
F P
0 g
s
.82609 .57726 m .81725 .51913 L .77617 .49084 L p 0 .63 0 r
F P
0 g
s
.78582 .48597 m .77617 .49084 L .81725 .51913 L p 0 .916 1 r
F P
0 g
s
.77617 .49084 m .78582 .48597 L .82682 .51452 L p 0 .916 1 r
F P
0 g
s
.82606 .57729 m .82609 .57726 L p .77617 .49084 L 0 .63 0 r
F P
0 g
s
.78582 .48597 m .77617 .49084 L .78408 .54987 L p 0 .1 .45 r
F P
0 g
s
.82609 .57726 m .83597 .5728 L .82682 .51452 L p 0 .114 .472 r
F P
0 g
s
.83597 .5728 m .82609 .57726 L .82606 .57729 L p 0 .1 .1 r
F P
0 g
s
.82606 .57729 m .83594 .57282 L .83597 .5728 L p 0 .1 .1 r
F P
0 g
s
.83594 .57282 m .82606 .57729 L .78408 .54987 L p 0 .916 1 r
F P
0 g
s
.78408 .54987 m .82606 .57729 L p .82606 .57729 L 0 .63 0 r
F P
0 g
s
.78408 .54987 m .78408 .54987 L p .82606 .57729 L 0 .63 0 r
F P
0 g
s
.79405 .54515 m .78408 .54987 L .77617 .49084 L p 0 .1 .45 r
F P
0 g
s
.77617 .49084 m .78582 .48597 L .79405 .54515 L p 0 .1 .45 r
F P
0 g
s
.71239 .41213 m .71843 .46851 L .76197 .49801 L p 0 .634 0 r
F P
0 g
s
.71239 .41213 m .71843 .46851 L .76197 .49801 L p 0 .634 0 r
F P
0 g
s
.77617 .49084 m .73273 .46093 L p .73273 .46093 L 0 .63 .275 r
F P
0 g
s
.76197 .49801 m .74796 .50508 L .75497 .56368 L p 0 .1 0 r
F P
0 g
s
.74796 .50508 m .76197 .49801 L .76942 .55683 L p 0 .1 0 r
F P
0 g
s
.76197 .49801 m .77617 .49084 L .78408 .54987 L p 0 .1 0 r
F P
0 g
s
.78408 .54987 m .76942 .55683 L .76197 .49801 L p 0 .1 0 r
F P
0 g
s
.71843 .46851 m .70433 .47599 L .74796 .50508 L p 0 .916 0 r
F P
0 g
s
.76942 .55683 m .75497 .56368 L .74796 .50508 L p 0 .1 0 r
F P
0 g
s
.75497 .56368 m .74796 .50508 L .70433 .47599 L p 0 .638 0 r
F P
0 g
s
.75497 .56368 m .76942 .55683 L .76197 .49801 L p 0 .1 0 r
F P
0 g
s
.70433 .47599 m .71028 .53545 L .75497 .56368 L p 0 .638 0 r
F P
0 g
s
.71028 .53545 m .72483 .52819 L .76942 .55683 L p 0 .916 0 r
F P
0 g
s
.76942 .55683 m .75497 .56368 L .71028 .53545 L p 0 .916 0 r
F P
0 g
s
.70433 .47599 m .71843 .46851 L .76197 .49801 L p 0 .916 0 r
F P
0 g
s
.76942 .55683 m .76197 .49801 L .71843 .46851 L p 0 .634 0 r
F P
0 g
s
.73273 .46093 m .72936 .46271 L .76197 .49801 L p 0 .916 0 r
F P
0 g
s
.77617 .49084 m .76197 .49801 L .76942 .55683 L p 0 .1 0 r
F P
0 g
s
.76942 .55683 m .76197 .49801 L .71843 .46851 L p 0 .634 0 r
F P
0 g
s
.77617 .49084 m .76197 .49801 L .71843 .46851 L p 0 .916 0 r
F P
0 g
s
.71843 .46851 m .73273 .46093 L .77617 .49084 L p 0 .916 0 r
F P
0 g
s
.76942 .55683 m .78408 .54987 L .77617 .49084 L p 0 .1 0 r
F P
0 g
s
.71843 .46851 m .72483 .52819 L .76942 .55683 L p 0 .634 0 r
F P
0 g
s
.71843 .46851 m .72483 .52819 L .76942 .55683 L p 0 .634 0 r
F P
0 g
s
.73273 .46093 m .7396 .52082 L .78408 .54987 L p 0 .63 .275 r
F P
0 g
s
.73273 .46093 m .7396 .52082 L p .78408 .54987 L 0 .63 0 r
F P
0 g
s
.78408 .54987 m .78278 .54011 L p .77694 .53751 L 0 .63 .275 r
F P
0 g
s
.78278 .54011 m .77617 .49084 L p .77694 .53751 L 0 .63 .275 r
F P
0 g
s
.76197 .49801 m .77617 .49084 L .73273 .46093 L p 0 .916 0 r
F P
0 g
s
.73273 .46093 m .77694 .53751 L .77617 .49084 L 0 .63 .275 r
F
.78408 .54987 m .77617 .49084 L .73273 .46093 L p 0 .63 0 r
F P
0 g
s
.78408 .54987 m .79405 .54515 L .78582 .48597 L p 0 .1 .45 r
F P
0 g
s
.79405 .54515 m .78408 .54987 L .7396 .52082 L p 0 .916 1 r
F P
0 g
s
.7396 .52082 m .78408 .54987 L p .78408 .54987 L 0 .63 0 r
F P
0 g
s
.7396 .52082 m .7396 .52082 L p .78408 .54987 L 0 .63 0 r
F P
0 g
s
.74964 .51581 m .7396 .52082 L p .73273 .46093 L 0 .1 .425 r
F P
0 g
s
.77617 .49084 m .77617 .49084 L p .73273 .46093 L 0 .63 .275 r
F P
0 g
s
.72625 .40437 m .73273 .46093 L .77617 .49084 L p 0 .63 .275 r
F P
0 g
s
.73273 .46093 m .77617 .49084 L p .77617 .49084 L 0 .63 0 r
F P
0 g
s
.72625 .40437 m .73273 .46093 L p .77617 .49084 L 0 .63 0 r
F P
0 g
s
.74245 .45578 m .73273 .46093 L .72625 .40437 L p 0 .1 .425 r
F P
0 g
s
.73273 .46093 m .73273 .46093 L p .77617 .49084 L 0 .63 0 r
F P
0 g
s
.74245 .45578 m .73273 .46093 L p .77617 .49084 L 0 .916 1 r
F P
0 g
s
.77617 .49084 m .77482 .48078 L p .7687 .47789 L 0 .63 .275 r
F P
0 g
s
.77482 .48078 m .76869 .43501 L p .7687 .47789 L 0 .63 .275 r
F P
0 g
s
.76869 .43501 m .72625 .40437 L p .7687 .47789 L 0 .63 .275 r
F P
0 g
s
.77617 .49084 m .76869 .43501 L .72625 .40437 L p 0 .63 0 r
F P
0 g
s
.77617 .49084 m .78582 .48597 L .77804 .43002 L p 0 .1 .45 r
F P
0 g
s
.78582 .48597 m .77617 .49084 L .73273 .46093 L p 0 .916 1 r
F P
0 g
s
.73273 .46093 m .74245 .45578 L .78582 .48597 L p 0 .916 1 r
F P
0 g
s
.73273 .46093 m .74245 .45578 L .74964 .51581 L p 0 .1 .425 r
F P
0 g
s
.77617 .49084 m .78582 .48597 L .74245 .45578 L p 0 .916 1 r
F P
0 g
s
.73566 .3991 m .72625 .40437 L .76869 .43501 L p 0 .914 1 r
F P
0 g
s
.72625 .40437 m .73566 .3991 L .74245 .45578 L p 0 .1 .425 r
F P
0 g
s
.60024 .59036 m .61323 .58388 L .65843 .60947 L p 0 .916 0 r
F P
0 g
s
.67155 .60325 m .65843 .60947 L .61323 .58388 L p 0 .916 0 r
F P
0 g
s
.61018 .52591 m .62298 .51913 L .62641 .5773 L p 0 .1 0 r
F P
0 g
s
.62641 .5773 m .61323 .58388 L .61018 .52591 L p 0 .1 0 r
F P
0 g
s
.69872 .59036 m .71239 .58388 L .75489 .60946 L p 0 .916 1 r
F P
0 g
s
.76866 .60323 m .75489 .60946 L .71239 .58388 L p 0 .916 1 r
F P
0 g
s
.46193 .44029 m .46197 .44027 L .47379 .43289 L p 0 .93 .764 r
F P
0 g
s
.46088 .49595 m .51027 .52397 L p .46197 .44027 L 0 .671 .39 r
F P
0 g
s
.46197 .44027 m .46193 .44029 L .46088 .49595 L p 0 .671 .39 r
F P
0 g
s
.46088 .49595 m .51027 .52397 L p .46197 .44027 L 0 .671 .39 r
F P
0 g
s
.46197 .44027 m .46193 .44029 L .46088 .49595 L p 0 .671 .39 r
F P
0 g
s
.37647 .60146 m .3653 .60771 L .36526 .60765 L p 0 .525 .891 r
F P
0 g
s
.36526 .60765 m .37644 .6014 L .37647 .60146 L p 0 .525 .891 r
F P
0 g
s
.51027 .52397 m .46088 .49595 L .47302 .48876 L p 0 .916 1 r
F P
0 g
s
.47302 .48876 m .52242 .51716 L .51027 .52397 L p 0 .916 1 r
F P
0 g
s
.51027 .52397 m .51056 .582 L .49824 .58851 L p 0 .1 .396 r
F P
0 g
s
.51027 .52397 m .51056 .582 L .55861 .60769 L p 0 .671 .39 r
F P
0 g
s
.51027 .52397 m .51056 .582 L .55861 .60769 L p 0 .671 .39 r
F P
0 g
s
.55861 .60769 m .51056 .582 L .52305 .5754 L p 0 .916 1 r
F P
0 g
s
.52305 .5754 m .57108 .60144 L .55861 .60769 L p 0 .916 1 r
F P
0 g
s
.51056 .582 m .51027 .52397 L .52242 .51716 L p 0 .1 .396 r
F P
0 g
s
.51027 .52397 m .46088 .49595 L .4489 .50305 L p 0 .916 1 r
F P
0 g
s
.51056 .582 m .51027 .52397 L .46088 .49595 L p 0 .671 .39 r
F P
0 g
s
.46088 .49595 m .51027 .52397 L .52242 .51716 L p 0 .916 1 r
F P
0 g
s
.51027 .52397 m .51056 .582 L .52305 .5754 L p 0 .1 .396 r
F P
0 g
s
.52305 .5754 m .52242 .51716 L .51027 .52397 L p 0 .1 .396 r
F P
0 g
s
.51056 .582 m .51027 .52397 L .46088 .49595 L p 0 .671 .39 r
F P
0 g
s
.65528 .44025 m .60991 .40991 L .59691 .4176 L p 0 .914 1 r
F P
0 g
s
.65959 .49595 m .65528 .44025 L .60991 .40991 L p 0 .648 .324 r
F P
0 g
s
.60991 .40991 m .65528 .44025 L .66841 .43287 L p 0 .914 1 r
F P
0 g
s
.65528 .44025 m .65959 .49595 L .67311 .48876 L p 0 .1 .423 r
F P
0 g
s
.67311 .48876 m .66841 .43287 L .65528 .44025 L p 0 .1 .423 r
F P
0 g
s
.65959 .49595 m .65528 .44025 L .60991 .40991 L p 0 .648 .324 r
F P
0 g
s
.55861 .44025 m .56023 .49595 L .54757 .50305 L p 0 .1 0 r
F P
0 g
s
.55861 .44025 m .56023 .49595 L .60694 .52397 L p 0 .661 0 r
F P
0 g
s
.55861 .44025 m .56023 .49595 L .60694 .52397 L p 0 .661 0 r
F P
0 g
s
.60694 .52397 m .56023 .49595 L .57307 .48876 L p 0 .916 0 r
F P
0 g
s
.57307 .48876 m .61974 .51716 L .60694 .52397 L p 0 .916 0 r
F P
0 g
s
.56023 .49595 m .55861 .44025 L .57108 .43287 L p 0 .1 0 r
F P
0 g
s
.60694 .52397 m .56023 .49595 L .54757 .50305 L p 0 .916 0 r
F P
0 g
s
.60991 .582 m .60694 .52397 L .56023 .49595 L p 0 .661 0 r
F P
0 g
s
.56023 .49595 m .60694 .52397 L .61974 .51716 L p 0 .916 0 r
F P
0 g
s
.60694 .52397 m .60991 .582 L .62309 .5754 L p 0 .1 0 r
F P
0 g
s
.62309 .5754 m .61974 .51716 L .60694 .52397 L p 0 .1 0 r
F P
0 g
s
.60991 .582 m .60694 .52397 L .56023 .49595 L p 0 .661 0 r
F P
0 g
s
.55861 .44025 m .51059 .40993 L .49827 .41762 L p 0 .914 0 r
F P
0 g
s
.56023 .49595 m .55861 .44025 L .51059 .40993 L p 0 .661 0 r
F P
0 g
s
.51059 .40993 m .55861 .44025 L .57108 .43287 L p 0 .914 0 r
F P
0 g
s
.55861 .44025 m .56023 .49595 L .57307 .48876 L p 0 .1 0 r
F P
0 g
s
.57307 .48876 m .57108 .43287 L .55861 .44025 L p 0 .1 0 r
F P
0 g
s
.56023 .49595 m .55861 .44025 L .51059 .40993 L p 0 .661 0 r
F P
0 g
s
.4136 .52397 m .41121 .58195 L .39957 .58846 L p 0 .1 0 r
F P
0 g
s
.41124 .58201 m .46194 .60769 L p .4136 .52397 L 0 .679 0 r
F P
0 g
s
.4136 .52397 m .41121 .58195 L .41124 .58201 L p 0 .679 0 r
F P
0 g
s
.41124 .58201 m .46194 .60769 L p .4136 .52397 L 0 .679 0 r
F P
0 g
s
.4136 .52397 m .41121 .58195 L .41124 .58201 L p 0 .679 0 r
F P
0 g
s
.46194 .60769 m .41124 .58201 L .42304 .57542 L p 0 .916 0 r
F P
0 g
s
.42304 .57542 m .47376 .60144 L .46194 .60769 L p 0 .916 0 r
F P
0 g
s
.41121 .58195 m .4136 .52397 L .42509 .51716 L p 0 .1 0 r
F P
0 g
s
.47379 .43289 m .47376 .43291 L .46193 .44029 L p 0 .93 .764 r
F P
0 g
s
.46088 .49595 m .46193 .44029 L .47376 .43291 L p 0 .1 .365 r
F P
0 g
s
.46193 .44029 m .46088 .49595 L .4489 .50305 L p 0 .1 .365 r
F P
0 g
s
.76699 .26009 m .77439 .31083 L .81535 .34386 L p 0 .612 0 r
F P
0 g
s
.81535 .34386 m .77439 .31083 L .78857 .30243 L p 0 .911 0 r
F P
0 g
s
.78857 .30243 m .82942 .33591 L .81535 .34386 L p 0 .911 0 r
F P
0 g
s
.77439 .31083 m .76699 .26009 L .78073 .25158 L p 0 .1 0 r
F P
0 g
s
.86441 .25968 m .8248 .2243 L .81273 .23177 L p 0 .907 1 r
F P
0 g
s
.86441 .25968 m .87452 .31043 L .86217 .31741 L p 0 .1 .45 r
F P
0 g
s
.87452 .31043 m .86441 .25968 L .8248 .2243 L p 0 .59 .184 r
F P
0 g
s
.81603 .17588 m .8248 .2243 L .86441 .25968 L p 0 .59 .184 r
F P
0 g
s
.86441 .25968 m .87452 .31043 L .91276 .34345 L p 0 .59 .184 r
F P
0 g
s
.81603 .17588 m .8248 .2243 L .81273 .23177 L p 0 .1 .425 r
F P
0 g
s
.77779 .24909 m .76404 .25763 L .77138 .3084 L p 0 .1 0 r
F P
0 g
s
.71558 .17369 m .72158 .22214 L .76404 .25763 L p 0 .612 0 r
F P
0 g
s
.76404 .25763 m .77779 .24909 L .73542 .21311 L p 0 .907 0 r
F P
0 g
s
.73542 .21311 m .72158 .22214 L .76404 .25763 L p 0 .907 0 r
F P
0 g
s
.77138 .3084 m .76404 .25763 L .72158 .22214 L p 0 .612 0 r
F P
0 g
s
.77779 .24909 m .76404 .25763 L .72158 .22214 L p 0 .907 0 r
F P
0 g
s
.71558 .17369 m .72901 .16459 L .73542 .21311 L p 0 .1 0 r
F P
0 g
s
.73542 .21311 m .72158 .22214 L .71558 .17369 L p 0 .1 0 r
F P
0 g
s
.72901 .16459 m .71558 .17369 L .72158 .22214 L p 0 .1 0 r
F P
0 g
s
.71558 .17369 m .72901 .16459 L .6853 .12628 L p 0 .903 0 r
F P
0 g
s
.6853 .12628 m .6718 .1359 L .71558 .17369 L p 0 .903 0 r
F P
0 g
s
.72158 .22214 m .71558 .17369 L .6718 .1359 L p 0 .612 0 r
F P
0 g
s
.61931 .17328 m .61928 .17329 L p .66776 .25722 L 0 .63 .275 r
F P
0 g
s
.61931 .17328 m .61928 .17329 L p .66776 .25722 L 0 .63 0 r
F P
0 g
s
.61931 .17328 m .62797 .16712 L .62794 .16712 L p 0 1 .86 r
F P
0 g
s
.62794 .16712 m .61928 .17329 L .61931 .17328 L p 0 1 .86 r
F P
0 g
s
.65896 .3164 m .67242 .308 L .71623 .34118 L p 0 .911 0 r
F P
0 g
s
.66776 .25722 m .67242 .308 L .71623 .34118 L p 0 .63 .275 r
F P
0 g
s
.66776 .25722 m .67242 .308 L .71623 .34118 L p 0 .63 0 r
F P
0 g
s
.65896 .3164 m .67242 .308 L .66776 .25722 L p 0 .1 0 r
F P
0 g
s
.60948 .2307 m .6226 .2217 L .66776 .25722 L p 0 .907 0 r
F P
0 g
s
.67242 .308 m .66776 .25722 L .6226 .2217 L p 0 .63 .275 r
F P
0 g
s
.67242 .308 m .66776 .25722 L .6226 .2217 L p 0 .63 0 r
F P
0 g
s
.61928 .17329 m .6226 .2217 L .66776 .25722 L p 0 .63 .275 r
F P
0 g
s
.61928 .17329 m .6226 .2217 L .66776 .25722 L p 0 .63 0 r
F P
0 g
s
.80981 .2292 m .82189 .2217 L .81318 .17326 L p 0 .1 .423 r
F P
0 g
s
.82189 .2217 m .81318 .17326 L .77206 .13541 L p 0 .59 .184 r
F P
0 g
s
.72532 .33577 m .71623 .34118 L .67242 .308 L p 0 .911 1 r
F P
0 g
s
.66776 .25722 m .67663 .25143 L .68156 .30229 L p 0 .1 .396 r
F P
0 g
s
.68156 .30229 m .67242 .308 L .66776 .25722 L p 0 .1 .396 r
F P
0 g
s
.67663 .25143 m .66776 .25722 L .67242 .308 L p 0 .1 .396 r
F P
0 g
s
.66776 .25722 m .67663 .25143 L .63151 .21559 L p 0 .907 1 r
F P
0 g
s
.63151 .21559 m .6226 .2217 L .66776 .25722 L p 0 .907 1 r
F P
0 g
s
.67663 .25143 m .66776 .25722 L .6226 .2217 L p 0 .907 1 r
F P
0 g
s
.56003 .31643 m .57281 .30802 L .61928 .34118 L p 0 .911 1 r
F P
0 g
s
.57277 .30796 m .57281 .30802 L .61928 .34118 L p 0 .645 .315 r
F P
0 g
s
.57081 .25722 m .57277 .30796 L p .61928 .34118 L 0 .645 .315 r
F P
0 g
s
.61928 .17329 m .62794 .16712 L .63151 .21559 L p 0 .1 .365 r
F P
0 g
s
.63151 .21559 m .6226 .2217 L .61928 .17329 L p 0 .1 .365 r
F P
0 g
s
.52268 .34091 m .53495 .33284 L .53499 .3329 L p 0 .546 .889 r
F P
0 g
s
.53499 .3329 m .52272 .34097 L .52268 .34091 L p 0 .546 .889 r
F P
0 g
s
.57117 .25697 m .57314 .30771 L p .61965 .34095 L 0 .645 0 r
F P
0 g
s
.57117 .25697 m .58376 .24833 L .58611 .29919 L p 0 .1 0 r
F P
0 g
s
.58611 .29919 m .57314 .30771 L .57117 .25697 L p 0 .1 0 r
F P
0 g
s
.57314 .30771 m .57318 .30778 L .61965 .34095 L p 0 .645 0 r
F P
0 g
s
.63258 .33288 m .61965 .34095 L .57318 .30778 L p 0 .911 0 r
F P
0 g
s
.8651 .43534 m .87956 .42797 L .83998 .39696 L p 0 .914 0 r
F P
0 g
s
.83998 .39696 m .82539 .40475 L .8651 .43534 L p 0 .914 0 r
F P
0 g
s
.87959 .42803 m .86513 .4354 L .87529 .49118 L p 0 .114 0 r
F P
0 g
s
.86513 .4354 m .87959 .42803 L .87956 .42797 L p 0 .562 0 r
F P
0 g
s
.87956 .42797 m .8651 .43534 L .86513 .4354 L p 0 .562 0 r
F P
0 g
s
.86513 .4354 m .8651 .43534 L .82539 .40475 L p 0 .612 0 r
F P
0 g
s
.87529 .49118 m .86513 .4354 L p .82539 .40475 L 0 .612 0 r
F P
0 g
s
.76869 .43501 m .77804 .43002 L .73566 .3991 L p 0 .914 1 r
F P
0 g
s
.61323 .58388 m .62641 .5773 L .67155 .60325 L p 0 .916 0 r
F P
0 g
s
.71239 .58388 m .72625 .5773 L .76866 .60323 L p 0 .916 1 r
F P
0 g
s
.62335 .51893 m .63633 .51205 L .64015 .57045 L p 0 .1 .425 r
F P
0 g
s
.64015 .57045 m .62679 .57711 L .62335 .51893 L p 0 .1 .425 r
F P
0 g
s
.68523 .59676 m .67193 .60307 L .62679 .57711 L p 0 .916 1 r
F P
0 g
s
.67193 .43479 m .68523 .42734 L .69043 .48336 L p 0 .1 0 r
F P
0 g
s
.69043 .48336 m .67672 .49063 L .67193 .43479 L p 0 .1 0 r
F P
0 g
s
.78302 .59674 m .76905 .60305 L .72665 .57711 L p 0 .916 0 r
F P
0 g
s
.47302 .48876 m .52242 .51716 L p .47379 .43289 L 0 .668 .382 r
F P
0 g
s
.47379 .43289 m .47376 .43291 L .47302 .48876 L p 0 .668 .382 r
F P
0 g
s
.52242 .51716 m .52305 .5754 L .51056 .582 L p 0 .1 .396 r
F P
0 g
s
.52242 .51716 m .52305 .5754 L .57108 .60144 L p 0 .668 .382 r
F P
0 g
s
.52242 .51716 m .47302 .48876 L .46088 .49595 L p 0 .916 1 r
F P
0 g
s
.52305 .5754 m .52242 .51716 L .47302 .48876 L p 0 .668 .382 r
F P
0 g
s
.66841 .43287 m .62309 .40212 L .60991 .40991 L p 0 .914 1 r
F P
0 g
s
.67311 .48876 m .66841 .43287 L .62309 .40212 L p 0 .645 .315 r
F P
0 g
s
.42509 .51716 m .42301 .57535 L .41121 .58195 L p 0 .1 0 r
F P
0 g
s
.42304 .57542 m .47376 .60144 L p .42509 .51716 L 0 .677 0 r
F P
0 g
s
.42509 .51716 m .42301 .57535 L .42304 .57542 L p 0 .677 0 r
F P
0 g
s
.57108 .43287 m .57307 .48876 L .56023 .49595 L p 0 .1 0 r
F P
0 g
s
.57108 .43287 m .57307 .48876 L .61974 .51716 L p 0 .658 0 r
F P
0 g
s
.61974 .51716 m .57307 .48876 L .56023 .49595 L p 0 .916 0 r
F P
0 g
s
.62309 .5754 m .61974 .51716 L .57307 .48876 L p 0 .658 0 r
F P
0 g
s
.57108 .43287 m .52308 .40214 L .51059 .40993 L p 0 .914 0 r
F P
0 g
s
.57307 .48876 m .57108 .43287 L .52308 .40214 L p 0 .658 0 r
F P
0 g
s
.47376 .43291 m .47302 .48876 L .46088 .49595 L p 0 .1 .365 r
F P
0 g
s
.4741 .4327 m .47413 .43268 L .48612 .4252 L p 0 .93 0 r
F P
0 g
s
.47338 .48855 m .52277 .51696 L p .47413 .43268 L 0 .668 0 r
F P
0 g
s
.47413 .43268 m .4741 .4327 L .47338 .48855 L p 0 .668 0 r
F P
0 g
s
.38812 .59495 m .37679 .60128 L .37676 .60122 L p 0 .525 0 r
F P
0 g
s
.37676 .60122 m .38808 .59489 L .38812 .59495 L p 0 .525 0 r
F P
0 g
s
.42338 .57522 m .4741 .60126 L p .42543 .51696 L 0 .677 .411 r
F P
0 g
s
.4741 .60126 m .42338 .57522 L .43535 .56853 L p 0 .916 1 r
F P
0 g
s
.43535 .56853 m .48609 .59493 L .4741 .60126 L p 0 .916 1 r
F P
0 g
s
.42543 .51696 m .42335 .57516 L .42338 .57522 L p 0 .677 .411 r
F P
0 g
s
.42335 .57516 m .42543 .51696 L .43708 .51005 L p 0 .1 .365 r
F P
0 g
s
.57144 .43266 m .57344 .48855 L .62011 .51696 L p 0 .658 .35 r
F P
0 g
s
.62011 .51696 m .57344 .48855 L .58646 .48125 L p 0 .916 1 r
F P
0 g
s
.58646 .48125 m .63309 .51005 L .62011 .51696 L p 0 .916 1 r
F P
0 g
s
.57344 .48855 m .57144 .43266 L .58409 .42518 L p 0 .1 .396 r
F P
0 g
s
.62347 .5752 m .62011 .51696 L .57344 .48855 L p 0 .658 .35 r
F P
0 g
s
.52344 .40192 m .57144 .43266 L .58409 .42518 L p 0 .914 1 r
F P
0 g
s
.57144 .43266 m .57344 .48855 L .58646 .48125 L p 0 .1 .396 r
F P
0 g
s
.58646 .48125 m .58409 .42518 L .57144 .43266 L p 0 .1 .396 r
F P
0 g
s
.57344 .48855 m .57144 .43266 L .52344 .40192 L p 0 .658 .35 r
F P
0 g
s
.57344 .48855 m .62011 .51696 L .63309 .51005 L p 0 .916 1 r
F P
0 g
s
.62011 .51696 m .62347 .5752 L .63683 .56851 L p 0 .1 .423 r
F P
0 g
s
.63683 .56851 m .63309 .51005 L .62011 .51696 L p 0 .1 .423 r
F P
0 g
s
.52277 .51696 m .52341 .5752 L .57144 .60126 L p 0 .668 0 r
F P
0 g
s
.57144 .60126 m .52341 .5752 L .53608 .56851 L p 0 .916 0 r
F P
0 g
s
.53608 .56851 m .58409 .59493 L .57144 .60126 L p 0 .916 0 r
F P
0 g
s
.52341 .5752 m .52277 .51696 L .53509 .51005 L p 0 .1 0 r
F P
0 g
s
.52277 .51696 m .47338 .48855 L .4857 .48125 L p 0 .916 0 r
F P
0 g
s
.4857 .48125 m .53509 .51005 L .52277 .51696 L p 0 .916 0 r
F P
0 g
s
.47338 .48855 m .52277 .51696 L .53509 .51005 L p 0 .916 0 r
F P
0 g
s
.52277 .51696 m .52341 .5752 L .53608 .56851 L p 0 .1 0 r
F P
0 g
s
.53608 .56851 m .53509 .51005 L .52277 .51696 L p 0 .1 0 r
F P
0 g
s
.52341 .5752 m .52277 .51696 L .47338 .48855 L p 0 .668 0 r
F P
0 g
s
.62347 .40189 m .66879 .43266 L .6821 .42518 L p 0 .914 0 r
F P
0 g
s
.66879 .43266 m .6735 .48855 L .68721 .48125 L p 0 .1 0 r
F P
0 g
s
.68721 .48125 m .6821 .42518 L .66879 .43266 L p 0 .1 0 r
F P
0 g
s
.6735 .48855 m .66879 .43266 L .62347 .40189 L p 0 .645 0 r
F P
0 g
s
.48612 .4252 m .48609 .42522 L .4741 .4327 L p 0 .93 0 r
F P
0 g
s
.47338 .48855 m .4741 .4327 L .48609 .42522 L p 0 .1 0 r
F P
0 g
s
.78073 .25158 m .78857 .30243 L .77439 .31083 L p 0 .1 0 r
F P
0 g
s
.78073 .25158 m .78857 .30243 L .82942 .33591 L p 0 .607 0 r
F P
0 g
s
.78073 .25158 m .78857 .30243 L .82942 .33591 L p 0 .607 0 r
F P
0 g
s
.82942 .33591 m .78857 .30243 L .80295 .29392 L p 0 .911 0 r
F P
0 g
s
.80295 .29392 m .84368 .32785 L .82942 .33591 L p 0 .911 0 r
F P
0 g
s
.78857 .30243 m .78073 .25158 L .79466 .24296 L p 0 .1 0 r
F P
0 g
s
.62797 .16712 m .6367 .1609 L .63667 .1609 L p 0 1 .86 r
F P
0 g
s
.63667 .1609 m .62794 .16712 L .62797 .16712 L p 0 1 .86 r
F P
0 g
s
.62797 .16712 m .62794 .16712 L p .67663 .25143 L 0 .627 .269 r
F P
0 g
s
.62797 .16712 m .62794 .16712 L p .67663 .25143 L 0 .627 .269 r
F P
0 g
s
.67242 .308 m .68156 .30229 L .72532 .33577 L p 0 .911 1 r
F P
0 g
s
.67663 .25143 m .68156 .30229 L .72532 .33577 L p 0 .627 .269 r
F P
0 g
s
.67663 .25143 m .68156 .30229 L .72532 .33577 L p 0 .627 .269 r
F P
0 g
s
.7345 .33032 m .72532 .33577 L .68156 .30229 L p 0 .911 1 r
F P
0 g
s
.67663 .25143 m .68559 .24559 L .6908 .29652 L p 0 .1 .396 r
F P
0 g
s
.6908 .29652 m .68156 .30229 L .67663 .25143 L p 0 .1 .396 r
F P
0 g
s
.67242 .308 m .68156 .30229 L .67663 .25143 L p 0 .1 .396 r
F P
0 g
s
.6226 .2217 m .63151 .21559 L .67663 .25143 L p 0 .907 1 r
F P
0 g
s
.68156 .30229 m .67663 .25143 L .63151 .21559 L p 0 .627 .269 r
F P
0 g
s
.68559 .24559 m .67663 .25143 L .68156 .30229 L p 0 .1 .396 r
F P
0 g
s
.62794 .16712 m .63151 .21559 L .67663 .25143 L p 0 .627 .269 r
F P
0 g
s
.62794 .16712 m .63151 .21559 L .67663 .25143 L p 0 .627 .269 r
F P
0 g
s
.67663 .25143 m .68559 .24559 L .64051 .20942 L p 0 .907 1 r
F P
0 g
s
.64051 .20942 m .63151 .21559 L .67663 .25143 L p 0 .907 1 r
F P
0 g
s
.68156 .30229 m .67663 .25143 L .63151 .21559 L p 0 .627 .269 r
F P
0 g
s
.68559 .24559 m .67663 .25143 L .63151 .21559 L p 0 .907 1 r
F P
0 g
s
.62794 .16712 m .63667 .1609 L .64051 .20942 L p 0 .1 .365 r
F P
0 g
s
.64051 .20942 m .63151 .21559 L .62794 .16712 L p 0 .1 .365 r
F P
0 g
s
.77138 .3084 m .78557 .29997 L .77779 .24909 L p 0 .1 0 r
F P
0 g
s
.72158 .22214 m .73542 .21311 L .77779 .24909 L p 0 .907 0 r
F P
0 g
s
.78557 .29997 m .77779 .24909 L .73542 .21311 L p 0 .607 0 r
F P
0 g
s
.79173 .24043 m .77779 .24909 L .78557 .29997 L p 0 .1 0 r
F P
0 g
s
.72901 .16459 m .73542 .21311 L .77779 .24909 L p 0 .607 0 r
F P
0 g
s
.72901 .16459 m .73542 .21311 L .77779 .24909 L p 0 .607 0 r
F P
0 g
s
.77779 .24909 m .79173 .24043 L .74946 .20396 L p 0 .907 0 r
F P
0 g
s
.74946 .20396 m .73542 .21311 L .77779 .24909 L p 0 .907 0 r
F P
0 g
s
.78557 .29997 m .77779 .24909 L .73542 .21311 L p 0 .607 0 r
F P
0 g
s
.79173 .24043 m .77779 .24909 L .73542 .21311 L p 0 .907 0 r
F P
0 g
s
.72901 .16459 m .74262 .15537 L .74946 .20396 L p 0 .1 0 r
F P
0 g
s
.74946 .20396 m .73542 .21311 L .72901 .16459 L p 0 .1 0 r
F P
0 g
s
.72158 .22214 m .73542 .21311 L .72901 .16459 L p 0 .1 0 r
F P
0 g
s
.73542 .21311 m .72901 .16459 L .6853 .12628 L p 0 .607 0 r
F P
0 g
s
.74262 .15537 m .72901 .16459 L .73542 .21311 L p 0 .1 0 r
F P
0 g
s
.72901 .16459 m .74262 .15537 L .699 .11653 L p 0 .903 0 r
F P
0 g
s
.699 .11653 m .6853 .12628 L .72901 .16459 L p 0 .903 0 r
F P
0 g
s
.73542 .21311 m .72901 .16459 L .6853 .12628 L p 0 .607 0 r
F P
0 g
s
.78582 .48597 m .77804 .43002 L .73566 .3991 L p 0 .627 .269 r
F P
0 g
s
.77804 .43002 m .78747 .42498 L .74517 .39378 L p 0 .914 1 r
F P
0 g
s
.74517 .39378 m .73566 .3991 L .77804 .43002 L p 0 .914 1 r
F P
0 g
s
.77804 .43002 m .78582 .48597 L .82682 .51452 L p 0 .627 .269 r
F P
0 g
s
.77804 .43002 m .78582 .48597 L .82682 .51452 L p 0 .627 .269 r
F P
0 g
s
.78747 .42498 m .77804 .43002 L .78582 .48597 L p 0 .1 .45 r
F P
0 g
s
.78582 .48597 m .77804 .43002 L .73566 .3991 L p 0 .627 .269 r
F P
0 g
s
.77804 .43002 m .78747 .42498 L .79556 .48106 L p 0 .1 .45 r
F P
0 g
s
.79556 .48106 m .78582 .48597 L .77804 .43002 L p 0 .1 .45 r
F P
0 g
s
.83648 .50987 m .82682 .51452 L .78582 .48597 L p 0 .916 1 r
F P
0 g
s
.82682 .51452 m .83648 .50987 L .79556 .48106 L p 0 .916 1 r
F P
0 g
s
.79556 .48106 m .78582 .48597 L .82682 .51452 L p 0 .916 1 r
F P
0 g
s
.83648 .50987 m .82682 .51452 L .83597 .5728 L p 0 .114 .472 r
F P
0 g
s
.83597 .5728 m .82682 .51452 L .78582 .48597 L p 0 .627 .269 r
F P
0 g
s
.83597 .5728 m .82682 .51452 L .78582 .48597 L p 0 .627 .269 r
F P
0 g
s
.53495 .33284 m .54739 .32466 L .54742 .32472 L p 0 .546 .889 r
F P
0 g
s
.54742 .32472 m .53499 .3329 L .53495 .33284 L p 0 .546 .889 r
F P
0 g
s
.58376 .24833 m .58611 .29919 L p .63258 .33288 L 0 .641 0 r
F P
0 g
s
.58376 .24833 m .58611 .29919 L p .63258 .33288 L 0 .641 0 r
F P
0 g
s
.58376 .24833 m .59653 .23958 L .59925 .29054 L p 0 .1 0 r
F P
0 g
s
.59925 .29054 m .58611 .29919 L .58376 .24833 L p 0 .1 0 r
F P
0 g
s
.57318 .30778 m .58614 .29925 L .63258 .33288 L p 0 .911 0 r
F P
0 g
s
.58611 .29919 m .58614 .29925 L .63258 .33288 L p 0 .641 0 r
F P
0 g
s
.58611 .29919 m .58614 .29925 L .63258 .33288 L p 0 .641 0 r
F P
0 g
s
.64568 .32469 m .63258 .33288 L .58614 .29925 L p 0 .911 0 r
F P
0 g
s
.87529 .49118 m .89023 .484 L .87959 .42803 L p 0 .114 0 r
F P
0 g
s
.87959 .42803 m .87956 .42797 L .83998 .39696 L p 0 .607 0 r
F P
0 g
s
.89023 .484 m .87959 .42803 L p .83998 .39696 L 0 .607 0 r
F P
0 g
s
.87956 .42797 m .89421 .4205 L .85477 .38907 L p 0 .914 0 r
F P
0 g
s
.85477 .38907 m .83998 .39696 L .87956 .42797 L p 0 .914 0 r
F P
0 g
s
.89424 .42057 m .87959 .42803 L .89023 .484 L p 0 .114 0 r
F P
0 g
s
.87959 .42803 m .89424 .42057 L .89421 .4205 L p 0 .562 0 r
F P
0 g
s
.89421 .4205 m .87956 .42797 L .87959 .42803 L p 0 .562 0 r
F P
0 g
s
.87959 .42803 m .87956 .42797 L .83998 .39696 L p 0 .607 0 r
F P
0 g
s
.89023 .484 m .87959 .42803 L p .83998 .39696 L 0 .607 0 r
F P
0 g
s
.63633 .51205 m .64948 .50508 L .6537 .56368 L p 0 .1 .425 r
F P
0 g
s
.6537 .56368 m .64015 .57045 L .63633 .51205 L p 0 .1 .425 r
F P
0 g
s
.62679 .57711 m .64015 .57045 L .68523 .59676 L p 0 .916 1 r
F P
0 g
s
.69872 .59036 m .68523 .59676 L .64015 .57045 L p 0 .916 1 r
F P
0 g
s
.68523 .42734 m .69872 .41979 L .70433 .47599 L p 0 .1 0 r
F P
0 g
s
.70433 .47599 m .69043 .48336 L .68523 .42734 L p 0 .1 0 r
F P
0 g
s
.72665 .57711 m .74071 .57045 L .78302 .59674 L p 0 .916 0 r
F P
0 g
s
.79717 .59034 m .78302 .59674 L .74071 .57045 L p 0 .916 0 r
F P
0 g
s
.6367 .1609 m .63667 .1609 L p .68559 .24559 L 0 .624 .261 r
F P
0 g
s
.6367 .1609 m .64552 .15462 L .64549 .15463 L p 0 1 .86 r
F P
0 g
s
.64549 .15463 m .63667 .1609 L .6367 .1609 L p 0 1 .86 r
F P
0 g
s
.6367 .1609 m .63667 .1609 L p .68559 .24559 L 0 .624 .261 r
F P
0 g
s
.68156 .30229 m .6908 .29652 L .7345 .33032 L p 0 .911 1 r
F P
0 g
s
.68559 .24559 m .6908 .29652 L .7345 .33032 L p 0 .624 .261 r
F P
0 g
s
.68559 .24559 m .6908 .29652 L .7345 .33032 L p 0 .624 .261 r
F P
0 g
s
.74376 .32481 m .7345 .33032 L .6908 .29652 L p 0 .911 1 r
F P
0 g
s
.68559 .24559 m .69462 .2397 L .70011 .2907 L p 0 .1 .396 r
F P
0 g
s
.70011 .2907 m .6908 .29652 L .68559 .24559 L p 0 .1 .396 r
F P
0 g
s
.68156 .30229 m .6908 .29652 L .68559 .24559 L p 0 .1 .396 r
F P
0 g
s
.63151 .21559 m .64051 .20942 L .68559 .24559 L p 0 .907 1 r
F P
0 g
s
.6908 .29652 m .68559 .24559 L .64051 .20942 L p 0 .624 .261 r
F P
0 g
s
.69462 .2397 m .68559 .24559 L .6908 .29652 L p 0 .1 .396 r
F P
0 g
s
.63667 .1609 m .64051 .20942 L .68559 .24559 L p 0 .624 .261 r
F P
0 g
s
.63667 .1609 m .64051 .20942 L .68559 .24559 L p 0 .624 .261 r
F P
0 g
s
.68559 .24559 m .69462 .2397 L .64959 .20319 L p 0 .907 1 r
F P
0 g
s
.64959 .20319 m .64051 .20942 L .68559 .24559 L p 0 .907 1 r
F P
0 g
s
.6908 .29652 m .68559 .24559 L .64051 .20942 L p 0 .624 .261 r
F P
0 g
s
.69462 .2397 m .68559 .24559 L .64051 .20942 L p 0 .907 1 r
F P
0 g
s
.63667 .1609 m .64549 .15463 L .64959 .20319 L p 0 .1 .365 r
F P
0 g
s
.64959 .20319 m .64051 .20942 L .63667 .1609 L p 0 .1 .365 r
F P
0 g
s
.4857 .48125 m .53509 .51005 L p .48612 .4252 L 0 .666 0 r
F P
0 g
s
.48612 .4252 m .48609 .42522 L .4857 .48125 L p 0 .666 0 r
F P
0 g
s
.48609 .42522 m .48612 .4252 L .49827 .41762 L p 0 .93 0 r
F P
0 g
s
.4857 .48125 m .53509 .51005 L p .48612 .4252 L 0 .666 0 r
F P
0 g
s
.48612 .4252 m .48609 .42522 L .4857 .48125 L p 0 .666 0 r
F P
0 g
s
.3996 .58852 m .38812 .59495 L .38808 .59489 L p 0 .525 0 r
F P
0 g
s
.38808 .59489 m .39957 .58846 L .3996 .58852 L p 0 .525 0 r
F P
0 g
s
.43708 .51005 m .43532 .56847 L .42335 .57516 L p 0 .1 .365 r
F P
0 g
s
.43535 .56853 m .48609 .59493 L p .43708 .51005 L 0 .675 .404 r
F P
0 g
s
.43708 .51005 m .43532 .56847 L .43535 .56853 L p 0 .675 .404 r
F P
0 g
s
.43535 .56853 m .48609 .59493 L p .43708 .51005 L 0 .675 .404 r
F P
0 g
s
.48609 .59493 m .43535 .56853 L .44749 .56174 L p 0 .916 1 r
F P
0 g
s
.44749 .56174 m .49824 .58851 L .48609 .59493 L p 0 .916 1 r
F P
0 g
s
.43708 .51005 m .43532 .56847 L .43535 .56853 L p 0 .675 .404 r
F P
0 g
s
.43532 .56847 m .43708 .51005 L .4489 .50305 L p 0 .1 .365 r
F P
0 g
s
.58409 .42518 m .58646 .48125 L .57344 .48855 L p 0 .1 .396 r
F P
0 g
s
.58409 .42518 m .58646 .48125 L .63309 .51005 L p 0 .655 .342 r
F P
0 g
s
.58409 .42518 m .58646 .48125 L .63309 .51005 L p 0 .655 .342 r
F P
0 g
s
.58646 .48125 m .58409 .42518 L .59691 .4176 L p 0 .1 .396 r
F P
0 g
s
.58409 .42518 m .53611 .39401 L .52344 .40192 L p 0 .914 1 r
F P
0 g
s
.58646 .48125 m .58409 .42518 L .53611 .39401 L p 0 .655 .342 r
F P
0 g
s
.53611 .39401 m .58409 .42518 L .59691 .4176 L p 0 .914 1 r
F P
0 g
s
.58409 .42518 m .58646 .48125 L .59966 .47385 L p 0 .1 .396 r
F P
0 g
s
.59966 .47385 m .59691 .4176 L .58409 .42518 L p 0 .1 .396 r
F P
0 g
s
.58646 .48125 m .58409 .42518 L .53611 .39401 L p 0 .655 .342 r
F P
0 g
s
.63309 .51005 m .58646 .48125 L .59966 .47385 L p 0 .916 1 r
F P
0 g
s
.59966 .47385 m .64625 .50305 L .63309 .51005 L p 0 .916 1 r
F P
0 g
s
.63309 .51005 m .58646 .48125 L .57344 .48855 L p 0 .916 1 r
F P
0 g
s
.63683 .56851 m .63309 .51005 L .58646 .48125 L p 0 .655 .342 r
F P
0 g
s
.58646 .48125 m .63309 .51005 L .64625 .50305 L p 0 .916 1 r
F P
0 g
s
.63309 .51005 m .63683 .56851 L .65039 .56172 L p 0 .1 .423 r
F P
0 g
s
.65039 .56172 m .64625 .50305 L .63309 .51005 L p 0 .1 .423 r
F P
0 g
s
.63683 .56851 m .63309 .51005 L .58646 .48125 L p 0 .655 .342 r
F P
0 g
s
.53509 .51005 m .53608 .56851 L .52341 .5752 L p 0 .1 0 r
F P
0 g
s
.53509 .51005 m .53608 .56851 L .58409 .59493 L p 0 .666 0 r
F P
0 g
s
.53509 .51005 m .53608 .56851 L .58409 .59493 L p 0 .666 0 r
F P
0 g
s
.58409 .59493 m .53608 .56851 L .54892 .56172 L p 0 .916 0 r
F P
0 g
s
.54892 .56172 m .59691 .58851 L .58409 .59493 L p 0 .916 0 r
F P
0 g
s
.53608 .56851 m .53509 .51005 L .54757 .50305 L p 0 .1 0 r
F P
0 g
s
.53509 .51005 m .4857 .48125 L .49819 .47385 L p 0 .916 0 r
F P
0 g
s
.49819 .47385 m .54757 .50305 L .53509 .51005 L p 0 .916 0 r
F P
0 g
s
.53509 .51005 m .4857 .48125 L .47338 .48855 L p 0 .916 0 r
F P
0 g
s
.53608 .56851 m .53509 .51005 L .4857 .48125 L p 0 .666 0 r
F P
0 g
s
.4857 .48125 m .53509 .51005 L .54757 .50305 L p 0 .916 0 r
F P
0 g
s
.53509 .51005 m .53608 .56851 L .54892 .56172 L p 0 .1 0 r
F P
0 g
s
.54892 .56172 m .54757 .50305 L .53509 .51005 L p 0 .1 0 r
F P
0 g
s
.53608 .56851 m .53509 .51005 L .4857 .48125 L p 0 .666 0 r
F P
0 g
s
.6821 .42518 m .63683 .39399 L .62347 .40189 L p 0 .914 0 r
F P
0 g
s
.68721 .48125 m .6821 .42518 L .63683 .39399 L p 0 .641 0 r
F P
0 g
s
.63683 .39399 m .6821 .42518 L .69559 .4176 L p 0 .914 0 r
F P
0 g
s
.6821 .42518 m .68721 .48125 L .70112 .47385 L p 0 .1 0 r
F P
0 g
s
.70112 .47385 m .69559 .4176 L .6821 .42518 L p 0 .1 0 r
F P
0 g
s
.68721 .48125 m .6821 .42518 L .63683 .39399 L p 0 .641 0 r
F P
0 g
s
.69559 .4176 m .65039 .38597 L .63683 .39399 L p 0 .914 0 r
F P
0 g
s
.59691 .4176 m .59966 .47385 L .64625 .50305 L p 0 .652 .333 r
F P
0 g
s
.59691 .4176 m .59966 .47385 L .64625 .50305 L p 0 .652 .333 r
F P
0 g
s
.60991 .40991 m .61304 .46634 L .65959 .49595 L p 0 .648 .324 r
F P
0 g
s
.60991 .40991 m .61304 .46634 L .65959 .49595 L p 0 .648 .324 r
F P
0 g
s
.62309 .40212 m .62662 .45873 L .67311 .48876 L p 0 .645 .315 r
F P
0 g
s
.62347 .40189 m .62701 .45851 L .6735 .48855 L p 0 .645 0 r
F P
0 g
s
.63683 .39399 m .64079 .45078 L .68721 .48125 L p 0 .641 0 r
F P
0 g
s
.63683 .39399 m .64079 .45078 L .68721 .48125 L p 0 .641 0 r
F P
0 g
s
.65039 .38597 m .65477 .44294 L .70112 .47385 L p 0 .638 0 r
F P
0 g
s
.70112 .47385 m .69559 .4176 L .65039 .38597 L p 0 .638 0 r
F P
0 g
s
.48609 .42522 m .4857 .48125 L .47338 .48855 L p 0 .1 0 r
F P
0 g
s
.49827 .41762 m .49824 .41764 L .48609 .42522 L p 0 .93 0 r
F P
0 g
s
.4857 .48125 m .48609 .42522 L .49824 .41764 L p 0 .1 0 r
F P
0 g
s
.78582 .48597 m .79556 .48106 L .78747 .42498 L p 0 .1 .45 r
F P
0 g
s
.79556 .48106 m .78747 .42498 L .74517 .39378 L p 0 .624 .261 r
F P
0 g
s
.78747 .42498 m .79699 .4199 L .75476 .38841 L p 0 .914 1 r
F P
0 g
s
.75476 .38841 m .74517 .39378 L .78747 .42498 L p 0 .914 1 r
F P
0 g
s
.78747 .42498 m .79556 .48106 L .83648 .50987 L p 0 .624 .261 r
F P
0 g
s
.78747 .42498 m .79556 .48106 L .83648 .50987 L p 0 .624 .261 r
F P
0 g
s
.79699 .4199 m .78747 .42498 L .79556 .48106 L p 0 .1 .45 r
F P
0 g
s
.79556 .48106 m .78747 .42498 L .74517 .39378 L p 0 .624 .261 r
F P
0 g
s
.78582 .48597 m .79556 .48106 L .83648 .50987 L p 0 .916 1 r
F P
0 g
s
.78747 .42498 m .79699 .4199 L .80538 .47609 L p 0 .1 .45 r
F P
0 g
s
.80538 .47609 m .79556 .48106 L .78747 .42498 L p 0 .1 .45 r
F P
0 g
s
.84623 .50518 m .83648 .50987 L .79556 .48106 L p 0 .916 1 r
F P
0 g
s
.83597 .5728 m .84594 .56829 L .83648 .50987 L p 0 .114 .472 r
F P
0 g
s
.84594 .56829 m .83648 .50987 L .79556 .48106 L p 0 .624 .261 r
F P
0 g
s
.83648 .50987 m .84623 .50518 L .80538 .47609 L p 0 .916 1 r
F P
0 g
s
.80538 .47609 m .79556 .48106 L .83648 .50987 L p 0 .916 1 r
F P
0 g
s
.84623 .50518 m .83648 .50987 L .84594 .56829 L p 0 .114 .472 r
F P
0 g
s
.84594 .56829 m .83648 .50987 L .79556 .48106 L p 0 .624 .261 r
F P
0 g
s
.79466 .24296 m .80295 .29392 L .84368 .32785 L p 0 .601 0 r
F P
0 g
s
.79466 .24296 m .80295 .29392 L .78857 .30243 L p 0 .1 0 r
F P
0 g
s
.73542 .21311 m .74946 .20396 L .79173 .24043 L p 0 .907 0 r
F P
0 g
s
.74262 .15537 m .74946 .20396 L .79173 .24043 L p 0 .601 0 r
F P
0 g
s
.73542 .21311 m .74946 .20396 L .74262 .15537 L p 0 .1 0 r
F P
0 g
s
.74946 .20396 m .74262 .15537 L .699 .11653 L p 0 .601 0 r
F P
0 g
s
.78557 .29997 m .79995 .29142 L .79173 .24043 L p 0 .1 0 r
F P
0 g
s
.79995 .29142 m .79173 .24043 L .74946 .20396 L p 0 .601 0 r
F P
0 g
s
.64552 .15462 m .64549 .15463 L p .69462 .2397 L 0 .621 .254 r
F P
0 g
s
.64552 .15462 m .65441 .14828 L .65438 .14829 L p 0 1 .86 r
F P
0 g
s
.65438 .14829 m .64549 .15463 L .64552 .15462 L p 0 1 .86 r
F P
0 g
s
.64552 .15462 m .64549 .15463 L p .69462 .2397 L 0 .621 .254 r
F P
0 g
s
.6908 .29652 m .70011 .2907 L .74376 .32481 L p 0 .911 1 r
F P
0 g
s
.69462 .2397 m .70011 .2907 L .74376 .32481 L p 0 .621 .254 r
F P
0 g
s
.69462 .2397 m .70011 .2907 L .74376 .32481 L p 0 .621 .254 r
F P
0 g
s
.75311 .31926 m .74376 .32481 L .70011 .2907 L p 0 .911 1 r
F P
0 g
s
.69462 .2397 m .70375 .23376 L .70952 .28483 L p 0 .1 .396 r
F P
0 g
s
.70952 .28483 m .70011 .2907 L .69462 .2397 L p 0 .1 .396 r
F P
0 g
s
.6908 .29652 m .70011 .2907 L .69462 .2397 L p 0 .1 .396 r
F P
0 g
s
.64051 .20942 m .64959 .20319 L .69462 .2397 L p 0 .907 1 r
F P
0 g
s
.70011 .2907 m .69462 .2397 L .64959 .20319 L p 0 .621 .254 r
F P
0 g
s
.70375 .23376 m .69462 .2397 L .70011 .2907 L p 0 .1 .396 r
F P
0 g
s
.64549 .15463 m .64959 .20319 L .69462 .2397 L p 0 .621 .254 r
F P
0 g
s
.64549 .15463 m .64959 .20319 L .69462 .2397 L p 0 .621 .254 r
F P
0 g
s
.69462 .2397 m .70375 .23376 L .65875 .19691 L p 0 .907 1 r
F P
0 g
s
.65875 .19691 m .64959 .20319 L .69462 .2397 L p 0 .907 1 r
F P
0 g
s
.70011 .2907 m .69462 .2397 L .64959 .20319 L p 0 .621 .254 r
F P
0 g
s
.70375 .23376 m .69462 .2397 L .64959 .20319 L p 0 .907 1 r
F P
0 g
s
.64549 .15463 m .65438 .14829 L .65875 .19691 L p 0 .1 .365 r
F P
0 g
s
.65875 .19691 m .64959 .20319 L .64549 .15463 L p 0 .1 .365 r
F P
0 g
s
.54739 .32466 m .55999 .31637 L .56003 .31643 L p 0 .546 .889 r
F P
0 g
s
.56003 .31643 m .54742 .32472 L .54739 .32466 L p 0 .546 .889 r
F P
0 g
s
.59925 .29054 m .59929 .2906 L .64568 .32469 L p 0 .638 0 r
F P
0 g
s
.59653 .23958 m .59925 .29054 L p .64568 .32469 L 0 .638 0 r
F P
0 g
s
.59653 .23958 m .59925 .29054 L p .64568 .32469 L 0 .638 0 r
F P
0 g
s
.59925 .29054 m .59929 .2906 L .64568 .32469 L p 0 .638 0 r
F P
0 g
s
.65896 .3164 m .64568 .32469 L .59929 .2906 L p 0 .911 0 r
F P
0 g
s
.59653 .23958 m .60948 .2307 L .61258 .28177 L p 0 .1 0 r
F P
0 g
s
.61258 .28177 m .59925 .29054 L .59653 .23958 L p 0 .1 0 r
F P
0 g
s
.58614 .29925 m .59929 .2906 L .64568 .32469 L p 0 .911 0 r
F P
0 g
s
.8008 .23916 m .80928 .29017 L .84996 .32431 L p 0 .599 .205 r
F P
0 g
s
.84996 .32431 m .80928 .29017 L .8216 .28287 L p 0 .911 1 r
F P
0 g
s
.8216 .28287 m .86217 .31741 L .84996 .32431 L p 0 .911 1 r
F P
0 g
s
.80928 .29017 m .8008 .23916 L .81273 .23177 L p 0 .1 .425 r
F P
0 g
s
.89023 .484 m .90537 .47671 L .89424 .42057 L p 0 .114 0 r
F P
0 g
s
.89424 .42057 m .89421 .4205 L .85477 .38907 L p 0 .601 0 r
F P
0 g
s
.90537 .47671 m .89424 .42057 L p .85477 .38907 L 0 .601 0 r
F P
0 g
s
.79556 .48106 m .80538 .47609 L .84623 .50518 L p 0 .916 1 r
F P
0 g
s
.79699 .4199 m .80538 .47609 L .84623 .50518 L p 0 .621 .254 r
F P
0 g
s
.79699 .4199 m .80538 .47609 L .84623 .50518 L p 0 .621 .254 r
F P
0 g
s
.85607 .50044 m .84623 .50518 L .80538 .47609 L p 0 .916 1 r
F P
0 g
s
.84594 .56829 m .856 .56374 L .84623 .50518 L p 0 .114 .472 r
F P
0 g
s
.856 .56374 m .84623 .50518 L .80538 .47609 L p 0 .621 .254 r
F P
0 g
s
.84623 .50518 m .85607 .50044 L .81531 .47109 L p 0 .916 1 r
F P
0 g
s
.81531 .47109 m .80538 .47609 L .84623 .50518 L p 0 .916 1 r
F P
0 g
s
.85607 .50044 m .84623 .50518 L .856 .56374 L p 0 .114 .472 r
F P
0 g
s
.856 .56374 m .84623 .50518 L .80538 .47609 L p 0 .621 .254 r
F P
0 g
s
.79556 .48106 m .80538 .47609 L .79699 .4199 L p 0 .1 .45 r
F P
0 g
s
.80538 .47609 m .79699 .4199 L .75476 .38841 L p 0 .621 .254 r
F P
0 g
s
.79699 .4199 m .8066 .41477 L .76444 .38298 L p 0 .914 1 r
F P
0 g
s
.76444 .38298 m .75476 .38841 L .79699 .4199 L p 0 .914 1 r
F P
0 g
s
.8066 .41477 m .79699 .4199 L .80538 .47609 L p 0 .1 .45 r
F P
0 g
s
.80538 .47609 m .79699 .4199 L .75476 .38841 L p 0 .621 .254 r
F P
0 g
s
.79699 .4199 m .8066 .41477 L .81531 .47109 L p 0 .1 .45 r
F P
0 g
s
.81531 .47109 m .80538 .47609 L .79699 .4199 L p 0 .1 .45 r
F P
0 g
s
.64015 .57045 m .6537 .56368 L .69872 .59036 L p 0 .916 1 r
F P
0 g
s
.64948 .50508 m .66281 .49801 L .66744 .55683 L p 0 .1 .425 r
F P
0 g
s
.66744 .55683 m .6537 .56368 L .64948 .50508 L p 0 .1 .425 r
F P
0 g
s
.71239 .58388 m .69872 .59036 L .6537 .56368 L p 0 .916 1 r
F P
0 g
s
.69872 .41979 m .71239 .41213 L .71843 .46851 L p 0 .1 0 r
F P
0 g
s
.71843 .46851 m .70433 .47599 L .69872 .41979 L p 0 .1 0 r
F P
0 g
s
.74071 .57045 m .75497 .56368 L .79717 .59034 L p 0 .916 0 r
F P
0 g
s
.80981 .2292 m .79787 .23662 L .80629 .28766 L p 0 .1 .423 r
F P
0 g
s
.74861 .1513 m .75564 .19993 L .79787 .23662 L p 0 .599 .205 r
F P
0 g
s
.79787 .23662 m .80981 .2292 L .76767 .19209 L p 0 .907 1 r
F P
0 g
s
.76767 .19209 m .75564 .19993 L .79787 .23662 L p 0 .907 1 r
F P
0 g
s
.80629 .28766 m .79787 .23662 L .75564 .19993 L p 0 .599 .205 r
F P
0 g
s
.80981 .2292 m .79787 .23662 L .75564 .19993 L p 0 .907 1 r
F P
0 g
s
.74861 .1513 m .76027 .1434 L .76767 .19209 L p 0 .1 .396 r
F P
0 g
s
.76767 .19209 m .75564 .19993 L .74861 .1513 L p 0 .1 .396 r
F P
0 g
s
.76027 .1434 m .74861 .1513 L .75564 .19993 L p 0 .1 .396 r
F P
0 g
s
.74861 .1513 m .76027 .1434 L .71676 .10388 L p 0 .903 1 r
F P
0 g
s
.71676 .10388 m .70502 .11224 L .74861 .1513 L p 0 .903 1 r
F P
0 g
s
.75564 .19993 m .74861 .1513 L .70502 .11224 L p 0 .599 .205 r
F P
0 g
s
.49819 .47385 m .54757 .50305 L p .49827 .41762 L 0 .663 0 r
F P
0 g
s
.49827 .41762 m .49824 .41764 L .49819 .47385 L p 0 .663 0 r
F P
0 g
s
.49824 .41764 m .49827 .41762 L .51059 .40993 L p 0 .93 0 r
F P
0 g
s
.49819 .47385 m .54757 .50305 L p .49827 .41762 L 0 .663 0 r
F P
0 g
s
.49827 .41762 m .49824 .41764 L .49819 .47385 L p 0 .663 0 r
F P
0 g
s
.3996 .58852 m .39957 .58846 L .41121 .58195 L p 0 .525 0 r
F P
0 g
s
.41121 .58195 m .41124 .58201 L .3996 .58852 L p 0 .525 0 r
F P
0 g
s
.4489 .50305 m .44746 .56168 L .43532 .56847 L p 0 .1 .365 r
F P
0 g
s
.44749 .56174 m .49824 .58851 L p .4489 .50305 L 0 .673 .397 r
F P
0 g
s
.4489 .50305 m .44746 .56168 L .44749 .56174 L p 0 .673 .397 r
F P
0 g
s
.44749 .56174 m .49824 .58851 L p .4489 .50305 L 0 .673 .397 r
F P
0 g
s
.49824 .58851 m .44749 .56174 L .4598 .55486 L p 0 .916 1 r
F P
0 g
s
.4598 .55486 m .51056 .582 L .49824 .58851 L p 0 .916 1 r
F P
0 g
s
.4489 .50305 m .44746 .56168 L .44749 .56174 L p 0 .673 .397 r
F P
0 g
s
.44746 .56168 m .4489 .50305 L .46088 .49595 L p 0 .1 .365 r
F P
0 g
s
.59691 .4176 m .59966 .47385 L .58646 .48125 L p 0 .1 .396 r
F P
0 g
s
.59966 .47385 m .59691 .4176 L .60991 .40991 L p 0 .1 .396 r
F P
0 g
s
.59691 .4176 m .54896 .386 L .53611 .39401 L p 0 .914 1 r
F P
0 g
s
.59966 .47385 m .59691 .4176 L .54896 .386 L p 0 .652 .333 r
F P
0 g
s
.54896 .386 m .59691 .4176 L .60991 .40991 L p 0 .914 1 r
F P
0 g
s
.59691 .4176 m .59966 .47385 L .61304 .46634 L p 0 .1 .396 r
F P
0 g
s
.61304 .46634 m .60991 .40991 L .59691 .4176 L p 0 .1 .396 r
F P
0 g
s
.59966 .47385 m .59691 .4176 L .54896 .386 L p 0 .652 .333 r
F P
0 g
s
.64625 .50305 m .59966 .47385 L .61304 .46634 L p 0 .916 1 r
F P
0 g
s
.61304 .46634 m .65959 .49595 L .64625 .50305 L p 0 .916 1 r
F P
0 g
s
.64625 .50305 m .59966 .47385 L .58646 .48125 L p 0 .916 1 r
F P
0 g
s
.65039 .56172 m .64625 .50305 L .59966 .47385 L p 0 .652 .333 r
F P
0 g
s
.59966 .47385 m .64625 .50305 L .65959 .49595 L p 0 .916 1 r
F P
0 g
s
.64625 .50305 m .65039 .56172 L .66414 .55484 L p 0 .1 .423 r
F P
0 g
s
.66414 .55484 m .65959 .49595 L .64625 .50305 L p 0 .1 .423 r
F P
0 g
s
.65039 .56172 m .64625 .50305 L .59966 .47385 L p 0 .652 .333 r
F P
0 g
s
.65039 .38597 m .69559 .4176 L .70926 .40991 L p 0 .914 0 r
F P
0 g
s
.69559 .4176 m .70112 .47385 L .71523 .46634 L p 0 .1 0 r
F P
0 g
s
.71523 .46634 m .70926 .40991 L .69559 .4176 L p 0 .1 0 r
F P
0 g
s
.54757 .50305 m .54892 .56172 L .53608 .56851 L p 0 .1 0 r
F P
0 g
s
.54757 .50305 m .54892 .56172 L .59691 .58851 L p 0 .663 0 r
F P
0 g
s
.54757 .50305 m .54892 .56172 L .59691 .58851 L p 0 .663 0 r
F P
0 g
s
.59691 .58851 m .54892 .56172 L .56195 .55484 L p 0 .916 0 r
F P
0 g
s
.56195 .55484 m .60991 .582 L .59691 .58851 L p 0 .916 0 r
F P
0 g
s
.54892 .56172 m .54757 .50305 L .56023 .49595 L p 0 .1 0 r
F P
0 g
s
.54757 .50305 m .49819 .47385 L .51086 .46634 L p 0 .916 0 r
F P
0 g
s
.51086 .46634 m .56023 .49595 L .54757 .50305 L p 0 .916 0 r
F P
0 g
s
.54757 .50305 m .49819 .47385 L .4857 .48125 L p 0 .916 0 r
F P
0 g
s
.54892 .56172 m .54757 .50305 L .49819 .47385 L p 0 .663 0 r
F P
0 g
s
.49819 .47385 m .54757 .50305 L .56023 .49595 L p 0 .916 0 r
F P
0 g
s
.54757 .50305 m .54892 .56172 L .56195 .55484 L p 0 .1 0 r
F P
0 g
s
.56195 .55484 m .56023 .49595 L .54757 .50305 L p 0 .1 0 r
F P
0 g
s
.54892 .56172 m .54757 .50305 L .49819 .47385 L p 0 .663 0 r
F P
0 g
s
.70112 .47385 m .69559 .4176 L .65039 .38597 L p 0 .638 0 r
F P
0 g
s
.65039 .38597 m .65477 .44294 L .70112 .47385 L p 0 .638 0 r
F P
0 g
s
.70112 .47385 m .65477 .44294 L .66895 .43499 L p 0 .916 0 r
F P
0 g
s
.66895 .43499 m .71523 .46634 L .70112 .47385 L p 0 .916 0 r
F P
0 g
s
.49824 .41764 m .49819 .47385 L .4857 .48125 L p 0 .1 0 r
F P
0 g
s
.51059 .40993 m .51056 .40995 L .49824 .41764 L p 0 .93 0 r
F P
0 g
s
.49819 .47385 m .49824 .41764 L .51056 .40995 L p 0 .1 0 r
F P
0 g
s
.90066 .41722 m .91321 .41082 L .87396 .37883 L p 0 .914 1 r
F P
0 g
s
.87396 .37883 m .86128 .38559 L .90066 .41722 L p 0 .914 1 r
F P
0 g
s
.91321 .41082 m .90066 .41722 L .90069 .41728 L p 0 .562 .887 r
F P
0 g
s
.90069 .41728 m .90066 .41722 L .86128 .38559 L p 0 .599 .205 r
F P
0 g
s
.91325 .41088 m .90069 .41728 L .91203 .4735 L p 0 .114 .472 r
F P
0 g
s
.90069 .41728 m .91325 .41088 L .91321 .41082 L p 0 .562 .887 r
F P
0 g
s
.91203 .4735 m .90069 .41728 L p .86128 .38559 L 0 .599 .205 r
F P
0 g
s
.65441 .14828 m .65438 .14829 L p .70375 .23376 L 0 .618 .247 r
F P
0 g
s
.70011 .2907 m .70952 .28483 L .75311 .31926 L p 0 .911 1 r
F P
0 g
s
.70375 .23376 m .70952 .28483 L .75311 .31926 L p 0 .618 .247 r
F P
0 g
s
.70011 .2907 m .70952 .28483 L .70375 .23376 L p 0 .1 .396 r
F P
0 g
s
.64959 .20319 m .65875 .19691 L .70375 .23376 L p 0 .907 1 r
F P
0 g
s
.70952 .28483 m .70375 .23376 L .65875 .19691 L p 0 .618 .247 r
F P
0 g
s
.65438 .14829 m .65875 .19691 L .70375 .23376 L p 0 .618 .247 r
F P
0 g
s
.81273 .23177 m .8216 .28287 L .80928 .29017 L p 0 .1 .425 r
F P
0 g
s
.81273 .23177 m .8216 .28287 L .86217 .31741 L p 0 .594 .194 r
F P
0 g
s
.81273 .23177 m .8216 .28287 L .86217 .31741 L p 0 .594 .194 r
F P
0 g
s
.86217 .31741 m .8216 .28287 L .83407 .27549 L p 0 .911 1 r
F P
0 g
s
.83407 .27549 m .87452 .31043 L .86217 .31741 L p 0 .911 1 r
F P
0 g
s
.8216 .28287 m .81273 .23177 L .8248 .2243 L p 0 .1 .425 r
F P
0 g
s
.80538 .47609 m .81531 .47109 L .85607 .50044 L p 0 .916 1 r
F P
0 g
s
.8066 .41477 m .81531 .47109 L .85607 .50044 L p 0 .618 .247 r
F P
0 g
s
.856 .56374 m .86617 .55915 L .85607 .50044 L p 0 .114 .472 r
F P
0 g
s
.86617 .55915 m .85607 .50044 L .81531 .47109 L p 0 .618 .247 r
F P
0 g
s
.80538 .47609 m .81531 .47109 L .8066 .41477 L p 0 .1 .45 r
F P
0 g
s
.81531 .47109 m .8066 .41477 L .76444 .38298 L p 0 .618 .247 r
F P
0 g
s
.55999 .31637 m .57277 .30796 L .57281 .30802 L p 0 .546 .889 r
F P
0 g
s
.57281 .30802 m .56003 .31643 L .55999 .31637 L p 0 .546 .889 r
F P
0 g
s
.59929 .2906 m .61262 .28184 L .65896 .3164 L p 0 .911 0 r
F P
0 g
s
.61258 .28177 m .61262 .28184 L .65896 .3164 L p 0 .634 0 r
F P
0 g
s
.60948 .2307 m .61258 .28177 L p .65896 .3164 L 0 .634 0 r
F P
0 g
s
.61258 .28177 m .61262 .28184 L .65896 .3164 L p 0 .634 0 r
F P
0 g
s
.60948 .2307 m .61258 .28177 L p .65896 .3164 L 0 .634 0 r
F P
0 g
s
.67242 .308 m .65896 .3164 L .61262 .28184 L p 0 .911 0 r
F P
0 g
s
.60948 .2307 m .6226 .2217 L .6261 .27288 L p 0 .1 0 r
F P
0 g
s
.6261 .27288 m .61258 .28177 L .60948 .2307 L p 0 .1 0 r
F P
0 g
s
.80629 .28766 m .81862 .28033 L .80981 .2292 L p 0 .1 .423 r
F P
0 g
s
.75564 .19993 m .76767 .19209 L .80981 .2292 L p 0 .907 1 r
F P
0 g
s
.81862 .28033 m .80981 .2292 L .76767 .19209 L p 0 .594 .194 r
F P
0 g
s
.82189 .2217 m .80981 .2292 L .81862 .28033 L p 0 .1 .423 r
F P
0 g
s
.76027 .1434 m .76767 .19209 L .80981 .2292 L p 0 .594 .194 r
F P
0 g
s
.76027 .1434 m .76767 .19209 L .80981 .2292 L p 0 .594 .194 r
F P
0 g
s
.80981 .2292 m .82189 .2217 L .77984 .18416 L p 0 .907 1 r
F P
0 g
s
.77984 .18416 m .76767 .19209 L .80981 .2292 L p 0 .907 1 r
F P
0 g
s
.81862 .28033 m .80981 .2292 L .76767 .19209 L p 0 .594 .194 r
F P
0 g
s
.82189 .2217 m .80981 .2292 L .76767 .19209 L p 0 .907 1 r
F P
0 g
s
.76027 .1434 m .77206 .13541 L .77984 .18416 L p 0 .1 .396 r
F P
0 g
s
.77984 .18416 m .76767 .19209 L .76027 .1434 L p 0 .1 .396 r
F P
0 g
s
.75564 .19993 m .76767 .19209 L .76027 .1434 L p 0 .1 .396 r
F P
0 g
s
.76767 .19209 m .76027 .1434 L .71676 .10388 L p 0 .594 .194 r
F P
0 g
s
.77206 .13541 m .76027 .1434 L .76767 .19209 L p 0 .1 .396 r
F P
0 g
s
.76027 .1434 m .77206 .13541 L .72863 .09542 L p 0 .903 1 r
F P
0 g
s
.72863 .09542 m .71676 .10388 L .76027 .1434 L p 0 .903 1 r
F P
0 g
s
.76767 .19209 m .76027 .1434 L .71676 .10388 L p 0 .594 .194 r
F P
0 g
s
.6537 .56368 m .66744 .55683 L .71239 .58388 L p 0 .916 1 r
F P
0 g
s
.66281 .49801 m .67633 .49084 L .68138 .54987 L p 0 .1 .425 r
F P
0 g
s
.68138 .54987 m .66744 .55683 L .66281 .49801 L p 0 .1 .425 r
F P
0 g
s
.72625 .5773 m .71239 .58388 L .66744 .55683 L p 0 .916 1 r
F P
0 g
s
.71239 .41213 m .72625 .40437 L .73273 .46093 L p 0 .1 0 r
F P
0 g
s
.73273 .46093 m .71843 .46851 L .71239 .41213 L p 0 .1 0 r
F P
0 g
s
.82606 .57729 m .81152 .58386 L .76942 .55683 L p 0 .916 0 r
F P
0 g
s
.91203 .4735 m .92501 .46725 L .91325 .41088 L p 0 .114 .472 r
F P
0 g
s
.91325 .41088 m .91321 .41082 L .87396 .37883 L p 0 .594 .194 r
F P
0 g
s
.92501 .46725 m .91325 .41088 L p .87396 .37883 L 0 .594 .194 r
F P
0 g
s
.91321 .41082 m .92591 .40435 L .88679 .37198 L p 0 .914 1 r
F P
0 g
s
.88679 .37198 m .87396 .37883 L .91321 .41082 L p 0 .914 1 r
F P
0 g
s
.92594 .40441 m .91325 .41088 L .92501 .46725 L p 0 .114 .472 r
F P
0 g
s
.91325 .41088 m .92594 .40441 L .92591 .40435 L p 0 .562 .887 r
F P
0 g
s
.92591 .40435 m .91321 .41082 L .91325 .41088 L p 0 .562 .887 r
F P
0 g
s
.91325 .41088 m .91321 .41082 L .87396 .37883 L p 0 .594 .194 r
F P
0 g
s
.92501 .46725 m .91325 .41088 L p .87396 .37883 L 0 .594 .194 r
F P
0 g
s
.51086 .46634 m .56023 .49595 L p .51059 .40993 L 0 .661 0 r
F P
0 g
s
.51059 .40993 m .51056 .40995 L .51086 .46634 L p 0 .661 0 r
F P
0 g
s
.51056 .40995 m .51059 .40993 L .52308 .40214 L p 0 .93 0 r
F P
0 g
s
.51086 .46634 m .56023 .49595 L p .51059 .40993 L 0 .661 0 r
F P
0 g
s
.51059 .40993 m .51056 .40995 L .51086 .46634 L p 0 .661 0 r
F P
0 g
s
.41124 .58201 m .41121 .58195 L .42301 .57535 L p 0 .525 0 r
F P
0 g
s
.42301 .57535 m .42304 .57542 L .41124 .58201 L p 0 .525 0 r
F P
0 g
s
.46088 .49595 m .45977 .55479 L .44746 .56168 L p 0 .1 .365 r
F P
0 g
s
.4598 .55486 m .51056 .582 L p .46088 .49595 L 0 .671 .39 r
F P
0 g
s
.46088 .49595 m .45977 .55479 L .4598 .55486 L p 0 .671 .39 r
F P
0 g
s
.4598 .55486 m .51056 .582 L p .46088 .49595 L 0 .671 .39 r
F P
0 g
s
.51056 .582 m .4598 .55486 L .47229 .54787 L p 0 .916 1 r
F P
0 g
s
.47229 .54787 m .52305 .5754 L .51056 .582 L p 0 .916 1 r
F P
0 g
s
.46088 .49595 m .45977 .55479 L .4598 .55486 L p 0 .671 .39 r
F P
0 g
s
.45977 .55479 m .46088 .49595 L .47302 .48876 L p 0 .1 .365 r
F P
0 g
s
.60991 .40991 m .61304 .46634 L .59966 .47385 L p 0 .1 .396 r
F P
0 g
s
.61304 .46634 m .60991 .40991 L .62309 .40212 L p 0 .1 .396 r
F P
0 g
s
.60991 .40991 m .56199 .37787 L .54896 .386 L p 0 .914 1 r
F P
0 g
s
.61304 .46634 m .60991 .40991 L .56199 .37787 L p 0 .648 .324 r
F P
0 g
s
.56199 .37787 m .60991 .40991 L .62309 .40212 L p 0 .914 1 r
F P
0 g
s
.60991 .40991 m .61304 .46634 L .62662 .45873 L p 0 .1 .396 r
F P
0 g
s
.62662 .45873 m .62309 .40212 L .60991 .40991 L p 0 .1 .396 r
F P
0 g
s
.61304 .46634 m .60991 .40991 L .56199 .37787 L p 0 .648 .324 r
F P
0 g
s
.65959 .49595 m .61304 .46634 L .62662 .45873 L p 0 .916 1 r
F P
0 g
s
.62662 .45873 m .67311 .48876 L .65959 .49595 L p 0 .916 1 r
F P
0 g
s
.65959 .49595 m .61304 .46634 L .59966 .47385 L p 0 .916 1 r
F P
0 g
s
.66414 .55484 m .65959 .49595 L .61304 .46634 L p 0 .648 .324 r
F P
0 g
s
.61304 .46634 m .65959 .49595 L .67311 .48876 L p 0 .916 1 r
F P
0 g
s
.65959 .49595 m .66414 .55484 L .67808 .54785 L p 0 .1 .423 r
F P
0 g
s
.67808 .54785 m .67311 .48876 L .65959 .49595 L p 0 .1 .423 r
F P
0 g
s
.66414 .55484 m .65959 .49595 L .61304 .46634 L p 0 .648 .324 r
F P
0 g
s
.70926 .40991 m .66414 .37784 L .65039 .38597 L p 0 .914 0 r
F P
0 g
s
.71523 .46634 m .70926 .40991 L .66414 .37784 L p 0 .634 0 r
F P
0 g
s
.72313 .40212 m .67808 .3696 L p .67808 .3696 L 0 .63 .275 r
F P
0 g
s
.66414 .37784 m .70926 .40991 L .72313 .40212 L p 0 .914 0 r
F P
0 g
s
.70926 .40991 m .71523 .46634 L .72954 .45873 L p 0 .1 0 r
F P
0 g
s
.72954 .45873 m .72313 .40212 L .70926 .40991 L p 0 .1 0 r
F P
0 g
s
.71523 .46634 m .70926 .40991 L .66414 .37784 L p 0 .634 0 r
F P
0 g
s
.72313 .40212 m .67808 .3696 L .66414 .37784 L p 0 .914 0 r
F P
0 g
s
.66414 .37784 m .66895 .43499 L .71523 .46634 L p 0 .634 0 r
F P
0 g
s
.66414 .37784 m .66895 .43499 L .71523 .46634 L p 0 .634 0 r
F P
0 g
s
.67808 .3696 m .68334 .42692 L .72954 .45873 L p 0 .63 .275 r
F P
0 g
s
.72954 .45873 m .72313 .40212 L p .67808 .3696 L 0 .63 .275 r
F P
0 g
s
.72313 .40212 m .72313 .40212 L p .67808 .3696 L 0 .63 .275 r
F P
0 g
s
.56023 .49595 m .56195 .55484 L .54892 .56172 L p 0 .1 0 r
F P
0 g
s
.56023 .49595 m .56195 .55484 L .60991 .582 L p 0 .661 0 r
F P
0 g
s
.56023 .49595 m .56195 .55484 L .60991 .582 L p 0 .661 0 r
F P
0 g
s
.56023 .49595 m .51086 .46634 L .49819 .47385 L p 0 .916 0 r
F P
0 g
s
.56195 .55484 m .56023 .49595 L .51086 .46634 L p 0 .661 0 r
F P
0 g
s
.56195 .55484 m .56023 .49595 L .51086 .46634 L p 0 .661 0 r
F P
0 g
s
.60991 .582 m .56195 .55484 L .57516 .54785 L p 0 .916 0 r
F P
0 g
s
.57516 .54785 m .62309 .5754 L .60991 .582 L p 0 .916 0 r
F P
0 g
s
.56195 .55484 m .56023 .49595 L .57307 .48876 L p 0 .1 0 r
F P
0 g
s
.56023 .49595 m .51086 .46634 L .52371 .45873 L p 0 .916 0 r
F P
0 g
s
.52371 .45873 m .57307 .48876 L .56023 .49595 L p 0 .916 0 r
F P
0 g
s
.51086 .46634 m .56023 .49595 L .57307 .48876 L p 0 .916 0 r
F P
0 g
s
.56023 .49595 m .56195 .55484 L .57516 .54785 L p 0 .1 0 r
F P
0 g
s
.57516 .54785 m .57307 .48876 L .56023 .49595 L p 0 .1 0 r
F P
0 g
s
.51056 .40995 m .51086 .46634 L .49819 .47385 L p 0 .1 0 r
F P
0 g
s
.52308 .40214 m .52305 .40216 L .51056 .40995 L p 0 .93 0 r
F P
0 g
s
.51086 .46634 m .51056 .40995 L .52305 .40216 L p 0 .1 0 r
F P
0 g
s
.8248 .2243 m .83407 .27549 L .8216 .28287 L p 0 .1 .425 r
F P
0 g
s
.8248 .2243 m .83407 .27549 L .87452 .31043 L p 0 .59 .184 r
F P
0 g
s
.6718 .1359 m .6853 .12628 L .68528 .12629 L p 0 1 0 r
F P
0 g
s
.68528 .12629 m .67177 .1359 L .6718 .1359 L p 0 1 0 r
F P
0 g
s
.6718 .1359 m .67177 .1359 L p .72158 .22214 L 0 .612 0 r
F P
0 g
s
.72158 .22214 m .72791 .27335 L .77138 .3084 L p 0 .612 0 r
F P
0 g
s
.78557 .29997 m .77138 .3084 L .72791 .27335 L p 0 .911 0 r
F P
0 g
s
.72158 .22214 m .73542 .21311 L .7422 .26442 L p 0 .1 0 r
F P
0 g
s
.7422 .26442 m .72791 .27335 L .72158 .22214 L p 0 .1 0 r
F P
0 g
s
.73542 .21311 m .72158 .22214 L .72791 .27335 L p 0 .1 0 r
F P
0 g
s
.67177 .1359 m .67668 .18461 L .72158 .22214 L p 0 .612 0 r
F P
0 g
s
.72158 .22214 m .73542 .21311 L .69061 .17506 L p 0 .907 0 r
F P
0 g
s
.69061 .17506 m .67668 .18461 L .72158 .22214 L p 0 .907 0 r
F P
0 g
s
.72791 .27335 m .72158 .22214 L .67668 .18461 L p 0 .612 0 r
F P
0 g
s
.73542 .21311 m .72158 .22214 L .67668 .18461 L p 0 .907 0 r
F P
0 g
s
.67177 .1359 m .68528 .12629 L .69061 .17506 L p 0 .1 0 r
F P
0 g
s
.69061 .17506 m .67668 .18461 L .67177 .1359 L p 0 .1 0 r
F P
0 g
s
.61262 .28184 m .62614 .27294 L .67242 .308 L p 0 .911 0 r
F P
0 g
s
.6261 .27288 m .62614 .27294 L .67242 .308 L p 0 .63 .275 r
F P
0 g
s
.6261 .27288 m .62614 .27294 L .67242 .308 L p 0 .63 0 r
F P
0 g
s
.6226 .2217 m .6261 .27288 L p .67242 .308 L 0 .63 .275 r
F P
0 g
s
.6226 .2217 m .6261 .27288 L p .67242 .308 L 0 .63 0 r
F P
0 g
s
.76767 .19209 m .77984 .18416 L .82189 .2217 L p 0 .907 1 r
F P
0 g
s
.77206 .13541 m .77984 .18416 L .82189 .2217 L p 0 .59 .184 r
F P
0 g
s
.81862 .28033 m .83109 .27292 L .82189 .2217 L p 0 .1 .423 r
F P
0 g
s
.83109 .27292 m .82189 .2217 L .77984 .18416 L p 0 .59 .184 r
F P
0 g
s
.76767 .19209 m .77984 .18416 L .77206 .13541 L p 0 .1 .396 r
F P
0 g
s
.77984 .18416 m .77206 .13541 L .72863 .09542 L p 0 .59 .184 r
F P
0 g
s
.68156 .30229 m .67242 .308 L .62614 .27294 L p 0 .911 1 r
F P
0 g
s
.6226 .2217 m .63151 .21559 L .63529 .26684 L p 0 .1 .365 r
F P
0 g
s
.63529 .26684 m .6261 .27288 L .6226 .2217 L p 0 .1 .365 r
F P
0 g
s
.57314 .30771 m .58611 .29919 L .58614 .29925 L p 0 .546 0 r
F P
0 g
s
.58614 .29925 m .57318 .30778 L .57314 .30771 L p 0 .546 0 r
F P
0 g
s
.82539 .40475 m .83998 .39696 L .79809 .36414 L p 0 .914 0 r
F P
0 g
s
.79809 .36414 m .78338 .37238 L .82539 .40475 L p 0 .914 0 r
F P
0 g
s
.82539 .40475 m .83471 .46129 L .87529 .49118 L p 0 .612 0 r
F P
0 g
s
.83998 .39696 m .82539 .40475 L .83471 .46129 L p 0 .1 0 r
F P
0 g
s
.83471 .46129 m .82539 .40475 L .78338 .37238 L p 0 .612 0 r
F P
0 g
s
.89023 .484 m .87529 .49118 L .83471 .46129 L p 0 .916 0 r
F P
0 g
s
.87529 .49118 m .89023 .484 L .84979 .45369 L p 0 .916 0 r
F P
0 g
s
.84979 .45369 m .83471 .46129 L .87529 .49118 L p 0 .916 0 r
F P
0 g
s
.89023 .484 m .87529 .49118 L .88604 .55016 L p 0 .114 0 r
F P
0 g
s
.88604 .55016 m .87529 .49118 L .83471 .46129 L p 0 .612 0 r
F P
0 g
s
.82539 .40475 m .83998 .39696 L .84979 .45369 L p 0 .1 0 r
F P
0 g
s
.84979 .45369 m .83471 .46129 L .82539 .40475 L p 0 .1 0 r
F P
0 g
s
.66744 .55683 m .68138 .54987 L .72625 .5773 L p 0 .916 1 r
F P
0 g
s
.92501 .46725 m .93814 .46093 L .92594 .40441 L p 0 .114 .472 r
F P
0 g
s
.92594 .40441 m .92591 .40435 L .88679 .37198 L p 0 .59 .184 r
F P
0 g
s
.93814 .46093 m .92594 .40441 L p .88679 .37198 L 0 .59 .184 r
F P
0 g
s
.76942 .55683 m .78408 .54987 L .82606 .57729 L p 0 .916 0 r
F P
0 g
s
.67672 .49063 m .69043 .48336 L .69593 .54261 L p 0 .1 0 r
F P
0 g
s
.69593 .54261 m .68179 .54967 L .67672 .49063 L p 0 .1 0 r
F P
0 g
s
.74071 .57045 m .72665 .57711 L .68179 .54967 L p 0 .916 0 r
F P
0 g
s
.52371 .45873 m .57307 .48876 L p .52308 .40214 L 0 .658 0 r
F P
0 g
s
.52308 .40214 m .52305 .40216 L .52371 .45873 L p 0 .658 0 r
F P
0 g
s
.67808 .3696 m .72313 .40212 L .73255 .39683 L p 0 .914 1 r
F P
0 g
s
.72313 .40212 m .72954 .45873 L .73926 .45355 L p 0 .1 .423 r
F P
0 g
s
.73926 .45355 m .73255 .39683 L .72313 .40212 L p 0 .1 .423 r
F P
0 g
s
.47302 .48876 m .47225 .54781 L .45977 .55479 L p 0 .1 .365 r
F P
0 g
s
.47229 .54787 m .52305 .5754 L p .47302 .48876 L 0 .668 .382 r
F P
0 g
s
.47302 .48876 m .47225 .54781 L .47229 .54787 L p 0 .668 .382 r
F P
0 g
s
.62309 .40212 m .62662 .45873 L .61304 .46634 L p 0 .1 .396 r
F P
0 g
s
.62309 .40212 m .5752 .36962 L .56199 .37787 L p 0 .914 1 r
F P
0 g
s
.62662 .45873 m .62309 .40212 L .5752 .36962 L p 0 .645 .315 r
F P
0 g
s
.67311 .48876 m .62662 .45873 L .61304 .46634 L p 0 .916 1 r
F P
0 g
s
.67808 .54785 m .67311 .48876 L .62662 .45873 L p 0 .645 .315 r
F P
0 g
s
.72954 .45873 m .72313 .40212 L .67808 .3696 L p 0 .63 0 r
F P
0 g
s
.68334 .42692 m .72954 .45873 L p .72954 .45873 L 0 .63 0 r
F P
0 g
s
.67808 .3696 m .68334 .42692 L p .72954 .45873 L 0 .63 0 r
F P
0 g
s
.68334 .42692 m .68334 .42692 L p .72954 .45873 L 0 .63 0 r
F P
0 g
s
.72954 .45873 m .68334 .42692 L .69312 .42143 L p 0 .916 1 r
F P
0 g
s
.69312 .42143 m .73926 .45355 L .72954 .45873 L p 0 .916 1 r
F P
0 g
s
.57307 .48876 m .57516 .54785 L .56195 .55484 L p 0 .1 0 r
F P
0 g
s
.57307 .48876 m .57516 .54785 L .62309 .5754 L p 0 .658 0 r
F P
0 g
s
.57307 .48876 m .52371 .45873 L .51086 .46634 L p 0 .916 0 r
F P
0 g
s
.57516 .54785 m .57307 .48876 L .52371 .45873 L p 0 .658 0 r
F P
0 g
s
.52305 .40216 m .52371 .45873 L .51086 .46634 L p 0 .1 0 r
F P
0 g
s
.42338 .57522 m .42335 .57516 L .43532 .56847 L p 0 .525 .891 r
F P
0 g
s
.43532 .56847 m .43535 .56853 L .42338 .57522 L p 0 .525 .891 r
F P
0 g
s
.52341 .40193 m .52344 .40192 L .53611 .39401 L p 0 .93 .764 r
F P
0 g
s
.52408 .45851 m .57344 .48855 L p .52344 .40192 L 0 .658 .35 r
F P
0 g
s
.52344 .40192 m .52341 .40193 L .52408 .45851 L p 0 .658 .35 r
F P
0 g
s
.57344 .48855 m .57555 .54765 L .62347 .5752 L p 0 .658 .35 r
F P
0 g
s
.62347 .5752 m .57555 .54765 L .58896 .54056 L p 0 .916 1 r
F P
0 g
s
.58896 .54056 m .63683 .56851 L .62347 .5752 L p 0 .916 1 r
F P
0 g
s
.57555 .54765 m .57344 .48855 L .58646 .48125 L p 0 .1 .396 r
F P
0 g
s
.57344 .48855 m .52408 .45851 L .53712 .45078 L p 0 .916 1 r
F P
0 g
s
.53712 .45078 m .58646 .48125 L .57344 .48855 L p 0 .916 1 r
F P
0 g
s
.52408 .45851 m .57344 .48855 L .58646 .48125 L p 0 .916 1 r
F P
0 g
s
.57344 .48855 m .57555 .54765 L .58896 .54056 L p 0 .1 .396 r
F P
0 g
s
.58896 .54056 m .58646 .48125 L .57344 .48855 L p 0 .1 .396 r
F P
0 g
s
.57555 .54765 m .57344 .48855 L .52408 .45851 L p 0 .658 .35 r
F P
0 g
s
.47265 .54767 m .52341 .5752 L p .47338 .48855 L 0 .668 0 r
F P
0 g
s
.52341 .5752 m .47265 .54767 L .48532 .54058 L p 0 .916 0 r
F P
0 g
s
.48532 .54058 m .53608 .56851 L .52341 .5752 L p 0 .916 0 r
F P
0 g
s
.47338 .48855 m .47261 .54761 L .47265 .54767 L p 0 .668 0 r
F P
0 g
s
.47261 .54761 m .47338 .48855 L .4857 .48125 L p 0 .1 0 r
F P
0 g
s
.6735 .48855 m .62701 .45851 L .64079 .45078 L p 0 .916 0 r
F P
0 g
s
.64079 .45078 m .68721 .48125 L .6735 .48855 L p 0 .916 0 r
F P
0 g
s
.62701 .45851 m .62347 .40189 L .63683 .39399 L p 0 .1 0 r
F P
0 g
s
.62701 .45851 m .6735 .48855 L .68721 .48125 L p 0 .916 0 r
F P
0 g
s
.6735 .48855 m .67848 .54765 L .69263 .54056 L p 0 .1 0 r
F P
0 g
s
.69263 .54056 m .68721 .48125 L .6735 .48855 L p 0 .1 0 r
F P
0 g
s
.67848 .54765 m .6735 .48855 L .62701 .45851 L p 0 .645 0 r
F P
0 g
s
.57558 .36938 m .62347 .40189 L .63683 .39399 L p 0 .914 0 r
F P
0 g
s
.62347 .40189 m .62701 .45851 L .64079 .45078 L p 0 .1 0 r
F P
0 g
s
.64079 .45078 m .63683 .39399 L .62347 .40189 L p 0 .1 0 r
F P
0 g
s
.62701 .45851 m .62347 .40189 L .57558 .36938 L p 0 .645 0 r
F P
0 g
s
.53611 .39401 m .53608 .39403 L .52341 .40193 L p 0 .93 .764 r
F P
0 g
s
.52408 .45851 m .52341 .40193 L .53608 .39403 L p 0 .1 .365 r
F P
0 g
s
.62614 .27294 m .63532 .2669 L .68156 .30229 L p 0 .911 1 r
F P
0 g
s
.63529 .26684 m .63532 .2669 L .68156 .30229 L p 0 .627 .269 r
F P
0 g
s
.63151 .21559 m .63529 .26684 L p .68156 .30229 L 0 .627 .269 r
F P
0 g
s
.63529 .26684 m .63532 .2669 L .68156 .30229 L p 0 .627 .269 r
F P
0 g
s
.63151 .21559 m .63529 .26684 L p .68156 .30229 L 0 .627 .269 r
F P
0 g
s
.6908 .29652 m .68156 .30229 L .63532 .2669 L p 0 .911 1 r
F P
0 g
s
.63151 .21559 m .64051 .20942 L .64456 .26074 L p 0 .1 .365 r
F P
0 g
s
.64456 .26074 m .63529 .26684 L .63151 .21559 L p 0 .1 .365 r
F P
0 g
s
.6853 .12628 m .68528 .12629 L p .73542 .21311 L 0 .607 0 r
F P
0 g
s
.6853 .12628 m .699 .11653 L .69897 .11653 L p 0 1 0 r
F P
0 g
s
.69897 .11653 m .68528 .12629 L .6853 .12628 L p 0 1 0 r
F P
0 g
s
.6853 .12628 m .68528 .12629 L p .73542 .21311 L 0 .607 0 r
F P
0 g
s
.72791 .27335 m .7422 .26442 L .78557 .29997 L p 0 .911 0 r
F P
0 g
s
.73542 .21311 m .7422 .26442 L .78557 .29997 L p 0 .607 0 r
F P
0 g
s
.73542 .21311 m .7422 .26442 L .78557 .29997 L p 0 .607 0 r
F P
0 g
s
.79995 .29142 m .78557 .29997 L .7422 .26442 L p 0 .911 0 r
F P
0 g
s
.73542 .21311 m .74946 .20396 L .75669 .25537 L p 0 .1 0 r
F P
0 g
s
.75669 .25537 m .7422 .26442 L .73542 .21311 L p 0 .1 0 r
F P
0 g
s
.72791 .27335 m .7422 .26442 L .73542 .21311 L p 0 .1 0 r
F P
0 g
s
.67668 .18461 m .69061 .17506 L .73542 .21311 L p 0 .907 0 r
F P
0 g
s
.7422 .26442 m .73542 .21311 L .69061 .17506 L p 0 .607 0 r
F P
0 g
s
.74946 .20396 m .73542 .21311 L .7422 .26442 L p 0 .1 0 r
F P
0 g
s
.68528 .12629 m .69061 .17506 L .73542 .21311 L p 0 .607 0 r
F P
0 g
s
.68528 .12629 m .69061 .17506 L .73542 .21311 L p 0 .607 0 r
F P
0 g
s
.73542 .21311 m .74946 .20396 L .70473 .16538 L p 0 .907 0 r
F P
0 g
s
.70473 .16538 m .69061 .17506 L .73542 .21311 L p 0 .907 0 r
F P
0 g
s
.7422 .26442 m .73542 .21311 L .69061 .17506 L p 0 .607 0 r
F P
0 g
s
.74946 .20396 m .73542 .21311 L .69061 .17506 L p 0 .907 0 r
F P
0 g
s
.68528 .12629 m .69897 .11653 L .70473 .16538 L p 0 .1 0 r
F P
0 g
s
.70473 .16538 m .69061 .17506 L .68528 .12629 L p 0 .1 0 r
F P
0 g
s
.84594 .56829 m .83597 .5728 L .83594 .57282 L p 0 .1 .1 r
F P
0 g
s
.83594 .57282 m .83597 .5728 L p .78582 .48597 L 0 .627 .269 r
F P
0 g
s
.83594 .57282 m .83597 .5728 L p .78582 .48597 L 0 .627 .269 r
F P
0 g
s
.73566 .3991 m .74245 .45578 L .78582 .48597 L p 0 .627 .269 r
F P
0 g
s
.73566 .3991 m .74245 .45578 L .78582 .48597 L p 0 .627 .269 r
F P
0 g
s
.79556 .48106 m .78582 .48597 L .74245 .45578 L p 0 .916 1 r
F P
0 g
s
.78582 .48597 m .79556 .48106 L .75226 .45057 L p 0 .916 1 r
F P
0 g
s
.75226 .45057 m .74245 .45578 L .78582 .48597 L p 0 .916 1 r
F P
0 g
s
.78582 .48597 m .79405 .54515 L .83594 .57282 L p 0 .627 .269 r
F P
0 g
s
.78582 .48597 m .79405 .54515 L .83594 .57282 L p 0 .627 .269 r
F P
0 g
s
.79556 .48106 m .78582 .48597 L .79405 .54515 L p 0 .1 .45 r
F P
0 g
s
.78582 .48597 m .79556 .48106 L .80411 .54038 L p 0 .1 .45 r
F P
0 g
s
.80411 .54038 m .79405 .54515 L .78582 .48597 L p 0 .1 .45 r
F P
0 g
s
.73566 .3991 m .74517 .39378 L .75226 .45057 L p 0 .1 .425 r
F P
0 g
s
.75226 .45057 m .74245 .45578 L .73566 .3991 L p 0 .1 .425 r
F P
0 g
s
.79405 .54515 m .78582 .48597 L .74245 .45578 L p 0 .627 .269 r
F P
0 g
s
.79405 .54515 m .78582 .48597 L .74245 .45578 L p 0 .627 .269 r
F P
0 g
s
.83594 .57282 m .84592 .56831 L .84594 .56829 L p 0 .1 .1 r
F P
0 g
s
.84592 .56831 m .83594 .57282 L .79405 .54515 L p 0 .916 1 r
F P
0 g
s
.78408 .54987 m .79405 .54515 L .83594 .57282 L p 0 .916 1 r
F P
0 g
s
.58611 .29919 m .59925 .29054 L .59929 .2906 L p 0 .546 0 r
F P
0 g
s
.59929 .2906 m .58614 .29925 L .58611 .29919 L p 0 .546 0 r
F P
0 g
s
.83471 .46129 m .84979 .45369 L .83998 .39696 L p 0 .1 0 r
F P
0 g
s
.84979 .45369 m .83998 .39696 L .79809 .36414 L p 0 .607 0 r
F P
0 g
s
.83998 .39696 m .85477 .38907 L .81301 .35579 L p 0 .914 0 r
F P
0 g
s
.81301 .35579 m .79809 .36414 L .83998 .39696 L p 0 .914 0 r
F P
0 g
s
.83998 .39696 m .84979 .45369 L .89023 .484 L p 0 .607 0 r
F P
0 g
s
.83998 .39696 m .84979 .45369 L .89023 .484 L p 0 .607 0 r
F P
0 g
s
.85477 .38907 m .83998 .39696 L .84979 .45369 L p 0 .1 0 r
F P
0 g
s
.84979 .45369 m .83998 .39696 L .79809 .36414 L p 0 .607 0 r
F P
0 g
s
.83471 .46129 m .84979 .45369 L .89023 .484 L p 0 .916 0 r
F P
0 g
s
.83998 .39696 m .85477 .38907 L .86508 .44597 L p 0 .1 0 r
F P
0 g
s
.86508 .44597 m .84979 .45369 L .83998 .39696 L p 0 .1 0 r
F P
0 g
s
.90537 .47671 m .89023 .484 L .84979 .45369 L p 0 .916 0 r
F P
0 g
s
.88604 .55016 m .90148 .54319 L .89023 .484 L p 0 .114 0 r
F P
0 g
s
.90148 .54319 m .89023 .484 L .84979 .45369 L p 0 .607 0 r
F P
0 g
s
.89023 .484 m .90537 .47671 L .86508 .44597 L p 0 .916 0 r
F P
0 g
s
.86508 .44597 m .84979 .45369 L .89023 .484 L p 0 .916 0 r
F P
0 g
s
.90537 .47671 m .89023 .484 L .90148 .54319 L p 0 .114 0 r
F P
0 g
s
.90148 .54319 m .89023 .484 L .84979 .45369 L p 0 .607 0 r
F P
0 g
s
.73255 .39683 m .68755 .364 L .67808 .3696 L p 0 .914 1 r
F P
0 g
s
.73926 .45355 m .73255 .39683 L .68755 .364 L p 0 .627 .269 r
F P
0 g
s
.68755 .364 m .73255 .39683 L .74205 .39148 L p 0 .914 1 r
F P
0 g
s
.73255 .39683 m .73926 .45355 L .74907 .44833 L p 0 .1 .423 r
F P
0 g
s
.74907 .44833 m .74205 .39148 L .73255 .39683 L p 0 .1 .423 r
F P
0 g
s
.73926 .45355 m .73255 .39683 L .68755 .364 L p 0 .627 .269 r
F P
0 g
s
.68179 .54967 m .69593 .54261 L .74071 .57045 L p 0 .916 0 r
F P
0 g
s
.69043 .48336 m .70433 .47599 L .71028 .53545 L p 0 .1 0 r
F P
0 g
s
.71028 .53545 m .69593 .54261 L .69043 .48336 L p 0 .1 0 r
F P
0 g
s
.75497 .56368 m .74071 .57045 L .69593 .54261 L p 0 .916 0 r
F P
0 g
s
.63532 .2669 m .6446 .2608 L .6908 .29652 L p 0 .911 1 r
F P
0 g
s
.64456 .26074 m .6446 .2608 L .6908 .29652 L p 0 .624 .261 r
F P
0 g
s
.64051 .20942 m .64456 .26074 L p .6908 .29652 L 0 .624 .261 r
F P
0 g
s
.64456 .26074 m .6446 .2608 L .6908 .29652 L p 0 .624 .261 r
F P
0 g
s
.64051 .20942 m .64456 .26074 L p .6908 .29652 L 0 .624 .261 r
F P
0 g
s
.70011 .2907 m .6908 .29652 L .6446 .2608 L p 0 .911 1 r
F P
0 g
s
.64051 .20942 m .64959 .20319 L .65392 .25458 L p 0 .1 .365 r
F P
0 g
s
.65392 .25458 m .64456 .26074 L .64051 .20942 L p 0 .1 .365 r
F P
0 g
s
.43535 .56853 m .43532 .56847 L .44746 .56168 L p 0 .525 .891 r
F P
0 g
s
.44746 .56168 m .44749 .56174 L .43535 .56853 L p 0 .525 .891 r
F P
0 g
s
.53712 .45078 m .58646 .48125 L p .53611 .39401 L 0 .655 .342 r
F P
0 g
s
.53611 .39401 m .53608 .39403 L .53712 .45078 L p 0 .655 .342 r
F P
0 g
s
.53608 .39403 m .53611 .39401 L .54896 .386 L p 0 .93 .764 r
F P
0 g
s
.53712 .45078 m .58646 .48125 L p .53611 .39401 L 0 .655 .342 r
F P
0 g
s
.53611 .39401 m .53608 .39403 L .53712 .45078 L p 0 .655 .342 r
F P
0 g
s
.58646 .48125 m .58896 .54056 L .57555 .54765 L p 0 .1 .396 r
F P
0 g
s
.58646 .48125 m .58896 .54056 L .63683 .56851 L p 0 .655 .342 r
F P
0 g
s
.58646 .48125 m .58896 .54056 L .63683 .56851 L p 0 .655 .342 r
F P
0 g
s
.63683 .56851 m .58896 .54056 L .60256 .53337 L p 0 .916 1 r
F P
0 g
s
.60256 .53337 m .65039 .56172 L .63683 .56851 L p 0 .916 1 r
F P
0 g
s
.58896 .54056 m .58646 .48125 L .59966 .47385 L p 0 .1 .396 r
F P
0 g
s
.58646 .48125 m .53712 .45078 L .55035 .44294 L p 0 .916 1 r
F P
0 g
s
.55035 .44294 m .59966 .47385 L .58646 .48125 L p 0 .916 1 r
F P
0 g
s
.58646 .48125 m .53712 .45078 L .52408 .45851 L p 0 .916 1 r
F P
0 g
s
.58896 .54056 m .58646 .48125 L .53712 .45078 L p 0 .655 .342 r
F P
0 g
s
.53712 .45078 m .58646 .48125 L .59966 .47385 L p 0 .916 1 r
F P
0 g
s
.58646 .48125 m .58896 .54056 L .60256 .53337 L p 0 .1 .396 r
F P
0 g
s
.60256 .53337 m .59966 .47385 L .58646 .48125 L p 0 .1 .396 r
F P
0 g
s
.58896 .54056 m .58646 .48125 L .53712 .45078 L p 0 .655 .342 r
F P
0 g
s
.4857 .48125 m .48528 .54052 L .47261 .54761 L p 0 .1 0 r
F P
0 g
s
.48532 .54058 m .53608 .56851 L p .4857 .48125 L 0 .666 0 r
F P
0 g
s
.4857 .48125 m .48528 .54052 L .48532 .54058 L p 0 .666 0 r
F P
0 g
s
.48532 .54058 m .53608 .56851 L p .4857 .48125 L 0 .666 0 r
F P
0 g
s
.53608 .56851 m .48532 .54058 L .49817 .5334 L p 0 .916 0 r
F P
0 g
s
.49817 .5334 m .54892 .56172 L .53608 .56851 L p 0 .916 0 r
F P
0 g
s
.4857 .48125 m .48528 .54052 L .48532 .54058 L p 0 .666 0 r
F P
0 g
s
.48528 .54052 m .4857 .48125 L .49819 .47385 L p 0 .1 0 r
F P
0 g
s
.63683 .39399 m .64079 .45078 L .62701 .45851 L p 0 .1 0 r
F P
0 g
s
.68721 .48125 m .64079 .45078 L .65477 .44294 L p 0 .916 0 r
F P
0 g
s
.65477 .44294 m .70112 .47385 L .68721 .48125 L p 0 .916 0 r
F P
0 g
s
.68721 .48125 m .64079 .45078 L .62701 .45851 L p 0 .916 0 r
F P
0 g
s
.69263 .54056 m .68721 .48125 L .64079 .45078 L p 0 .641 0 r
F P
0 g
s
.64079 .45078 m .68721 .48125 L .70112 .47385 L p 0 .916 0 r
F P
0 g
s
.68721 .48125 m .69263 .54056 L .70698 .53337 L p 0 .1 0 r
F P
0 g
s
.70698 .53337 m .70112 .47385 L .68721 .48125 L p 0 .1 0 r
F P
0 g
s
.69263 .54056 m .68721 .48125 L .64079 .45078 L p 0 .641 0 r
F P
0 g
s
.70112 .47385 m .65477 .44294 L .64079 .45078 L p 0 .916 0 r
F P
0 g
s
.59966 .47385 m .60256 .53337 L .65039 .56172 L p 0 .652 .333 r
F P
0 g
s
.59966 .47385 m .60256 .53337 L .65039 .56172 L p 0 .652 .333 r
F P
0 g
s
.61304 .46634 m .61636 .52608 L .66414 .55484 L p 0 .648 .324 r
F P
0 g
s
.61304 .46634 m .61636 .52608 L .66414 .55484 L p 0 .648 .324 r
F P
0 g
s
.62662 .45873 m .63036 .51868 L .67808 .54785 L p 0 .645 .315 r
F P
0 g
s
.62701 .45851 m .63077 .51847 L .67848 .54765 L p 0 .645 0 r
F P
0 g
s
.64079 .45078 m .64499 .51095 L .69263 .54056 L p 0 .641 0 r
F P
0 g
s
.64079 .45078 m .64499 .51095 L .69263 .54056 L p 0 .641 0 r
F P
0 g
s
.65477 .44294 m .65942 .50333 L .70698 .53337 L p 0 .638 0 r
F P
0 g
s
.70698 .53337 m .70112 .47385 L .65477 .44294 L p 0 .638 0 r
F P
0 g
s
.64079 .45078 m .63683 .39399 L .65039 .38597 L p 0 .1 0 r
F P
0 g
s
.63683 .39399 m .58899 .36102 L .57558 .36938 L p 0 .914 0 r
F P
0 g
s
.64079 .45078 m .63683 .39399 L .58899 .36102 L p 0 .641 0 r
F P
0 g
s
.58899 .36102 m .63683 .39399 L .65039 .38597 L p 0 .914 0 r
F P
0 g
s
.63683 .39399 m .64079 .45078 L .65477 .44294 L p 0 .1 0 r
F P
0 g
s
.65477 .44294 m .65039 .38597 L .63683 .39399 L p 0 .1 0 r
F P
0 g
s
.64079 .45078 m .63683 .39399 L .58899 .36102 L p 0 .641 0 r
F P
0 g
s
.65039 .38597 m .65477 .44294 L .64079 .45078 L p 0 .1 0 r
F P
0 g
s
.65039 .38597 m .60259 .35253 L .58899 .36102 L p 0 .914 0 r
F P
0 g
s
.55035 .44294 m .59966 .47385 L p .54896 .386 L 0 .652 .333 r
F P
0 g
s
.55035 .44294 m .59966 .47385 L p .54896 .386 L 0 .652 .333 r
F P
0 g
s
.56377 .43499 m .61304 .46634 L p .56199 .37787 L 0 .648 .324 r
F P
0 g
s
.56377 .43499 m .61304 .46634 L p .56199 .37787 L 0 .648 .324 r
F P
0 g
s
.57739 .42692 m .62662 .45873 L p .5752 .36962 L 0 .645 .315 r
F P
0 g
s
.57778 .42668 m .62701 .45851 L p .57558 .36938 L 0 .645 0 r
F P
0 g
s
.59161 .41849 m .64079 .45078 L p .58899 .36102 L 0 .641 0 r
F P
0 g
s
.59161 .41849 m .64079 .45078 L p .58899 .36102 L 0 .641 0 r
F P
0 g
s
.60564 .41018 m .65477 .44294 L p .60259 .35253 L 0 .638 0 r
F P
0 g
s
.65477 .44294 m .65039 .38597 L .60259 .35253 L p 0 .638 0 r
F P
0 g
s
.53608 .39403 m .53712 .45078 L .52408 .45851 L p 0 .1 .365 r
F P
0 g
s
.54896 .386 m .54892 .38601 L .53608 .39403 L p 0 .93 .764 r
F P
0 g
s
.53712 .45078 m .53608 .39403 L .54892 .38601 L p 0 .1 .365 r
F P
0 g
s
.84592 .56831 m .84594 .56829 L p .79556 .48106 L 0 .624 .261 r
F P
0 g
s
.856 .56374 m .84594 .56829 L .84592 .56831 L p 0 .1 .1 r
F P
0 g
s
.84592 .56831 m .84594 .56829 L p .79556 .48106 L 0 .624 .261 r
F P
0 g
s
.74245 .45578 m .75226 .45057 L .79556 .48106 L p 0 .916 1 r
F P
0 g
s
.74517 .39378 m .75226 .45057 L .79556 .48106 L p 0 .624 .261 r
F P
0 g
s
.74517 .39378 m .75226 .45057 L .79556 .48106 L p 0 .624 .261 r
F P
0 g
s
.80538 .47609 m .79556 .48106 L .75226 .45057 L p 0 .916 1 r
F P
0 g
s
.79405 .54515 m .80411 .54038 L .79556 .48106 L p 0 .1 .45 r
F P
0 g
s
.80411 .54038 m .79556 .48106 L .75226 .45057 L p 0 .624 .261 r
F P
0 g
s
.79556 .48106 m .80538 .47609 L .76217 .44532 L p 0 .916 1 r
F P
0 g
s
.76217 .44532 m .75226 .45057 L .79556 .48106 L p 0 .916 1 r
F P
0 g
s
.79556 .48106 m .80411 .54038 L .84592 .56831 L p 0 .624 .261 r
F P
0 g
s
.79556 .48106 m .80411 .54038 L .84592 .56831 L p 0 .624 .261 r
F P
0 g
s
.80538 .47609 m .79556 .48106 L .80411 .54038 L p 0 .1 .45 r
F P
0 g
s
.80411 .54038 m .79556 .48106 L .75226 .45057 L p 0 .624 .261 r
F P
0 g
s
.79556 .48106 m .80538 .47609 L .81426 .53556 L p 0 .1 .45 r
F P
0 g
s
.81426 .53556 m .80411 .54038 L .79556 .48106 L p 0 .1 .45 r
F P
0 g
s
.74517 .39378 m .75476 .38841 L .76217 .44532 L p 0 .1 .425 r
F P
0 g
s
.76217 .44532 m .75226 .45057 L .74517 .39378 L p 0 .1 .425 r
F P
0 g
s
.79405 .54515 m .80411 .54038 L .84592 .56831 L p 0 .916 1 r
F P
0 g
s
.84592 .56831 m .85598 .56376 L .856 .56374 L p 0 .1 .1 r
F P
0 g
s
.85598 .56376 m .84592 .56831 L .80411 .54038 L p 0 .916 1 r
F P
0 g
s
.74205 .39148 m .69712 .35834 L .68755 .364 L p 0 .914 1 r
F P
0 g
s
.74907 .44833 m .74205 .39148 L .69712 .35834 L p 0 .624 .261 r
F P
0 g
s
.69712 .35834 m .74205 .39148 L .75165 .38609 L p 0 .914 1 r
F P
0 g
s
.74205 .39148 m .74907 .44833 L .75898 .44305 L p 0 .1 .423 r
F P
0 g
s
.75898 .44305 m .75165 .38609 L .74205 .39148 L p 0 .1 .423 r
F P
0 g
s
.74907 .44833 m .74205 .39148 L .69712 .35834 L p 0 .624 .261 r
F P
0 g
s
.699 .11653 m .69897 .11653 L p .74946 .20396 L 0 .601 0 r
F P
0 g
s
.7422 .26442 m .75669 .25537 L .79995 .29142 L p 0 .911 0 r
F P
0 g
s
.74946 .20396 m .75669 .25537 L .79995 .29142 L p 0 .601 0 r
F P
0 g
s
.7422 .26442 m .75669 .25537 L .74946 .20396 L p 0 .1 0 r
F P
0 g
s
.69061 .17506 m .70473 .16538 L .74946 .20396 L p 0 .907 0 r
F P
0 g
s
.75669 .25537 m .74946 .20396 L .70473 .16538 L p 0 .601 0 r
F P
0 g
s
.69897 .11653 m .70473 .16538 L .74946 .20396 L p 0 .601 0 r
F P
0 g
s
.6446 .2608 m .65396 .25464 L .70011 .2907 L p 0 .911 1 r
F P
0 g
s
.65392 .25458 m .65396 .25464 L .70011 .2907 L p 0 .621 .254 r
F P
0 g
s
.64959 .20319 m .65392 .25458 L p .70011 .2907 L 0 .621 .254 r
F P
0 g
s
.65392 .25458 m .65396 .25464 L .70011 .2907 L p 0 .621 .254 r
F P
0 g
s
.64959 .20319 m .65392 .25458 L p .70011 .2907 L 0 .621 .254 r
F P
0 g
s
.70952 .28483 m .70011 .2907 L .65396 .25464 L p 0 .911 1 r
F P
0 g
s
.64959 .20319 m .65875 .19691 L .66338 .24836 L p 0 .1 .365 r
F P
0 g
s
.66338 .24836 m .65392 .25458 L .64959 .20319 L p 0 .1 .365 r
F P
0 g
s
.59925 .29054 m .61258 .28177 L .61262 .28184 L p 0 .546 0 r
F P
0 g
s
.61262 .28184 m .59929 .2906 L .59925 .29054 L p 0 .546 0 r
F P
0 g
s
.84979 .45369 m .86508 .44597 L .85477 .38907 L p 0 .1 0 r
F P
0 g
s
.86508 .44597 m .85477 .38907 L .81301 .35579 L p 0 .601 0 r
F P
0 g
s
.84979 .45369 m .86508 .44597 L .90537 .47671 L p 0 .916 0 r
F P
0 g
s
.85477 .38907 m .86508 .44597 L .90537 .47671 L p 0 .601 0 r
F P
0 g
s
.90148 .54319 m .91714 .53611 L .90537 .47671 L p 0 .114 0 r
F P
0 g
s
.91714 .53611 m .90537 .47671 L .86508 .44597 L p 0 .601 0 r
F P
0 g
s
.85598 .56376 m .856 .56374 L p .80538 .47609 L 0 .621 .254 r
F P
0 g
s
.86617 .55915 m .856 .56374 L .85598 .56376 L p 0 .1 .1 r
F P
0 g
s
.85598 .56376 m .856 .56374 L p .80538 .47609 L 0 .621 .254 r
F P
0 g
s
.75226 .45057 m .76217 .44532 L .80538 .47609 L p 0 .916 1 r
F P
0 g
s
.75476 .38841 m .76217 .44532 L .80538 .47609 L p 0 .621 .254 r
F P
0 g
s
.75476 .38841 m .76217 .44532 L .80538 .47609 L p 0 .621 .254 r
F P
0 g
s
.81531 .47109 m .80538 .47609 L .76217 .44532 L p 0 .916 1 r
F P
0 g
s
.80538 .47609 m .81426 .53556 L .85598 .56376 L p 0 .621 .254 r
F P
0 g
s
.80538 .47609 m .81426 .53556 L .85598 .56376 L p 0 .621 .254 r
F P
0 g
s
.80538 .47609 m .81531 .47109 L .82452 .53069 L p 0 .1 .45 r
F P
0 g
s
.82452 .53069 m .81426 .53556 L .80538 .47609 L p 0 .1 .45 r
F P
0 g
s
.75476 .38841 m .76444 .38298 L .77217 .44002 L p 0 .1 .425 r
F P
0 g
s
.77217 .44002 m .76217 .44532 L .75476 .38841 L p 0 .1 .425 r
F P
0 g
s
.80411 .54038 m .81426 .53556 L .80538 .47609 L p 0 .1 .45 r
F P
0 g
s
.81426 .53556 m .80538 .47609 L .76217 .44532 L p 0 .621 .254 r
F P
0 g
s
.80538 .47609 m .81531 .47109 L .77217 .44002 L p 0 .916 1 r
F P
0 g
s
.77217 .44002 m .76217 .44532 L .80538 .47609 L p 0 .916 1 r
F P
0 g
s
.81531 .47109 m .80538 .47609 L .81426 .53556 L p 0 .1 .45 r
F P
0 g
s
.81426 .53556 m .80538 .47609 L .76217 .44532 L p 0 .621 .254 r
F P
0 g
s
.80411 .54038 m .81426 .53556 L .85598 .56376 L p 0 .916 1 r
F P
0 g
s
.85598 .56376 m .86614 .55917 L .86617 .55915 L p 0 .1 .1 r
F P
0 g
s
.86614 .55917 m .85598 .56376 L .81426 .53556 L p 0 .916 1 r
F P
0 g
s
.70433 .47599 m .71843 .46851 L .72483 .52819 L p 0 .1 0 r
F P
0 g
s
.72483 .52819 m .71028 .53545 L .70433 .47599 L p 0 .1 0 r
F P
0 g
s
.69593 .54261 m .71028 .53545 L .75497 .56368 L p 0 .916 0 r
F P
0 g
s
.70502 .11224 m .71676 .10388 L .71673 .10388 L p 0 1 .86 r
F P
0 g
s
.71673 .10388 m .705 .11224 L .70502 .11224 L p 0 1 .86 r
F P
0 g
s
.70502 .11224 m .705 .11224 L p .75564 .19993 L 0 .599 .205 r
F P
0 g
s
.75564 .19993 m .76308 .25139 L .80629 .28766 L p 0 .599 .205 r
F P
0 g
s
.81862 .28033 m .80629 .28766 L .76308 .25139 L p 0 .911 1 r
F P
0 g
s
.75564 .19993 m .76767 .19209 L .7755 .24363 L p 0 .1 .396 r
F P
0 g
s
.7755 .24363 m .76308 .25139 L .75564 .19993 L p 0 .1 .396 r
F P
0 g
s
.76767 .19209 m .75564 .19993 L .76308 .25139 L p 0 .1 .396 r
F P
0 g
s
.705 .11224 m .71095 .16111 L .75564 .19993 L p 0 .599 .205 r
F P
0 g
s
.75564 .19993 m .76767 .19209 L .72307 .15281 L p 0 .907 1 r
F P
0 g
s
.72307 .15281 m .71095 .16111 L .75564 .19993 L p 0 .907 1 r
F P
0 g
s
.76308 .25139 m .75564 .19993 L .71095 .16111 L p 0 .599 .205 r
F P
0 g
s
.76767 .19209 m .75564 .19993 L .71095 .16111 L p 0 .907 1 r
F P
0 g
s
.705 .11224 m .71673 .10388 L .72307 .15281 L p 0 .1 .365 r
F P
0 g
s
.72307 .15281 m .71095 .16111 L .705 .11224 L p 0 .1 .365 r
F P
0 g
s
.75165 .38609 m .70678 .35263 L .69712 .35834 L p 0 .914 1 r
F P
0 g
s
.75898 .44305 m .75165 .38609 L .70678 .35263 L p 0 .621 .254 r
F P
0 g
s
.70678 .35263 m .75165 .38609 L .76134 .38065 L p 0 .914 1 r
F P
0 g
s
.75165 .38609 m .75898 .44305 L .76899 .43773 L p 0 .1 .423 r
F P
0 g
s
.76899 .43773 m .76134 .38065 L .75165 .38609 L p 0 .1 .423 r
F P
0 g
s
.75898 .44305 m .75165 .38609 L .70678 .35263 L p 0 .621 .254 r
F P
0 g
s
.44749 .56174 m .44746 .56168 L .45977 .55479 L p 0 .525 .891 r
F P
0 g
s
.45977 .55479 m .4598 .55486 L .44749 .56174 L p 0 .525 .891 r
F P
0 g
s
.54896 .386 m .54892 .38601 L .55035 .44294 L p 0 .652 .333 r
F P
0 g
s
.54892 .38601 m .54896 .386 L .56199 .37787 L p 0 .93 .764 r
F P
0 g
s
.54896 .386 m .54892 .38601 L .55035 .44294 L p 0 .652 .333 r
F P
0 g
s
.59966 .47385 m .60256 .53337 L .58896 .54056 L p 0 .1 .396 r
F P
0 g
s
.65039 .56172 m .60256 .53337 L .61636 .52608 L p 0 .916 1 r
F P
0 g
s
.61636 .52608 m .66414 .55484 L .65039 .56172 L p 0 .916 1 r
F P
0 g
s
.60256 .53337 m .59966 .47385 L .61304 .46634 L p 0 .1 .396 r
F P
0 g
s
.59966 .47385 m .55035 .44294 L .56377 .43499 L p 0 .916 1 r
F P
0 g
s
.56377 .43499 m .61304 .46634 L .59966 .47385 L p 0 .916 1 r
F P
0 g
s
.59966 .47385 m .55035 .44294 L .53712 .45078 L p 0 .916 1 r
F P
0 g
s
.60256 .53337 m .59966 .47385 L .55035 .44294 L p 0 .652 .333 r
F P
0 g
s
.55035 .44294 m .59966 .47385 L .61304 .46634 L p 0 .916 1 r
F P
0 g
s
.59966 .47385 m .60256 .53337 L .61636 .52608 L p 0 .1 .396 r
F P
0 g
s
.61636 .52608 m .61304 .46634 L .59966 .47385 L p 0 .1 .396 r
F P
0 g
s
.60256 .53337 m .59966 .47385 L .55035 .44294 L p 0 .652 .333 r
F P
0 g
s
.65477 .44294 m .65039 .38597 L .66414 .37784 L p 0 .1 0 r
F P
0 g
s
.65477 .44294 m .70112 .47385 L .71523 .46634 L p 0 .916 0 r
F P
0 g
s
.70112 .47385 m .70698 .53337 L .72155 .52608 L p 0 .1 0 r
F P
0 g
s
.72155 .52608 m .71523 .46634 L .70112 .47385 L p 0 .1 0 r
F P
0 g
s
.60259 .35253 m .65039 .38597 L .66414 .37784 L p 0 .914 0 r
F P
0 g
s
.65039 .38597 m .65477 .44294 L .66895 .43499 L p 0 .1 0 r
F P
0 g
s
.66895 .43499 m .66414 .37784 L .65039 .38597 L p 0 .1 0 r
F P
0 g
s
.49819 .47385 m .49814 .53333 L .48528 .54052 L p 0 .1 0 r
F P
0 g
s
.49817 .5334 m .54892 .56172 L p .49819 .47385 L 0 .663 0 r
F P
0 g
s
.49819 .47385 m .49814 .53333 L .49817 .5334 L p 0 .663 0 r
F P
0 g
s
.49817 .5334 m .54892 .56172 L p .49819 .47385 L 0 .663 0 r
F P
0 g
s
.54892 .56172 m .49817 .5334 L .51121 .5261 L p 0 .916 0 r
F P
0 g
s
.51121 .5261 m .56195 .55484 L .54892 .56172 L p 0 .916 0 r
F P
0 g
s
.49819 .47385 m .49814 .53333 L .49817 .5334 L p 0 .663 0 r
F P
0 g
s
.49814 .53333 m .49819 .47385 L .51086 .46634 L p 0 .1 0 r
F P
0 g
s
.65477 .44294 m .65039 .38597 L .60259 .35253 L p 0 .638 0 r
F P
0 g
s
.66414 .37784 m .66895 .43499 L .65477 .44294 L p 0 .1 0 r
F P
0 g
s
.60564 .41018 m .65477 .44294 L p .60259 .35253 L 0 .638 0 r
F P
0 g
s
.65477 .44294 m .60564 .41018 L .61988 .40174 L p 0 .916 0 r
F P
0 g
s
.61988 .40174 m .66895 .43499 L .65477 .44294 L p 0 .916 0 r
F P
0 g
s
.70698 .53337 m .70112 .47385 L .65477 .44294 L p 0 .638 0 r
F P
0 g
s
.65477 .44294 m .65942 .50333 L .70698 .53337 L p 0 .638 0 r
F P
0 g
s
.70698 .53337 m .65942 .50333 L .67406 .49559 L p 0 .916 0 r
F P
0 g
s
.67406 .49559 m .72155 .52608 L .70698 .53337 L p 0 .916 0 r
F P
0 g
s
.54892 .38601 m .55035 .44294 L .53712 .45078 L p 0 .1 .365 r
F P
0 g
s
.56199 .37787 m .56195 .37788 L .54892 .38601 L p 0 .93 .764 r
F P
0 g
s
.55035 .44294 m .54892 .38601 L .56195 .37788 L p 0 .1 .365 r
F P
0 g
s
.86128 .38559 m .87396 .37883 L .83238 .34494 L p 0 .914 1 r
F P
0 g
s
.83238 .34494 m .81958 .3521 L .86128 .38559 L p 0 .914 1 r
F P
0 g
s
.86128 .38559 m .87181 .44257 L .91203 .4735 L p 0 .599 .205 r
F P
0 g
s
.87396 .37883 m .86128 .38559 L .87181 .44257 L p 0 .1 .45 r
F P
0 g
s
.87181 .44257 m .86128 .38559 L .81958 .3521 L p 0 .599 .205 r
F P
0 g
s
.86128 .38559 m .87396 .37883 L .88493 .43595 L p 0 .1 .45 r
F P
0 g
s
.88493 .43595 m .87181 .44257 L .86128 .38559 L p 0 .1 .45 r
F P
0 g
s
.92501 .46725 m .91203 .4735 L .87181 .44257 L p 0 .916 1 r
F P
0 g
s
.91203 .4735 m .92501 .46725 L .88493 .43595 L p 0 .916 1 r
F P
0 g
s
.88493 .43595 m .87181 .44257 L .91203 .4735 L p 0 .916 1 r
F P
0 g
s
.92501 .46725 m .91203 .4735 L .92403 .53299 L p 0 .114 .472 r
F P
0 g
s
.92403 .53299 m .91203 .4735 L .87181 .44257 L p 0 .599 .205 r
F P
0 g
s
.65396 .25464 m .66342 .24842 L .70952 .28483 L p 0 .911 1 r
F P
0 g
s
.66338 .24836 m .66342 .24842 L .70952 .28483 L p 0 .618 .247 r
F P
0 g
s
.65875 .19691 m .66338 .24836 L p .70952 .28483 L 0 .618 .247 r
F P
0 g
s
.86614 .55917 m .86617 .55915 L p .81531 .47109 L 0 .618 .247 r
F P
0 g
s
.76217 .44532 m .77217 .44002 L .81531 .47109 L p 0 .916 1 r
F P
0 g
s
.76444 .38298 m .77217 .44002 L .81531 .47109 L p 0 .618 .247 r
F P
0 g
s
.81426 .53556 m .82452 .53069 L .81531 .47109 L p 0 .1 .45 r
F P
0 g
s
.82452 .53069 m .81531 .47109 L .77217 .44002 L p 0 .618 .247 r
F P
0 g
s
.81531 .47109 m .82452 .53069 L .86614 .55917 L p 0 .618 .247 r
F P
0 g
s
.81426 .53556 m .82452 .53069 L .86614 .55917 L p 0 .916 1 r
F P
0 g
s
.61258 .28177 m .6261 .27288 L .62614 .27294 L p 0 .546 0 r
F P
0 g
s
.62614 .27294 m .61262 .28184 L .61258 .28177 L p 0 .546 0 r
F P
0 g
s
.71676 .10388 m .71673 .10388 L p .76767 .19209 L 0 .594 .194 r
F P
0 g
s
.71676 .10388 m .72863 .09542 L .7286 .09543 L p 0 1 .86 r
F P
0 g
s
.7286 .09543 m .71673 .10388 L .71676 .10388 L p 0 1 .86 r
F P
0 g
s
.71676 .10388 m .71673 .10388 L p .76767 .19209 L 0 .594 .194 r
F P
0 g
s
.76767 .19209 m .7755 .24363 L .81862 .28033 L p 0 .594 .194 r
F P
0 g
s
.76767 .19209 m .7755 .24363 L .81862 .28033 L p 0 .594 .194 r
F P
0 g
s
.76767 .19209 m .77984 .18416 L .78808 .23577 L p 0 .1 .396 r
F P
0 g
s
.78808 .23577 m .7755 .24363 L .76767 .19209 L p 0 .1 .396 r
F P
0 g
s
.76308 .25139 m .7755 .24363 L .81862 .28033 L p 0 .911 1 r
F P
0 g
s
.83109 .27292 m .81862 .28033 L .7755 .24363 L p 0 .911 1 r
F P
0 g
s
.76308 .25139 m .7755 .24363 L .76767 .19209 L p 0 .1 .396 r
F P
0 g
s
.71095 .16111 m .72307 .15281 L .76767 .19209 L p 0 .907 1 r
F P
0 g
s
.7755 .24363 m .76767 .19209 L .72307 .15281 L p 0 .594 .194 r
F P
0 g
s
.77984 .18416 m .76767 .19209 L .7755 .24363 L p 0 .1 .396 r
F P
0 g
s
.71673 .10388 m .72307 .15281 L .76767 .19209 L p 0 .594 .194 r
F P
0 g
s
.71673 .10388 m .72307 .15281 L .76767 .19209 L p 0 .594 .194 r
F P
0 g
s
.76767 .19209 m .77984 .18416 L .73533 .1444 L p 0 .907 1 r
F P
0 g
s
.73533 .1444 m .72307 .15281 L .76767 .19209 L p 0 .907 1 r
F P
0 g
s
.7755 .24363 m .76767 .19209 L .72307 .15281 L p 0 .594 .194 r
F P
0 g
s
.77984 .18416 m .76767 .19209 L .72307 .15281 L p 0 .907 1 r
F P
0 g
s
.71673 .10388 m .7286 .09543 L .73533 .1444 L p 0 .1 .365 r
F P
0 g
s
.73533 .1444 m .72307 .15281 L .71673 .10388 L p 0 .1 .365 r
F P
0 g
s
.76134 .38065 m .71653 .34686 L .70678 .35263 L p 0 .914 1 r
F P
0 g
s
.76899 .43773 m .76134 .38065 L .71653 .34686 L p 0 .618 .247 r
F P
0 g
s
.78408 .54987 m .76942 .55683 L .72483 .52819 L p 0 .916 0 r
F P
0 g
s
.71843 .46851 m .73273 .46093 L .7396 .52082 L p 0 .1 0 r
F P
0 g
s
.7396 .52082 m .72483 .52819 L .71843 .46851 L p 0 .1 0 r
F P
0 g
s
.87181 .44257 m .88493 .43595 L .87396 .37883 L p 0 .1 .45 r
F P
0 g
s
.88493 .43595 m .87396 .37883 L .83238 .34494 L p 0 .594 .194 r
F P
0 g
s
.87396 .37883 m .88679 .37198 L .84533 .33769 L p 0 .914 1 r
F P
0 g
s
.84533 .33769 m .83238 .34494 L .87396 .37883 L p 0 .914 1 r
F P
0 g
s
.87396 .37883 m .88493 .43595 L .92501 .46725 L p 0 .594 .194 r
F P
0 g
s
.87396 .37883 m .88493 .43595 L .92501 .46725 L p 0 .594 .194 r
F P
0 g
s
.88679 .37198 m .87396 .37883 L .88493 .43595 L p 0 .1 .45 r
F P
0 g
s
.88493 .43595 m .87396 .37883 L .83238 .34494 L p 0 .594 .194 r
F P
0 g
s
.87181 .44257 m .88493 .43595 L .92501 .46725 L p 0 .916 1 r
F P
0 g
s
.87396 .37883 m .88679 .37198 L .8982 .42925 L p 0 .1 .45 r
F P
0 g
s
.8982 .42925 m .88493 .43595 L .87396 .37883 L p 0 .1 .45 r
F P
0 g
s
.93814 .46093 m .92501 .46725 L .88493 .43595 L p 0 .916 1 r
F P
0 g
s
.92403 .53299 m .93746 .52692 L .92501 .46725 L p 0 .114 .472 r
F P
0 g
s
.93746 .52692 m .92501 .46725 L .88493 .43595 L p 0 .594 .194 r
F P
0 g
s
.92501 .46725 m .93814 .46093 L .8982 .42925 L p 0 .916 1 r
F P
0 g
s
.8982 .42925 m .88493 .43595 L .92501 .46725 L p 0 .916 1 r
F P
0 g
s
.93814 .46093 m .92501 .46725 L .93746 .52692 L p 0 .114 .472 r
F P
0 g
s
.93746 .52692 m .92501 .46725 L .88493 .43595 L p 0 .594 .194 r
F P
0 g
s
.4598 .55486 m .45977 .55479 L .47225 .54781 L p 0 .525 .891 r
F P
0 g
s
.47225 .54781 m .47229 .54787 L .4598 .55486 L p 0 .525 .891 r
F P
0 g
s
.56199 .37787 m .56195 .37788 L .56377 .43499 L p 0 .648 .324 r
F P
0 g
s
.56195 .37788 m .56199 .37787 L .5752 .36962 L p 0 .93 .764 r
F P
0 g
s
.56199 .37787 m .56195 .37788 L .56377 .43499 L p 0 .648 .324 r
F P
0 g
s
.61304 .46634 m .61636 .52608 L .60256 .53337 L p 0 .1 .396 r
F P
0 g
s
.66414 .55484 m .61636 .52608 L .63036 .51868 L p 0 .916 1 r
F P
0 g
s
.63036 .51868 m .67808 .54785 L .66414 .55484 L p 0 .916 1 r
F P
0 g
s
.61636 .52608 m .61304 .46634 L .62662 .45873 L p 0 .1 .396 r
F P
0 g
s
.61304 .46634 m .56377 .43499 L .57739 .42692 L p 0 .916 1 r
F P
0 g
s
.57739 .42692 m .62662 .45873 L .61304 .46634 L p 0 .916 1 r
F P
0 g
s
.61304 .46634 m .56377 .43499 L .55035 .44294 L p 0 .916 1 r
F P
0 g
s
.61636 .52608 m .61304 .46634 L .56377 .43499 L p 0 .648 .324 r
F P
0 g
s
.56377 .43499 m .61304 .46634 L .62662 .45873 L p 0 .916 1 r
F P
0 g
s
.61304 .46634 m .61636 .52608 L .63036 .51868 L p 0 .1 .396 r
F P
0 g
s
.63036 .51868 m .62662 .45873 L .61304 .46634 L p 0 .1 .396 r
F P
0 g
s
.61636 .52608 m .61304 .46634 L .56377 .43499 L p 0 .648 .324 r
F P
0 g
s
.72954 .45873 m .68334 .42692 L p .68334 .42692 L 0 .63 .275 r
F P
0 g
s
.71523 .46634 m .66895 .43499 L .68334 .42692 L p 0 .916 0 r
F P
0 g
s
.68334 .42692 m .72954 .45873 L .71523 .46634 L p 0 .916 0 r
F P
0 g
s
.71523 .46634 m .66895 .43499 L .65477 .44294 L p 0 .916 0 r
F P
0 g
s
.72155 .52608 m .71523 .46634 L .66895 .43499 L p 0 .634 0 r
F P
0 g
s
.66895 .43499 m .71523 .46634 L .72954 .45873 L p 0 .916 0 r
F P
0 g
s
.71523 .46634 m .72155 .52608 L .73632 .51868 L p 0 .1 0 r
F P
0 g
s
.73632 .51868 m .72954 .45873 L .71523 .46634 L p 0 .1 0 r
F P
0 g
s
.72155 .52608 m .71523 .46634 L .66895 .43499 L p 0 .634 0 r
F P
0 g
s
.72954 .45873 m .68334 .42692 L .66895 .43499 L p 0 .916 0 r
F P
0 g
s
.66895 .43499 m .67406 .49559 L .72155 .52608 L p 0 .634 0 r
F P
0 g
s
.66895 .43499 m .67406 .49559 L .72155 .52608 L p 0 .634 0 r
F P
0 g
s
.68334 .42692 m .68893 .48773 L .73632 .51868 L p 0 .63 .275 r
F P
0 g
s
.73632 .51868 m .72954 .45873 L p .68334 .42692 L 0 .63 .275 r
F P
0 g
s
.72954 .45873 m .72954 .45873 L p .68334 .42692 L 0 .63 .275 r
F P
0 g
s
.66895 .43499 m .66414 .37784 L .67808 .3696 L p 0 .1 0 r
F P
0 g
s
.66414 .37784 m .6164 .34392 L .60259 .35253 L p 0 .914 0 r
F P
0 g
s
.66895 .43499 m .66414 .37784 L .6164 .34392 L p 0 .634 0 r
F P
0 g
s
.67808 .3696 m .6304 .33518 L p .6304 .33518 L 0 .63 .275 r
F P
0 g
s
.6164 .34392 m .66414 .37784 L .67808 .3696 L p 0 .914 0 r
F P
0 g
s
.66414 .37784 m .66895 .43499 L .68334 .42692 L p 0 .1 0 r
F P
0 g
s
.68334 .42692 m .67808 .3696 L .66414 .37784 L p 0 .1 0 r
F P
0 g
s
.66895 .43499 m .66414 .37784 L .6164 .34392 L p 0 .634 0 r
F P
0 g
s
.67808 .3696 m .68334 .42692 L .66895 .43499 L p 0 .1 0 r
F P
0 g
s
.67808 .3696 m .6304 .33518 L .6164 .34392 L p 0 .914 0 r
F P
0 g
s
.61988 .40174 m .66895 .43499 L p .6164 .34392 L 0 .634 0 r
F P
0 g
s
.61988 .40174 m .66895 .43499 L p .6164 .34392 L 0 .634 0 r
F P
0 g
s
.63434 .39317 m .68334 .42692 L p .6304 .33518 L 0 .63 .275 r
F P
0 g
s
.68334 .42692 m .67808 .3696 L p .6304 .33518 L 0 .63 .275 r
F P
0 g
s
.67808 .3696 m .67808 .3696 L p .6304 .33518 L 0 .63 .275 r
F P
0 g
s
.51086 .46634 m .51118 .52604 L .49814 .53333 L p 0 .1 0 r
F P
0 g
s
.51121 .5261 m .56195 .55484 L p .51086 .46634 L 0 .661 0 r
F P
0 g
s
.51086 .46634 m .51118 .52604 L .51121 .5261 L p 0 .661 0 r
F P
0 g
s
.51121 .5261 m .56195 .55484 L p .51086 .46634 L 0 .661 0 r
F P
0 g
s
.51086 .46634 m .51118 .52604 L .51121 .5261 L p 0 .661 0 r
F P
0 g
s
.56195 .55484 m .51121 .5261 L .52445 .5187 L p 0 .916 0 r
F P
0 g
s
.52445 .5187 m .57516 .54785 L .56195 .55484 L p 0 .916 0 r
F P
0 g
s
.51118 .52604 m .51086 .46634 L .52371 .45873 L p 0 .1 0 r
F P
0 g
s
.56195 .37788 m .56377 .43499 L .55035 .44294 L p 0 .1 .365 r
F P
0 g
s
.5752 .36962 m .57517 .36964 L .56195 .37788 L p 0 .93 .764 r
F P
0 g
s
.56377 .43499 m .56195 .37788 L .57517 .36964 L p 0 .1 .365 r
F P
0 g
s
.67668 .18461 m .68188 .23619 L p .72791 .27335 L 0 .612 0 r
F P
0 g
s
.67668 .18461 m .69061 .17506 L .69625 .22673 L p 0 .1 0 r
F P
0 g
s
.69625 .22673 m .68188 .23619 L .67668 .18461 L p 0 .1 0 r
F P
0 g
s
.68188 .23619 m .68191 .23626 L .72791 .27335 L p 0 .612 0 r
F P
0 g
s
.7422 .26442 m .72791 .27335 L .68191 .23626 L p 0 .911 0 r
F P
0 g
s
.72863 .09542 m .7286 .09543 L p .77984 .18416 L 0 .59 .184 r
F P
0 g
s
.6261 .27288 m .63529 .26684 L .63532 .2669 L p 0 .546 .889 r
F P
0 g
s
.63532 .2669 m .62614 .27294 L .6261 .27288 L p 0 .546 .889 r
F P
0 g
s
.7755 .24363 m .78808 .23577 L .83109 .27292 L p 0 .911 1 r
F P
0 g
s
.77984 .18416 m .78808 .23577 L .83109 .27292 L p 0 .59 .184 r
F P
0 g
s
.7755 .24363 m .78808 .23577 L .77984 .18416 L p 0 .1 .396 r
F P
0 g
s
.72307 .15281 m .73533 .1444 L .77984 .18416 L p 0 .907 1 r
F P
0 g
s
.78808 .23577 m .77984 .18416 L .73533 .1444 L p 0 .59 .184 r
F P
0 g
s
.7286 .09543 m .73533 .1444 L .77984 .18416 L p 0 .59 .184 r
F P
0 g
s
.90148 .54319 m .88604 .55016 L .88602 .55019 L p 0 .1 0 r
F P
0 g
s
.88602 .55019 m .88604 .55016 L p .83471 .46129 L 0 .612 0 r
F P
0 g
s
.78338 .37238 m .79173 .42964 L .83471 .46129 L p 0 .612 0 r
F P
0 g
s
.84979 .45369 m .83471 .46129 L .79173 .42964 L p 0 .916 0 r
F P
0 g
s
.83471 .46129 m .84458 .52118 L .88602 .55019 L p 0 .612 0 r
F P
0 g
s
.83471 .46129 m .84979 .45369 L .86018 .51378 L p 0 .1 0 r
F P
0 g
s
.86018 .51378 m .84458 .52118 L .83471 .46129 L p 0 .1 0 r
F P
0 g
s
.78338 .37238 m .79809 .36414 L .80694 .42158 L p 0 .1 0 r
F P
0 g
s
.80694 .42158 m .79173 .42964 L .78338 .37238 L p 0 .1 0 r
F P
0 g
s
.83471 .46129 m .84979 .45369 L .80694 .42158 L p 0 .916 0 r
F P
0 g
s
.80694 .42158 m .79173 .42964 L .83471 .46129 L p 0 .916 0 r
F P
0 g
s
.84979 .45369 m .83471 .46129 L .84458 .52118 L p 0 .1 0 r
F P
0 g
s
.84458 .52118 m .83471 .46129 L .79173 .42964 L p 0 .612 0 r
F P
0 g
s
.88602 .55019 m .90146 .54321 L .90148 .54319 L p 0 .1 0 r
F P
0 g
s
.90146 .54321 m .88602 .55019 L .84458 .52118 L p 0 .916 0 r
F P
0 g
s
.88493 .43595 m .8982 .42925 L .88679 .37198 L p 0 .1 .45 r
F P
0 g
s
.8982 .42925 m .88679 .37198 L .84533 .33769 L p 0 .59 .184 r
F P
0 g
s
.88493 .43595 m .8982 .42925 L .93814 .46093 L p 0 .916 1 r
F P
0 g
s
.88679 .37198 m .8982 .42925 L .93814 .46093 L p 0 .59 .184 r
F P
0 g
s
.93746 .52692 m .95106 .52078 L .93814 .46093 L p 0 .114 .472 r
F P
0 g
s
.95106 .52078 m .93814 .46093 L .8982 .42925 L p 0 .59 .184 r
F P
0 g
s
.72483 .52819 m .7396 .52082 L .78408 .54987 L p 0 .916 0 r
F P
0 g
s
.73561 .33558 m .78028 .37 L .795 .36173 L p 0 .914 0 r
F P
0 g
s
.78028 .37 m .78857 .42731 L .80379 .41921 L p 0 .1 0 r
F P
0 g
s
.80379 .41921 m .795 .36173 L .78028 .37 L p 0 .1 0 r
F P
0 g
s
.78857 .42731 m .78028 .37 L .73561 .33558 L p 0 .612 0 r
F P
0 g
s
.5752 .36962 m .57517 .36964 L .57739 .42692 L p 0 .645 .315 r
F P
0 g
s
.68334 .42692 m .67808 .3696 L .68755 .364 L p 0 .1 .396 r
F P
0 g
s
.6304 .33518 m .67808 .3696 L .68755 .364 L p 0 .914 1 r
F P
0 g
s
.67808 .3696 m .68334 .42692 L .69312 .42143 L p 0 .1 .396 r
F P
0 g
s
.69312 .42143 m .68755 .364 L .67808 .3696 L p 0 .1 .396 r
F P
0 g
s
.68334 .42692 m .72954 .45873 L .73926 .45355 L p 0 .916 1 r
F P
0 g
s
.72954 .45873 m .73632 .51868 L .74636 .51365 L p 0 .1 .423 r
F P
0 g
s
.74636 .51365 m .73926 .45355 L .72954 .45873 L p 0 .1 .423 r
F P
0 g
s
.62662 .45873 m .63036 .51868 L .61636 .52608 L p 0 .1 .396 r
F P
0 g
s
.62662 .45873 m .57739 .42692 L .56377 .43499 L p 0 .916 1 r
F P
0 g
s
.63036 .51868 m .62662 .45873 L .57739 .42692 L p 0 .645 .315 r
F P
0 g
s
.73632 .51868 m .72954 .45873 L .68334 .42692 L p 0 .63 0 r
F P
0 g
s
.68893 .48773 m .73632 .51868 L p .73632 .51868 L 0 .63 0 r
F P
0 g
s
.68334 .42692 m .68893 .48773 L p .73632 .51868 L 0 .63 0 r
F P
0 g
s
.68893 .48773 m .68893 .48773 L p .73632 .51868 L 0 .63 0 r
F P
0 g
s
.73632 .51868 m .68893 .48773 L .69904 .48239 L p 0 .916 1 r
F P
0 g
s
.69904 .48239 m .74636 .51365 L .73632 .51868 L p 0 .916 1 r
F P
0 g
s
.68334 .42692 m .67808 .3696 L .6304 .33518 L p 0 .63 0 r
F P
0 g
s
.68755 .364 m .69312 .42143 L .68334 .42692 L p 0 .1 .396 r
F P
0 g
s
.63434 .39317 m .68334 .42692 L p .68334 .42692 L 0 .63 0 r
F P
0 g
s
.6304 .33518 m .63434 .39317 L .68334 .42692 L 0 .63 0 r
F
.63434 .39317 m .63434 .39317 L .68334 .42692 L F
.68334 .42692 m .63434 .39317 L .64417 .38735 L p 0 .916 1 r
F P
0 g
s
.64417 .38735 m .69312 .42143 L .68334 .42692 L p 0 .916 1 r
F P
0 g
s
.52371 .45873 m .52441 .51864 L .51118 .52604 L p 0 .1 0 r
F P
0 g
s
.52445 .5187 m .57516 .54785 L p .52371 .45873 L 0 .658 0 r
F P
0 g
s
.52371 .45873 m .52441 .51864 L .52445 .5187 L p 0 .658 0 r
F P
0 g
s
.57517 .36964 m .57739 .42692 L .56377 .43499 L p 0 .1 .365 r
F P
0 g
s
.47265 .54767 m .47261 .54761 L .48528 .54052 L p 0 .525 0 r
F P
0 g
s
.48528 .54052 m .48532 .54058 L .47265 .54767 L p 0 .525 0 r
F P
0 g
s
.57555 .3694 m .57558 .36938 L .58899 .36102 L p 0 .93 0 r
F P
0 g
s
.57558 .36938 m .57555 .3694 L .57778 .42668 L p 0 .645 0 r
F P
0 g
s
.52483 .51849 m .57555 .54765 L p .52408 .45851 L 0 .658 .35 r
F P
0 g
s
.52408 .45851 m .52479 .51842 L .52483 .51849 L p 0 .658 .35 r
F P
0 g
s
.57555 .54765 m .52483 .51849 L .53826 .51097 L p 0 .916 1 r
F P
0 g
s
.53826 .51097 m .58896 .54056 L .57555 .54765 L p 0 .916 1 r
F P
0 g
s
.52479 .51842 m .52408 .45851 L .53712 .45078 L p 0 .1 .365 r
F P
0 g
s
.67848 .54765 m .63077 .51847 L .64499 .51095 L p 0 .916 0 r
F P
0 g
s
.64499 .51095 m .69263 .54056 L .67848 .54765 L p 0 .916 0 r
F P
0 g
s
.63077 .51847 m .62701 .45851 L .64079 .45078 L p 0 .1 0 r
F P
0 g
s
.62701 .45851 m .57778 .42668 L .59161 .41849 L p 0 .916 0 r
F P
0 g
s
.59161 .41849 m .64079 .45078 L .62701 .45851 L p 0 .916 0 r
F P
0 g
s
.57778 .42668 m .62701 .45851 L .64079 .45078 L p 0 .916 0 r
F P
0 g
s
.62701 .45851 m .63077 .51847 L .64499 .51095 L p 0 .1 0 r
F P
0 g
s
.64499 .51095 m .64079 .45078 L .62701 .45851 L p 0 .1 0 r
F P
0 g
s
.63077 .51847 m .62701 .45851 L .57778 .42668 L p 0 .645 0 r
F P
0 g
s
.58899 .36102 m .58896 .36103 L .57555 .3694 L p 0 .93 0 r
F P
0 g
s
.57778 .42668 m .57555 .3694 L .58896 .36103 L p 0 .1 0 r
F P
0 g
s
.63529 .26684 m .64456 .26074 L .6446 .2608 L p 0 .546 .889 r
F P
0 g
s
.6446 .2608 m .63532 .2669 L .63529 .26684 L p 0 .546 .889 r
F P
0 g
s
.68191 .23626 m .69629 .2268 L .7422 .26442 L p 0 .911 0 r
F P
0 g
s
.69625 .22673 m .69629 .2268 L .7422 .26442 L p 0 .607 0 r
F P
0 g
s
.69061 .17506 m .69625 .22673 L p .7422 .26442 L 0 .607 0 r
F P
0 g
s
.69625 .22673 m .69629 .2268 L .7422 .26442 L p 0 .607 0 r
F P
0 g
s
.69061 .17506 m .69625 .22673 L p .7422 .26442 L 0 .607 0 r
F P
0 g
s
.75669 .25537 m .7422 .26442 L .69629 .2268 L p 0 .911 0 r
F P
0 g
s
.69061 .17506 m .70473 .16538 L .71084 .21714 L p 0 .1 0 r
F P
0 g
s
.71084 .21714 m .69625 .22673 L .69061 .17506 L p 0 .1 0 r
F P
0 g
s
.74245 .45578 m .74964 .51581 L .79405 .54515 L p 0 .627 .269 r
F P
0 g
s
.74245 .45578 m .74964 .51581 L .79405 .54515 L p 0 .627 .269 r
F P
0 g
s
.80411 .54038 m .79405 .54515 L .74964 .51581 L p 0 .916 1 r
F P
0 g
s
.74245 .45578 m .75226 .45057 L .75978 .51075 L p 0 .1 .425 r
F P
0 g
s
.75978 .51075 m .74964 .51581 L .74245 .45578 L p 0 .1 .425 r
F P
0 g
s
.7396 .52082 m .74964 .51581 L .79405 .54515 L p 0 .916 1 r
F P
0 g
s
.90146 .54321 m .90148 .54319 L p .84979 .45369 L 0 .607 0 r
F P
0 g
s
.91714 .53611 m .90148 .54319 L .90146 .54321 L p 0 .1 0 r
F P
0 g
s
.90146 .54321 m .90148 .54319 L p .84979 .45369 L 0 .607 0 r
F P
0 g
s
.79173 .42964 m .80694 .42158 L .84979 .45369 L p 0 .916 0 r
F P
0 g
s
.79809 .36414 m .80694 .42158 L .84979 .45369 L p 0 .607 0 r
F P
0 g
s
.79809 .36414 m .80694 .42158 L .84979 .45369 L p 0 .607 0 r
F P
0 g
s
.79809 .36414 m .81301 .35579 L .82238 .41339 L p 0 .1 0 r
F P
0 g
s
.82238 .41339 m .80694 .42158 L .79809 .36414 L p 0 .1 0 r
F P
0 g
s
.86508 .44597 m .84979 .45369 L .80694 .42158 L p 0 .916 0 r
F P
0 g
s
.84458 .52118 m .86018 .51378 L .84979 .45369 L p 0 .1 0 r
F P
0 g
s
.86018 .51378 m .84979 .45369 L .80694 .42158 L p 0 .607 0 r
F P
0 g
s
.84979 .45369 m .86508 .44597 L .82238 .41339 L p 0 .916 0 r
F P
0 g
s
.82238 .41339 m .80694 .42158 L .84979 .45369 L p 0 .916 0 r
F P
0 g
s
.84979 .45369 m .86018 .51378 L .90146 .54321 L p 0 .607 0 r
F P
0 g
s
.84979 .45369 m .86018 .51378 L .90146 .54321 L p 0 .607 0 r
F P
0 g
s
.86508 .44597 m .84979 .45369 L .86018 .51378 L p 0 .1 0 r
F P
0 g
s
.86018 .51378 m .84979 .45369 L .80694 .42158 L p 0 .607 0 r
F P
0 g
s
.84979 .45369 m .86508 .44597 L .876 .50627 L p 0 .1 0 r
F P
0 g
s
.876 .50627 m .86018 .51378 L .84979 .45369 L p 0 .1 0 r
F P
0 g
s
.84458 .52118 m .86018 .51378 L .90146 .54321 L p 0 .916 0 r
F P
0 g
s
.90146 .54321 m .91712 .53613 L .91714 .53611 L p 0 .1 0 r
F P
0 g
s
.91712 .53613 m .90146 .54321 L .86018 .51378 L p 0 .916 0 r
F P
0 g
s
.68755 .364 m .69312 .42143 L .73926 .45355 L p 0 .627 .269 r
F P
0 g
s
.68755 .364 m .69312 .42143 L .73926 .45355 L p 0 .627 .269 r
F P
0 g
s
.73926 .45355 m .69312 .42143 L .703 .41589 L p 0 .916 1 r
F P
0 g
s
.703 .41589 m .74907 .44833 L .73926 .45355 L p 0 .916 1 r
F P
0 g
s
.69312 .42143 m .68755 .364 L .69712 .35834 L p 0 .1 .396 r
F P
0 g
s
.73926 .45355 m .69312 .42143 L .68334 .42692 L p 0 .916 1 r
F P
0 g
s
.74636 .51365 m .73926 .45355 L .69312 .42143 L p 0 .627 .269 r
F P
0 g
s
.69312 .42143 m .73926 .45355 L .74907 .44833 L p 0 .916 1 r
F P
0 g
s
.73926 .45355 m .74636 .51365 L .75651 .50857 L p 0 .1 .423 r
F P
0 g
s
.75651 .50857 m .74907 .44833 L .73926 .45355 L p 0 .1 .423 r
F P
0 g
s
.74636 .51365 m .73926 .45355 L .69312 .42143 L p 0 .627 .269 r
F P
0 g
s
.68755 .364 m .63992 .32924 L .6304 .33518 L p 0 .914 1 r
F P
0 g
s
.69312 .42143 m .68755 .364 L .63992 .32924 L p 0 .627 .269 r
F P
0 g
s
.63992 .32924 m .68755 .364 L .69712 .35834 L p 0 .914 1 r
F P
0 g
s
.68755 .364 m .69312 .42143 L .703 .41589 L p 0 .1 .396 r
F P
0 g
s
.703 .41589 m .69712 .35834 L .68755 .364 L p 0 .1 .396 r
F P
0 g
s
.69312 .42143 m .68755 .364 L .63992 .32924 L p 0 .627 .269 r
F P
0 g
s
.64456 .26074 m .65392 .25458 L .65396 .25464 L p 0 .546 .889 r
F P
0 g
s
.65396 .25464 m .6446 .2608 L .64456 .26074 L p 0 .546 .889 r
F P
0 g
s
.795 .36173 m .75044 .32681 L .73561 .33558 L p 0 .914 0 r
F P
0 g
s
.80379 .41921 m .795 .36173 L .75044 .32681 L p 0 .607 0 r
F P
0 g
s
.75044 .32681 m .795 .36173 L .80993 .35333 L p 0 .914 0 r
F P
0 g
s
.795 .36173 m .80379 .41921 L .81923 .41099 L p 0 .1 0 r
F P
0 g
s
.81923 .41099 m .80993 .35333 L .795 .36173 L p 0 .1 0 r
F P
0 g
s
.80379 .41921 m .795 .36173 L .75044 .32681 L p 0 .607 0 r
F P
0 g
s
.48532 .54058 m .48528 .54052 L .49814 .53333 L p 0 .525 0 r
F P
0 g
s
.49814 .53333 m .49817 .5334 L .48532 .54058 L p 0 .525 0 r
F P
0 g
s
.58899 .36102 m .58896 .36103 L .59161 .41849 L p 0 .641 0 r
F P
0 g
s
.58896 .36103 m .58899 .36102 L .60259 .35253 L p 0 .93 0 r
F P
0 g
s
.58899 .36102 m .58896 .36103 L .59161 .41849 L p 0 .641 0 r
F P
0 g
s
.53826 .51097 m .58896 .54056 L p .53712 .45078 L 0 .655 .342 r
F P
0 g
s
.53826 .51097 m .58896 .54056 L p .53712 .45078 L 0 .655 .342 r
F P
0 g
s
.58896 .54056 m .53826 .51097 L .5519 .50335 L p 0 .916 1 r
F P
0 g
s
.5519 .50335 m .60256 .53337 L .58896 .54056 L p 0 .916 1 r
F P
0 g
s
.53712 .45078 m .53822 .51091 L .52479 .51842 L p 0 .1 .365 r
F P
0 g
s
.53712 .45078 m .53822 .51091 L .53826 .51097 L p 0 .655 .342 r
F P
0 g
s
.53712 .45078 m .53822 .51091 L .53826 .51097 L p 0 .655 .342 r
F P
0 g
s
.53822 .51091 m .53712 .45078 L .55035 .44294 L p 0 .1 .365 r
F P
0 g
s
.69263 .54056 m .64499 .51095 L .65942 .50333 L p 0 .916 0 r
F P
0 g
s
.65942 .50333 m .70698 .53337 L .69263 .54056 L p 0 .916 0 r
F P
0 g
s
.64079 .45078 m .64499 .51095 L .63077 .51847 L p 0 .1 0 r
F P
0 g
s
.64499 .51095 m .64079 .45078 L .65477 .44294 L p 0 .1 0 r
F P
0 g
s
.64079 .45078 m .59161 .41849 L .60564 .41018 L p 0 .916 0 r
F P
0 g
s
.60564 .41018 m .65477 .44294 L .64079 .45078 L p 0 .916 0 r
F P
0 g
s
.64079 .45078 m .59161 .41849 L .57778 .42668 L p 0 .916 0 r
F P
0 g
s
.64499 .51095 m .64079 .45078 L .59161 .41849 L p 0 .641 0 r
F P
0 g
s
.59161 .41849 m .64079 .45078 L .65477 .44294 L p 0 .916 0 r
F P
0 g
s
.64079 .45078 m .64499 .51095 L .65942 .50333 L p 0 .1 0 r
F P
0 g
s
.65942 .50333 m .65477 .44294 L .64079 .45078 L p 0 .1 0 r
F P
0 g
s
.64499 .51095 m .64079 .45078 L .59161 .41849 L p 0 .641 0 r
F P
0 g
s
.65477 .44294 m .65942 .50333 L .64499 .51095 L p 0 .1 0 r
F P
0 g
s
.65477 .44294 m .60564 .41018 L .59161 .41849 L p 0 .916 0 r
F P
0 g
s
.5519 .50335 m .60256 .53337 L p .55035 .44294 L 0 .652 .333 r
F P
0 g
s
.5519 .50335 m .60256 .53337 L p .55035 .44294 L 0 .652 .333 r
F P
0 g
s
.56573 .49561 m .61636 .52608 L p .56377 .43499 L 0 .648 .324 r
F P
0 g
s
.56573 .49561 m .61636 .52608 L p .56377 .43499 L 0 .648 .324 r
F P
0 g
s
.57978 .48775 m .63036 .51868 L p .57739 .42692 L 0 .645 .315 r
F P
0 g
s
.58019 .48753 m .63077 .51847 L p .57778 .42668 L 0 .645 0 r
F P
0 g
s
.59446 .47955 m .64499 .51095 L p .59161 .41849 L 0 .641 0 r
F P
0 g
s
.59446 .47955 m .64499 .51095 L p .59161 .41849 L 0 .641 0 r
F P
0 g
s
.60894 .47144 m .65942 .50333 L p .60564 .41018 L 0 .638 0 r
F P
0 g
s
.65942 .50333 m .65477 .44294 L .60564 .41018 L p 0 .638 0 r
F P
0 g
s
.58896 .36103 m .59161 .41849 L .57778 .42668 L p 0 .1 0 r
F P
0 g
s
.60259 .35253 m .60256 .35255 L .58896 .36103 L p 0 .93 0 r
F P
0 g
s
.59161 .41849 m .58896 .36103 L .60256 .35255 L p 0 .1 0 r
F P
0 g
s
.74964 .51581 m .75978 .51075 L .80411 .54038 L p 0 .916 1 r
F P
0 g
s
.75226 .45057 m .75978 .51075 L .80411 .54038 L p 0 .624 .261 r
F P
0 g
s
.75226 .45057 m .75978 .51075 L .80411 .54038 L p 0 .624 .261 r
F P
0 g
s
.75226 .45057 m .76217 .44532 L .77002 .50564 L p 0 .1 .425 r
F P
0 g
s
.77002 .50564 m .75978 .51075 L .75226 .45057 L p 0 .1 .425 r
F P
0 g
s
.81426 .53556 m .80411 .54038 L .75978 .51075 L p 0 .916 1 r
F P
0 g
s
.69712 .35834 m .703 .41589 L .74907 .44833 L p 0 .624 .261 r
F P
0 g
s
.69712 .35834 m .703 .41589 L .74907 .44833 L p 0 .624 .261 r
F P
0 g
s
.74907 .44833 m .703 .41589 L .71298 .4103 L p 0 .916 1 r
F P
0 g
s
.71298 .4103 m .75898 .44305 L .74907 .44833 L p 0 .916 1 r
F P
0 g
s
.74907 .44833 m .703 .41589 L .69312 .42143 L p 0 .916 1 r
F P
0 g
s
.75651 .50857 m .74907 .44833 L .703 .41589 L p 0 .624 .261 r
F P
0 g
s
.703 .41589 m .74907 .44833 L .75898 .44305 L p 0 .916 1 r
F P
0 g
s
.74907 .44833 m .75651 .50857 L .76675 .50344 L p 0 .1 .423 r
F P
0 g
s
.76675 .50344 m .75898 .44305 L .74907 .44833 L p 0 .1 .423 r
F P
0 g
s
.75651 .50857 m .74907 .44833 L .703 .41589 L p 0 .624 .261 r
F P
0 g
s
.69712 .35834 m .703 .41589 L .69312 .42143 L p 0 .1 .396 r
F P
0 g
s
.703 .41589 m .69712 .35834 L .70678 .35263 L p 0 .1 .396 r
F P
0 g
s
.69712 .35834 m .64953 .32325 L .63992 .32924 L p 0 .914 1 r
F P
0 g
s
.703 .41589 m .69712 .35834 L .64953 .32325 L p 0 .624 .261 r
F P
0 g
s
.64953 .32325 m .69712 .35834 L .70678 .35263 L p 0 .914 1 r
F P
0 g
s
.69712 .35834 m .703 .41589 L .71298 .4103 L p 0 .1 .396 r
F P
0 g
s
.71298 .4103 m .70678 .35263 L .69712 .35834 L p 0 .1 .396 r
F P
0 g
s
.703 .41589 m .69712 .35834 L .64953 .32325 L p 0 .624 .261 r
F P
0 g
s
.69629 .2268 m .71088 .2172 L .75669 .25537 L p 0 .911 0 r
F P
0 g
s
.71084 .21714 m .71088 .2172 L .75669 .25537 L p 0 .601 0 r
F P
0 g
s
.70473 .16538 m .71084 .21714 L p .75669 .25537 L 0 .601 0 r
F P
0 g
s
.65392 .25458 m .66338 .24836 L .66342 .24842 L p 0 .546 .889 r
F P
0 g
s
.66342 .24842 m .65396 .25464 L .65392 .25458 L p 0 .546 .889 r
F P
0 g
s
.91712 .53613 m .91714 .53611 L p .86508 .44597 L 0 .601 0 r
F P
0 g
s
.80694 .42158 m .82238 .41339 L .86508 .44597 L p 0 .916 0 r
F P
0 g
s
.81301 .35579 m .82238 .41339 L .86508 .44597 L p 0 .601 0 r
F P
0 g
s
.86018 .51378 m .876 .50627 L .86508 .44597 L p 0 .1 0 r
F P
0 g
s
.876 .50627 m .86508 .44597 L .82238 .41339 L p 0 .601 0 r
F P
0 g
s
.86508 .44597 m .876 .50627 L .91712 .53613 L p 0 .601 0 r
F P
0 g
s
.86018 .51378 m .876 .50627 L .91712 .53613 L p 0 .916 0 r
F P
0 g
s
.75978 .51075 m .77002 .50564 L .81426 .53556 L p 0 .916 1 r
F P
0 g
s
.76217 .44532 m .77002 .50564 L .81426 .53556 L p 0 .621 .254 r
F P
0 g
s
.76217 .44532 m .77002 .50564 L .81426 .53556 L p 0 .621 .254 r
F P
0 g
s
.82452 .53069 m .81426 .53556 L .77002 .50564 L p 0 .916 1 r
F P
0 g
s
.76217 .44532 m .77217 .44002 L .78036 .50048 L p 0 .1 .425 r
F P
0 g
s
.78036 .50048 m .77002 .50564 L .76217 .44532 L p 0 .1 .425 r
F P
0 g
s
.71095 .16111 m .71727 .21291 L p .76308 .25139 L 0 .599 .205 r
F P
0 g
s
.71095 .16111 m .72307 .15281 L .72979 .20467 L p 0 .1 .365 r
F P
0 g
s
.72979 .20467 m .71727 .21291 L .71095 .16111 L p 0 .1 .365 r
F P
0 g
s
.71727 .21291 m .71731 .21297 L .76308 .25139 L p 0 .599 .205 r
F P
0 g
s
.7755 .24363 m .76308 .25139 L .71731 .21297 L p 0 .911 1 r
F P
0 g
s
.80993 .35333 m .76549 .31791 L .75044 .32681 L p 0 .914 0 r
F P
0 g
s
.81923 .41099 m .80993 .35333 L .76549 .31791 L p 0 .601 0 r
F P
0 g
s
.70678 .35263 m .71298 .4103 L .75898 .44305 L p 0 .621 .254 r
F P
0 g
s
.70678 .35263 m .71298 .4103 L .75898 .44305 L p 0 .621 .254 r
F P
0 g
s
.75898 .44305 m .71298 .4103 L .72306 .40465 L p 0 .916 1 r
F P
0 g
s
.72306 .40465 m .76899 .43773 L .75898 .44305 L p 0 .916 1 r
F P
0 g
s
.75898 .44305 m .71298 .4103 L .703 .41589 L p 0 .916 1 r
F P
0 g
s
.76675 .50344 m .75898 .44305 L .71298 .4103 L p 0 .621 .254 r
F P
0 g
s
.71298 .4103 m .75898 .44305 L .76899 .43773 L p 0 .916 1 r
F P
0 g
s
.75898 .44305 m .76675 .50344 L .7771 .49825 L p 0 .1 .423 r
F P
0 g
s
.7771 .49825 m .76899 .43773 L .75898 .44305 L p 0 .1 .423 r
F P
0 g
s
.76675 .50344 m .75898 .44305 L .71298 .4103 L p 0 .621 .254 r
F P
0 g
s
.70678 .35263 m .71298 .4103 L .703 .41589 L p 0 .1 .396 r
F P
0 g
s
.71298 .4103 m .70678 .35263 L .71653 .34686 L p 0 .1 .396 r
F P
0 g
s
.70678 .35263 m .65924 .31719 L .64953 .32325 L p 0 .914 1 r
F P
0 g
s
.71298 .4103 m .70678 .35263 L .65924 .31719 L p 0 .621 .254 r
F P
0 g
s
.65924 .31719 m .70678 .35263 L .71653 .34686 L p 0 .914 1 r
F P
0 g
s
.70678 .35263 m .71298 .4103 L .72306 .40465 L p 0 .1 .396 r
F P
0 g
s
.72306 .40465 m .71653 .34686 L .70678 .35263 L p 0 .1 .396 r
F P
0 g
s
.71298 .4103 m .70678 .35263 L .65924 .31719 L p 0 .621 .254 r
F P
0 g
s
.60256 .35255 m .60259 .35253 L .6164 .34392 L p 0 .93 0 r
F P
0 g
s
.60259 .35253 m .60256 .35255 L .60564 .41018 L p 0 .638 0 r
F P
0 g
s
.49817 .5334 m .49814 .53333 L .51118 .52604 L p 0 .525 0 r
F P
0 g
s
.51118 .52604 m .51121 .5261 L .49817 .5334 L p 0 .525 0 r
F P
0 g
s
.60259 .35253 m .60256 .35255 L .60564 .41018 L p 0 .638 0 r
F P
0 g
s
.60256 .53337 m .5519 .50335 L .56573 .49561 L p 0 .916 1 r
F P
0 g
s
.56573 .49561 m .61636 .52608 L .60256 .53337 L p 0 .916 1 r
F P
0 g
s
.55035 .44294 m .55186 .50328 L .53822 .51091 L p 0 .1 .365 r
F P
0 g
s
.55035 .44294 m .55186 .50328 L .5519 .50335 L p 0 .652 .333 r
F P
0 g
s
.55035 .44294 m .55186 .50328 L .5519 .50335 L p 0 .652 .333 r
F P
0 g
s
.55186 .50328 m .55035 .44294 L .56377 .43499 L p 0 .1 .365 r
F P
0 g
s
.65942 .50333 m .65477 .44294 L .66895 .43499 L p 0 .1 0 r
F P
0 g
s
.60564 .41018 m .65477 .44294 L .66895 .43499 L p 0 .916 0 r
F P
0 g
s
.65477 .44294 m .65942 .50333 L .67406 .49559 L p 0 .1 0 r
F P
0 g
s
.67406 .49559 m .66895 .43499 L .65477 .44294 L p 0 .1 0 r
F P
0 g
s
.65942 .50333 m .65477 .44294 L .60564 .41018 L p 0 .638 0 r
F P
0 g
s
.66895 .43499 m .67406 .49559 L .65942 .50333 L p 0 .1 0 r
F P
0 g
s
.60894 .47144 m .65942 .50333 L p .60564 .41018 L 0 .638 0 r
F P
0 g
s
.65942 .50333 m .60894 .47144 L .62365 .46322 L p 0 .916 0 r
F P
0 g
s
.62365 .46322 m .67406 .49559 L .65942 .50333 L p 0 .916 0 r
F P
0 g
s
.6164 .34392 m .61636 .34394 L .60256 .35255 L p 0 .93 0 r
F P
0 g
s
.60564 .41018 m .60256 .35255 L .61636 .34394 L p 0 .1 0 r
F P
0 g
s
.60256 .35255 m .60564 .41018 L .59161 .41849 L p 0 .1 0 r
F P
0 g
s
.93746 .52692 m .92403 .53299 L .92402 .53301 L p 0 .1 .1 r
F P
0 g
s
.92402 .53301 m .92403 .53299 L p .87181 .44257 L 0 .599 .205 r
F P
0 g
s
.81958 .3521 m .82918 .40978 L .87181 .44257 L p 0 .599 .205 r
F P
0 g
s
.81958 .3521 m .83238 .34494 L .84242 .40276 L p 0 .1 .425 r
F P
0 g
s
.84242 .40276 m .82918 .40978 L .81958 .3521 L p 0 .1 .425 r
F P
0 g
s
.88493 .43595 m .87181 .44257 L .82918 .40978 L p 0 .916 1 r
F P
0 g
s
.87181 .44257 m .88493 .43595 L .84242 .40276 L p 0 .916 1 r
F P
0 g
s
.84242 .40276 m .82918 .40978 L .87181 .44257 L p 0 .916 1 r
F P
0 g
s
.87181 .44257 m .88298 .50297 L .92402 .53301 L p 0 .599 .205 r
F P
0 g
s
.88493 .43595 m .87181 .44257 L .88298 .50297 L p 0 .1 .45 r
F P
0 g
s
.88298 .50297 m .87181 .44257 L .82918 .40978 L p 0 .599 .205 r
F P
0 g
s
.87181 .44257 m .88493 .43595 L .89656 .49652 L p 0 .1 .45 r
F P
0 g
s
.89656 .49652 m .88298 .50297 L .87181 .44257 L p 0 .1 .45 r
F P
0 g
s
.92402 .53301 m .93744 .52694 L .93746 .52692 L p 0 .1 .1 r
F P
0 g
s
.93744 .52694 m .92402 .53301 L .88298 .50297 L p 0 .916 1 r
F P
0 g
s
.77212 .31399 m .81651 .34964 L .82932 .34244 L p 0 .914 1 r
F P
0 g
s
.81651 .34964 m .82604 .40737 L .83929 .40031 L p 0 .1 .423 r
F P
0 g
s
.83929 .40031 m .82932 .34244 L .81651 .34964 L p 0 .1 .423 r
F P
0 g
s
.82604 .40737 m .81651 .34964 L .77212 .31399 L p 0 .599 .205 r
F P
0 g
s
.77002 .50564 m .78036 .50048 L .82452 .53069 L p 0 .916 1 r
F P
0 g
s
.77217 .44002 m .78036 .50048 L .82452 .53069 L p 0 .618 .247 r
F P
0 g
s
.72307 .15281 m .72979 .20467 L p .7755 .24363 L 0 .594 .194 r
F P
0 g
s
.72307 .15281 m .72979 .20467 L p .7755 .24363 L 0 .594 .194 r
F P
0 g
s
.72307 .15281 m .73533 .1444 L .74246 .19634 L p 0 .1 .365 r
F P
0 g
s
.74246 .19634 m .72979 .20467 L .72307 .15281 L p 0 .1 .365 r
F P
0 g
s
.71731 .21297 m .72983 .20474 L .7755 .24363 L p 0 .911 1 r
F P
0 g
s
.72979 .20467 m .72983 .20474 L .7755 .24363 L p 0 .594 .194 r
F P
0 g
s
.72979 .20467 m .72983 .20474 L .7755 .24363 L p 0 .594 .194 r
F P
0 g
s
.78808 .23577 m .7755 .24363 L .72983 .20474 L p 0 .911 1 r
F P
0 g
s
.76899 .43773 m .72306 .40465 L .71298 .4103 L p 0 .916 1 r
F P
0 g
s
.7771 .49825 m .76899 .43773 L .72306 .40465 L p 0 .618 .247 r
F P
0 g
s
.71653 .34686 m .72306 .40465 L .71298 .4103 L p 0 .1 .396 r
F P
0 g
s
.71653 .34686 m .72306 .40465 L .76899 .43773 L p 0 .618 .247 r
F P
0 g
s
.71653 .34686 m .66905 .31107 L .65924 .31719 L p 0 .914 1 r
F P
0 g
s
.72306 .40465 m .71653 .34686 L .66905 .31107 L p 0 .618 .247 r
F P
0 g
s
.93744 .52694 m .93746 .52692 L p .88493 .43595 L 0 .594 .194 r
F P
0 g
s
.95106 .52078 m .93746 .52692 L .93744 .52694 L p 0 .1 .1 r
F P
0 g
s
.93744 .52694 m .93746 .52692 L p .88493 .43595 L 0 .594 .194 r
F P
0 g
s
.82918 .40978 m .84242 .40276 L .88493 .43595 L p 0 .916 1 r
F P
0 g
s
.83238 .34494 m .84242 .40276 L .88493 .43595 L p 0 .594 .194 r
F P
0 g
s
.83238 .34494 m .84242 .40276 L .88493 .43595 L p 0 .594 .194 r
F P
0 g
s
.83238 .34494 m .84533 .33769 L .85583 .39565 L p 0 .1 .425 r
F P
0 g
s
.85583 .39565 m .84242 .40276 L .83238 .34494 L p 0 .1 .425 r
F P
0 g
s
.8982 .42925 m .88493 .43595 L .84242 .40276 L p 0 .916 1 r
F P
0 g
s
.88298 .50297 m .89656 .49652 L .88493 .43595 L p 0 .1 .45 r
F P
0 g
s
.89656 .49652 m .88493 .43595 L .84242 .40276 L p 0 .594 .194 r
F P
0 g
s
.88493 .43595 m .8982 .42925 L .85583 .39565 L p 0 .916 1 r
F P
0 g
s
.85583 .39565 m .84242 .40276 L .88493 .43595 L p 0 .916 1 r
F P
0 g
s
.88493 .43595 m .89656 .49652 L .93744 .52694 L p 0 .594 .194 r
F P
0 g
s
.88493 .43595 m .89656 .49652 L .93744 .52694 L p 0 .594 .194 r
F P
0 g
s
.8982 .42925 m .88493 .43595 L .89656 .49652 L p 0 .1 .45 r
F P
0 g
s
.89656 .49652 m .88493 .43595 L .84242 .40276 L p 0 .594 .194 r
F P
0 g
s
.88493 .43595 m .8982 .42925 L .9103 .49 L p 0 .1 .45 r
F P
0 g
s
.9103 .49 m .89656 .49652 L .88493 .43595 L p 0 .1 .45 r
F P
0 g
s
.88298 .50297 m .89656 .49652 L .93744 .52694 L p 0 .916 1 r
F P
0 g
s
.93744 .52694 m .95104 .5208 L .95106 .52078 L p 0 .1 .1 r
F P
0 g
s
.95104 .5208 m .93744 .52694 L .89656 .49652 L p 0 .916 1 r
F P
0 g
s
.6164 .34392 m .61636 .34394 L .61988 .40174 L p 0 .634 0 r
F P
0 g
s
.61636 .34394 m .6164 .34392 L .6304 .33518 L p 0 .93 0 r
F P
0 g
s
.6304 .33518 m .63037 .3352 L .61636 .34394 L p 0 .93 0 r
F P
0 g
s
.6304 .33518 m .63037 .3352 L .63434 .39317 L p 0 .63 .275 r
F P
0 g
s
.6164 .34392 m .61636 .34394 L .61988 .40174 L p 0 .634 0 r
F P
0 g
s
.51121 .5261 m .51118 .52604 L .52441 .51864 L p 0 .525 0 r
F P
0 g
s
.52441 .51864 m .52445 .5187 L .51121 .5261 L p 0 .525 0 r
F P
0 g
s
.61636 .52608 m .56573 .49561 L .57978 .48775 L p 0 .916 1 r
F P
0 g
s
.57978 .48775 m .63036 .51868 L .61636 .52608 L p 0 .916 1 r
F P
0 g
s
.56377 .43499 m .5657 .49554 L .55186 .50328 L p 0 .1 .365 r
F P
0 g
s
.56377 .43499 m .5657 .49554 L .56573 .49561 L p 0 .648 .324 r
F P
0 g
s
.56377 .43499 m .5657 .49554 L .56573 .49561 L p 0 .648 .324 r
F P
0 g
s
.5657 .49554 m .56377 .43499 L .57739 .42692 L p 0 .1 .365 r
F P
0 g
s
.72155 .52608 m .67406 .49559 L .68893 .48773 L p 0 .916 0 r
F P
0 g
s
.68893 .48773 m .73632 .51868 L .72155 .52608 L p 0 .916 0 r
F P
0 g
s
.67406 .49559 m .66895 .43499 L .68334 .42692 L p 0 .1 0 r
F P
0 g
s
.68334 .42692 m .63434 .39317 L p .63434 .39317 L 0 .63 .275 r
F P
0 g
s
.66895 .43499 m .61988 .40174 L .63434 .39317 L p 0 .916 0 r
F P
0 g
s
.63434 .39317 m .68334 .42692 L .66895 .43499 L p 0 .916 0 r
F P
0 g
s
.66895 .43499 m .61988 .40174 L .60564 .41018 L p 0 .916 0 r
F P
0 g
s
.67406 .49559 m .66895 .43499 L .61988 .40174 L p 0 .634 0 r
F P
0 g
s
.61988 .40174 m .66895 .43499 L .68334 .42692 L p 0 .916 0 r
F P
0 g
s
.66895 .43499 m .67406 .49559 L .68893 .48773 L p 0 .1 0 r
F P
0 g
s
.68893 .48773 m .68334 .42692 L .66895 .43499 L p 0 .1 0 r
F P
0 g
s
.67406 .49559 m .66895 .43499 L .61988 .40174 L p 0 .634 0 r
F P
0 g
s
.68334 .42692 m .68893 .48773 L .67406 .49559 L p 0 .1 0 r
F P
0 g
s
.68334 .42692 m .63434 .39317 L .61988 .40174 L p 0 .916 0 r
F P
0 g
s
.62365 .46322 m .67406 .49559 L p .61988 .40174 L 0 .634 0 r
F P
0 g
s
.62365 .46322 m .67406 .49559 L p .61988 .40174 L 0 .634 0 r
F P
0 g
s
.63859 .45486 m .68893 .48773 L p .63434 .39317 L 0 .63 .275 r
F P
0 g
s
.68893 .48773 m .68334 .42692 L p .63434 .39317 L 0 .63 .275 r
F P
0 g
s
.68334 .42692 m .68334 .42692 L p .63434 .39317 L 0 .63 .275 r
F P
0 g
s
.61636 .34394 m .61988 .40174 L .60564 .41018 L p 0 .1 0 r
F P
0 g
s
.61988 .40174 m .61636 .34394 L .63037 .3352 L p 0 .1 0 r
F P
0 g
s
.82932 .34244 m .78504 .30635 L .77212 .31399 L p 0 .914 1 r
F P
0 g
s
.83929 .40031 m .82932 .34244 L .78504 .30635 L p 0 .594 .194 r
F P
0 g
s
.78504 .30635 m .82932 .34244 L .84228 .33516 L p 0 .914 1 r
F P
0 g
s
.82932 .34244 m .83929 .40031 L .85271 .39317 L p 0 .1 .423 r
F P
0 g
s
.85271 .39317 m .84228 .33516 L .82932 .34244 L p 0 .1 .423 r
F P
0 g
s
.83929 .40031 m .82932 .34244 L .78504 .30635 L p 0 .594 .194 r
F P
0 g
s
.68188 .23619 m .69625 .22673 L .69629 .2268 L p 0 .546 0 r
F P
0 g
s
.69629 .2268 m .68191 .23626 L .68188 .23619 L p 0 .546 0 r
F P
0 g
s
.72983 .20474 m .7425 .19641 L .78808 .23577 L p 0 .911 1 r
F P
0 g
s
.74246 .19634 m .7425 .19641 L .78808 .23577 L p 0 .59 .184 r
F P
0 g
s
.73533 .1444 m .74246 .19634 L p .78808 .23577 L 0 .59 .184 r
F P
0 g
s
.79173 .42964 m .8006 .49038 L .84458 .52118 L p 0 .612 0 r
F P
0 g
s
.79173 .42964 m .80694 .42158 L .81634 .48253 L p 0 .1 0 r
F P
0 g
s
.81634 .48253 m .8006 .49038 L .79173 .42964 L p 0 .1 0 r
F P
0 g
s
.86018 .51378 m .84458 .52118 L .8006 .49038 L p 0 .916 0 r
F P
0 g
s
.95104 .5208 m .95106 .52078 L p .8982 .42925 L 0 .59 .184 r
F P
0 g
s
.84242 .40276 m .85583 .39565 L .8982 .42925 L p 0 .916 1 r
F P
0 g
s
.84533 .33769 m .85583 .39565 L .8982 .42925 L p 0 .59 .184 r
F P
0 g
s
.89656 .49652 m .9103 .49 L .8982 .42925 L p 0 .1 .45 r
F P
0 g
s
.9103 .49 m .8982 .42925 L .85583 .39565 L p 0 .59 .184 r
F P
0 g
s
.8982 .42925 m .9103 .49 L .95104 .5208 L p 0 .59 .184 r
F P
0 g
s
.89656 .49652 m .9103 .49 L .95104 .5208 L p 0 .916 1 r
F P
0 g
s
.73561 .33558 m .74278 .39359 L .78857 .42731 L p 0 .612 0 r
F P
0 g
s
.78857 .42731 m .74278 .39359 L .75812 .38498 L p 0 .916 0 r
F P
0 g
s
.75812 .38498 m .80379 .41921 L .78857 .42731 L p 0 .916 0 r
F P
0 g
s
.74278 .39359 m .78857 .42731 L .80379 .41921 L p 0 .916 0 r
F P
0 g
s
.78857 .42731 m .79736 .48811 L .81311 .48022 L p 0 .1 0 r
F P
0 g
s
.81311 .48022 m .80379 .41921 L .78857 .42731 L p 0 .1 0 r
F P
0 g
s
.79736 .48811 m .78857 .42731 L .74278 .39359 L p 0 .612 0 r
F P
0 g
s
.74278 .39359 m .73561 .33558 L .75044 .32681 L p 0 .1 0 r
F P
0 g
s
.68825 .29909 m .73561 .33558 L .75044 .32681 L p 0 .914 0 r
F P
0 g
s
.73561 .33558 m .74278 .39359 L .75812 .38498 L p 0 .1 0 r
F P
0 g
s
.75812 .38498 m .75044 .32681 L .73561 .33558 L p 0 .1 0 r
F P
0 g
s
.74278 .39359 m .73561 .33558 L .68825 .29909 L p 0 .612 0 r
F P
0 g
s
.63037 .3352 m .6304 .33518 L .63992 .32924 L p 0 .93 .764 r
F P
0 g
s
.6304 .33518 m .63037 .3352 L .63434 .39317 L p 0 .63 0 r
F P
0 g
s
.68893 .48773 m .68334 .42692 L .69312 .42143 L p 0 .1 .396 r
F P
0 g
s
.63434 .39317 m .68334 .42692 L .69312 .42143 L p 0 .916 1 r
F P
0 g
s
.68334 .42692 m .68893 .48773 L .69904 .48239 L p 0 .1 .396 r
F P
0 g
s
.69904 .48239 m .69312 .42143 L .68334 .42692 L p 0 .1 .396 r
F P
0 g
s
.57739 .42692 m .57974 .48769 L .5657 .49554 L p 0 .1 .365 r
F P
0 g
s
.57739 .42692 m .57974 .48769 L .57978 .48775 L p 0 .645 .315 r
F P
0 g
s
.84228 .33516 m .79811 .29862 L .78504 .30635 L p 0 .914 1 r
F P
0 g
s
.85271 .39317 m .84228 .33516 L .79811 .29862 L p 0 .59 .184 r
F P
0 g
s
.68893 .48773 m .68334 .42692 L .63434 .39317 L p 0 .63 0 r
F P
0 g
s
.69312 .42143 m .69904 .48239 L .68893 .48773 L p 0 .1 .396 r
F P
0 g
s
.63859 .45486 m .68893 .48773 L p .68893 .48773 L 0 .63 0 r
F P
0 g
s
.63434 .39317 m .63859 .45486 L .68893 .48773 L 0 .63 0 r
F
.63859 .45486 m .63859 .45486 L .68893 .48773 L F
.68893 .48773 m .63859 .45486 L .64876 .44918 L p 0 .916 1 r
F P
0 g
s
.64876 .44918 m .69904 .48239 L .68893 .48773 L p 0 .916 1 r
F P
0 g
s
.63992 .32924 m .63989 .32926 L .63037 .3352 L p 0 .93 .764 r
F P
0 g
s
.63434 .39317 m .63037 .3352 L .63989 .32926 L p 0 .1 .365 r
F P
0 g
s
.63037 .3352 m .63434 .39317 L .61988 .40174 L p 0 .1 0 r
F P
0 g
s
.52483 .51849 m .52479 .51842 L .53822 .51091 L p 0 .525 .891 r
F P
0 g
s
.53822 .51091 m .53826 .51097 L .52483 .51849 L p 0 .525 .891 r
F P
0 g
s
.63077 .51847 m .58019 .48753 L .59446 .47955 L p 0 .916 0 r
F P
0 g
s
.59446 .47955 m .64499 .51095 L .63077 .51847 L p 0 .916 0 r
F P
0 g
s
.57778 .42668 m .58015 .48746 L .58019 .48753 L p 0 .645 0 r
F P
0 g
s
.58015 .48746 m .57778 .42668 L .59161 .41849 L p 0 .1 0 r
F P
0 g
s
.71088 .2172 m .69629 .2268 L .69625 .22673 L p 0 .546 0 r
F P
0 g
s
.69625 .22673 m .71084 .21714 L .71088 .2172 L p 0 .546 0 r
F P
0 g
s
.80694 .42158 m .81634 .48253 L .86018 .51378 L p 0 .607 0 r
F P
0 g
s
.80694 .42158 m .81634 .48253 L .86018 .51378 L p 0 .607 0 r
F P
0 g
s
.80694 .42158 m .82238 .41339 L .83232 .47455 L p 0 .1 0 r
F P
0 g
s
.83232 .47455 m .81634 .48253 L .80694 .42158 L p 0 .1 0 r
F P
0 g
s
.8006 .49038 m .81634 .48253 L .86018 .51378 L p 0 .916 0 r
F P
0 g
s
.876 .50627 m .86018 .51378 L .81634 .48253 L p 0 .916 0 r
F P
0 g
s
.64417 .38735 m .69312 .42143 L p .63992 .32924 L 0 .627 .269 r
F P
0 g
s
.63992 .32924 m .63989 .32926 L .64417 .38735 L p 0 .627 .269 r
F P
0 g
s
.63989 .32926 m .63992 .32924 L .64953 .32325 L p 0 .93 .764 r
F P
0 g
s
.64417 .38735 m .69312 .42143 L p .63992 .32924 L 0 .627 .269 r
F P
0 g
s
.63992 .32924 m .63989 .32926 L .64417 .38735 L p 0 .627 .269 r
F P
0 g
s
.69312 .42143 m .69904 .48239 L .74636 .51365 L p 0 .627 .269 r
F P
0 g
s
.69312 .42143 m .69904 .48239 L .74636 .51365 L p 0 .627 .269 r
F P
0 g
s
.74636 .51365 m .69904 .48239 L .70925 .47699 L p 0 .916 1 r
F P
0 g
s
.70925 .47699 m .75651 .50857 L .74636 .51365 L p 0 .916 1 r
F P
0 g
s
.69904 .48239 m .69312 .42143 L .703 .41589 L p 0 .1 .396 r
F P
0 g
s
.64417 .38735 m .69312 .42143 L .703 .41589 L p 0 .916 1 r
F P
0 g
s
.69312 .42143 m .69904 .48239 L .70925 .47699 L p 0 .1 .396 r
F P
0 g
s
.70925 .47699 m .703 .41589 L .69312 .42143 L p 0 .1 .396 r
F P
0 g
s
.69312 .42143 m .64417 .38735 L .6541 .38146 L p 0 .916 1 r
F P
0 g
s
.6541 .38146 m .703 .41589 L .69312 .42143 L p 0 .916 1 r
F P
0 g
s
.69312 .42143 m .64417 .38735 L .63434 .39317 L p 0 .916 1 r
F P
0 g
s
.69904 .48239 m .69312 .42143 L .64417 .38735 L p 0 .627 .269 r
F P
0 g
s
.69904 .48239 m .69312 .42143 L .64417 .38735 L p 0 .627 .269 r
F P
0 g
s
.63989 .32926 m .64417 .38735 L .63434 .39317 L p 0 .1 .365 r
F P
0 g
s
.64953 .32325 m .6495 .32326 L .63989 .32926 L p 0 .93 .764 r
F P
0 g
s
.64417 .38735 m .63989 .32926 L .6495 .32326 L p 0 .1 .365 r
F P
0 g
s
.75044 .32681 m .75812 .38498 L .80379 .41921 L p 0 .607 0 r
F P
0 g
s
.75044 .32681 m .75812 .38498 L .80379 .41921 L p 0 .607 0 r
F P
0 g
s
.80379 .41921 m .75812 .38498 L .7737 .37625 L p 0 .916 0 r
F P
0 g
s
.7737 .37625 m .81923 .41099 L .80379 .41921 L p 0 .916 0 r
F P
0 g
s
.80379 .41921 m .75812 .38498 L .74278 .39359 L p 0 .916 0 r
F P
0 g
s
.81311 .48022 m .80379 .41921 L .75812 .38498 L p 0 .607 0 r
F P
0 g
s
.75812 .38498 m .80379 .41921 L .81923 .41099 L p 0 .916 0 r
F P
0 g
s
.80379 .41921 m .81311 .48022 L .8291 .47221 L p 0 .1 0 r
F P
0 g
s
.8291 .47221 m .81923 .41099 L .80379 .41921 L p 0 .1 0 r
F P
0 g
s
.81311 .48022 m .80379 .41921 L .75812 .38498 L p 0 .607 0 r
F P
0 g
s
.75044 .32681 m .75812 .38498 L .74278 .39359 L p 0 .1 0 r
F P
0 g
s
.75812 .38498 m .75044 .32681 L .76549 .31791 L p 0 .1 0 r
F P
0 g
s
.75044 .32681 m .70317 .28978 L .68825 .29909 L p 0 .914 0 r
F P
0 g
s
.75812 .38498 m .75044 .32681 L .70317 .28978 L p 0 .607 0 r
F P
0 g
s
.70317 .28978 m .75044 .32681 L .76549 .31791 L p 0 .914 0 r
F P
0 g
s
.75044 .32681 m .75812 .38498 L .7737 .37625 L p 0 .1 0 r
F P
0 g
s
.7737 .37625 m .76549 .31791 L .75044 .32681 L p 0 .1 0 r
F P
0 g
s
.75812 .38498 m .75044 .32681 L .70317 .28978 L p 0 .607 0 r
F P
0 g
s
.53826 .51097 m .53822 .51091 L .55186 .50328 L p 0 .525 .891 r
F P
0 g
s
.55186 .50328 m .5519 .50335 L .53826 .51097 L p 0 .525 .891 r
F P
0 g
s
.59161 .41849 m .59442 .47948 L .58015 .48746 L p 0 .1 0 r
F P
0 g
s
.59161 .41849 m .59442 .47948 L .59446 .47955 L p 0 .641 0 r
F P
0 g
s
.64499 .51095 m .59446 .47955 L .60894 .47144 L p 0 .916 0 r
F P
0 g
s
.60894 .47144 m .65942 .50333 L .64499 .51095 L p 0 .916 0 r
F P
0 g
s
.59161 .41849 m .59442 .47948 L .59446 .47955 L p 0 .641 0 r
F P
0 g
s
.59442 .47948 m .59161 .41849 L .60564 .41018 L p 0 .1 0 r
F P
0 g
s
.6541 .38146 m .703 .41589 L p .64953 .32325 L 0 .624 .261 r
F P
0 g
s
.64953 .32325 m .6495 .32326 L .6541 .38146 L p 0 .624 .261 r
F P
0 g
s
.6495 .32326 m .64953 .32325 L .65924 .31719 L p 0 .93 .764 r
F P
0 g
s
.6541 .38146 m .703 .41589 L p .64953 .32325 L 0 .624 .261 r
F P
0 g
s
.64953 .32325 m .6495 .32326 L .6541 .38146 L p 0 .624 .261 r
F P
0 g
s
.703 .41589 m .70925 .47699 L .69904 .48239 L p 0 .1 .396 r
F P
0 g
s
.703 .41589 m .70925 .47699 L .75651 .50857 L p 0 .624 .261 r
F P
0 g
s
.703 .41589 m .70925 .47699 L .75651 .50857 L p 0 .624 .261 r
F P
0 g
s
.70925 .47699 m .703 .41589 L .71298 .4103 L p 0 .1 .396 r
F P
0 g
s
.75651 .50857 m .70925 .47699 L .71957 .47154 L p 0 .916 1 r
F P
0 g
s
.71957 .47154 m .76675 .50344 L .75651 .50857 L p 0 .916 1 r
F P
0 g
s
.703 .41589 m .6541 .38146 L .66413 .37552 L p 0 .916 1 r
F P
0 g
s
.66413 .37552 m .71298 .4103 L .703 .41589 L p 0 .916 1 r
F P
0 g
s
.703 .41589 m .6541 .38146 L .64417 .38735 L p 0 .916 1 r
F P
0 g
s
.70925 .47699 m .703 .41589 L .6541 .38146 L p 0 .624 .261 r
F P
0 g
s
.6541 .38146 m .703 .41589 L .71298 .4103 L p 0 .916 1 r
F P
0 g
s
.703 .41589 m .70925 .47699 L .71957 .47154 L p 0 .1 .396 r
F P
0 g
s
.71957 .47154 m .71298 .4103 L .703 .41589 L p 0 .1 .396 r
F P
0 g
s
.70925 .47699 m .703 .41589 L .6541 .38146 L p 0 .624 .261 r
F P
0 g
s
.6495 .32326 m .6541 .38146 L .64417 .38735 L p 0 .1 .365 r
F P
0 g
s
.65924 .31719 m .65921 .3172 L .6495 .32326 L p 0 .93 .764 r
F P
0 g
s
.6541 .38146 m .6495 .32326 L .65921 .3172 L p 0 .1 .365 r
F P
0 g
s
.81634 .48253 m .83232 .47455 L .876 .50627 L p 0 .916 0 r
F P
0 g
s
.82238 .41339 m .83232 .47455 L .876 .50627 L p 0 .601 0 r
F P
0 g
s
.71727 .21291 m .72979 .20467 L .72983 .20474 L p 0 .546 .889 r
F P
0 g
s
.72983 .20474 m .71731 .21297 L .71727 .21291 L p 0 .546 .889 r
F P
0 g
s
.76549 .31791 m .7737 .37625 L .75812 .38498 L p 0 .1 0 r
F P
0 g
s
.76549 .31791 m .7737 .37625 L .81923 .41099 L p 0 .601 0 r
F P
0 g
s
.81923 .41099 m .7737 .37625 L .75812 .38498 L p 0 .916 0 r
F P
0 g
s
.8291 .47221 m .81923 .41099 L .7737 .37625 L p 0 .601 0 r
F P
0 g
s
.76549 .31791 m .71833 .28032 L .70317 .28978 L p 0 .914 0 r
F P
0 g
s
.7737 .37625 m .76549 .31791 L .71833 .28032 L p 0 .601 0 r
F P
0 g
s
.66413 .37552 m .71298 .4103 L p .65924 .31719 L 0 .621 .254 r
F P
0 g
s
.65924 .31719 m .65921 .3172 L .66413 .37552 L p 0 .621 .254 r
F P
0 g
s
.65921 .3172 m .65924 .31719 L .66905 .31107 L p 0 .93 .764 r
F P
0 g
s
.66413 .37552 m .71298 .4103 L p .65924 .31719 L 0 .621 .254 r
F P
0 g
s
.65924 .31719 m .65921 .3172 L .66413 .37552 L p 0 .621 .254 r
F P
0 g
s
.71298 .4103 m .71957 .47154 L .70925 .47699 L p 0 .1 .396 r
F P
0 g
s
.71298 .4103 m .71957 .47154 L .76675 .50344 L p 0 .621 .254 r
F P
0 g
s
.71298 .4103 m .71957 .47154 L .76675 .50344 L p 0 .621 .254 r
F P
0 g
s
.76675 .50344 m .71957 .47154 L .72999 .46603 L p 0 .916 1 r
F P
0 g
s
.72999 .46603 m .7771 .49825 L .76675 .50344 L p 0 .916 1 r
F P
0 g
s
.71957 .47154 m .71298 .4103 L .72306 .40465 L p 0 .1 .396 r
F P
0 g
s
.71298 .4103 m .66413 .37552 L .6541 .38146 L p 0 .916 1 r
F P
0 g
s
.71957 .47154 m .71298 .4103 L .66413 .37552 L p 0 .621 .254 r
F P
0 g
s
.66413 .37552 m .71298 .4103 L .72306 .40465 L p 0 .916 1 r
F P
0 g
s
.71298 .4103 m .71957 .47154 L .72999 .46603 L p 0 .1 .396 r
F P
0 g
s
.72999 .46603 m .72306 .40465 L .71298 .4103 L p 0 .1 .396 r
F P
0 g
s
.71957 .47154 m .71298 .4103 L .66413 .37552 L p 0 .621 .254 r
F P
0 g
s
.71298 .4103 m .66413 .37552 L .67427 .36951 L p 0 .916 1 r
F P
0 g
s
.67427 .36951 m .72306 .40465 L .71298 .4103 L p 0 .916 1 r
F P
0 g
s
.65921 .3172 m .66413 .37552 L .6541 .38146 L p 0 .1 .365 r
F P
0 g
s
.66905 .31107 m .66902 .31108 L .65921 .3172 L p 0 .93 .764 r
F P
0 g
s
.66413 .37552 m .65921 .3172 L .66902 .31108 L p 0 .1 .365 r
F P
0 g
s
.5519 .50335 m .55186 .50328 L .5657 .49554 L p 0 .525 .891 r
F P
0 g
s
.5657 .49554 m .56573 .49561 L .5519 .50335 L p 0 .525 .891 r
F P
0 g
s
.60564 .41018 m .6089 .47137 L .60894 .47144 L p 0 .638 0 r
F P
0 g
s
.60564 .41018 m .6089 .47137 L .60894 .47144 L p 0 .638 0 r
F P
0 g
s
.60894 .47144 m .6089 .47137 L .62361 .46315 L p 0 .525 0 r
F P
0 g
s
.6089 .47137 m .60564 .41018 L .61988 .40174 L p 0 .1 0 r
F P
0 g
s
.60564 .41018 m .6089 .47137 L .59442 .47948 L p 0 .1 0 r
F P
0 g
s
.82918 .40978 m .83937 .47104 L .88298 .50297 L p 0 .599 .205 r
F P
0 g
s
.82918 .40978 m .84242 .40276 L .85309 .46419 L p 0 .1 .425 r
F P
0 g
s
.85309 .46419 m .83937 .47104 L .82918 .40978 L p 0 .1 .425 r
F P
0 g
s
.89656 .49652 m .88298 .50297 L .83937 .47104 L p 0 .916 1 r
F P
0 g
s
.77212 .31399 m .78056 .3724 L .82604 .40737 L p 0 .599 .205 r
F P
0 g
s
.82604 .40737 m .78056 .3724 L .79394 .3649 L p 0 .916 1 r
F P
0 g
s
.79394 .3649 m .83929 .40031 L .82604 .40737 L p 0 .916 1 r
F P
0 g
s
.78056 .3724 m .77212 .31399 L .78504 .30635 L p 0 .1 .396 r
F P
0 g
s
.78056 .3724 m .82604 .40737 L .83929 .40031 L p 0 .916 1 r
F P
0 g
s
.82604 .40737 m .83615 .46868 L .84988 .4618 L p 0 .1 .423 r
F P
0 g
s
.84988 .4618 m .83929 .40031 L .82604 .40737 L p 0 .1 .423 r
F P
0 g
s
.83615 .46868 m .82604 .40737 L .78056 .3724 L p 0 .599 .205 r
F P
0 g
s
.72501 .27615 m .77212 .31399 L .78504 .30635 L p 0 .914 1 r
F P
0 g
s
.77212 .31399 m .78056 .3724 L .79394 .3649 L p 0 .1 .396 r
F P
0 g
s
.79394 .3649 m .78504 .30635 L .77212 .31399 L p 0 .1 .396 r
F P
0 g
s
.78056 .3724 m .77212 .31399 L .72501 .27615 L p 0 .599 .205 r
F P
0 g
s
.72979 .20467 m .74246 .19634 L .7425 .19641 L p 0 .546 .889 r
F P
0 g
s
.7425 .19641 m .72983 .20474 L .72979 .20467 L p 0 .546 .889 r
F P
0 g
s
.67427 .36951 m .72306 .40465 L p .66905 .31107 L 0 .618 .247 r
F P
0 g
s
.66905 .31107 m .66902 .31108 L .67427 .36951 L p 0 .618 .247 r
F P
0 g
s
.72306 .40465 m .72999 .46603 L .71957 .47154 L p 0 .1 .396 r
F P
0 g
s
.72306 .40465 m .72999 .46603 L .7771 .49825 L p 0 .618 .247 r
F P
0 g
s
.72306 .40465 m .67427 .36951 L .66413 .37552 L p 0 .916 1 r
F P
0 g
s
.72999 .46603 m .72306 .40465 L .67427 .36951 L p 0 .618 .247 r
F P
0 g
s
.66902 .31108 m .67427 .36951 L .66413 .37552 L p 0 .1 .365 r
F P
0 g
s
.83937 .47104 m .85309 .46419 L .89656 .49652 L p 0 .916 1 r
F P
0 g
s
.84242 .40276 m .85309 .46419 L .89656 .49652 L p 0 .594 .194 r
F P
0 g
s
.84242 .40276 m .85309 .46419 L .89656 .49652 L p 0 .594 .194 r
F P
0 g
s
.84242 .40276 m .85583 .39565 L .86699 .45725 L p 0 .1 .425 r
F P
0 g
s
.86699 .45725 m .85309 .46419 L .84242 .40276 L p 0 .1 .425 r
F P
0 g
s
.9103 .49 m .89656 .49652 L .85309 .46419 L p 0 .916 1 r
F P
0 g
s
.56573 .49561 m .5657 .49554 L .57974 .48769 L p 0 .525 .891 r
F P
0 g
s
.57974 .48769 m .57978 .48775 L .56573 .49561 L p 0 .525 .891 r
F P
0 g
s
.61988 .40174 m .62361 .46315 L .6089 .47137 L p 0 .1 0 r
F P
0 g
s
.61988 .40174 m .62361 .46315 L .62365 .46322 L p 0 .634 0 r
F P
0 g
s
.61988 .40174 m .62361 .46315 L .62365 .46322 L p 0 .634 0 r
F P
0 g
s
.62361 .46315 m .61988 .40174 L .63434 .39317 L p 0 .1 0 r
F P
0 g
s
.67406 .49559 m .62365 .46322 L .63859 .45486 L p 0 .916 0 r
F P
0 g
s
.63859 .45486 m .68893 .48773 L .67406 .49559 L p 0 .916 0 r
F P
0 g
s
.78504 .30635 m .79394 .3649 L .78056 .3724 L p 0 .1 .396 r
F P
0 g
s
.78504 .30635 m .79394 .3649 L .83929 .40031 L p 0 .594 .194 r
F P
0 g
s
.78504 .30635 m .79394 .3649 L .83929 .40031 L p 0 .594 .194 r
F P
0 g
s
.83929 .40031 m .79394 .3649 L .80748 .35731 L p 0 .916 1 r
F P
0 g
s
.80748 .35731 m .85271 .39317 L .83929 .40031 L p 0 .916 1 r
F P
0 g
s
.79394 .3649 m .78504 .30635 L .79811 .29862 L p 0 .1 .396 r
F P
0 g
s
.83929 .40031 m .79394 .3649 L .78056 .3724 L p 0 .916 1 r
F P
0 g
s
.84988 .4618 m .83929 .40031 L .79394 .3649 L p 0 .594 .194 r
F P
0 g
s
.79394 .3649 m .83929 .40031 L .85271 .39317 L p 0 .916 1 r
F P
0 g
s
.83929 .40031 m .84988 .4618 L .86379 .45484 L p 0 .1 .423 r
F P
0 g
s
.86379 .45484 m .85271 .39317 L .83929 .40031 L p 0 .1 .423 r
F P
0 g
s
.84988 .4618 m .83929 .40031 L .79394 .3649 L p 0 .594 .194 r
F P
0 g
s
.78504 .30635 m .73803 .26803 L .72501 .27615 L p 0 .914 1 r
F P
0 g
s
.79394 .3649 m .78504 .30635 L .73803 .26803 L p 0 .594 .194 r
F P
0 g
s
.73803 .26803 m .78504 .30635 L .79811 .29862 L p 0 .914 1 r
F P
0 g
s
.78504 .30635 m .79394 .3649 L .80748 .35731 L p 0 .1 .396 r
F P
0 g
s
.80748 .35731 m .79811 .29862 L .78504 .30635 L p 0 .1 .396 r
F P
0 g
s
.79394 .3649 m .78504 .30635 L .73803 .26803 L p 0 .594 .194 r
F P
0 g
s
.85309 .46419 m .86699 .45725 L .9103 .49 L p 0 .916 1 r
F P
0 g
s
.85583 .39565 m .86699 .45725 L .9103 .49 L p 0 .59 .184 r
F P
0 g
s
.68821 .29911 m .68825 .29909 L .70317 .28978 L p 0 .93 0 r
F P
0 g
s
.69412 .35775 m .74278 .39359 L p .68825 .29909 L 0 .612 0 r
F P
0 g
s
.68825 .29909 m .68821 .29911 L .69412 .35775 L p 0 .612 0 r
F P
0 g
s
.74278 .39359 m .75041 .45524 L .79736 .48811 L p 0 .612 0 r
F P
0 g
s
.79736 .48811 m .75041 .45524 L .76629 .44684 L p 0 .916 0 r
F P
0 g
s
.76629 .44684 m .81311 .48022 L .79736 .48811 L p 0 .916 0 r
F P
0 g
s
.75041 .45524 m .74278 .39359 L .75812 .38498 L p 0 .1 0 r
F P
0 g
s
.74278 .39359 m .69412 .35775 L .70957 .34859 L p 0 .916 0 r
F P
0 g
s
.70957 .34859 m .75812 .38498 L .74278 .39359 L p 0 .916 0 r
F P
0 g
s
.69412 .35775 m .74278 .39359 L .75812 .38498 L p 0 .916 0 r
F P
0 g
s
.74278 .39359 m .75041 .45524 L .76629 .44684 L p 0 .1 0 r
F P
0 g
s
.76629 .44684 m .75812 .38498 L .74278 .39359 L p 0 .1 0 r
F P
0 g
s
.75041 .45524 m .74278 .39359 L .69412 .35775 L p 0 .612 0 r
F P
0 g
s
.70317 .28978 m .70314 .28979 L .68821 .29911 L p 0 .93 0 r
F P
0 g
s
.69412 .35775 m .68821 .29911 L .70314 .28979 L p 0 .1 0 r
F P
0 g
s
.63434 .39317 m .63855 .45479 L .63859 .45486 L p 0 .63 .275 r
F P
0 g
s
.63434 .39317 m .63855 .45479 L .63859 .45486 L p 0 .63 0 r
F P
0 g
s
.63859 .45486 m .63855 .45479 L .64872 .44911 L p 0 .525 .891 r
F P
0 g
s
.63855 .45479 m .63434 .39317 L .64417 .38735 L p 0 .1 .365 r
F P
0 g
s
.79811 .29862 m .80748 .35731 L .79394 .3649 L p 0 .1 .396 r
F P
0 g
s
.79811 .29862 m .80748 .35731 L .85271 .39317 L p 0 .59 .184 r
F P
0 g
s
.85271 .39317 m .80748 .35731 L .79394 .3649 L p 0 .916 1 r
F P
0 g
s
.86379 .45484 m .85271 .39317 L .80748 .35731 L p 0 .59 .184 r
F P
0 g
s
.79811 .29862 m .75121 .25981 L .73803 .26803 L p 0 .914 1 r
F P
0 g
s
.80748 .35731 m .79811 .29862 L .75121 .25981 L p 0 .59 .184 r
F P
0 g
s
.63434 .39317 m .63855 .45479 L .62361 .46315 L p 0 .1 0 r
F P
0 g
s
.58019 .48753 m .58015 .48746 L .59442 .47948 L p 0 .525 0 r
F P
0 g
s
.59442 .47948 m .59446 .47955 L .58019 .48753 L p 0 .525 0 r
F P
0 g
s
.64417 .38735 m .64872 .44911 L .63855 .45479 L p 0 .1 .365 r
F P
0 g
s
.64876 .44918 m .69904 .48239 L p .64417 .38735 L 0 .627 .269 r
F P
0 g
s
.64417 .38735 m .64872 .44911 L .64876 .44918 L p 0 .627 .269 r
F P
0 g
s
.64876 .44918 m .69904 .48239 L p .64417 .38735 L 0 .627 .269 r
F P
0 g
s
.69904 .48239 m .64876 .44918 L .65903 .44343 L p 0 .916 1 r
F P
0 g
s
.65903 .44343 m .70925 .47699 L .69904 .48239 L p 0 .916 1 r
F P
0 g
s
.64417 .38735 m .64872 .44911 L .64876 .44918 L p 0 .627 .269 r
F P
0 g
s
.64872 .44911 m .64417 .38735 L .6541 .38146 L p 0 .1 .365 r
F P
0 g
s
.70957 .34859 m .75812 .38498 L p .70317 .28978 L 0 .607 0 r
F P
0 g
s
.70317 .28978 m .70314 .28979 L .70957 .34859 L p 0 .607 0 r
F P
0 g
s
.70314 .28979 m .70317 .28978 L .71833 .28032 L p 0 .93 0 r
F P
0 g
s
.70957 .34859 m .75812 .38498 L p .70317 .28978 L 0 .607 0 r
F P
0 g
s
.70317 .28978 m .70314 .28979 L .70957 .34859 L p 0 .607 0 r
F P
0 g
s
.75812 .38498 m .76629 .44684 L .75041 .45524 L p 0 .1 0 r
F P
0 g
s
.75812 .38498 m .76629 .44684 L .81311 .48022 L p 0 .607 0 r
F P
0 g
s
.75812 .38498 m .76629 .44684 L .81311 .48022 L p 0 .607 0 r
F P
0 g
s
.76629 .44684 m .75812 .38498 L .7737 .37625 L p 0 .1 0 r
F P
0 g
s
.81311 .48022 m .76629 .44684 L .78243 .43832 L p 0 .916 0 r
F P
0 g
s
.78243 .43832 m .8291 .47221 L .81311 .48022 L p 0 .916 0 r
F P
0 g
s
.75812 .38498 m .70957 .34859 L .72526 .3393 L p 0 .916 0 r
F P
0 g
s
.72526 .3393 m .7737 .37625 L .75812 .38498 L p 0 .916 0 r
F P
0 g
s
.75812 .38498 m .70957 .34859 L .69412 .35775 L p 0 .916 0 r
F P
0 g
s
.76629 .44684 m .75812 .38498 L .70957 .34859 L p 0 .607 0 r
F P
0 g
s
.70957 .34859 m .75812 .38498 L .7737 .37625 L p 0 .916 0 r
F P
0 g
s
.75812 .38498 m .76629 .44684 L .78243 .43832 L p 0 .1 0 r
F P
0 g
s
.78243 .43832 m .7737 .37625 L .75812 .38498 L p 0 .1 0 r
F P
0 g
s
.76629 .44684 m .75812 .38498 L .70957 .34859 L p 0 .607 0 r
F P
0 g
s
.70314 .28979 m .70957 .34859 L .69412 .35775 L p 0 .1 0 r
F P
0 g
s
.71833 .28032 m .7183 .28033 L .70314 .28979 L p 0 .93 0 r
F P
0 g
s
.70957 .34859 m .70314 .28979 L .7183 .28033 L p 0 .1 0 r
F P
0 g
s
.59446 .47955 m .59442 .47948 L .6089 .47137 L p 0 .525 0 r
F P
0 g
s
.6089 .47137 m .60894 .47144 L .59446 .47955 L p 0 .525 0 r
F P
0 g
s
.6541 .38146 m .65899 .44336 L .64872 .44911 L p 0 .1 .365 r
F P
0 g
s
.65903 .44343 m .70925 .47699 L p .6541 .38146 L 0 .624 .261 r
F P
0 g
s
.6541 .38146 m .65899 .44336 L .65903 .44343 L p 0 .624 .261 r
F P
0 g
s
.65903 .44343 m .70925 .47699 L p .6541 .38146 L 0 .624 .261 r
F P
0 g
s
.6541 .38146 m .65899 .44336 L .65903 .44343 L p 0 .624 .261 r
F P
0 g
s
.65899 .44336 m .6541 .38146 L .66413 .37552 L p 0 .1 .365 r
F P
0 g
s
.70925 .47699 m .65903 .44343 L .66941 .43763 L p 0 .916 1 r
F P
0 g
s
.66941 .43763 m .71957 .47154 L .70925 .47699 L p 0 .916 1 r
F P
0 g
s
.72526 .3393 m .7737 .37625 L p .71833 .28032 L 0 .601 0 r
F P
0 g
s
.71833 .28032 m .7183 .28033 L .72526 .3393 L p 0 .601 0 r
F P
0 g
s
.7737 .37625 m .78243 .43832 L .76629 .44684 L p 0 .1 0 r
F P
0 g
s
.7737 .37625 m .78243 .43832 L .8291 .47221 L p 0 .601 0 r
F P
0 g
s
.7737 .37625 m .72526 .3393 L .70957 .34859 L p 0 .916 0 r
F P
0 g
s
.78243 .43832 m .7737 .37625 L .72526 .3393 L p 0 .601 0 r
F P
0 g
s
.7183 .28033 m .72526 .3393 L .70957 .34859 L p 0 .1 0 r
F P
0 g
s
.66413 .37552 m .66937 .43755 L .65899 .44336 L p 0 .1 .365 r
F P
0 g
s
.66941 .43763 m .71957 .47154 L p .66413 .37552 L 0 .621 .254 r
F P
0 g
s
.66413 .37552 m .66937 .43755 L .66941 .43763 L p 0 .621 .254 r
F P
0 g
s
.66941 .43763 m .71957 .47154 L p .66413 .37552 L 0 .621 .254 r
F P
0 g
s
.71957 .47154 m .66941 .43763 L .6799 .43176 L p 0 .916 1 r
F P
0 g
s
.6799 .43176 m .72999 .46603 L .71957 .47154 L p 0 .916 1 r
F P
0 g
s
.66413 .37552 m .66937 .43755 L .66941 .43763 L p 0 .621 .254 r
F P
0 g
s
.66937 .43755 m .66413 .37552 L .67427 .36951 L p 0 .1 .365 r
F P
0 g
s
.62361 .46315 m .62365 .46322 L .60894 .47144 L p 0 .525 0 r
F P
0 g
s
.72498 .27617 m .72501 .27615 L .73803 .26803 L p 0 .93 .764 r
F P
0 g
s
.73218 .3352 m .78056 .3724 L p .72501 .27615 L 0 .599 .205 r
F P
0 g
s
.72501 .27615 m .72498 .27617 L .73218 .3352 L p 0 .599 .205 r
F P
0 g
s
.78056 .3724 m .78954 .43456 L .83615 .46868 L p 0 .599 .205 r
F P
0 g
s
.78954 .43456 m .78056 .3724 L .79394 .3649 L p 0 .1 .396 r
F P
0 g
s
.78056 .3724 m .73218 .3352 L .74566 .32721 L p 0 .916 1 r
F P
0 g
s
.74566 .32721 m .79394 .3649 L .78056 .3724 L p 0 .916 1 r
F P
0 g
s
.73218 .3352 m .78056 .3724 L .79394 .3649 L p 0 .916 1 r
F P
0 g
s
.78056 .3724 m .78954 .43456 L .80341 .42723 L p 0 .1 .396 r
F P
0 g
s
.80341 .42723 m .79394 .3649 L .78056 .3724 L p 0 .1 .396 r
F P
0 g
s
.78954 .43456 m .78056 .3724 L .73218 .3352 L p 0 .599 .205 r
F P
0 g
s
.83615 .46868 m .78954 .43456 L .80341 .42723 L p 0 .916 1 r
F P
0 g
s
.80341 .42723 m .84988 .4618 L .83615 .46868 L p 0 .916 1 r
F P
0 g
s
.73803 .26803 m .738 .26805 L .72498 .27617 L p 0 .93 .764 r
F P
0 g
s
.73218 .3352 m .72498 .27617 L .738 .26805 L p 0 .1 .365 r
F P
0 g
s
.67427 .36951 m .67986 .43169 L .66937 .43755 L p 0 .1 .365 r
F P
0 g
s
.6799 .43176 m .72999 .46603 L p .67427 .36951 L 0 .618 .247 r
F P
0 g
s
.67427 .36951 m .67986 .43169 L .6799 .43176 L p 0 .618 .247 r
F P
0 g
s
.62365 .46322 m .62361 .46315 L .63855 .45479 L p 0 .525 0 r
F P
0 g
s
.63855 .45479 m .63859 .45486 L .62365 .46322 L p 0 .525 0 r
F P
0 g
s
.74566 .32721 m .79394 .3649 L p .73803 .26803 L 0 .594 .194 r
F P
0 g
s
.73803 .26803 m .738 .26805 L .74566 .32721 L p 0 .594 .194 r
F P
0 g
s
.738 .26805 m .73803 .26803 L .75121 .25981 L p 0 .93 .764 r
F P
0 g
s
.74566 .32721 m .79394 .3649 L p .73803 .26803 L 0 .594 .194 r
F P
0 g
s
.73803 .26803 m .738 .26805 L .74566 .32721 L p 0 .594 .194 r
F P
0 g
s
.79394 .3649 m .80341 .42723 L .78954 .43456 L p 0 .1 .396 r
F P
0 g
s
.79394 .3649 m .80341 .42723 L .84988 .4618 L p 0 .594 .194 r
F P
0 g
s
.79394 .3649 m .80341 .42723 L .84988 .4618 L p 0 .594 .194 r
F P
0 g
s
.80341 .42723 m .79394 .3649 L .80748 .35731 L p 0 .1 .396 r
F P
0 g
s
.79394 .3649 m .74566 .32721 L .75932 .31911 L p 0 .916 1 r
F P
0 g
s
.75932 .31911 m .80748 .35731 L .79394 .3649 L p 0 .916 1 r
F P
0 g
s
.79394 .3649 m .74566 .32721 L .73218 .3352 L p 0 .916 1 r
F P
0 g
s
.80341 .42723 m .79394 .3649 L .74566 .32721 L p 0 .594 .194 r
F P
0 g
s
.74566 .32721 m .79394 .3649 L .80748 .35731 L p 0 .916 1 r
F P
0 g
s
.79394 .3649 m .80341 .42723 L .81746 .41981 L p 0 .1 .396 r
F P
0 g
s
.81746 .41981 m .80748 .35731 L .79394 .3649 L p 0 .1 .396 r
F P
0 g
s
.80341 .42723 m .79394 .3649 L .74566 .32721 L p 0 .594 .194 r
F P
0 g
s
.84988 .4618 m .80341 .42723 L .81746 .41981 L p 0 .916 1 r
F P
0 g
s
.81746 .41981 m .86379 .45484 L .84988 .4618 L p 0 .916 1 r
F P
0 g
s
.738 .26805 m .74566 .32721 L .73218 .3352 L p 0 .1 .365 r
F P
0 g
s
.75121 .25981 m .75118 .25982 L .738 .26805 L p 0 .93 .764 r
F P
0 g
s
.74566 .32721 m .738 .26805 L .75118 .25982 L p 0 .1 .365 r
F P
0 g
s
.70045 .42026 m .75041 .45524 L p .69412 .35775 L 0 .612 0 r
F P
0 g
s
.69412 .35775 m .70041 .42019 L .70045 .42026 L p 0 .612 0 r
F P
0 g
s
.70041 .42019 m .69412 .35775 L .70957 .34859 L p 0 .1 0 r
F P
0 g
s
.75041 .45524 m .70045 .42026 L .71646 .41131 L p 0 .916 0 r
F P
0 g
s
.71646 .41131 m .76629 .44684 L .75041 .45524 L p 0 .916 0 r
F P
0 g
s
.64872 .44911 m .64876 .44918 L .63859 .45486 L p 0 .525 .891 r
F P
0 g
s
.75932 .31911 m .80748 .35731 L p .75121 .25981 L 0 .59 .184 r
F P
0 g
s
.75121 .25981 m .75118 .25982 L .75932 .31911 L p 0 .59 .184 r
F P
0 g
s
.80748 .35731 m .81746 .41981 L .80341 .42723 L p 0 .1 .396 r
F P
0 g
s
.80748 .35731 m .81746 .41981 L .86379 .45484 L p 0 .59 .184 r
F P
0 g
s
.80748 .35731 m .75932 .31911 L .74566 .32721 L p 0 .916 1 r
F P
0 g
s
.81746 .41981 m .80748 .35731 L .75932 .31911 L p 0 .59 .184 r
F P
0 g
s
.75118 .25982 m .75932 .31911 L .74566 .32721 L p 0 .1 .365 r
F P
0 g
s
.64876 .44918 m .64872 .44911 L .65899 .44336 L p 0 .525 .891 r
F P
0 g
s
.65899 .44336 m .65903 .44343 L .64876 .44918 L p 0 .525 .891 r
F P
0 g
s
.70957 .34859 m .71642 .41124 L .70041 .42019 L p 0 .1 0 r
F P
0 g
s
.71646 .41131 m .76629 .44684 L p .70957 .34859 L 0 .607 0 r
F P
0 g
s
.70957 .34859 m .71642 .41124 L .71646 .41131 L p 0 .607 0 r
F P
0 g
s
.71646 .41131 m .76629 .44684 L p .70957 .34859 L 0 .607 0 r
F P
0 g
s
.76629 .44684 m .71646 .41131 L .73272 .40222 L p 0 .916 0 r
F P
0 g
s
.73272 .40222 m .78243 .43832 L .76629 .44684 L p 0 .916 0 r
F P
0 g
s
.70957 .34859 m .71642 .41124 L .71646 .41131 L p 0 .607 0 r
F P
0 g
s
.71642 .41124 m .70957 .34859 L .72526 .3393 L p 0 .1 0 r
F P
0 g
s
.65903 .44343 m .65899 .44336 L .66937 .43755 L p 0 .525 .891 r
F P
0 g
s
.66937 .43755 m .66941 .43763 L .65903 .44343 L p 0 .525 .891 r
F P
0 g
s
.72526 .3393 m .73268 .40214 L .71642 .41124 L p 0 .1 0 r
F P
0 g
s
.73272 .40222 m .78243 .43832 L p .72526 .3393 L 0 .601 0 r
F P
0 g
s
.72526 .3393 m .73268 .40214 L .73272 .40222 L p 0 .601 0 r
F P
0 g
s
.66941 .43763 m .66937 .43755 L .67986 .43169 L p 0 .525 .891 r
F P
0 g
s
.67986 .43169 m .6799 .43176 L .66941 .43763 L p 0 .525 .891 r
F P
0 g
s
.73989 .3982 m .78954 .43456 L p .73218 .3352 L 0 .599 .205 r
F P
0 g
s
.73218 .3352 m .73985 .39813 L .73989 .3982 L p 0 .599 .205 r
F P
0 g
s
.73985 .39813 m .73218 .3352 L .74566 .32721 L p 0 .1 .365 r
F P
0 g
s
.78954 .43456 m .73989 .3982 L .75388 .39038 L p 0 .916 1 r
F P
0 g
s
.75388 .39038 m .80341 .42723 L .78954 .43456 L p 0 .916 1 r
F P
0 g
s
.74566 .32721 m .75383 .39031 L .73985 .39813 L p 0 .1 .365 r
F P
0 g
s
.75388 .39038 m .80341 .42723 L p .74566 .32721 L 0 .594 .194 r
F P
0 g
s
.74566 .32721 m .75383 .39031 L .75388 .39038 L p 0 .594 .194 r
F P
0 g
s
.75388 .39038 m .80341 .42723 L p .74566 .32721 L 0 .594 .194 r
F P
0 g
s
.80341 .42723 m .75388 .39038 L .76805 .38246 L p 0 .916 1 r
F P
0 g
s
.76805 .38246 m .81746 .41981 L .80341 .42723 L p 0 .916 1 r
F P
0 g
s
.74566 .32721 m .75383 .39031 L .75388 .39038 L p 0 .594 .194 r
F P
0 g
s
.75383 .39031 m .74566 .32721 L .75932 .31911 L p 0 .1 .365 r
F P
0 g
s
.70045 .42026 m .70041 .42019 L .71642 .41124 L p 0 .525 0 r
F P
0 g
s
.71642 .41124 m .71646 .41131 L .70045 .42026 L p 0 .525 0 r
F P
0 g
s
.75932 .31911 m .76801 .38238 L .75383 .39031 L p 0 .1 .365 r
F P
0 g
s
.76805 .38246 m .81746 .41981 L p .75932 .31911 L 0 .59 .184 r
F P
0 g
s
.75932 .31911 m .76801 .38238 L .76805 .38246 L p 0 .59 .184 r
F P
0 g
s
.71646 .41131 m .71642 .41124 L .73268 .40214 L p 0 .525 0 r
F P
0 g
s
.73268 .40214 m .73272 .40222 L .71646 .41131 L p 0 .525 0 r
F P
0 g
s
.73989 .3982 m .73985 .39813 L .75383 .39031 L p 0 .525 .891 r
F P
0 g
s
.75383 .39031 m .75388 .39038 L .73989 .3982 L p 0 .525 .891 r
F P
0 g
s
.75388 .39038 m .75383 .39031 L .76801 .38238 L p 0 .525 .891 r
F P
0 g
s
.76801 .38238 m .76805 .38246 L .75388 .39038 L p 0 .525 .891 r
F P
0 g
s
[ .01 .01 ] 0 setdash
.16771 .48466 m
.74209 .07151 L
s
.74209 .07151 m
.78676 .37421 L
s
.78676 .37421 m
.12589 .74312 L
s
.12589 .74312 m
.16771 .48466 L
s
.91222 .23212 m
.74209 .07151 L
s
.74209 .07151 m
.78676 .37421 L
s
.78676 .37421 m
.97858 .52209 L
s
.97858 .52209 m
.91222 .23212 L
s
.003 w
[ ] 0 setdash
.91222 .23212 m
.74209 .07151 L
s
.25 Mabswid
.88664 .20797 m
.8813 .21122 L
s
gsave
.89732 .20147 -61 -15.2625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.8321 .15648 m
.82685 .15988 L
s
gsave
.84258 .14967 -61 -15.5417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77315 .10083 m
.76801 .10439 L
s
gsave
.78342 .0937 -61 -15.86 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.87339 .19546 m
.8702 .19743 L
s
.85989 .18271 m
.85671 .18471 L
s
.84613 .16972 m
.84297 .17174 L
s
.81779 .14297 m
.81466 .14504 L
s
.80321 .1292 m
.80009 .13129 L
s
.78833 .11516 m
.78523 .11727 L
s
.89965 .22024 m
.89643 .22217 L
s
.75766 .08621 m
.7546 .08837 L
s
gsave
.89501 .11566 -61 -15.5417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.32213 .81482 m
.97858 .52209 L
s
.25 Mabswid
.44152 .76158 m
.44167 .75533 L
s
gsave
.4412 .77408 -73.4292 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.59489 .69319 m
.59463 .68695 L
s
gsave
.59541 .70568 -65.7903 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.77804 .61152 m
.77725 .60532 L
s
gsave
.77962 .62392 -67.98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.47016 .74881 m
.47021 .74506 L
s
.49977 .7356 m
.49977 .73185 L
s
.5304 .72195 m
.53035 .7182 L
s
.56208 .70782 m
.56198 .70407 L
s
.62888 .67803 m
.62867 .67429 L
s
.66412 .66232 m
.66384 .65858 L
s
.70067 .64602 m
.70033 .64228 L
s
.73862 .6291 m
.73821 .62537 L
s
.41379 .77395 m
.41393 .7702 L
s
.38693 .78592 m
.38711 .78218 L
s
.36091 .79753 m
.36113 .79379 L
s
.33568 .80878 m
.33593 .80504 L
s
.81902 .59325 m
.81847 .58954 L
s
.86166 .57423 m
.86103 .57053 L
s
.90605 .55444 m
.90534 .55075 L
s
.95231 .53381 m
.95152 .53014 L
s
gsave
.59803 .76812 -68.4848 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{364.5, 364.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005/0001K0P10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^CLg=gIfM[Fe]OCdm?clo5D005Gooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_C/k>gYjN[Vi^OShn000EED0EJX00?l003lo?ginO[fm_Oclo0<30d92@X61PL30`3lo
?ginO[fm_Ol0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5Q@<30d92@X61PL30`?l0ZP00
oeD0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9R@L71dI6AXF5QLC4a?l0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=S@/;2dY:BXV9RLS8b?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6AT@l?3di>CXf=SLc<c?mEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUA<C4e9B
DY6ATM3@d?mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVALG5eIFEYFEUMCDe?mEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWA/K6eYJFYVIVMSHf?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXAlO7eiNGYfMWMcLg?nZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYB<S8f9RHZ6QXN3Ph?nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZBLW9fIV
IZFUYNCTi?nZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][B/[:fYZJZVYZNSXj?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/Bl_;fi^KZf][Nc/k?ooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]C<c<g9bL[6a/O3`l0000?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nN
KIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nN
KIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nN
KIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nNKIh00?nN
0ol?WPCo0ih3oe6N003nWP03oiko00;o3Yh01onNWYkoW_l00ih00onNWP1>WP00oih2WP03oiko00jN
00?oWYh00Yh01OnNWYko052N003jWP;o1Ih01?nNW_l>WP05oijNW_l00ih00onNWP1>WP00nIh00onN
WP09WP03oijN00bN00CoWYko0ih00onNWP1>WP00n9h00onNWP0:WP;o3Ih01?nNW_l3WP03oijN04jN
003oWP:N00?oWYh00ih00onNWP07WP04oijNo`:N00GoWYjNo`1@WP00mIh2o`FN00?oWYh00Yh00onN
WP04WP03oijN00NN0_l4WP?oDIh00?BN00?oWYh019h3o`>N00?oWYh01Ih00onNWP0[WP?o0Yh3obfN
003cWP03oijN00>N0_l0163oX?l3WP03oijN00FN00?oWYh0;9h01?nNW_l_WP00n9h02?lP823oH93o
0Yh00onNWP05WP?o;9h01?nNW_l_WP00kih2o`FN0_l02B1P863oX92Po`08WP03oijN00;o;9h2oc2N
003^WP03oijN00BN00?o8?l012001_mPT62@o`^N0_l[WP;o<9h00>fN00?oWYh019h03omP8?lPH21P
8?n@X92Po`0;WP03oijN02RN00CoWYko;ih00?>N00Go820Po`058005oi1PT6000_l;WP;o:9h01?nN
W_l_WP00jYh00onNWP03WPCo014PH21Pof0PH23oT:2@X?nPo`0:WP?o9Ih3o`:N0ol]WP00jIh00onN
WP03WP?o00>@ob000b000olP80028009oi1PT62@oi3o00bN00?oWYh0Eih00>RN00?oWYh00ih06Om@
oon@ob1P863oH21P8?n@X92PT?n@X?l039h00onNWP1FWP00k9h6o`03T?lP00<P00?o82000R002on@
H91PT62@H93o00bN00?oWYh0EIh00>BN0_l5WPCo00=@ool00Y005OmP863oH21P8?n@X92PT:2@X92P
o`0<WP03oijN05BN003SWP03oijN00BN2Ol00e3o8003800Aob0P8?n@H91PT?n@H91PT?l02Yh3o`nN
0om3WP00hYh00onNWP03WP?o021@ooooD?m@oi3oH21P8?lPH23oT:2@X93oT:2@X92Po`bN00?oWYh0
2ih01OnNWYko04:N003XWP_o00=@ob000b000olP8002800=of2@H93oT62@H91PT002o`^N00?oWYh0
2Yh01OnNWYko04:N003NWP;o29h01?m@oe03o`0OD?m@oi3oH21P8?lPH21Poj2@X92Poj2@X92PT?n@
o`0;WP03oijN00VN00GoWYjNo`12WP00gIh00onNWP08WP_o00=@ob000b000olP8002800Aof2@H91P
of2@H91PT?n@H?l02ih00onNWP08WP05oijNW_l0@Yh00=bN00?oWYh02Ih01?m@oe03o`0>D?m@oi3o
H21P8?lPH203o`0@T:2@X92PT:2@X93oT:2@o`VN00?oW_l02Ih01OnNWYko04:N003QWP?o19h;o`03
D?lP00@P01Oo8?lPof3oH91PT62@H91PT?n@H91Po`0;WP03oijN00JN00GoWYjNo`12WP00fIh2o`FN
00GoH?n@o`04WP;o00m@oe3oD?m@oi3oH21P86000_l05R1Poj2@oi2Poj2@X92PT:3oX92PT?l;WP;o
1ih3od>N003HWP03oijN00>N0_l28004oj1Po`>N2_l00e2@o`0380;o0b005OmPT63oH?mPT62@H91P
of2@H91Po`0<WP03oijN04ZN003GWP03oijN00>N00[o8?lPH?n@X93o0Yh2o`07D?m@oe3oD002o`03
T?lP00;o01]Pof0PH?nPT:2@oi3oT:2@X92Poj2@X92PT?l02ih2od^N003LWP04ob0Po`8P00OoX62P
H?nN00_o00>@ool00b000olP80028005oi1PT6000_l03i1PT62@H?mPT62@H91Po`09WP04oijNodZN
003CWP;o1Yh2o`0;H23o863oT:2@X9000ol01e3oD?m@oe000_l04I3o860PH?mP860Poi2PT:2@00;o
00nPT:2@X?nPT:2@X92PT?l039h00onNWP17WP00dYh00onNWP04WP;o00DPob0Po`028007oj1PX62P
H00=o`@P00?o82000R006?n@H91PT62@oi1PT63oH91PT62@H91Po`bN00?oWYh0AYh00=6N00?oWYh0
19h2o`0?863oH23o863oT:2@X92P00;o00E@oe3oD004o`0TT?lPH21P8?lPH23oT:2@X92PT:3oX92P
oj2@X92PT:2@X93o39h00onNWP15WP00eYh2o`058?lP8?l00R002_lP8?nPH:1PX60;o`03T?lP00@P
01ko820Poi1PT62@oi1PT?n@H?mPT62@H91PT62@H?l:WP?oAYh00<jN00?oWYh019h2o`0BH23o863o
H23o860Poj2@X92P0_l01e3oD?m@oe000_l2T00Tof0PH23o860Poi2PT:2@oi2PT:3oX93oT:2@X92P
T:2@X93o39h00onNWP13WP00cIh00onNWP03WPCo0R001?lP8?l2800;ob0P8?mPX62PH:002_l00i1@
o`04800Nob0P8?n@H91PT63oH91PT?n@oi1PT62@H91PT62@0ol;WP03oijN04:N003<WP03oijN00>N
03[oD?m@of0Pob1Pof0PH?mP8?nPT:2@X93oD?m@oe3oD?m@oi3oH21P8?lPH23oT:2@X92Poj2@X92P
0_l02i2PT:2@X92PT:2@00;o00>Poih02Yh00onNWP11WP00d9h7o`8P00Co823o0b002_lP8?mPX62P
H:0;o`03D?lP00<P01;o820Poi1PT62@H91PT62@H902o`0:H91PT62@H91PT0;o00=PT?l02ih00onN
WP0DWPCo0ih3ob:N0038WP;o1Ih4o`1<D?m@of0Pob1P8?lPH?mP8?nPT:2@X93oD?m@oe3oD?m@oi3o
H21P8?lPH21Poj2@X92PT:2@X92PT?n@oi2PT:2@X92PT:3oX92Po`VN0olEWP07oijNW_nNo`03WP03
oijN01nN0037WP03oijN00BN2Ol28005ob0P8?l00R002_lP8?mPX62PH:0;o`03D93o00<P00?o8200
0R006_mPT62@H91PT62@H93oT63oH91PT62@H91P0_l0191PT?l;WP03oijN01>N00?oWYh00Yh01OnN
WYko026N0036WP03oijN00>N0ol07e3ooom@oe3oH23o860Pob1Pof0Poj2@X92PT?m@oe000ol0153o
D?l2T00Sob1P8?lPH21Poj2@X92Poj2@X92PT?n@X93oT:2@X92PT:000_l01I2PT:3o00^N0_l;WPOo
0Yh01OnNWYko00>N00?oWYh07ih00<^N3?l38004ob0Po`8P00[o823oH:1PX62P2ol00e2@o`048004
ob0P80;o01R@H91Pof2@H91PT63oH91Pof2@H91PT602o`06T62@H93o39h00onNWP0BWP04oijNo`>N
00?oWYh07ih00<ZN00?oD?l00_l04e3ooom@oe3oH21Pof0Pob1Pof000ol02I2PT:2@oe3oD003o`04
D?m@o`:@00So860PH?mP80;o01VPT:2@X93oT:2@X92Poj2@X93oT:2@X92P00;o00N@X92PT:3o00ZN
0olCWP04oijNo`>N00?oWYh07ih00<:N0_l4WQ3o0R001?lP8?l280;o00PPof3oH:1PX0_o00=@T?l0
12006?lPol01`91PT62@oi1PT62@H?mPT62@H0;o00j@H91PT?n@H91PT62@o`^N0_l?WP04oijNo`:N
00GoWYjNo`0QWP00`Ih00onNWP02WPGo00E@ooooD003o`03D?m@00;o00LPH?mP8?lP00;o00eP8?nP
T?n@X93oD?m@00?o00A@oe3o0Y001OlPH21P00;o1@406:2@X92PT:2@X92Poj2@X92PT:3oX92PT0;o
00RPT:2@X92Po`^N0_l?WP;o19h3ob:N0030WP03oijN00:N4ol28003ob0P00;o00/Pob0Pof2PH?mP
X00<o`03T53o008P0_l07/01`0700L2@H91PT62@H91Pof2@H91PT62@oi1PT0;o00UPT62@H91PT?l0
2ih2ocVN0033WP;o00=@oe000ol02e3ooom@oe3oD?m@00;o00@PH?mP0_l02R1Pof0Poj2@X903o`03
D?m@00?o00=@oe000_l2T0?o2P405Z2@oi2PT:2@X?nPT:2@X92PT:3oX902o`0:X92PT:2@X92Po`ZN
0olhWP00_Ih00onNWP02WP03ob3o01?o0R02o`058?lP8?l00b001_nPH:1PX0co02F@D?o00L01`07o
0L01`0700On@H91PT62@oi1PT62@H91PT?n@00;o00YPT62@H91PT62@0_l7WP05oijNW_l0=ih00;bN
00?oWYh00Yh01olPH?m@oe000ol02e3ooom@oe3oD?m@00;o01<PoomP8?lPH?mP863oT:2@X92P00;o
00M@oe3oD?m@00;o19060@03o`4100@102?oT:2@X92PT?n@X92PT:2@X92Poj3oX92PT:2@X92PT?n@
o`0;WP03oijN03BN002kWP04oijNWP;o0b0Eo`058?lP8?l00b002_lP8?nPH:1PX60<o`0:D91@T?l1
`0700@;o01S00L01`?mPT62@H93oT62@H91PT62@H903o`0=T62@H91PT62@oi1Po`0;WP03oijN03>N
002nWP0:of3oH21Poe3oD0?o00]@oe3oD?m@oe3oD002o`0C863oH23o860Pob1Poi2PT:2@X002o`05
D?m@oe000_l3d0F@00?o0@4010400ol10@020@0Do`6@X92PT?n@X92PT:2@X92PT:02o`0>T:2@X92P
T:2@X?nPT?l;WP03oijN03:N002gWP;o19h01?lP8?l381Co0R001?lP8?l3800:ob0Poj1PX62PH0Oo
00G@T=2@d002T00SD91@T?l1`0700L3o`0700L01H91PT?n@H91PT62@H91PT6000ol03V2@H91PT62@
H?mPT63o2Ih00onNo`0cWP00]Yh00onNWP02WP;o00]P863oH21Poe3oD003o`0;D?m@oe3oD?m@oe00
0_l04b1Pof0Pob1P8?lPH?n@X92PT:000_l00e3oo`02o`O@1I000ol10@040@03o`4100D100nPT?n@
X92PT:2@X92PT:000_l0493oT:2@X92PT:3oX92PT?l;WP03oijN032N002eWP03oijN00:N00?o8?l0
0b001?lP820Do`8P00Co823o0b002_lP8?nPH:1PX604o`0:T=2@d93@T=2@d0:@025@T52@o`700L01
`?o0ol01`070T63oH91PT62@H91PT6000_l04I1Pof2@H91PT63oH91PT63o00^N00?oWYh0;ih00;VN
00oo863oH21Pof0PH?m@oe000ol01E3oD?m@00?o00=@oe000_l04b1Pof0Pob1P8?lPH?n@X92PT:00
0ol5d003om3@00K@19000ol10@040@;o1P42o`0OX92PT:2@X92PT:2@oi2PT?n@X92PT:2@oi2PT:2@
o`0:WP;o<9h00;6N0_l4WP;o0b001OlP823o00@P4ol28004ob0Po`<P00[o823oX62PH:1P0_l06i3@
T=2@d93oT=2@d93@T=1@T52@o`700L01`002o`050L01`0400ol02i1PT62@H91PT62@00;o019PT63o
H91PT62@oi1PT62@H?l8WP03oiko032N002`WP03oijN00>N00ooH?mP863oH21Pof0PH2000_l01e3o
oom@oe000ol01E3oD?m@00;o01@PH?mP863oH23o860Poj2@X92Po`W@0_l7d0B@00?o0@401042o`<1
00oo0@41oj2@X92PT:2@X9000_l04j2@X93oT:2@X93oT:2@X92PT?l01Yh01?nNW_l`WP00[ih00onN
WP03WP04ob0Po`<P00Go820Po`0481?o0R001OlP823o008P03co820Pof2PH:1PX62@d93@T=2@d93@
om2@d93@T=1@T52@o`700L01o`7o0Ol1`0700On@H91PT62@H902o`0DH91PT63oH91PT?n@H91PT62@
H?l9WP03oijN02fN002cWP;o011P863oH21Pof0PH23o860P0_l00e3oo`03o`09D?m@oe3oD?m@00;o
01LPH23o863oH21Pof0Poj2@X92PT:2@o`09d003om3@00G@19000ol10@040@;o1`402OnPT:2@X92P
T002o`0DX92PT:2@oi2PT?n@X92PT:2@X903o`FN0_l_WP00[9h2o`BN0ol38005ob0P8?l012001?lP
820Co`<P00Co823o0b003OlP8?mPX62PH:1PX6000_l0493@T=2@d93@om2@d93@T=02T006D93o0L01
0_l04/01`0700L01`07oT62@H91PT0;o01IPT62@H91Pof2@H?mPT62@H91PT63o1ih00onNWP0]WP00
Zih00onNWP02WP?o019@of0PH?mP863oH21P8?lPH202o`0MD?oooe3oD?m@oe3oD?m@oe3oH23o863o
H21Pof000_l03:2@X92PT:2@X92Po`S@00?od=001]02T0;o00<1ool01@400ol10@040@0Ooj2@X92P
T:3oX92PT:2@X93oT:3oX92PT:2@X92Po`07WP03oijN02fN002ZWP03oijN00:N1_l38005ob0P8?l0
12001?lP820Do`8P00Co823o0b02o`0G0L01X62PH:1PX62PH:3oT=2@d93@T=000_l01i3@T=2@d900
0_l04I3o0Ol1`0700L3o`0700L0100;o00EPT62@H002o`0ET62@H91PT63oH?mPT62@H91PT63o00NN
00?oWYh0;Ih00:jN01OoD?m@oe3oH21Pof0PH?mP860Pob1P8002o`0JD?oooe3oD?m@oe3oD?m@oe3o
H23o863oH202o`D100^PT:2@X92PT:2@X002o`S@00?od=001=03o`:@00?o0@401@400ol10@050@05
oi2PT:000_l02I2PT:2@X92PT002o`0;X92PT:2@X92PT?l01ih00onNWP0/WP00YYh2o`BN2Ol38005
ob0P8?l012000olP800Eo`8P00?o82000ol04l01`0700L01X62PH:1PX62PH:000_l03=2@d93@T=2@
oi3@T0?o01V@d?n@D?o00L01`070ol01`0700L3oH91P00;o00Z@H91PT62@H91P0_l02Y1PT62@H91P
T?l7WP03oijN02bN002UWP03oijN00>N0_l0653oD?m@oe3oH21Pof0PH?mP860Pob3o80;o00]@oooo
D?m@oe3oD003o`08D?m@of0Pob02o`H100?o0@400`40392PT:2@X92PT?n@o`S@00?od?l00ol3d004
oi3oo`L10_l60@03oi2P00;o00^@X92PT:2@X92PT002o`09X92PT:2@X93o00JN0_l^WP00Y9h00onN
WP02WPco0b001OlP823o00@P0_l281Co0R02o`09`0700L01`07000;o00l1`070H:1PX62PH:3oX600
0_l01Y3@T=2@d0?o00XPoi3od93@oi1@0_l040700L01`07o0L01`070of02o`0FT62@H91PT62@H93o
T?n@H91PT62@o`NN00?oWYh0;9h00:NN0_l05e3oD?m@oe3oD?m@of0PH?mP863oH21P00;o00<PH200
0_l01e3ooom@oe000ol02E3ooom@oe3oH003o`@100?o0@4010400ol10@020@0=T:2@X92PT?n@X92P
o`03d0Co00IP8?n@X?l3d005oi2@T?l01`400ol10@040@0Joi3oT:2@X92PT:2@X93oT:3oX92PT:2@
X?l7WP03oijN02^N002QWP03oijN00:N3ol38006ob0P8?lP0_l00b3o800281Go00P1`0700L01`0;o
01X1`0700Ol1`0700J1PX62Poj1PX62Poi3oT0;o0b001?n@H902o`0ET?ooT52@o`700L01`07o0L01
`07000?o01IPT62@H91PT62@oi1PT?n@H91PT63o1ih00onNWP0=WPCo0ih3oaBN002PWP03oijN00:N
0_l05E3oD?m@oe3oD?m@oe3oH21Pof0PH002o`07860Pob1P8002o`07D?oooe3oD003o`05D?oooe00
0ol50@03o`4100<100?o0@400`42o`@100^PT:2@oi2PT:2@X003o`0;8?lPH21Poj2@X9000_l00m3o
o`02T003o`4100D100?o0@400`43o`0FX92PT:2@X92PT:3oX92Poj2@X92Po`NN00?oWYh03Ih01onN
WYkoW_l00ih00onNWP0AWP00Wih01?nNWYhBo`<P00?o82000_l48004ob0P81;o00R@d901`0700@;o
01[00L01o`700L01`?o00L01X62PH?mPX62Po`@P00?o82000R001_mPT62@H0;o00G@T?m@T002o`0<
`0700L01o`700OlP0ol03i1PT62@H91PT63oH91PT002o`04H91Po`NN00?oWYh03Yh00onNWP02WP05
oijNW_l04ih00::N01KoH?m@oe3oD?m@oe3oD?m@oe3oH21P0ol02V3oH21P8?lPH202o`07D?m@oe3o
D003o`04D?ooo`K@00?o0@400`400ol10@020@;o1@400ol10@030@0HT:3oX93oT?mP860Pob1P863o
X92PT:2@0_l2d005oi2@T?l01P401Ol1og3o00<101KoX92PT:2@X92Poj2@X92PT?n@X93o1Ih00onN
o`07WPOo0Yh01OnNWYko00>N00?oWYh04Ih009^N0_l4WP03ob0P017o0R02o`<P00?o82000R001?lP
820@o`07T=2@d93@T002o`0@0L01`?o00L01`?o00L01`0;o00@1`0700_l00f3oo`02o`@P00?o8200
0R003omPT62@H91PT?o@T?m@T002o`05`0700L000_l0723o0L01`07oT62@H91PT63oH91PT62@H?mP
T?l7WP03oijN00nN00CoWYko0ih00onNWP0AWP00VYh00onNWP02WP;o02eP863oD?m@oe3oD?m@oe3o
D?m@of3oH?mP863oH21P8?lPH21Poe3oD?m@oe001?l<d003o`4100810_l40@03o`4100@100Co0@41
0ol0653oT?mP860Pob1P863oX92PT:2@X92Po`;@00?oT?l00_l01@7ooolP00?o1P405?nPT:2@X92P
oj2@X92PT:2@oi3o1ih00onNWP0?WP04oijNo`>N00?oWYh04Ih009VN00?oWYh00Yh00olPo`0381;o
0R001OlP823o00@P00?o82000R0;o`0IT=2@d93oT=2@d93@T=3o0L01`07o0L01`002o`070L01`07o
0@06o`03D93o00@P01Co820Pof2@H91PT62@H93od93oD0?o01lPoooo`070ol01`0700On@H91PT62@
oi1PT62@H91P00;o1ih00onNWP0<WP04oijNo`:N00GoWYjNo`0CWP00W9h2o`0D863oH21Poe3oD?m@
oe3oD?m@oe03o`0IH21Pof0PH?mP860Pob1P863oD?m@oe3oD002o`O@0_l7d0;o10400ol10@030@03
o`4100811?l0153oD?l2T00Eob1P863oH21Poj2@X92PT?n@X92P00;o00G@ooooT002o`H100?o0@40
10404OnPT:2@X93oT:2@X92PT:2@00;o1Yh00onNWP0=WP;o19h3oaBN002EWP;o19h00olPo`028004
ob0P817o0b001OlP823o00@P00?o82000R08o`0Id93@T=2@d93@T=3od93@T=2@d93o`0700@02o`06
`0700Ol12_l00e2@o`048003ob0P008P00goT62@H93oT62@H91P00Go011@T?l1`0700L3o`0700L01
0_l0462@H93oT62@H91PT62@H?l6WP;o:ih009BN00?oWYh00ih05_mP8?lPH?mP863oD?m@oe3oD?m@
oe03o`0GD?mP863oH21Pof0PH23o860PH?m@oe000_l6d003om3@00G@00?od=001]000ol10@030@04
o`410@Co00Q@ooooD?m@o`:@01Wo860PH?mP860Poi2PT:2@X?nPT:2@X93o00?@00CoT93o1P400ol1
0@050@0@oi2PT?n@X92PT:2@X92Po`FN00?oW_l0:ih009>N00?oWYh00Yh2o`<P00Co823o0b0Ao`<P
00Go820Po`048003ob0P008P1_l01m2@d93@T=000_l01Y3@T=2@d0;o00N@d93@T=2@00;o00P1`070
ol3o`0co00>@ob000b000olP8002800?oi1PT62@H?mPT62@H91P00;o02?@T?m@T?l1`0700L3o`070
0L01`?mPT?n@H91PT62@H91Po`07WP03oijN02VN002GWP0bob3o860Pob1Pof0PH?m@oe3oD?m@oe3o
D?m@oe3oH21Pof0PH23o860Pob1P863oD?l<d003om3@00G@00?od=001]001?l10@42o`8100CoD?m@
0ol00e3oD002o`0MT?lPH21Pof0PH23oT:2@X92PT:2@X92PT:3oX?l00]000on@T002o`D10_l60@0>
oi3oT:2@X92PT:2@X?l7WP03oijN02VN002@WP;o19h01?lP8?l38004ob0Po`<P4Ol38003ob0P008P
00Go820Po`0480;o02K@T=2@d?o@T=2@d93@T?n@d93@T=2@oi3@T=2@d93@o`7o0L01`0co00>@ob00
0b000olP8002800eoi1PT62@H91PT62@H91Pof2@om2@oe2@D?o00L01`07o0L01`070of3oH91PT62@
H91PT?l01ih00onNWP0XWP00Sih00onNWP02WP;o01@PH23o860Pob1Pof0PH?m@oe3oD0?o01Q@oe3o
D?m@of0PH?mP860Pob1P8?lPH202o`O@0_l7d0;o1]02o`K@0_l50@0:oe3oD?m@oe3oD0;o0Y007OmP
863oH21P8?n@X92PT:2@X92PT:2@X?nPT:3o00;@00GoT92@o`060@03o`4100@10_l02j2@X92PT:2@
X93o00NN00?oWYh0:9h008jN00?oWYh00Yh3o`<P00Go820Po`028004ob0P817o12001OlP823o00<P
02Co8?oo`070d93@T=2@d93oT=2@d93@T=3od93@T=2@d?o@T=04o`05T0700L003?l00i1@o`038003
ob0P008P01OoT62@H91Pof2@H91PT62@oi1PT?o@T002o`0?T53o`0700L01o`700L0100?o00Z@H91P
T62@H93o1ih00onNWP0XWP00TIh2o`0ED?oo860Pob1P8?lPH?mP863oD?m@00?o01I@oe3oD?m@oe3o
H21P8?lPH23o860P0_l60@03om3@00G@00?od=001]000oo@d005d004om3od0;o00BPom3o0P402_m@
oe3oD?m@oe02o`:@01ooH21Pof0PH21Poj2@X92Poj2@X92PT:2@oi2PT:3o00?@00?oT9000_l90@0>
o`410OnPT:2@X92PT?l6WP;o:Yh008ZN0_l4WPKo0b001?lP8?l38004ob0P817o12001OlP823o008P
0ol01l01`0700L000_l01]2@d93@T0;o00O@T=2@d93@00;o00F@d93@T004o`098?mPX?n@ol0100_o
00>@D?l02B005OmPT62@H93oT62@H91PT?n@H91PT002o`05T=3oT5000_l05P700L01`07o0L01`07o
T62@H91PT?l8WP03oijN01ZN1_l7WP00RIh00onNWP02WP?o00=@oe000_l03R1P8?lPH?mP863oH21P
0ol06E3oD?m@oe3oD?m@oe3oH21P8?lPH23o8?l030400oo@d005d003om3@00K@00Kod=3@om02o`08
H23oX92Pom04o`07D?m@oe3oD002o`:@00WoH21P860PH2000ol05Y2PT:2@oi2PT:2@X93oT:2@X92P
T?l2d004oi3oT0D10ol60@08oj2@X92PT?l8WP03oijN01^N00GoWYjNo`07WP00R9h00onNWP02WPWo
0b001?lP8?l38003ob0P01;o12001?lP8202o`0Q`0700L3o`0700L01`07od93@T=2@d?o@T=2@d93@
T?n@00?o00TPob0Pof2PH:000_l00m3oo`09o`03T53o00HP0_l08R3oH?mPT62@H91PT62@H93oT62@
H91PT63oT=3oT?n@`042o`0B`070ol01`0700On@H91PT63o1ih00onNWP0KWP03oijN00VN002<WP08
oe3oD?m@oe02o`0V863oH21Pof0PH?mPof3oD?m@oe3oD?m@oe3oD?m@of0PH23o8602o`L10_l70@;o
1]02o`K@0ol03F0PH?mP8?nPT:2@X9000ol01e3oD?m@oe000_l2T00Tof0PH21Pof0PH?nPT?n@X92P
T:2@X92PT?n@X92PT:2@X93o0]02o`:@0_l50@03o`4100@100OoX92PT:3o00NN0_lMWP03oijN00RN
0025WP03oijN00:N3?l28005ob0P8?l00b02o`8P4Ol4800Sob3o0L01`0700L01`07o0L01`0700L3o
T=2@d93@T?n@d9000ol00b3o8002800;ob0P8?nPH:1PX6003?l00e2@800280;o12001?mPT602o`0F
T62@H91PT62@oi1PT62@H91PT63oT0?o01I@T53o`0700L3o`0700L01oi1PT63o1ih2oajN00?oWYh0
1ih008BN00?oWYh00Yh4o`07D?m@oe3oD002o`09863oH21Pof0P00;o01QP863oD?m@oe3oD?m@oe3o
D?m@of0PH202o`D100?o0@401@400ol10@060@03om3@00G@00?od?l00_l04B1Pof0PH?mP863oT:2@
X92P00;o00Y@oe3oD?m@oe3o0Y003f0Pob3o860PH?nPT:2@X002o`0DT:2@X92PT:3oX92PT:2@X92P
T?l3d005oi2@T?l01@400ol10@040@05oj2@X?l01ih2oanN00?oWYh01Yh008>N00CoWYjN3ol28009
ob0P8?lPob3o00<P4Ol380;o00l1`0700L01`?o00L01`0400_l01l01`0700L000_l01M2@d93@00?o
00DPob0Po`03800;ob0P8?nPH:1PX6003?l0152@8?l28003ob0P00<P02WoT62@H93oT62@H91PT63o
H91PT62@H91PT63oT=2@oe2@D?o00L01`002o`090L01`07oT63o00RN00?oWYh06Ih01OnNWYko00RN
0026WP?o00]@ooooD?m@oe3oD002o`06863oH21P0_l0621Pof0PH?m@oe3oD?m@oe3oD?m@oe3oH0;o
2`42o`H100?o0@401P401?o@d=03o`0DH23o863oH21Pof0PH?n@X92PT:02o`03D?m@00?o00A@oe3o
0Y004OlPH23o860PH23oT:2@X92P00;o01B@X92PT:3oX92PT:2@X92PT:2@o`?@00GoT92@o`060@03
o`4100<100?oX?l029h00onNWP0IWPKo1ih007nN0_l4WP03ob3o00ko0R000olP8002o`<P00Co820P
4_l01P700L01`0;o01T1`0700L01o`700L01`?o00L01`0700Oo@00Co0R001?lP8?l3800;ob0P8?nP
H:1PX6003Ol00i3o80028003ob0P00<P01coT62@H91Pof3oH91PT63oH91PT62@H91PT62@0ol01]2@
oon@D0;o00h1`0700Ol1`0700On@o`NN00?oWYh09Yh007jN00?oWYh00Yh2o`05H23ooe000ol00e3o
D003o`05D?oo86000ol05f3oH21Pof0PH?m@oe3oD?m@oe3oD?m@00?o2@400ol10@050@03o`4100@1
0_l60@;o01Q@oe3oH23o860Pob1Pof0PH?n@X92PT:02o`05D?m@oe000ol00e3oT002o`0U860PH?mP
860Poi2PT:2@X92PT?n@X92Poj2@X92PT:2@X92PT002o`03X?o@00;@00GoT92@o`050@03o`4100<1
0ol6WP;o9ih007fN00?oWYh00Yh00olPo`0280oo0R001OlP823o00<P00Co820P3ol0393@T0700L01
`0700@;o00K00L01`042o`0:`0700L01o`700@So0R001OlP823o008P00_o820Poj1PX62PH00<o`03
D93o00@P00?o82000R007?n@H91PT62@H91Pof2@H?mPT62@H91PT62@H902o`0EH93od93@oi1@T?l1
`0700L01`07000;o29h00onNWP06WP?o79h0086N00Ko863oH202o`03D?oo00?o00E@ooooD002o`0J
8?ooH21Pof0PH?mP863oD?m@oe3oD?m@oe02o`G@0_l80@03o`4100D100?o0@4010400ol1o`04o`0M
D?m@of0Pob1P8?lPH?mP863oT:2@X92PT?m@oe000ol0153oD?l2T00Fob1P863oH21P8?n@X92PT:3o
X92PT0;o00nPoj2@X92PT:2@X92PT:000_l00i2Po`03d0;o0Y000ol10@050@;o2Yh00onNWP05WP05
oijNW_l06ih007VN0_l4WP;o0b000olP800@o`038?lP008P00Go820Po`0380go01V@d93@T=2@d?l1
`0700L01`?o00L01`07000;o00@1`0702ol28005ob0P8?l00b002olP8?nPH:1PX62P00_o00=@T?l0
12000olP8002800Moi1PT62@H?mPT62@H93oT?n@H91PT62@H91PT6000_l00i1PT002o`0;T=2@oe3o
`0700L000_l;WP;o1ih01OnNWYko01^N001hWP03oijN00>N00WoH?mP863oH2000_l00e3oD003o`05
D?oooe000_l05R1Pof0PH?mP863oH21Poe3oD?m@oe03o`_@0_l70@;o1`400ol1o`02o`03D?m@00?o
01e@oe3oH23o860Pob1P8?lPH?n@X92PT:2@oe3oD003o`03D?m@00;o0Y006?mP863oH21P863oX92P
T:3oX92PT:2@X0;o00b@X92PT:2@X92PT:02o`06T:2@X93o0m02o`03WP4100;o3ih00onNWP04WP05
oijNW_l06ih007NN00?oWYh00Yh2o`8P00Go820Po`0280oo0R001OlP823o00<P00Co820P2Ol01Y3@
T=2@d0;o01N@d93@T=2@ol01`0700L01o`700L01`00?o`8P00Go820Po`03800;ob0Poj1PX62PH:00
3?l00i1@o`038003ob0P00<P00ooH91PT62@oi1PT62@H9000_l02f2@H91PT62@H91P00;o00Z@H91P
T63oT=2@0_l00ikoWP0@WP03oijN00BN00GoWYjNo`0KWP00Nih03?lPob1Pof0PH?mP80;o00=@oe00
0ol01E3ooom@00;o01DPH?mP863oH21Pof0PH?m@oe3oD?l02]02o`K@00?o0@401P42o`<10_l01e3o
D?m@oe000ol07E3oD?mP8?lPH23o860Pob1P8?nPT:2@X93oD?m@00?o00=@oe000_l2T00Vof0PH?mP
860PH?nPT:2@X93oT:2@X92PT?n@oi2PT:2@X92PT:02o`07T:2@X92PT002o`03d?oo01>N00?oWYh0
19h01OnNWYko01^N001dWP03oijN00:N0_l28004ob0Po`<P00?o8?l03ol28005ob0P8?l00b001?lP
8206o`05d93@T=000_l03I3@T=2@d?o@T=2@d9000_l02P700L01`070ol0Ao`<P00Co823o0b002olP
823oH:1PX62P00co00>@D?l012000olP8002800Xof2@H91PT62@H91PT62@oi1Pof2@H91PT62@H?lP
of2@H91PT62@oaFN0_l5WP05oijNW_l06ih007>N00?oWYh00Yh3o`0AH23o863oH21Pof3oD?m@oe00
0ol01E3ooom@00;o010PH?mP863oH21Pof0PH?m@0ol8d003om3@00C@0_l6d003o`4100D11Ol01e3o
D?m@oe000ol08e3oD?mP863oH23o860PH21P8?nPT:2@X93oD?m@oe3oD?m@00;o0Y00<omP860Pob1P
863oX92PT:2@X92PT:2@X93oT:2@oi2PT:2@X92Pog3oX92PT:2@X92Po`0DWP;o1Yh3oabN001bWP03
oijN00:N1?l28004ob0Po`8P00?o82004?l28005ob0P8?l00b001?lP8203o`0;T=2@d93@T=2@d900
0_l03M2@d93@T?n@d93@T=000_l00l01`00Fo`8P00Co823o1b001omPX62PH:003?l00i1@o`048003
ob0P008P01goH91PT62@oi1PT62@H93oT62@H?mPT62@H91PT002o`0;H91PT62@H91PT?l04ih2obFN
001eWP;o01=@ooooH23o863oH23o863oD?m@00Go00E@ooooD002o`0>863oH21Pof0PH?mP8602o`G@
0_l7d003om3@00C@0_l6d003o`7o00?o00]@ooooD?m@oe3oD003o`03D?m@00;o00`PH?mP860PH21P
8603o`0?T:2@X93oD?m@oe3oD?m@00;o0Y009omP860Pob1P863oX92PT:2@oi2PT:2@X92Poj2@X93o
T:2@X92PT002o`0;X92PT:2@X92PT:000_l@WP03oiko02FN001^WP;o19h7o`8P00Co823o0R000olP
800@o`8P00Go820Po`038003ob0P00;o00R@d93@T=2@d0;o00j@d93@T=3od93@T=2@d0;o00B@d93@
0_l00b3oo`0Do`8P00?o82001B02o`088?mPof2PH:0=o`03D?lP00<P00?o82000b001_n@H91PT0;o
00ePT62@H91Pof2@H91P00;o00F@H91PT002o`0>H91PT62@H91PT63oH?lAWP03oijN02>N001]WP03
oijN00:N0ol00e3oD002o`0B860Pob3o860Pob1Poe3oD?m@0ol01E3ooom@00;o00XPH?mP863oH21P
0ol30@W@00?od=001=02o`O@00?od?l00_l00b1Po`02o`0AD?oooe3oD?m@oe3oD?m@oe000_l0221P
860PH21P0_l01R1P8?nPT0;o00>PT:000_l0@e3oD?m@oe3oD?n@of0PH23o860PH23oT:2@X?nPT?n@
X92PT:3oX92PT:2@X?nPT:2@ob3oT:2@X92PT:2@X?nPT?l049h00onNWP0SWP00K9h00onNWP02WPWo
0b000olPo`038003ob0P00oo0b001OlP823o008P0_l01/01`0700@;o00N@d93@T=2@00;o00g@T=2@
d93oT=2@d93@00Co0b0Fo`LP00?o8?l00b002?mPX62Poj1P3?l00e3o80038003ob0P00<P02koT62@
oi1PT63oH91PT63oH91PT62@H93oT62@ob3oT62@H91PT62@H93oT63o3ih2obBN001`WP03oe3o00;o
00=@oe000_l02b1Pof0Pob1P8?lP00;o00E@oe3oD003o`0@D?oooe3oH21Pof0PH?mPo`X10_l7d003
om3@00C@0_l3d0?o00EPof0PH003o`0HD?oooe3oD?m@oe3oD?m@oe3oH21P860P0_l03V0Pob1P8?nP
T:2@X?nP0_l05E3oD?m@oe3oD?n@of0PH21P860PH003o`0]X92PT:2@X92PT:2@X?nPT:2@X92PT:3o
X93o8?n@X92PT:2@X92PT?n@X93o00nN00?oWYh08Yh006RN0_l5WP_o0R001?lP8?l380;o00<Pool0
3Ol38004ob0P80;o00D1`0700@02o`0>`0700L01om2@d93@T=02o`06T=2@d93@0ol48004ob0P81Go
1202o`058?lP8?l00b001omPX62PH:003Ol00e2@o`0680;o0341ooooT62@H91PT62@oi1Pof2@H91P
T62@H93oT?lPoi1PT62@H91PT62@oi1PT63o00jN00?oWYh08Yh006NN00?oWYh00ih2o`03D?m@00?o
00=@oe000_l0221Pof0Pob1P0_l0221Poe3oD?m@0ol0353oD?m@of0PH?mP80;o2042o`D10_l7d0;o
1=002olPob1P863oH21P00?o00M@ooooD?m@00?o00Y@oe3oD?m@of0P0_l04V0PH?mP8?lPH21Poi2P
T:2@X0;o00Y@oe3oD?m@oe3o0Y00260PH21P8?l10_l30@0Joj2@X92PT:2@X?nPoj2@X92PT:2@X92P
oj02o`0AT:2@X92PT:2@X93oT:2@X9000_l;WP;o99h006JN00?oWYh00Yh?o`8P00So823o8?lPo`8P
3ol380?o01k00L01`0700L01`07o0L01`070oi3@T=2@d93@om02o`8P00?o82000R001?lP820Eo`04
8?lPo`<P00Co823o12001onPH:1PX6003?l00e2@800380?o00L1`0700L0100;o01IPT62@H91PT?n@
oi1PT62@H91PT62@0_l05B3oH91PT62@H91PT?n@H91PT62@o`0<WP03oijN026N001ZWP03of3o00;o
00=@oe000ol00e3oD002o`05863oH2000_l05V0Pob1Poe3oD?m@oe3oD?m@oe3oH202o`H10_l70@;o
1@42o`K@0ol0321P8?lPH21Pof0PH0?o00M@oe3oD?m@00?o00M@oe3oD?m@00;o01DPH?mP863oH21P
of0PH?n@X92PT:000_l02E3oD?m@oe3oD002o`03T60P00Co00<1o`401`402On@X92PT:2@X002o`0S
T:2@X92PT:2@X92Pog3oX92PT:2@X92PT:3oX92PT:2@X?l02ih00onNWP0QWP00Hih2o`>N0_l280ko
0R001?lPool38003ob0P00oo00`Pol01`0700L01`042o`0>`0700L01`?o00L01`042o`03T=2@00;o
00<Pob000R000olP80028004ob0P81Ko0R001OlP823o00<P00_o820Poj1PX62PH00=o`0XT23o`?o0
0L01o`700L01`070of2@H91PT62@oi1PT62@H91PT62@H0Co01B@H91PT62@H91Pof2@H91PT62@o`ZN
00?oWYh08Ih006:N00?oWYh00Yh01OlPob1P00Go00=@ool00ol01E3oH21P00;o00XPob1P8?lPH?m@
0ol02E3oD?m@oe3oD002o`D10_l60@03o`4100D10_l60@0Dom3oof0Pob1P8?lPH21Pof0PH202o`07
D?m@oe3oD003o`03D?m@00?o01Q@oolPH?mP863oH21Pof0PH?n@X92PT:02o`03D?m@00?o00=@oe00
0_l0193oool60@;o1`42o`0/X92PT:2@oi3oT:2@X92PT:2@X?m`oj3oX92PT:2@X92Poj2@X92PT:2@
X?l9WP03oijN026N001QWP04oijNWP;o0R000olP800=o`8P0_l28005ob0P8?l00R0?o`08`0700L01
`042o`05`0700L000_l01`700L01`0400_l01<01`043o`<P00Go820Po`048003ob0P008P5Ol28005
ob0P8?l00b002olP823oX62PH:1P00ko045@T?l1`0700L01`?o00L01`0700On@H91PT?n@H?mPT62@
H91PT63o8?mPT?n@H91PT62@H?mPT62@H91PT62@o`08WP;o8Yh006BN00[oH?mP8?lPH?m@0ol00e3o
D003o`0AD?ooof3oH23o860Pob1Poe000ol01E3oD?m@00?o0m090@03o`4100@100?o0@401P401Ol1
oom@00;o014PH23o860Pob1P863oH21P8002o`07D?m@oe3oD005o`05D?m@oe000_l05B1P8?lPH?mP
863oH21Poi2PT:2@X002o`07D?m@oe3oD003o`;@00?oT9000_l70@03o`4100H101?oX92PT?n@X93o
T:2@X92PT:2@00;o01RPT:3oX92PT:2@X?nPT:2@X92PT:2@X?l8WP03oijN022N001MWP;o0ih2o`8P
00Co823o0R0=o`<P00Co823o0b000olPo`0<o`05d93@T=000_l01l01`0700L000_l01@700L0100;o
00K00L01`047o`<P00Go820Po`058004ob0P81Go0b001?lP8?l3800<ob0P8?nPH:1PX62P2Ol01I3@
T=2@00;o00Z@D?o00L01`0700_l07`700L01`07oT62@oi1PT62@H91PT62@H93o8?n@H9000_l04V2@
H91PT?n@H91PT62@H91Po`NN0_lRWP00G9h00onNWP02WP0=ob3o863oH23o863oD003o`03D?m@00Go
00aP863oH23o860Pob02o`07D?oooe3oD002o`W@0_l70@03o`4100@10_l30@?o00=@oe000_l04B1P
8?lPH23o860PH23o860P00;o00M@oe3oD?m@00?o00M@oe3oD?m@00;o01XPH23o863oH21Pof0PH?n@
X92PT:2@oe3oD0?o2M000on@T002o`L100?o0@401@42o`08T:3oX92PT:02o`0OT:2@X93o8?n@X92P
T?n@X92PT?n@X92PT:2@X92Po`08WP03oijN022N001KWP03oijN00:N00Co823o0R001OlP8?lP00ko
0b001?lP8?l28003ob0P00[o00B@d93@0_l03Y3@T=2@d?l1`0700L010_l02<01`0700Ol12Ol38005
ob0P8?l01B001?lP820Eo`<P00Go820Po`02800<ob0P8?nPH:1PX62P1_l0B]3od93@T=2@d93@oi1@
T?l1`0700L01o`700L01`070of3oH91PT62@H?mPT62@ob3oT62@H91Pof2@H93oT62@H91PT62@H93o
1ih2ob6N001OWP;o00YP8?lPH?mP8?lP0_l01e3ooom@oe000ol03U3oH23o860Pob1Pof0P0_l00e3o
o`04o`O@0_l5d0;o1`42o`@10_l01e3oD?m@oe000_l04B1P8?lPH21Pof0PH23o860P00;o00=@oe00
0ol02e3ooom@oe3oD?m@00;o01HPH23o860Pob1Pof0PH?n@X92PT:2@1?l4d0;o2=02o`:@0_l60@03
o`4100H10_l05Z2@X92PT:2@oi2PT?lPoi2PT:2@X902o`0?X93oT:2@X92PT:2@X93o00RN00?oWYh0
7ih005RN00?oWYh00ih3o`8P00Co823o0R000olPo`0=o`8P00Go820Po`028003ob0P00Oo01g@T92@
d93@T=2@d?o@T=2@d93o`0700L01`07o0@0=o`<P00?o82000R000olP80028004ob0P81Go0b001OlP
823o008P00?o82000R001omPX62PH:000_l09M2@d93@T=2@oi3@T=2@d93@T?m@T53o`0700L01o`70
0L01`0400ol0391PT62@H91PT62@H0;o01R@H91PT62@H93oT?n@H91PT62@H91PT?l8WP03oijN01nN
001GWP03oijN00:N0ol0353oH23o863oH?mP80;o00=@oe000ol04U3ooom@of0Pob1Pof0PH?mP80;o
00A@oooo1M000i3od005d0;o1M02o`H11?l02E3oD?m@oe3oD002o`0B860Pob1P863oH21P8?lPH21@
0ol01E3oD?m@00?o00M@oe3oD?m@00;o01@PH23o860Pob1Pof0PH23oX92PT0;o00>PT?l02=02o`S@
0_l2T0;o2P42o`<100coX92PT:2@X92Poj02o`0HT:2@X92PT:2@X?nPoj2@X92PT:2@X93o29h00onN
WP0OWP00EYh00onNWP02WPKo0R001_lP8?lPo`8P3_l28004ob0Po`<P00?o82000ol02]2@d?o@T=2@
d902o`0=d93@T=2@oi3@T=2@d002o`03`070013o0b000olP80028003ob0P008P00?o82005ol28005
ob0P8?l01b002_mPX63oH:1PX602o`0`T=2@d93@T=3od93@T=2@d93@oi1@T?l1`0700L01`?o00L01
`07oT62@H91PT62@0ol02i1PT62@H91PT62@00;o00]PT62@H91PT62@o`07WP;o1ih4o`>N0ol@WP00
FIh2o`03D?oo00;o00/PH23o8?lPH?mP8004o`05D?m@oe000ol03U3oH23o863oH21Pof0P0_l5d0;o
1]02o`G@0_l6d00Ao`7ooe3oD?m@oe3oD?m@oe000_l04B1P8?lPH21Pof0PH21P8?lP00;o00M@oe3o
D?m@00?o02E@oe3oD?m@oe3oH23o860Pob1P860PH23oX93oT:2@X92PT:3o00S@0_l8d005oi2@T?l0
1@43o`L10_l05Y2PT:2@X92Pog3oX92PT:2@X92PT:02o`0;T:2@X92PT:2@X?l029h00onNWP04WP07
oijNW_nNo`03WP03oijN00fN001BWP;o19h8o`<P00?o8?l00R000olP800>o`8P00Co823o0b000olP
o`02o`07T=2@d93@T002o`06d93@T=2@0_l01M2@d93@00;o00B@d93@4ol38003ob0P008P00?o8200
0b000olP800Fo`8P00?o82002203o`0NX62PH:1PX62PH:3oT=2@d93@T=2@oi3@T=2@d93@0_l01E3o
D07000;o02l1`07o0L01`0700L3oH91PT62@H?lPof2@H91PT62@H91Pof3oH91PT62@H91Po`08WP03
oijN00FN00?oWYh00Yh01OnNWYko00nN001AWP03oijN00:N0ol00e3oD004o`0;863oH23o863oH200
0_l01e3oD?m@oe001?l02R1P8?lPH?mP8602o`<10_l7d003om3@00C@00>@ool01M000oo@o`03o`0?
D?m@oe3oD?m@oe3oD?m@00;o00`PH23o860PH?mP8602o`03860P00;o00M@oe3oD?m@00?o00=@oe00
0ol03e3oD?mP8?lPH21P860PH002o`<100coX92PT:2@X92PT:02o`S@0_l8d0;o0Y02o`D10_l70@08
oi2PT:2@X904o`0FX92PT:2@X92Poj2@oi2PT:2@X92Po`RN00?oWYh01Yh01OnNWYko00>N00?oWYh0
3Ih0052N00?oWYh00Yh;o`8P00Co823o0R000olPo`0=o`<P00Co823o0R03o`0=0L01`07od93@T=2@
d002o`0<T=2@d93@T?n@d93@0ol00b3oo`0Ao`<P00?o82000R001_lPoolPo`<P5_l980?o00G00L01
`002o`0MH:1PX62PH:1PX63od93@T=2@d93@om2@d93@T=000ol04Y1@T?l1`0700L3o`0700L01`0;o
00F@H91PT002o`0HH93oT62@H91PT63oH91Pof2@H91PT63o29h00onNWP07WP04oijNo`>N00?oWYh0
3Ih005>N0_l02E3ooom@oe3oD002o`08863oH23o8602o`068?ooD?m@0ol00e3oo`02o`06860PH21P
0ol30@;o1042o`O@00?od=001M02o`06d?oo860P0_l03e3oD?m@oe3oD?m@oe3oD002o`0A860Pob1P
860Pob1P8?lPH2000_l01e3oD?m@oe000ol00e3oD003o`0;D?m@of0PH21P86000_l30@03o`4100@1
00_oT:2@X92PT:2@X003o`S@00?od=000]02o`?@00GoT92@o`060@03o`4100H100GoX92PT002o`0@
X92Poj2@X92PT:2@oi2PT0;o00JPT:2@X?l8WP;o29h01?nNW_l3WP03oijN00fN001<WP;o19h00olP
o`0;o`8P00Go823o8002o`8P3Ol28003ob0P00?o00`1`0700L3o`0700L02o`06d93@T=2@0_l01]2@
d93@T0;o00<Pob000R0Co`<P00Co820P0_l48004ob0P81Go1R04o`040L01`0;o02T1`0700OmPX62P
H:1PX63oH:3oT=2@d93@T=2@d93oT=2@d93@oi1@T002o`05`0700L000_l02`700L01`07oT62@00;o
01UPT62@H91PT62@H93oT62@H93oT62@H93o00RN00?oWYh00ih01?nNW_l2WP05oijNW_l03ih004^N
00?oWYh00ih2o`03H?m@00Go00=@oe000_l01B1Pof0P00;o00APof0P0_l00e3oD003o`03D?m@00;o
00DPH?mPo`030@03o`4100@10_l50@;o1]02o`?@0_l01V0Pob1P80;o00m@oe3oD?m@oe3oD?m@oe00
0_l01B1P8?lP00;o00YPof0PH23o860P0_l03E3oD?m@oe3oD?m@oe000ol03E3oD21P860Po`7o0Ol0
1P400ol10@030@;o00bPT:2@X92Poj2@X?l8d0?o1m02o`>@00?o0@4010400ol10@050@;o01b@oonP
T:2@X92PT:2@X93oT:2@X92Poj2@X93o1ih2o`JN0_l4WP?o49h004ZN00?oWYh00ih3o`038?oo00[o
0R001?lPool28003ob3o00go0R02o`050L01`0400_l01/01`0700@;o00G00L01`002o`08d93@T=2@
oi02o`<P00Co820P4ol48005ob0P8?l012001?lP820Eo`<P1?l00l01`002o`0N0L01`07o0L01`070
oj1PX62PH?mPX62Poi3@T=2@0_l05m2@d?o@T=2@d93@T?m@T53o`0700L0100;o00W00L01`070of00
0_l0191PT602o`0=T62@H93oT62@H91PT002o`03H93o00JN00?oW_l07ih004jN0_l0223oof3oD?m@
0ol01e3oD?mP86000_l01R3o863oH0?o00=@oe000ol00e3oD002o`048?ooo`L10_l60@;o1@400oo@
d003d0;o00TPob1P8?lPH2000_l03e3oD?m@oe3oD?m@oe3oD002o`0A863oob1P863oH21P8?lPH200
0_l00e3oD003o`07D?m@oe3oD003o`04D?m@80?o0P400ol10@030@03o`4100<10_l50@;o00^@X92P
oj2@X92PT002d0;o1]000oo@d006d004oi2@T0;o1P400ol10@050@?o01R@X92PT:3oX92PT?n@X92P
T:2@X93oT?l8WP03oijN01fN0017WP;o19h01?lPob0>o`8P0_l28005ob0Pob003ol00l01`002o`0?
0L01`0700Ol1`0700L0100;o00C00L010_l00i3oo`038005ob0P8?l00b0Bo`058?oo8?l012000olP
80028004ob0P81Oo00D1`0700@02o`04`0700@;o01S00L01`?o00L01`07oH:1PX?nPH:1PX602o`08
T=2@d93@T=02o`07T=2@d93@T002o`0AT52@o`700L01`?o00L01`0400ol05Y1PT62@H93oT62@H?mP
T62@H91PT602o`VN00?oWYh079h004JN00?oWYh019h01_lPob3o80;o00=@oe001Ol03E3ooomPof0P
ob3o86001Ol01e3ooom@oe000ol50@;o1P42o`L100?o0@400P42o`0=8?lPH23o860Pob1P8002o`0?
D?m@oe3oD?m@oe3oD?m@00;o01HPH23o860PH?mP860Pob1P8:3oD?m@0ol01e3oD?m@oe001Ol01=3o
d?l60@03o`4100<100?o0@400`42o`D100koT:2@oi2PT:2@X92Po`W@00?od=001]001On@T93o00H1
00?o0@400P400om`o`02o`0FX92PT:2@X92PT:3oX92PT:2@X92PT0;o29h00onNWP0LWP00AIh00onN
WP02WP09oijNob3o8?lP00co0b001_lP8?lPo`8P3?l00m2@d002o`05`0700L000_l03P700L01`?o0
0L01`0700_l00`7oo`028005ob0P8?l00b001?lP820Co`<P00?o82000R000olP80028003ob0P008P
4Ol01Y3@T=2@d0;o00_00L01`?o00L01`002o`0;0L01`07o0L01`0400_l0;:3oX62PH:1PX62Poi3@
T=2@d93@T?n@d93@T=2@d?n@D93o0L01`0700L010ol030700On@H91PT62@H0?o00aPT62@H91PT62@
H?l8WP03oijN01bN0018WP?o0Yh00olPo`02o`088?ooD?m@oe03o`0?D?mP863oH?mP8?lPH?m@00?o
00=@oe001?l5d003o`4100@10_l50@;o1P43o`0?860Pob1P8?lPH23o860P00;o00]@oe3oD?m@oe3o
D003o`0ID?oo860Pob1P863oH21P8?lPH21Poe3oD003o`07D?m@oe3oD004o`O@00?o0@400`42o`D1
00?o0@400`400ol10@040@;o00Z@X92PT:2@X92P0_l8d0;o1m02o`:@00?o0@401043o`H101OoX92P
T:2@X92Poj2@X92PT:2@X92Po`08WP03oijN01bN0011WP;o19h3o`03d?oo00;o00@PoolP3?l38003
ob3o008P00?o82002Ol00i3@T002o`04d93@T0;o00d1`0700L3o`0700L0100;o00?00L001?l38005
ob0P8?l00b001?lP820Co`<P00?o82000R000olP80028003ob0P008P4?l02]3od93@T=2@d902o`0;
0L01`07o0L01`0400_l02/01`07o0L01`043o`0PH:1PX62PH:1PX63od93@T=2@d93@om2@d93@T=2@
oe02o`030L3o00?o00T1`0700L01`0400_l01f2@H91PT6000_l02i1PT62@H91PT63o00RN0_lMWP00
@9h00onNWP03WP04oe3oo`:@00CoH?mP0_l00b3oo`02o`03D?oo00?o00m@of0Pob1Pof0Pob1Poe00
0ol00e3oo`06d003om3@00?@0_l50@;o1P44o`0BD?oo860Pob1P8?lPH23o860P0_l03e3oD?m@oe3o
D?m@oe3oD002o`0F860Pob1P863oH21P8?lPH21Poe3oD0?o00=@oe000_l6d0;o2=000ol10@030@;o
1@400ol10@050@;o0`403On@X92PT:2@X92PT?l02M000oo@d006d0?o00B@oooo1P400ol10@040@0E
oi2PT:2@X93oT:2@X92PT:2@X93o00JN00?oW_l07Ih003nN00?oWYh00Yh6o`05d93o8?l00R000olP
o`0;o`8P00Co823o0R000olP8008o`07d93@T=2@d002o`05T=2@d9000_l01@700L0100;o00C00L01
1ol38005ob0P8?l00b001?lP820Co`<P00?o82000R000olP80028003ob0P008P3?l02=2@d93@T=2@
0_l01m2@d93@T=000_l04<01`070ol01`070ol01`043o`050L01`0400_l02Z1PX62PH:1PX602o`0@
T=2@d93@T=3od93@T=2@d0?o01:@D?o00L01`0700Ol1`0700L02o`07T62@H93oT002o`09H91PT62@
H93o00RN00?oWYh06ih004BN00CoD?m@0_l2T005of3oH2000_l01e3ooom@oe000ol0353oH23o863o
H23o80;o00A@oooo0m02o`O@0_l5d0;o1@44o`05D?oooe000_l03b1P8?lPH23o860Pob1P8002o`05
D?m@oe000ol01e3oD?m@oe000_l05R1P8?lPH21Pof0PH23o860PH?m@oe06o`;@00?od=001m000oo@
d006d003o`4100<100?o0@401P401Ol10@7o00H100[oX92PT:2@X92P0ol=d0;o00A@oooo0i080@;o
1P404_nPT:2@oi2PT?n@X92PT:2@o`RN00?oWYh06ih003bN00?oWYh00ih7o`06T=2@ob3o0b0=o`8P
00Co823o1206o`05T=2@d9000_l01m2@d93@T=000_l02i3@T=2@ol01`07000[o0b001OlP823o00<P
00Co820P4ol38003ob0P008P00?o82000R000olP800280Oo00J@oi3@T=02o`08T=2@d93@T=02o`07
T=2@d93@T002o`0:0L01`?o00L01`0?o00C00L010_l01L01`07000;o00MPX62PH:1P00;o00fPoi3@
T=2@d93@T=2@00Co02S@T=3oT52@o`700L01`070ol01`0700On@H93oT62@H?mPT62@H93o29h00onN
WP0KWP00>ih00onNWP02WP;o00LPoom@oe3o00>@00KoH?mPof05o`0BD?m@oe3oD?mP8?lPH?mPof0P
0ol3d0;o1M02o`O@0_l4d0;o00L1ooooD?m@00?o019@oolPH23o860Pob1P8?lPH202o`0?D?oooe3o
D?m@oe3oD?m@00;o01HPH23o860PH?mP860Pob1P863oD?m@0ol8d0;o2=02o`O@00?o0@401@42o`<1
00?o0@400`400ol10@040@07oi2PT:2@X002o`04T:3oo`O@1?l6d0;o0Y02o`L100?o0@401042o`0?
T?n@X92PT:2@X92PT:3o00RN00?oWYh06Yh003ZN0_l3WP;o0R06o`04T=2@o`8P0_l00b3oo`0;o`8P
00Oo823o8?lP00Co00G@T=2@d002o`05T=2@d9000_l03=2@d93@T=3od93@T0ko0b001OlP823o00<P
00Co820P4ol48005ob0P8?l012000olP800280Co01o@T=3od93@T=2@d93@om2@d93@T=2@d?o@T=2@
d93@00;o00?00L000ol01L01`07000;o00@1`0700_l02`700L01of2PH:1P00;o00VPH:1PT=2@d900
1Ol09Y3@T=2@d93@T?m@T53o`0700L01`?o00L01`070of3oH91PT62@0_l0162@H?l8WP03oijN01ZN
000iWP0;oijNoikoH?mPoj000ol00e3oT002T0;o00<Pool00_l00e3oo`03o`03D?m@00;o00PPH23o
8?lPH0;o0`43o`G@0_l5d0;o1]02o`0:d?ooD?m@oe3oD0?o019@oolPH23o860Pob1P8?lPH202o`0?
D?m@oe3oD?m@oe3oD?m@00;o014PH21Pof0PH?mP860Pob1P8004o`G@0_l8d0;o2=02o`O@00?o0Ol0
0`42o`D100?o0@400`42o`@10_l02Z2@X93oT:2@X902d0Go3=02o`:@0_l60@;o1P42o`0<X92PT:2@
X93oT:3o29h00onNWP0JWP00?Ih2o`038?lP00Oo00F@d90Po`028003ob3o00_o0b001?lPob03o`05
0L01`0400ol01M2@d93@00;o00F@d93@T002o`05d93@T=004Ol38005ob0P8?l00b000olP800Do`@P
00Go820Po`048003ob3o00Go00N@d93@T=2@00;o00S@T=2@d93@T0;o00o@T=2@d93@T?n@d93@T=00
0ol02`700L01o`700L0100;o00o00L01`?o00L01`?nPH:000_l01F2PH:1P00?o02?@T=2@d93@om2@
d93@T=2@d?n@D93o0L01`0700Ol1`0700@03o`0;T62@H91PT63oH?l01ih2oabN000nWP04of3oH0Go
00I@oi2@ob04o`05H?m@oe000ol00e3oD002o`05863oH2000_l30@;o1@43o`G@0_l5d0;o00k@oomP
oe3oD?m@oe3oD0?o00m@oolPH23o860Pob1P86000_l04R3ooe3oD?m@oe3oD?m@oe3oD0;o00hPH21P
of0PH?mP860PH0Co0P43o`O@00?od=001m000oo@d009d0?o0m000ol10@030@;o1@400ol10@030@;o
1042o`0;T?ooX92PT:2@X9002=02o`S@00GoT92@o`070@05o`410Ol00`403?nPT:2@X92PT:2@o`RN
00?oWYh06Ih003jN0_l280Oo00J@d?lPob02o`038?oo00[o0R000olPo`02o`05`0700L000_l01@70
0L0100?o00G@T=2@d002o`04T=2@d0;o0b0@o`<P00Go820Po`0280;o0b0Co`@P00Go820Po`0380Co
00H1`0700L03o`06T=2@d93@0_l0293@T=2@d93@0_l01i3@T=2@d9000ol01Y3@T=2@d0;o00G00L01
`002o`0A0L01`?o00L01`07o0L01`0400ol02F2PH:1PX62PH002o`0@T=2@d93@T?n@d93@T=2@d0;o
01]@T?oo`0700L01o`7o0L01`07oT62@H91PT6000_l8WP03oijN01VN000iWP03oijN00:N0_l00b1P
o`05o`>@0ol00b3oo`02o`03D?m@00?o00=@oe000_l0121Pool30@;o1@42o`D10ol5d0;o017@oolP
H21Poe3oD?m@oe3oD003o`0BD?oo860Pob1P8?lPob3o860P0_l03e3oD?m@oe3oD?m@oe3oD002o`0:
860PH?mP863oH0;o0`400ol10@060@;o1m02o`S@0_l3d0;o0m000oo@d005d0;o1@400ol10@020@;o
1@400ol10@020@?o00bPT:2@X92PT:2@X?l7d0;o2=000on@T002o`D10_l70@0:oj2@X92PT:2@o`RN
00?oWYh06Ih003VN00[oWYjNob3o8?l81Ol01]2@d?lPo`8P3_l0423oool1`0700Ol1`0700L02o`05
0L01`0400ol01=2@d903o`DP4?l38003ob0P008P00Co823o0b0Co`@P00Co820P1?l010700L02o`07
0L01`0700@03o`0Jd93@T=2@d?o@T=2@d93@T=3od?o@T=2@d902o`0=d93@T=2@d?l1`0700@02o`0?
`0700Ol1`0700L01`?lP00?o00^PH:1PX62PH:1PX002o`0@d93@T=2@d?o@T=2@d93@T0;o00B@ooo0
0ol02/01`0700L01`042o`06H91PT62@0_l7WP03oijN01VN000hWP03oijN00:N00Ko8?lPok02o`03
D?oo00>@00?o8?l00_l01R3ooe3oD0Go00A@oooo0`42o`@10_l60@;o1@43o`0@d?ooob1P860PH?m@
oe3oD0?o00E@ooooD002o`06860Pob1P0_l01b1P8?lPH2000_l03e3oD?m@oe3oD?m@oe3oD002o`07
860PH?mP8003o`P10_l70@?o1]02o`O@0ol8d003om3@00G@0_l50@;o0`400ol10@030@Co0`403_nP
T:2@X92PT:2@X93o1m000oo@d007d0;o00>@o`401P400ol10@050@09oi2PT:2@oiko00JN0_lJWP00
>9h00onNWP02WP06ob3o8?l81_l01I3@oolP00;o00<Pool03?l02l01`070ol01`07000;o00H1`070
0L02o`040L01`0Co12001?lP820@o`@P0_l00b3o80028004ob0P81?o12001_lPol3o`0;o0141`070
0L01`?o00L01`0700@02o`0<T=2@d93@T?n@d93@0_l0393@T?n@d93@T=2@d0;o01F@d93@T=2@ol01
`0700Ol1`0700L001Ol01L01`07000;o00YPX62PH:1PX62P0_l01m2@d93@T=000_l01i3@T=2@d900
0ol0652@`0700L01`07o0L01`070of2@H91Po`RN00?oWYh069h003fN00Co8?lP0_l00e3oo`02o`03
T?oo00;o00APoolP0_l01E3oD?m@00Co0m02o`@10_l50@;o1P42o`0D0Oooob1P860PH?mP863oD?m@
oe03o`05D?oooe000_l03b1PoolPH23o860Pob1P8002o`0?D?m@oe3oD?m@oe3oD?m@00;o00@PH21P
0_l60@;o1`42o`P10_l9d003om3@00C@0_l8d003om3@00G@0_l50@04o`410@Co2P42o`0:X92PT:2@
X93oT0;o1m000oo@d002d0;o0m000on@T002o`H100?o0@401042o`04X92Po`>N0_l3WP03oijN01RN
000mWP04ob3o80Oo00G@T?lPo`028003ob3o00So0Y001M2@d93@00;o00C00L010_l01L01`07000;o
00H1`0700L02o`PP00Co820P4?l0123o8?l38005ob0P8?l00b0Co`<P0ol04@700L01`070ol01`070
0L0100;o00o00L01`0700Oo@T=2@d9000ol0293@T=2@d93@0_l0493@T=2@d93oT=2@d93@T=02o`04
`0700@Co00S00L01`0700@;o01_00L01`?nPH:1PX62Poj1PX?n@d93@T=2@oi000_l01]2@d93@T0;o
00V@D?o00L01`0400_l02/01`0700On@H?l5WP04oikooaZN000hWP03oijN00:N0_l00f3oX003o`03
D?oo00:@00OoH?mP8?lP00Co00=@oe000ol7d0?o1042o`D100Co0@410_l0421P860PH21P863oH21P
oe03o`05D?oooe000ol04U3oH?mP8?lPH23o860Pob1P80;o015@ooooD?m@oe3oD?m@oe3oH003o`<1
0_l70@;o20400ol10@060@03om3@00?o0m000oo@d007d003om3@00G@0_l8d005o`7oog000_l50@03
o`4100<100?o0@400`42o`0:T:2@X93oT:2@X0;o1M02o`[@00CoT93o1`400ol10@040@03oj3o00JN
00?oW_l06Yh003RN00?oWYh00Yh01B3o8?n`00Ko00C@T?lP0_l00b3o8007o`03d93@00;o00N@d93@
T=2@00?o00C00L010_l01<01`044o`LP00Go820Po`02817o0b001OlP823o00<P00Co820P5?l04<01
`0700L3o`0700L01`042o`07`0700L01`002o`070L01`0700@03o`06d93@T=2@0_l02=2@d93@T=2@
0_l03m2@d93@T=3od93@T=2@d005o`0>0L01`0700L01o`700L02o`0C0L01`07oH:1PX?nPH:1PX63o
d003o`0@d93@T=2@d93@T=2@d?n@D0;o00H1`0700L02o`080L01`07oT?l8WP03oijN01NN000hWP06
oijNW_mP1Ol0153oD?l3T0;o00HPob1Poe06o`G@0ol6d0?o10401?l10@42o`0@D?mP860PH21Pof0P
H?mP80;o00E@ooooD003o`03D?m@00Co00lPH23o860Pob1P8?lPH2000_l03E3ooom@oe3oD?m@oe00
1?l00m3oo`060@;o2042o`L100?o0@400P42o`<100?od=001M02o`S@00?od=001M000oo@d002d0;o
00=@ool01P400ol10@030@;o10400ol10@030@;o00^PT?n@X92PT:2@o`07d0;o2=02o`:@00?o0@40
1@400ol10@020@?o1ih2oaVN000gWP03oijN00:N00Ko8?lPok05o`03T=2@00;o00@Pob0P1Ol00i3@
T002o`06d93@T=2@0_l01M2@d93@00Co00?00L001ol48004ob0Po`8P00Co820P4Ol38005ob0P8?l0
0b001?lP820?o`07d?o@T=2@d002o`06`0700L010_l02<01`0700L010_l04<01`0700L01`?o00L01
`042o`0@T=2@d93@T?n@d93@T=2@d0;o00V@d93@T=2@d9001?l05M2@d<01`0700L3o`0700L3o`070
0@02o`05`0700L000_l07f3oH:1PX62PH:3@T=2@d93@T?n@d93@T=2@d93oD9000_l02<01`0700Ol1
0_l00h^NWP05WP;o6ih003NN00?oWYh00Yh3o`03H?nP00?o00]@oi2@ob3o863oH005o`G@0ol5d0;o
1M04o`810_l00e3oD002o`0=860Pob1Pof0Pob1P8002o`07D?oooe3oD005o`0BD?oo860Pob1P8?lP
H23o860P0_l02E3ooom@oe3oD005o`O@0_l70@03o`4100L100?o0@401043o`P10_l6d0;o2=02o`G@
0ol7d0;o1@42o`@100?o0@400`400ol10@040@;o00VPT:2@X92PT:000_l6d003om3@00O@0_l00i3o
o`050@;o1ih4oabN000lWP04ob3o80Oo00F@d?lPo`028007ob3oom2@d002o`06T=2@d93@0_l01I3@
T=2@00?o00B@d93@2ol38004ob0Po`8P00Co820P4Ol38005ob0P8?l00b001?lP820=o`0<d93oom2@
d93@T=2@0_l01P700L01`0;o00/1`0700L01`?o00@03o`0Q0L01o`700L01`0700Oo@T=2@d93@om2@
d93@T=2@d?o@00Co00^@d93@T=2@d93@T002o`0:0L01`07o0L01`0;o00@1`0700_l010700L03o`0A
X62PH:1PX62PH?o@T=2@d9000_l02m2@d93@T=2@d?n@00;o00C0oooo1Yh5oajN000lWP04of3oH0Go
00U@oi2@ob1Pof000_l20@;o0m03o`G@0_l6d0;o0]02o`07D?m@oe3oD002o`0=860Pob1Pof0Pob1P
8002o`03D?oo00Go00E@ooooD002o`0?860Pob1P8?lPH23o860P00;o00E@ooooD004o`K@0_l8d0;o
1P42o`L10ol60@;o2042o`K@0_l7d0Co1]02o`O@00?o0@400`42o`@100?o0@400`401?l1ool30@0<
oj2@X92PT:2@X93o1m000oo@d007d0;o00>Nool01ih2ob:N000gWP03oijN00:N00Go8?oo2006o`05
T=3oob001?l010700L02o`04d93@T0;o00G@T=2@d003o`04d93@T0ko0b001?lP8?l28004ob0P817o
0b001?lP8?l48004ob0P80So00>@oi000_l03m2@d93@T?n@d93@T=2@d003o`0;0L01`070ol01`040
0_l02l01`?o00L01`07000;o01D1`0700L01`?n@d93@T=2@oi3@T=001_l0293@T=2@d93@0_l01Y3@
T=2@d0;o00[00L01`?o00L010_l00l01`002o`060L01`0700_l0262PH:1PX62P0ol01Y3@T=2@d0;o
00N@d93@T=2@00;o29h2obBN000gWP03oijN00:N0_l00b3o/004o`05D?n@T6001?l20@;o1042o`C@
0_l6d0;o00?@ool00_l01E3oD?m@00?o011@oolPH?mP863oH23o860P0_l01E3ooom@00?o00E@oooo
D002o`0?860Pob1Pof0PH23o860P00;o00A@oooo1m000oo@d004d0;o2=03o`D100Co0@7o1P42o`L1
00?o0@401P42o`W@1?l3d003om3@00O@00?od=001M000ol10@030@;o10400ol1o`0:0@09oi2PT:2@
X93o00:N00?od=001M000oo@d002d0;o29h3obFN000gWP0:oijNW_lPob3o20Ko00>@ob000_l01P70
ool1`0?o00?00L000_l01=2@d903o`04T=2@d17o0R001OlP823o008P00Co820P4Ol28005ob0P8?l0
12001?lP8207o`07d93@T=2@d002o`06T=2@d93@0_l0293@T=2@d93@0_l01L01`07000?o00S00L01
`0700@;o00K00L01`042o`0?`0700L01`07od93@T=2@00?o00N@d93@T=2@00;o00S@T=2@d93@T0;o
00K@T=2@d902o`080L01`07o0L03o`0D`0700L3o`0700L01of2PH:1PX?l3WP;o00S@T=2@d93oT0;o
1ih3obRN000fWP03oijN00:N00Co8?lP0_l00e3oo`02o`:@0_l20@;o0P42o`<10_l30@;o1M02o`0=
d?ooof3oD?m@oe3oD003o`0?D?mP863oH23o860Pob1P00?o00E@oe3oD003o`05D?oooe000_l03b1P
of0PH?mP860Pob1P8005o`03d?oo00S@0_l6d0;o1m02o`810_l30@;o20400ol10@050@03o`4100L1
0]04o`_@0_l8d003om3@00G@0_l30@?o2P400ol10@030@;o00FPT:2@o`05WP03om3@00?@0_l7WP?o
:Yh003JN00?oWYh00Yh01?lPob07o`08d93oo`700L02o`070L3oo`700@02o`03`07000;o00C@T=2@
0ol380go0b001?lP8?l380?o00<Pool03ol28005ob0P8?l012000olP8003o`06T=2@d93@0_l0493@
T=2@d93@om2@d93@T=02o`06T=2@d93@1?l01/01`0700@;o00O00L01`07000;o00H1`0700L02o`07
0L01`0700@04o`06T=2@d93@0_l0493@T=2@d93oT=2@d93@T=02o`0HT=2@d93@T?o0ol01`0700L01
o`700L010_l02/01`070oj1PX?l6WP03om3o00;o1ih3obbN000kWP04ob3o80;o00=@oe000_l4T0;o
1042o`810_l30@?o0P42o`0@d?ooH21P863oD?m@oe3oD0?o00]@of0PH?mP8?lPH002o`06860PD?m@
0ol01E3ooom@00?o011@of0PH?mP863oH21P8?lP0ol00`7oo`06d0;o1m02o`O@00?od=000]001?o@
d=02o`L10_l70@03o`4100D100?o0@400P42o`03L?oo00W@0_l6d0;o2=02o`G@0_l50@03o`4100<1
00?o0@400`400ol10@030@;o00>@oih01Yh00onNWP04WP04oikoobnN000kWP04ob3o80So00F@d93@
T003o`03`07000;o00P1`?oo0L01`0;o00@1oooo1R0=o`<P00?o82000ol5813o0b001OlP823o00DP
0_l01@700L0100;o00J@d93@T=02o`07T=2@d93@T002o`0@d93@T=2@oi3@om2@d93@T0;o00L1`070
0L0100;o00K00L01`042o`09`0700L01`07000Co0241`07od93@T=2@d93@om2@d93@T=3od93@T=2@
d93@om000ol03]2@d<01`0700Ol1`0700_l010700L02o`080L01`07oH?l<WP?o<Ih003JN00WoWYjN
of0Pob000_l00e3oo`03d0;o1Y02o`<10_l20@;o1042o`07860PH21P8002o`07D?m@oe3oD003o`0@
D?mP863oH23o860PH21P80;o00E@ooooD003o`0AD?m@oe3oH21Pof0PH?mP86000ol70@;o1m02o`O@
00?od=001=03o`O@0ol70@03o`4100D100?o0@401043o`P100?od=001]02o`K@0_l7d0;o1m000ol1
0@030@;o1042o`@100?o0@400`42o`ZN0_l00ikoWP0aWP00=Yh01OnNWYko00<P1_l01M2@d93@00?o
00G@T=2@d002o`03`07000;o00D1`?oo0@02o`PP3_l38003ob3o00PP4?l38004ob0P80Co00<1`040
0_l01l01`0700L000_l01m2@d93@T=000_l02I3@T=2@d?o@T003o`03T=2@00;o00O@T=2@d93@00;o
00O00L01`07000;o00T1`0700L01`0401?l02l01`?o00L01`07000;o013@T=2@d93@T?n@d93@T=2@
0_l00m2@d002o`0LT=2@d93@T=2@d93o`0700L3o`0700L3o`0700@;o00?00L000ol7WP?o=Ih003FN
00?oWYh00Yh01?mPof03o`?@0_l6d0;o1I03o`810_l03@7oof0PH21P8?lPH2000_l00e3oD003o`09
D?oooe3oH21P00;o00TPH21P8?lPH2000_l0553ooom@oe3oD?m@oe3oH21Pof0P0ol70@;o1`42o`O@
0_l5d0?o1m000oo@d006d0;o1`42o`D10_l00g3oo`050@;o1`42o`O@0_l7d003om3o00K@0_l6d0;o
1042o`@10_l40@03o`7o00RN0olgWP00=Ih00onNWP02WP04ob3o80?o00F@d93@T003o`05T=2@d900
0_l01M2@d93@00?o00<1ool022001?lP820>o`8P0_l68004ob0P813o0b03o`03`?o000;o00L1`070
0L0100;o00K00L01`043o`0:d93@T=2@d?o@T0;o00?@T=000_l01Y3@T=2@d0;o00N@d93@T=2@00;o
00/1`0700L01`?o00@02o`8P0_l02<01`0700L010_l01l01`0700L000_l01m2@d93@T=000_l01I3@
T=2@00?o012@d93@T=2@d?o@T=2@d93@0_l03L01`07o0L01`07o0L000ol7WP;o>Yh003ZN00<PH?l0
0ol00k3oo`06d0;o1M03o`:@01;oT93oD21P860PH?mP8?lPH202o`03D?m@00?o00E@oe3oD003o`0<
H21P8?lPH23o860P0_l0453ooom@oe3oD?m@oe3oH203o`H10_l70@;o1P43o`K@0ol6d0;o1]02o`O@
0_l70@Ko30400ol10@060@;o1m000oo@o`02o`?@00?od=001]000oo@d006d003o`4100810_l30@?o
1ih4oc^N000iWP03ob3o00;o00D1`?oo2003o`05d93@T=000_l01Y3@T=2@d0Oo1R001?lP8?l380ko
1R001OlP823o00<P4?l00b3o`004o`060L01`0700_l03`700L01`07o0L01`0700@02o`08T=2@d?o@
T=02o`06T=2@d93@0_l01Y3@T=2@d0;o00b@d93@T=2@ol01`042o`0C8?oo0L01`0700L3o`0700L01
`002o`0?0L01`0700L3oT=2@d93@00;o00N@d93@T=2@00;o00O@T=2@d93@00;o00N@d93@T=2@00;o
00L1`070ol3o00JN00?oW_l00olmWP00>Ih2o`<10_l20@?o00>Pool01M03o`C@0ol0453oD21P8?lP
H?mP8?lPH202o`03D?m@00?o01A@ooooD21P860PH23o860Pob1P80;o00e@oe3oD?m@oe3oD?m@00Co
1042o`H10_l60@;o1P42o`;@00?od=001=000oo@d005d0;o1]02o`K@00?o0@401?l;0@;o1`400ol1
0@060@;o00C@oooo2m000oo@d006d003om3@00K@00?o0@400ol7WP;o@Ih003BN00?oWYh00Yh2o`05
`0700L000_l00`700@02o`09/?ood93@T=2@00;o00?@ool01Ol38004ob0Po`8P00Co820P3Ol78005
ob0P8?l00R0Bo`0@0L01`0700L3o`0700L01`0;o00H1`0700L02o`050L01`0401?l01i3@T=2@d900
0_l05]2@d93@T=3od93@T=2@d?o@T=2@d903o`0@`0700L01`07o0L01`0700@;o00K00L01`042o`07
`0700L01`002o`07d93@T=2@d002o`06T=2@d93@0_l01i3@T=2@d9000_l01]2@d93@T0?o29h3od:N
000dWP03oijN00BN0_l50@?o0P42o`04X?ooo`C@0_l01E3oD?m@00;o00dPH23o863oH23o860P00Co
02=@ooooD?m@oe0PH21Pof0Pob1P8?lPH?m@oe3oD?m@oe3oD004o`;@0_l70@;o1`42o`H100?o0@40
0_l30@?o1m02o`K@0_l6d003om3@00Co0m000ol10@050@;o1`400ol10@050@;o0`42o`<12=000oo@
d005d0;o1m001?o@d=02o`RN1?m4WP00=9h00onNWP06WP?o00D1`0700@02o`03`07o00;o00@8oon@
2_l38004ob0Po`8P00?o82003_l38005ob0P8?l00R001?lP820>o`06d93@T=2@0_l01`700L01`040
0_l01l01`0700L000_l01@700L0100?o00H1`0700L02o`0@d93@T=2@d93oT=2@d93@T0;o00G@T=2@
d005o`0>d93@T=2@ol01`0700L02o`060L01`0700_l040700L01`07o0Ol1`0700L02o`06d93@T=2@
0_l04]2@d93@T=3od93@T=2@d?o@o`RN0_m8WP00=9h00onNWP09WP;o1@42o`<11Ol01e3oD?m@oe00
0_l03R1P8?lPH?mP8?lPH?m@1Ol07E3oD?m@oe3oH23o860Pob1Pof0PH?m@oe3oD?m@00?o00?@om00
0_l6d0;o1`42o`L100?o0@400_l30@;o1P42o`O@0_l7d003om3@00;o00A@oooo2=02o`L10_l60@;o
1@42o`T10_l6d0;o1]02o`G@0_l7WP;oBYh004:N0_l01@700L0100;o00?00Ol03?l38006ob0Pob3o
0b0?o`8P00Co823o0b001?lP820:o`06d93@T=2@0_l01]2@d93@T0;o00L1`0700L0100;o00K00L01
`043o`060L01`0700_l01P700L01`0;o00O@T=2@d93@00;o00J@d93@T=06o`0<T=2@oi3@T=2@d93@
0_l01l01`0700L000_l020700L01`?o00ol03<01`?o00L01`0700@?o013@T=2@d93oT=2@d93@T?n@
0ol7WP?oBih004BN0ol40@;o00EPoe3oD003o`03D?m@00;o00`PH23o863oH?mP8603o`09D?m@oe3o
D?m@00?o01=P8?lPH?mP863oH21Poe3oD?m@00;o0]02o`K@0_l6d0;o1`400ol10@020@04o`410@;o
1P42o`H10_l7d003om3@00;@00CoD?oo2=000oo@d006d0;o1`400ol10@030@;o20400ol10@060@;o
1]02o`G@0ol6WP?oCYh004NN0_l00l3o800280co0b000olPo`028003ob0P013o0R001?lP8?l38004
ob0P80Oo00F@d93@T002o`06d93@T=2@0_l01M2@d93@00?o01P1`0700L3o`07o0L01`070ol01`070
0L02o`050L01`0400ol02M2@d93@T?n@d003o`0;d93@T=2@d93@T=000_l0293@T=2@d93@0_l01/01
`0700@;o00k0ool1`0700L01`0700@;o00S00L01`0700@;o00R@d93@T=3od0?o1ih3oe2N000cWP03
oijN01:N0_l0221P863oD?m@0ol00e3oD002o`08860Pob3o8603o`07H?m@oe3oD003o`03D?m@00?o
00mP8?lPH?mP863oH21Poe000ol9d0;o1]000oo@d004d0?o1@43o`L10_l70@03o`4100@10_l6d0?o
1m000oo@d005d0;o2=000ol10@040@;o1`400ol10@050@;o1`43o`C@0ol7WP;o00>Noih0D9h003>N
00?oWYh04Ih2o`DP3?l28005ob0Pob000_l380ko0b001?lP8?l38004ob0P80Co00c@T?n@d93@T=2@
d902o`05d93@T=000_l01Y3@T=2@d0;o00O00Ooo`07000;o00L1`0700L0100;o00K00L01`042o`09
`0700L01om2@00Co00[@T=2@d93@T=2@0_l04=2@d93@T=3od93@T=2@d902o`0>0Oooo`700L01`070
0L02o`0@0L01`0700Ol1`0700L01`0;o00?@ool029h2oeFN000cWP03oijN012N00OoH21P860P00;o
00=@oe000ol00e3oD002o`05863oH2000_l01f0PH21Poe000ol01e3oD?m@oe000_l03B1P8?lPH?mP
863oH2000ol6d0;o2=000oo@d004d0;o1M04o`H10_l70@;o1P42o`D10ol8d003om3@00C@0_l6d0;o
2=000ol10@050@;o1P42o`H10_l70@;o29h2oeNN000cWP03oijN012N1B000olPo`0;o`<P00Co8?oo
1R0>o`<P00Co823o0b03o`0;`070oi3@T=2@d9000_l01m2@d93@T=000_l02I3@T=2@d?o@T002o`03
d93@00?o00H1`0700L02o`070L01`0700@02o`09`0700L01o`7000?o00_00L3@T=2@d93@T002o`06
d93@T=2@0_l01]2@d93@T0;o00?@T=000_l06i3@T0700L01`070ol01`0700L3o`0700L01`002o`04
0L01o`BN00CoWYjN0omIWP00@Ih3o`:N00LPH23o8?lP00;o00=@oe000ol01e3oD?mP86000_l02R1P
860PH21Poe03o`03D?m@00?o00a@oolPH?mP863oH203o`H10_l6d0?o1]02o`G@0ol6d0?o1P42o`L1
00?o0@401044o`H100?od=001M02o`K@0_l6d003om3o00O@00?o0@401042o`H10_l70@03o`7o00FN
00?oW_l00_mKWP00@9h3o`0:T?oo8?lPob3o80co0R02o`PP3ol28004ob0P80Co00X1`?o00L01`070
0_l01m2@d93@T=000_l02I3@T=2@d?o@T002o`03d93@00;o00J@d93@T=03o`060L01`0700_l02@70
0L01`?o00@03o`0;8?oo`0700L01`0400_l05I3@T=2@d93oT=2@d93@T?n@d93@T002o`09d93@T=2@
d93@00;o00K00L01`042o`06`0700L010_l01L01`07000;o1Yh3oefN000bWP03oijN00VN0ol0353o
T93o8?lPob3o80;o00=@oe001Ol03U3ooomP860PH21Pof0P0_l01e3ooom@oe000ol0253oob1Pof0P
0_l00`7o0@040@;o1P43o`K@0_l6d0;o1]02o`K@0ol60@;o1@42o`04L?ooo`<100?o0@401P42o`K@
0_l6d0;o00?@ool00m000oo@d007d0;o1P400ol10@050@03o`7o00;o1Yh2of2N000bWP03oijN00RN
1_l02Y3@ob3o8?lPob0<o`TP00?o82003ol280?o00_00L3o`0700L01`002o`070L01`0700@02o`06
T=2@d93@0_l01Y3oom2@d0;o00J@d93@T=02o`07T=2@d93@T002o`090L01`070ol0100;o0R02o`07
`0700L01`002o`070L01`0700@02o`06T=2@d93@0_l01I3@T=2@00;o00O@T=2@d93@00;o00n@d93@
T=2@d?l1`0700L000_l01@700L0100;o1Yh4of6N000bWP03oijN00NN00OoD?m@oe3o00:@00So8?lP
ob3o80;o00E@oe3oD003o`0>D21P860PH23o863oH202o`07D?m@oe3oD003o`04D?oo80Go1042o`H1
0ol60@;o1]000oo@d005d0;o1]03o`K@0_l50@Ko0`400ol10@050@;o1`42o`K@00?od?l00_l3d003
om3@00G@0_l7d0;o1P400ol1o`02o`JN1?mSWP00<Yh00onNWP05WPSo00_@T=3o8?lPob3o800;o`HP
00Go820Po`02813o00c0oooo`0700L01`042o`06`0700L010_l01/01`0700@;o00j@ooo@T=3od93@
T=2@d0;o00N@d93@T=2@00;o00W@T=2@d93o`0400_l02b3oo`700L01`07000;o00H1`0700L02o`0=
0L01`0700Oo@T=2@d002o`08T=2@d93@T=02o`0?T=2@d93@om2@d93@T=2@00;o00@1`0700_l6WP?o
Iih003:N00?oWYh00ih2o`068?ooD?m@0_l3T0;o00IP8?lPob04o`0DD?oooe3oD21P860PH?mP863o
H202o`03D?m@00?o00=@ool01?l60@?o1P42o`H10_l60@03om3@00G@0_l6d0?o1]02o`G@1Ol30@03
o`4100H10_l60@;o1P42o`03d?oo00?@00?od=001]02o`G@0_l8d004o`7oo`FN00CoW_ooJIh003NN
00Co820P1ol00m2@d002o`8P00?o8?l03?l38004ob0Po`8P00Co820P3?l00i3oo`02o`070L01`070
0@02o`06`0700L010_l01/01`0700@;o00k0ool1`07od93@T=2@d0;o00N@d93@T=2@00;o00W@T=2@
d93oT=001Ol01`700L01`0400_l03l01`0700L3o`0700L01`002o`0>0L01`070oi3@T=2@d902o`0>
d93@T=2@d?o@T=2@d902o`08d93@T=2@d?l7WP;oJih003JN00GoH21P8002o`03D?m@00;o0Y001OmP
of0P00;o00=Poe000ol0553oD?m@oe3oH23o863oH23o860P0_l00e3oD003o`05D?ood?l01=03o`H1
0_l60@?o1@400ol10@050@;o1]03o`K@0_l5d0Go0m000ol10@050@;o1P42o`L10_l00`7oo`030@03
om3@00G@0_l6d0;o1]02o`04d?ooo`JN0om]WP00<Ih00onNWP02WPDP1ol02]2@ob3o8?lPob0<o`<P
00Co823o0R001?lP8209o`0;d93oom2@d93@T=000_l01/01`0700@;o00O00L01`07000;o00d1o`70
0Ol1`0700L0100;o00N@d93@T=2@00;o00W@T=2@d93oT=001Ol01m2@d93@T=000_l01/01`0700@;o
00K00L01`042o`0?`0700L01`?o00L01`07000;o00k@T=2@d93oT=2@d93@T0;o00O@T=2@d93o00NN
0_m`WP00<Ih00onNWP02WP04863oH0?o00=@oe000_l2T008of3oH?mPof03o`07D?m@oe3oD002o`0B
860Pob1Pof0Pob1Poe3oD?m@1?l5d0;o1]03o`D10ol60@03o`4100@10_l60@?o1]02o`K@1?l3d003
om3@00G@0_l60@;o1P42o`040Oooo`<100?o0@401@42o`G@0_l7d0;o00?@ool01ih3og6N000aWP03
oijN00:N0R000olPo`07o`08d93o8?lPob0>o`<P00Co823o0R000olP8008o`09d?o@T=2@d93@00;o
00J@d93@T=03o`060L01`0700_l03@7ool01`?o00L01`0400_l01l01`0700L000_l01]2@d93@T0;o
00?@ool00ol01m2@d93@T=000_l01Y3@T=2@d0;o00K00L01`042o`0N`0700L01o`700L01`070ol01
`0700L3oT=2@d93@0_l0293@T=2@d93o1ih2oa2N1?l3WP?oFYh0036N00?oWYh00Yh0121Pof03o`03
D?m@00;o0Y02o`03863o00;o00]Poe3oD?m@oe3oD002o`0>860Pob1Pof0Pob1Poe04o`G@0_l6d0?o
1M03o`H100?o0@401@42o`D10ol60@;o1]001?m@ool3d003om3@00G@0_l6d0;o1P42o`030Ooo00<1
00?o0@401@42o`H10_l6d0;o00C@oooo1Ih4oaJN00?oW_l00ih00onNWP1GWP00<Ih01OnNWYko008P
00?o8?l01ol01M2@oolP00;o0b0<o`<P00Co823o0R000olP8003o`0;T=2@oi3@T=2@d9000_l01]2@
d93@T0;o00K@T=2@d902o`0>0Ooo`070ol01`0700L02o`060L01`0700_l01P700L01`0;o00?@ool0
1?l01Y3@T=2@d0;o00J@d93@T=02o`06T=2@d93@0_l03/01`0700Ol1`0700L010_l01/01`0700@;o
00K00L01`042o`07T=2@d93@o`07WP;o00>Noih05Yh00onNo`03WP03oijN05NN000eWP05ob1Pof00
0ol0153oD?l2T00=ob3oof0PH21Poe3oD003o`03D?m@00;o00/PH23o8?lPH23o8004o`G@0_l6d0;o
1]02o`K@00?o0@401@42o`H10_l60@;o1P401?m@ool3d0;o1]02o`K@0_l6d0;o00<1ool00`400ol1
0@050@;o1P42o`H10_l00m3oo`07WP;o6ih00onNo`03WP03oijN05NN000eWP03ob3o008P1ol0193@
ool680go0b000olPo`0380Co00W0oi3@T=2@d9000_l01]2@d93@T0;o00K@T=2@d902o`0>d?ooT=2@
ol01`0700L02o`060L01`0700_l01P700L01`0;o00@1oolP0ol01Y3@T=2@d0;o00J@d93@T=02o`06
T=2@d93@0_l03Y3@T=2@d?l1`0700L010_l05l01`0700Ol1`0700L01o`700L01`07o00NN0_lMWP03
oiko00>N00?oWYh0Eih0032N00?oWYh00Yh01OlPob1P00Go00a@oi2@ob1P860Pob02o`03D?m@00?o
00=@oe000_l0221Pof0Pob1P0_l60@;o1]03o`G@0ol5d003om3@00G@0_l60@;o1P42o`H100CoL?oo
0`42o`K@0_l6d0;o1]02o`03d?oo00?@00?o0@401@42o`D10_l60@;o00@1oooo1ih2oa^N1?l2WP05
oijNW_l0FIh0032N00?oWYh00Yh00olPo`0280Oo00>@d2000b001?lPob0=o`8P00?o82001?l02L01
o`700L01`002o`07d93@T=2@d002o`06T=2@d93@0_l03I3oT=2@oi3@T=2@d9000_l01P700L01`0;o
00H1`0700L02o`040Ooo80?o00K00L01`042o`06T=2@d93@0_l01Y3@T=2@d0;o00j@d93@T=3od93@
T=2@d0;o00g00L01`07o0L01`07000;o00H1`0700L02o`JN0olNWP03oijN00:N00GoWYjNo`1IWP00
<9h00onNWP02WP07ob3o863oD006o`09T60PH23o8?lP00;o00=@oe000ol02E3oD?mP863oH003o`H1
0_l50@?o1]02o`K@00?od=001=02o`K@0ol50@;o1P401?m`ool30@;o1P42o`K@0_l6d0;o00?@ool0
0m000oo@d005d0;o1@42o`H10_l00`7oo`06WPCo89h4o`:N0omJWP00;ih00onNWP03WP04ob3o80So
00>@ob000b001?lPob0<o`<P0_l02`7o0Ol1`0700L0100;o00K00L01`042o`06T=2@d93@0_l03I3o
om2@d?o@T=2@d9000_l01m2@d93@T=000_l01L01`07000;o00@1oolP0ol01/01`0700@;o00K00L01
`042o`06T=2@d93@0_l01I3@T=2@00;o00O@T=2@d93@00;o00f@d93@T=3o0L01`07000;o00L1`070
0L3o00NN0_n6WP00;ih00onNWP03WP04ob3o80;o00I@ooooD?l2T008H?mP8?lPob04o`03D?oo00?o
00A@of0P0_l60@;o1P43o`D10_l6d003om3@00G@0_l5d0?o1]02o`D100CoL23o0`42o`H10_l60@;o
1]02o`03d?oo00?@00?od=001M02o`G@0_l60@;o00<1ool01ih3ohNN000eWP;o0R08o`04T?lPo`8P
00?o8?l03ol02/01`?o00L01`042o`07`0700L01`002o`050L01`0400_l03Y3oom2@d?o@T=2@d93@
0_l01Y3@T=2@d0;o00J@d93@T=02o`04`?lP80?o00D1`0700@03o`050L01`0400_l01/01`0700@;o
00F@d93@T003o`06T=2@d93@0_l03I3@T=2@d?o@T=2@d9000_l01`700L01`?l01Yh4ohVN000dWP04
of3oH0?o00=@oe000_l2T005of3oH2000_l00f3oD003o`03D?m@00Ko1P42o`D10ol60@;o1@400oo@
d005d0;o1]02o`K@0_l6d004ob3oo`<10_l60@;o1@42o`H10_l00m3oo`03d0;o1]03o`C@0_l6d0;o
00<1ool01Yh2ohfN000_WP03oijN00:N00Go8?oo8007o`0:d93o8?lPob3o80_o00^@d93o`0700L01
`002o`060L01`0700_l01P700L01`0;o00d1o`700Oo@T=2@d93@00;o00J@d93@T=02o`06T=2@d93@
0_l00i3oo`04o`060L01`0700_l01P700L01`0;o00D1`0700@02o`05`0700L000ol01Y3@T=2@d0;o
00N@d93@T=2@00;o00C@T=2@0_l01m2@d93@T?l019h01?nNoon?WP00;ih00onNWP02WP;o00<PH200
0_l00e3oD002o`:@00[oH?mPof3oH?m@0ol00e3oD003o`K@00?o0@401043o`D10_l60@03o`4100D1
00?od=001=03o`G@0_l6d0Co0m02o`H10ol50@?o1042o`030Ooo00<10_l6d0?o1]02o`C@0_l00m3o
o`06WP;oTIh002jN00?oWYh00ih00olP800280Oo00[@T?lPob3o8?lP2Ol02Y3@om2@d93@T=03o`05
0L01`0400_l01L01`07000;o00h1ooo00L3o`0700L01`0?o00F@d93@T002o`05d93@T=000_l00i3o
o`04o`06d93@T=2@0_l01`700L01`0400_l01/01`0700@;o00?00Ol00ol01/01`0700@;o00N@d93@
T=2@00;o00K@T=2@d902o`05d93oT?l01Ih3oi>N000^WP03oijN00>N00@PH21P0ol00e3oD002o`:@
00coH?mPof3oH?m@oe03o`O@0_l6d0?o1042o`D100?o0@401@43o`H10_l5d0;o1M03o`C@0_l6d0?o
1P42o`D10ol40@;o1P43o`K@0_l5d0?o1Yh2oiJN000dWP048?lP80So00S@T?lPob3o80Oo00^@d93o
T=2@d93@T003o`06T=2@d93@0_l01<01`042o`0>`?o00L3o`0700L01`042o`06`0700L010_l01I3@
T=2@00;o00K@oon@d902o`04d93@T0?o00J@d93@T=02o`06`0700L010_l01/3oo`700@;o00C00L01
0_l01l01`0700L000_l01]2@d93@T0;o00?@ool00Yh00onNWP02WP?oUih003BN00@Pob1P0ol0153o
D?l3T006of3oH?mP1Ol8d0;o1]02o`K@0ol30@03o`4100D10_l60@;o1P43o`;@00?od?l00_l5d0?o
1=02o`K@0_l50@?o1P42o`@10ol60@;o1M02o`BN00?oWYh00_nJWP00<ih00olPo`0280Oo00>@d900
0_l280;o00lPooood93oT=2@d93@T=000ol01M2@d93@00;o00N@d93@T=2@00;o00/1`07o0L01`070
0@03o`050L01`0400ol01P700L01`0Co00?@T=000_l01Y3@T=2@d0;o00B@d93@0_l01Y3@T=2@d0;o
00K0ool1`042o`06`0700L010ol010700L02o`060L01`0700_l00m3oo`06WP?oW9h002jN00?oWYh0
0Yh01OlPob1P00Go00Y@oi2@ob3o8?lP0_l20@03om3@00?@0_l7d0;o1M03o`03d?oo00?@00?o0@40
0P43o`H10_l60@;o00@1oom`0ol6d0;o1]02o`C@0ol4d0?o1P42o`L10_l40@;o1@42o`JN0onNWP00
;Yh00onNWP02WP03ob3o008P1ol01Y3@ob3o80Co00[00L01`?n@d93@0ol01]2@d93@T0;o00k@T=2@
d93oT=2@d93@T0;o00@1`0700_l01P700L01`0;o00L1`0700L3o008P00Co0L010_l01Y3@T=2@d0?o
00G@T=2@d003o`04d93@T0;o00G@om2@d002o`06`0700L010ol01P700L01`0;o00@1`0700_l00`7o
o`06WP?oX9h002fN00?oWYh00ih01?lPob02o`06D?oooe3o0Y000olPo`03o`8100?o0@401043o`?@
0ol5d0?o00?@om000]000oo@d006d0;o0`42o`H10ol00`7oL004o`D10ol6d0;o1]02o`;@1?l5d0;o
1`42o`H10_l20@?o1Yh2oj>N000]WP03oijN00>N0_l280So00>@d?l00_l020700Ol1`0700_l01@70
0L0100;o00B@d93@0_l03Y3@T=2@d?o@T=2@d93@0_l01Y3@T=2@d0;o00?00L000ol01/01`0700@?o
00@1`0700_l01P700L01`0;o00K@T=2@d902o`05d93@T=000ol01=2@d902o`05d93@T=000ol01P70
0L01`0;o00D1`0700@03o`BN00?oWYh00_nUWP00<ih2o`05H23ooe001?l3T0;o0P400ol10@020@04
o`410@?o1042o`C@0ol00m3od002d003om3@00G@0ol5d0?o0`42o`040Oooo`<10_l40@;o1P42o`K@
0_l00m3oo`03d0;o1=02o`K@0_l60@;o00<1ool01ih3ojNN000bWP03ob3o008P1ol03]2@oi3@o`70
0L3o`0700_l00`700@02o`04`0700@?o00_@T?n@oi3@T=2@d003o`06d93@T=2@0_l01]2@d93@T0;o
00<1`0401?l01L01`07000?o00?00L000ol01L01`07000?o00B@d93@0ol01]2@d93@T0;o00C@T=2@
0ol01I3@T=2@00;o00D1`0700@02o`NN0onYWP00<Yh01OmPof0P00;o00=@oe001?l6T004o`410@;o
0`42o`810_l50@;o1=000oo@d005d0;o1]02o`K@1?l30@;o1P42o`@10_l60@;o00?@om000]02o`K@
0ol4d0;o1M02o`030Ooo00JN0on/WP00;Ih00onNWP02WP03ob3o008P1_l00i3@o`02o`06d93@T=2@
0_l00`700@02o`06`07ool010ol02`7o0L3oT=2@d93@00;o00F@d93@T002o`06d93@T=2@0ol00i3o
o`03o`06`0700L010_l01/01`0700@;o00C00L010_l01L01`07000?o00F@d93@T002o`07d93@T=2@
d002o`04T=2@d0;o00B@d93@0ol6WP;o[Yh002fN00?oWYh00Yh01?mPof05o`O@0_l7T0;o0P42o`81
0ol20@03o`4100@10_l5d0;o1=03o`K@0ol3d0?o1@43o`D10ol30@;o00<1ool00`43o`C@0ol6d0;o
1=02o`03d?nN00>N00?oWYh00_n`WP00;9h00onNWP03WP04ob3o80Co00[@T?n@d93@T=2@0ol01Y3@
T=2@d0;o00?00Ol00_l03@70ol01`?o00L01`0400ol01=2@d903o`04T=2@d0;o00>@ool01?l01M2@
d93@00Co00G00L01`002o`060L01`0700_l00`70o`02o`06`0700L010ol01M2@d93@00;o00J@d93@
T=02o`03T=3o00;o1Ih3oa:N0onMWP00;9h00onNWP03WP;o00@Poooo1m02o`K@0_l5T0Co0P401Ol1
0@7o00@10_l50@;o1M03o`?@1?l3d0?o1M03o`D10_l50@?o0`43o`D11?l4d0;o1M03o`JN0olCWP05
oijNW_l0W9h0036N00?o8?l00ol02/3oom2@d93@T=03o`05d93@T=000_l0493@T?n@d93o`070ol01
`042o`03`07000?o00?00L000_l01]2@d93@T0Co00?@T=000_l0193@T=02o`05T=2@d9001?l01070
0L02o`060Ooo`0700_l010700L02o`060L01`0700ol0193@T=02o`03T?oo00NN0_lFWP05oijNW_l0
W9h0036N1?l60@?o1]02o`G@1?l5T003o`4100810_l30@?o0P43o`810ol00m3oD003o`K@0_l4d0?o
1=05o`810ol60@;o1043o`D11?l2d0;o1Yh3oaRN00GoWYjNo`2LWP00;9h00onNWP02WP0<o`700Ol1
`0700L011Ol01=2@d902o`06d93@T=2@0_l03=2@d93@T=3o0L01`0;o00<1`0400ol00`70o`02o`03
`07o00;o00?@T=000ol01M2@d93@00?o00C@T=2@0_l01M2@d93@00Co00?00L000ol01L01`07000?o
00C00L010_l01L01`07000Co19h00onNo`02oaZN00GoWYjNo`2LWP00;9h00onNWP02o`:N00?o0@40
0P42o`H11Ol3d0?o00?@om000]03o`N@0_l20@?o0`43o`8100?o8?l00P42o`C@0ol5d0;o1=03o`;@
1_l40@;o1P42o`@10ol20@?o1Ih3oabN00GoWYjNo`2LWP00;9h00onNo`07WP;o00<1`0400ol01070
0L02o`0?2?ooom2@d?o@T=2@d93@00?o00K@T=2@d903o`03`07o00;o00D1`07o8003o`040L01`0?o
00B@d93@0_l01I3@T=2@00;o00C@T=2@0ol0193@T=04o`04`0700@?o00D1`0700@02o`04`0700@?o
1Yh2oanN00GoWYjNo`2LWP00:ih00onNo`0;WP?o0P43o`<11_l3d003om3@00K@0_l6T0Co0P42o`04
8?ooo`810ol40@;o1=03o`C@0_l00m3od002d0?o1=04o`@10_l50@;o00<1oih01Yh2ob:N0onMWP00
:ih3o`jN0ol00l01o`02o`030L0100;o00N`oi3@T=2@00?o00F@d93@T003o`03T=2@00;o00G@T?oo
8003o`030L3o00;o00S00Ooo`0700@;o00F@d93@T003o`03T=3o00;o00K@T=2@d902o`04d93@T0Co
00@1`0700ol00l01o`02o`JN0_o4WP00;Yh00onNWP0>WP?o0P42o`<10ol00k3oo`04d0;o1]05o`>@
0_l30@?o0P42o`810ol30@?o1=03o`?@0ol5d0?o1=03o`@10ol5WPCoaYh0036N0ol>WP0:ol01`?o0
0L01`0?o00J`ooo@T=03o`06d93@T=2@0_l01M2@d93@00?o00<1`0400_l00l01o`02o`080L3oo`70
0L02o`05d?o@T=000ol00m2@d002o`06T=2@d93@0_l0193@T=03o`030OnN00JN0_o9WP00=9h00onN
WP0=WP03o`4100810_l40@;o00BPoooo0m03o`03d?m@00?o1i03o`810ol20@;o0P43o`810ol6d0;o
0m03o`G@0ol2d0?o1Yh2ol^N0017WP;o00?00L000ol00l01o`02o`072?ooom2@d003o`03d93@00?o
00O@T=2@d93@00;o00?00L000_l00`70o`02o`07`?oool01`003o`05T=2@d9000ol00i3@T002o`05
d93@T=000ol2WP03oijN00:N0_o=WP00>9h3o`nN0_l30@?o0P47o`?@0ol3d0?o1Y03o`810ol0107o
ool20@?o0`42o`K@0_l3d0?o00?@oih019h00onNo`02olnN000kWP03oijN00jN0ol00l01`003o`03
`07o00?o00J@d93@T=03o`03d93@00;o00J@d93@T=04o`06`?oool010ol01`70ool1`0400_l01Y3@
T=2@d0?o00C@T?oo1Ih3om:N000nWP?o3Yh3o`<10ol20@Co1]02o`?@0ol3T004oi2@T0;o0P43o`81
0_l20@?o0P43o`G@0ol6WP;oe9h0046N00?oWYh03Yh2o`038?oo00;o00C00L011?l01I3@T=2@00?o
00>@d9001?l01M2@d93@00?o00H1`?oo0L03o`07`07ool01`002o`03d?oo00NN0_oFWP00AIh3o`^N
0_l40@?o1043o`K@0ol2d0?o1i02o`810ol20@;o0P43o`030Ooo00BN00?oW_l00_oHWP00B9h00onN
WP0:WP?o00@1`0700ol00l01`004o`05d93@T=000ol00m2@d003o`06d93@T=2@0ol01/01ooo00@?o
00<1ool01Yh2om^N001HWP?o1043o`<11?l00m3od002d0?o0m02o`N@0_l20@?o00<1ool01Yh3ombN
001;WP?o3Ih2o`05`0700L000ol00l01o`04o`05d93@T=000_l00i3@T003o`05T=2@d9001?l00`7o
o`05WP?ogih004jN00?oWYh039h3o`D10_l30@Go1=03o`?@0_l3T005oijNW_l00Yh00onNWP03od2N
0onNWP00DYh3o`^N0ol01<3o`043o`030L0100Go00C@T=2@0_l00m2@d004o`JN1?m3WP03oijN09fN
001EWP03oijN00^N0_l50@;o0`42o`04X?ooo`?@0ol2d0;o1Ih2odJN00?oWYh0WIh005RN0_l;WP?o
00@1`0700ol00l01o`02o`062?ooom2@0ol5WP;o4Yh4o`>N0ol/WP03oijN09fN001JWP03oijN00^N
0ol40@;o0`46o`:N00CoWYjN0_lHWP03oiko00>N00?oWYh0:9h00onNo`2NWP00Fih00onNWP0=WP?o
00<1`0400ol00`7oo`05WPCo6Yh00onNo`03WP03oijN02RN00?oW_l0WYh005nN0ol<WP?o0P42o`JN
0olAWPOo19h00onNo`03WP03oijN02NN00GoWYjNo`2MWP00HYh00onNWP0<WP;o19h4oanN00?oW_l0
0ih00onNWP0VWP?o00BNooooW9h006FN0ol<WP03oiko00;o7Ih4o`:N00GoWYjNo`3;WP00J9h00onN
WP09WP?o89h00onNWP02WP05oijNW_l0bih006bN0_l00ikoWP04ob:N1?l2WP?oc9h006jN1?ojWP00
Kih00onNWP3jWP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00
oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00
oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00
oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00
oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00
oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00
oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00oii]WP00
oii]WP00oii]WP00oii]WP00oii]WP00\
\>"],
  ImageRangeCache->{{{0, 363.5}, {363.5, 0}} -> {-5.04705*^-6, -0.0253919, 
  0.00289074, 0.00289074}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot structure with quickdraw3D", "Subsubsection"],

Cell[BoxData[
    \(\(radObjDrwQD3D[Grp]\ ; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Save ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " geometry under DXF file "
}], "Subsubsection"],

Cell[BoxData[
    \(<< Utilities`DXF`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WriteDXF["\<test.dxf\>", \ gr]\)], "Input"],

Cell[BoxData[
    \("test.dxf"\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Loop on phase at constant gap", "Section"],

Cell[BoxData[
    \(Prec = 0.00001; \nNmax = 10. ; \nGap = 16; \nphi1 = 0; \nphi2 = 28; \n
    dphi = 7; \n
    Tb = Table[{phi, solve[Gap, phi, 0]}, {phi, phi1, phi2, dphi}]; \n
    TbBx = Table[{Tb[\([i, 1]\)], Tb[\([i, 2, 1]\)]}, {i, 1, Length[Tb]}]; \n
    TbBz = Table[{Tb[\([i, 1]\)], Tb[\([i, 2, 2]\)]}, {i, 1, Length[Tb]}]; \n
    TbIx = Table[{Tb[\([i, 1]\)], Tb[\([i, 2, 3]\)]}, {i, 1, Length[Tb]}]; \n
    TbIz = Table[{Tb[\([i, 1]\)], Tb[\([i, 2, 4]\)]}, {i, 1, Length[Tb]}]; 
    \)], "Input"],

Cell[CellGroupData[{

Cell["Plot of the field integral vs. phase", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MultipleListPlot[TbIx, TbIz, PlotJoined -> True, 
      AxesLabel -> {"\<phase[mm]\>", "\<Field integral [G.cm]\>"}, 
      PlotLegend -> {"\<Hor.\>", "\<Vert\>"}, LegendSize -> {0.4, 0.4}]\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49443 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.404762 0.380952 0.247214 0.380952 [
[ 0 0 0 0 ]
[ 1 .49443 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0117721 0.785714 0.482655 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.0340136 0.298077 0.0602129 [
[.19388 .28558 -5 -14 ]
[.19388 .28558 5 0 ]
[.36395 .28558 -8 -14 ]
[.36395 .28558 8 0 ]
[.53401 .28558 -8 -14 ]
[.53401 .28558 8 0 ]
[.70408 .28558 -8 -14 ]
[.70408 .28558 8 0 ]
[.87415 .28558 -8 -14 ]
[.87415 .28558 8 0 ]
[1.025 .29808 0 -7 ]
[1.025 .29808 57.75 7 ]
[.01131 .05723 -18.25 -7 ]
[.01131 .05723 0 7 ]
[.01131 .17765 -18.25 -7 ]
[.01131 .17765 0 7 ]
[.01131 .4185 -10 -7 ]
[.01131 .4185 0 7 ]
[.01131 .53893 -10 -7 ]
[.01131 .53893 0 7 ]
[.02381 .64303 -52.5938 0 ]
[.02381 .64303 52.5938 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19388 .29808 m
.19388 .30433 L
s
gsave
.19388 .28558 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.36395 .29808 m
.36395 .30433 L
s
gsave
.36395 .28558 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.53401 .29808 m
.53401 .30433 L
s
gsave
.53401 .28558 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.70408 .29808 m
.70408 .30433 L
s
gsave
.70408 .28558 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.87415 .29808 m
.87415 .30433 L
s
gsave
.87415 .28558 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(25) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05782 .29808 m
.05782 .30183 L
s
.09184 .29808 m
.09184 .30183 L
s
.12585 .29808 m
.12585 .30183 L
s
.15986 .29808 m
.15986 .30183 L
s
.22789 .29808 m
.22789 .30183 L
s
.2619 .29808 m
.2619 .30183 L
s
.29592 .29808 m
.29592 .30183 L
s
.32993 .29808 m
.32993 .30183 L
s
.39796 .29808 m
.39796 .30183 L
s
.43197 .29808 m
.43197 .30183 L
s
.46599 .29808 m
.46599 .30183 L
s
.5 .29808 m
.5 .30183 L
s
.56803 .29808 m
.56803 .30183 L
s
.60204 .29808 m
.60204 .30183 L
s
.63605 .29808 m
.63605 .30183 L
s
.67007 .29808 m
.67007 .30183 L
s
.7381 .29808 m
.7381 .30183 L
s
.77211 .29808 m
.77211 .30183 L
s
.80612 .29808 m
.80612 .30183 L
s
.84014 .29808 m
.84014 .30183 L
s
.90816 .29808 m
.90816 .30183 L
s
.94218 .29808 m
.94218 .30183 L
s
.97619 .29808 m
.97619 .30183 L
s
.25 Mabswid
0 .29808 m
1 .29808 L
s
gsave
1.025 .29808 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(phase) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.250000 14.000000 moveto
(@) show
94.187500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
112.812500 14.000000 moveto
(D) show
116.750000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.02381 .05723 m
.03006 .05723 L
s
gsave
.01131 .05723 -79.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02381 .17765 m
.03006 .17765 L
s
gsave
.01131 .17765 -79.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02381 .4185 m
.03006 .4185 L
s
gsave
.01131 .4185 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .53893 m
.03006 .53893 L
s
gsave
.01131 .53893 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.02381 .08733 m
.02756 .08733 L
s
.02381 .11744 m
.02756 .11744 L
s
.02381 .14754 m
.02756 .14754 L
s
.02381 .20776 m
.02756 .20776 L
s
.02381 .23786 m
.02756 .23786 L
s
.02381 .26797 m
.02756 .26797 L
s
.02381 .32818 m
.02756 .32818 L
s
.02381 .35829 m
.02756 .35829 L
s
.02381 .3884 m
.02756 .3884 L
s
.02381 .44861 m
.02756 .44861 L
s
.02381 .47872 m
.02756 .47872 L
s
.02381 .50882 m
.02756 .50882 L
s
.02381 .02712 m
.02756 .02712 L
s
.02381 .56903 m
.02756 .56903 L
s
.02381 .59914 m
.02756 .59914 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -113.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Field) show
90.562500 14.000000 moveto
(integral) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
130.062500 14.000000 moveto
(@) show
134.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(G) show
142.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
145.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(cm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
160.250000 14.000000 moveto
(D) show
164.187500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .29809 m
.2619 .29808 L
.5 .29811 L
.7381 .29808 L
.97619 .29808 L
s
.0001 w
.02381 .29809 -1.875 0 Mabsadd m
.02381 .29809 0 2.5 Mabsadd L
.02381 .29809 1.875 0 Mabsadd L
.02381 .29809 0 -2.5 Mabsadd L
.02381 .29809 -1.875 0 Mabsadd L closepath F
.2619 .29808 -1.875 0 Mabsadd m
.2619 .29808 0 2.5 Mabsadd L
.2619 .29808 1.875 0 Mabsadd L
.2619 .29808 0 -2.5 Mabsadd L
.2619 .29808 -1.875 0 Mabsadd L closepath F
.5 .29811 -1.875 0 Mabsadd m
.5 .29811 0 2.5 Mabsadd L
.5 .29811 1.875 0 Mabsadd L
.5 .29811 0 -2.5 Mabsadd L
.5 .29811 -1.875 0 Mabsadd L closepath F
.7381 .29808 -1.875 0 Mabsadd m
.7381 .29808 0 2.5 Mabsadd L
.7381 .29808 1.875 0 Mabsadd L
.7381 .29808 0 -2.5 Mabsadd L
.7381 .29808 -1.875 0 Mabsadd L closepath F
.97619 .29808 -1.875 0 Mabsadd m
.97619 .29808 0 2.5 Mabsadd L
.97619 .29808 1.875 0 Mabsadd L
.97619 .29808 0 -2.5 Mabsadd L
.97619 .29808 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.02381 .01472 m
.2619 .33475 L
.5 .60332 L
.7381 .29494 L
.97619 .43251 L
s
.0001 w
[ ] 0 setdash
.02381 .01472 0 2.5 Mabsadd m
.02381 .01472 -0.56518 .7779 Mabsadd L
.02381 .01472 -2.37764 .77254 Mabsadd L
.02381 .01472 -0.91448 -0.29713 Mabsadd L
.02381 .01472 -1.46946 -2.02254 Mabsadd L
.02381 .01472 0 -0.96154 Mabsadd L
.02381 .01472 1.46946 -2.02254 Mabsadd L
.02381 .01472 .91448 -0.29713 Mabsadd L
.02381 .01472 2.37764 .77254 Mabsadd L
.02381 .01472 .56518 .7779 Mabsadd L
.02381 .01472 0 2.5 Mabsadd L closepath F
.2619 .33475 0 2.5 Mabsadd m
.2619 .33475 -0.56518 .7779 Mabsadd L
.2619 .33475 -2.37764 .77254 Mabsadd L
.2619 .33475 -0.91448 -0.29713 Mabsadd L
.2619 .33475 -1.46946 -2.02254 Mabsadd L
.2619 .33475 0 -0.96154 Mabsadd L
.2619 .33475 1.46946 -2.02254 Mabsadd L
.2619 .33475 .91448 -0.29713 Mabsadd L
.2619 .33475 2.37764 .77254 Mabsadd L
.2619 .33475 .56518 .7779 Mabsadd L
.2619 .33475 0 2.5 Mabsadd L closepath F
.5 .60332 0 2.5 Mabsadd m
.5 .60332 -0.56518 .7779 Mabsadd L
.5 .60332 -2.37764 .77254 Mabsadd L
.5 .60332 -0.91448 -0.29713 Mabsadd L
.5 .60332 -1.46946 -2.02254 Mabsadd L
.5 .60332 0 -0.96154 Mabsadd L
.5 .60332 1.46946 -2.02254 Mabsadd L
.5 .60332 .91448 -0.29713 Mabsadd L
.5 .60332 2.37764 .77254 Mabsadd L
.5 .60332 .56518 .7779 Mabsadd L
.5 .60332 0 2.5 Mabsadd L closepath F
.7381 .29494 0 2.5 Mabsadd m
.7381 .29494 -0.56518 .7779 Mabsadd L
.7381 .29494 -2.37764 .77254 Mabsadd L
.7381 .29494 -0.91448 -0.29713 Mabsadd L
.7381 .29494 -1.46946 -2.02254 Mabsadd L
.7381 .29494 0 -0.96154 Mabsadd L
.7381 .29494 1.46946 -2.02254 Mabsadd L
.7381 .29494 .91448 -0.29713 Mabsadd L
.7381 .29494 2.37764 .77254 Mabsadd L
.7381 .29494 .56518 .7779 Mabsadd L
.7381 .29494 0 2.5 Mabsadd L closepath F
.97619 .43251 0 2.5 Mabsadd m
.97619 .43251 -0.56518 .7779 Mabsadd L
.97619 .43251 -2.37764 .77254 Mabsadd L
.97619 .43251 -0.91448 -0.29713 Mabsadd L
.97619 .43251 -1.46946 -2.02254 Mabsadd L
.97619 .43251 0 -0.96154 Mabsadd L
.97619 .43251 1.46946 -2.02254 Mabsadd L
.97619 .43251 .91448 -0.29713 Mabsadd L
.97619 .43251 2.37764 .77254 Mabsadd L
.97619 .43251 .56518 .7779 Mabsadd L
.97619 .43251 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
.82381 .17102 m
.82381 .3234 L
.97619 .3234 L
.97619 .17102 L
F
1 g
.82381 .17102 m
.82381 .3234 L
.97619 .3234 L
.97619 .17102 L
F
0 g
.001 w
[ ] 0 setdash
.82381 .17102 m
.97619 .17102 L
.97619 .3234 L
.82381 .3234 L
.82381 .17102 L
s
% Start of sub-graphic
p
0.82381 0.171023 0.97619 0.323404 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0396825 0.396825 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0714286 0.35119 0.468254 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00935 w
[ .5 3 ] 0 Mabsdash
0 .5 m
1 .5 L
s
.00094 w
[ ] 0 setdash
.5 .5 0 2.5 Mabsadd m
.5 .5 -0.56518 .7779 Mabsadd L
.5 .5 -2.37764 .77254 Mabsadd L
.5 .5 -0.91448 -0.29713 Mabsadd L
.5 .5 -1.46946 -2.02254 Mabsadd L
.5 .5 0 -0.96154 Mabsadd L
.5 .5 1.46946 -2.02254 Mabsadd L
.5 .5 .91448 -0.29713 Mabsadd L
.5 .5 2.37764 .77254 Mabsadd L
.5 .5 .56518 .7779 Mabsadd L
.5 .5 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .26984 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Vert) show
84.187500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% Start of sub-graphic
p
0.0535714 0.531746 0.35119 0.928571 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
.00094 w
.5 .5 -1.875 0 Mabsadd m
.5 .5 0 2.5 Mabsadd L
.5 .5 1.875 0 Mabsadd L
.5 .5 0 -2.5 Mabsadd L
.5 .5 -1.875 0 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .73016 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Hor) show
81.687500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
84.687500 14.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .49443 L
0 .49443 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{441.125, 218.062},
  ImageMargins->{{32, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006i0000fPP10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF
^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF
^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF
^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH00?nF^YH003nF00?oUYH0oiIhUP00?iH00onFUP3oUWRF
000nUP?ooiIiUP00?YH3oonFNIH003jF0oooUWVF000oUP03oiJF0?nFN9H003nF0oooUWRF000oUP03
oiKo0?nFN9H003nF00?oUYH0oiIhUP00?iH01?nFUYH2oonFMIH003nF00?oUYH0oiIhUP00=iH00onF
UP05UP03oiJF0?nFN9H003NF00?oUYH01IH00onFUP03UP;ooiIcUP00=9H6o`FF0_ooUWVF000]UPSo
0YH00onFUP05UP03oiJF0?nFN9H003FF00?oU_l01iH00onFUP05UP;ooiIaUP00=YH2o`NF00?oUYH0
oiIhUP00=YH2o`NF00?oUYH029H00onFUP3oUVfF000gUP03oiJF00FF00?oUYH029H00onFUP3oUVfF
000oUP03oiJF0?nFN9H003nF0_l;UP03oiJF0?nFJiH003nF00?oUYH02YH00onFUP3oUV^F000oUP03
oiJF0?nFN9H003nF00?oUYH039H00onFUP3oUVVF000oUP03oiJF0?nFN9H003nF00?oUYH0oiIhUP00
?iH2o`nF00?oUYH0oiIWUP00?iH00onFUP3oUWRF000oUP03oiJF0?nFN9H003nF00?oUYH049H00onF
UP3oUVFF000oUP03oiJF0?nFN9H003nF00?oUYH04YH00onFUP3oUV>F000oUP03oiJF01:F00?oUYH0
oiISUP00?iH2oonFNIH003nF00?oUYH059H00onFUP3oUV6F000oUP03oiJF01BF00?oUYH0oiIQUP00
?iH00onFUP3oUWRF000oUP03oiJF01JF00?oUYH0oiIOUP00=9H4o`NF00?oUYH0oiIhUP00=9H01OnF
UYKo00JF00?oUYH0oiIhUP00=IH00onFUP07UP;o6IH2oonFGYH002fF1ol2UP03oiJF00JF00?oUYH0
oiIhUP00=iH00onFUP05UP03oiJF0?nFN9H003NF00?oUYH01IH00onFUP0JUP;ooiILUP00=9H01?nF
U_l7UP03oiJF0?nFN9H003FF0_l8UP03oiJF01bF00?oUYH0oiIIUP00?iH00onFUP0MUP03oiJF0?nF
2II4o`^F000oUP;ooiHZUP03o`00040000?oUYH02IH003nF00?oUYH07iH00onFUP3oUPNF00?o0000
@0000onFUP09UP00?iH00onFUP0OUP03oiJF0?nF1iH00ol000100003oiJF00VF000oUP03oiJF0?nF
:IH00ol000100003oiJF00VF000oUP03oiJF026F00?oUYH0oiH5UP03o`00040000?oUYH02IH003nF
00?oUYH08IH00onFUP3oUPFF00?o0000@0000onFUP09UP00?iH2oonF:YH00ol000100003oiJF00VF
000oUP03oiJF02>F00?oUYH0oiH3UP03o`00040000?oUYH02IH003nF00?oUYH089H4ob6F0ol2UP?o
7YH3o`03U_oo00;o79H4o`>F0olLUPCo0YH4ofVF00?o0000@0000onFUP09UP00?iH00onFUP0TUP03
oiJF01nF00CoUYKo0iH00onFUP0LUP03oiJF00BF00?oUYH06IH01onFUYKoU_l00iH00onFUP0IUP05
oiJFU_l01IH00onFUP1VUP03o`00040000?oUYH02IH003nF00?oUYH099H2ob2F00CoUYKo0iH00onF
UP0LUP03oiJF00BF00?oUYH06YH00onFUP02UP05oiJFU_l079H00onFUP06UP03oiJF06JF00?o0000
@0000onFUP09UP00?iH00onFUP0TUP03oiJF01nF00CoUYKo0iH00onFUP0LUP03oiJF00BF00?oUYH0
6iH01OnFUYKo00>F00?oUYH06iH00onFUP05UP03oiJF06JF00?o0000@0000onFUP09UP00?iH00onF
UP0TUP03oiJF01nF00CoUYKo0iH00onFUP0LUP03oiJF00BF00?oUYH079H01?nFU_l3UP03oiJF01bF
00?oUYH019H00onFUP1VUP03o`00040000?oUYH02IH003nF0_lQUPCo0iH00onFUP0LUP04oiJFo`>F
00?oUYH079H00onFUP04oanF00CoUYKo0iH00onFUP0LUP03oiJF00CoJIH00ol000100003oiJF00VF
000oUP03oiJF026F00?oUYH08YH01?nFU_l3UP03oiJF01bF00GoUYJFo`0NUP04oiJFo`:F00GoUYJF
o`0KUP04oiJFo`>F00?oUYH0JIH00ol000100003oiJF00VF000oUP03oiJF026F1?l4UP03oiJF01VF
0_l3UP?o7YH2o`>F1?lLUP;o19H3oafF0_l4UPCo7iH3odJF00?o00007@000ol0000300;o0P03o`<0
00?o000040000onFUP09UP00?iH00onFUP0YUP03oiJF0;BF00?oUYH05iH3oaFF0olCUP03o`0000T0
00?o0?l040000ol0o`030004o`00o`8000Go0000o`0C0003oiJF00VF000oUP03oiJF0>2F00?oUYH0
5iH00onFUP0GUP03oiJF016F00?o00000_l20003o`0000Ko00<0ool00P000ol000070003o`3o00<0
00?o00000`001Ol0003o01<000?oUYH02IH003nF00?oUYH0:iH00onFUP1^UP03oiJF046F0ol2UP?o
00BFoonF1ol3UP;o0YH01?nFUYH3o`04U_ooUPGo00BFoonF0_l4UP03oiJF016F00?o00002P000ol0
000?0003o`3o00<01?l20005o`000?l04`000onFUP09UP00?iH00onFUP0[UP03oiJF00BF00?oUYH0
<iH00onFUP0aUP;o=9H00onFUP0;UP04oiJFo`:F00KoUYKoU_l2UP03oiKo00:F00?oU_l00YH00onF
o`04UP04oiJFo`:F00CoUYKo0YH01?nFU_l5UP03oiJF016F00?o00002P000ol0000>0005o`000?l0
0P001?l00?l20005o`000?l04`000onFUP09UP00>YKQo`NF00CoUYKo0YH01_nFU_nFo`:F00CoUYJF
0_l00iKoUP03UP03oiJF00:F00CoUYKo0YH01?nFU_l2UP04oiJFo`FF00?oUYH04IH00ol0000K0005
o`000?l00`02o`801olB0003oiJF00VF000nUP?o1YH00onFUP04UP03oiJF00FF00?oUYH01IH00onF
UP04UP03oiJF00FF00?oU_l00iH3o`JF00?oUYH01IH00onFUP04UP03oiJF00FF00?oUYH019H00onF
UP05UP03oiJF00BF0ol5UP03oiJF00FF00?oUYH01IH00onFUP04UP03oiJF00FF00?oUYH019H00onF
UP04UP?o1YH00onFUP04UP03oiJF00FF00?oUYH019H00onFUP05UP03oiJF00FF00?oUYH00iH3o`bF
00CoUYKo0YH01?nFU_l2UP?o0YH01?nFUYH4o`03U_nF00>F00CoUYKo0YH01?nFU_l2UP04oiJFo`FF
00?oUYH04IH00ol0000J0003o`00008000?o00002P000ol0000A0003oiJF00VF000oUP03oiJF03:F
00?oUYH0<iH00onFUP0bUP03oiJF00:F00?oUYH0;IH00onFUP0;UP;o00BFoiJF0_l00iKoUP03UP03
oiKo00:F00?oU_l00YH00onFo`04UP;o00FFoonFo`02UP;o00FFoonFo`05UP03oiJF016F00?o0000
6@03o`800ol;0003o`00014000?oUYH02IH003nF00?oUYH0VYH00onFUP12UP;o00>FoiH00YH00onF
o`02UP?o0iH3o`:F0_l2UP04oiJFUP;o00FFoiJFo`02UP;o00FFoiJFo`06UP03oiJF016F00?o0000
@0000onFUP09UP00?iH00onFUP0_UP;oM9H00onFUP0nUP03oiJF016F00?oUYH05iH00onFUP0AUP03
o`00040000?oUYH02IH003nF00?oUYH0V9H00onFUP0=UP03oiJF03ZF0_lCUP?o5IH3oa>F00?o0000
@0000onFUP09UP00?iH2oiVF00?oUYH03IH00onFUP1mUP03o`00040000?oUYH02IH003nF00?oUYH0
<IH3ogNF00?oUYH0NYH00ol000100003oiJF00VF000oUP03oiJF036F0omRUP03oiJF08nF00?o0000
@0000onFUP09UP00?iH00onFUP0aUPCoNIH00onFUP1gUP03o`00040000?oUYH02IH003nF00?oUYH0
<YH00onFo`3cUP03o`00040000?oUYH02IH003nF00?oUYH0U9H00onFUP0JUP03oiJF07BF00?o0000
@0000onFUP09UP00?iH00onFUP0fUP03oiJF07^F00?oUYH0LIH00ol000100003oiJF00VF000oUP;o
]IH00onFUP1aUP03o`00040000?oUYH02IH003nF00?oUYH0TIH2obBF00?oUYH0KYH00ol000100003
oiJF00VF000oUP03oiJF03RF00?oUYH0kIH00ol000100003oiJF00VF000oUP03oiJF092F00?oUYH0
9iH2ofbF00?o0000@0000onFUP09UP00?iH00onFUP0jUP03oiJF05:F00?oUYH0UYH00ol000100003
oiJF00VF000oUP03oiJF03^F00?oUYH0OiH2ofVF00?o0000@0000onFUP09UP00?iH00onFUP2=UP03
oiJF032F00?oUYH0IIH00ol000100003oiJF00VF000oUP;o?YH00onFUP1=UP03oiJF036F00?oUYH0
I9H00ol000100003oiJF00VF000oUP03oiJF0<>F0_mSUP03o`00040000?oUYH02IH003nF00?oUYH0
?iH00onFUP19UP03oiJF09ZF00?o0000@0000onFUP09UP00?iH00onFUP0oUP03oiJF08BF0_mPUP03
o`00040000?oUYH02IH003nF00?oUYH0oiHYUP03o`00040000?oUYH02IH003BF1?l7UP03oiJF046F
0_m6UP03oiJF03fF0_mMUP03o`0001T00ol200?o0P03o`800ol00`3o000B0003oiJF00VF000dUP05
oiJFU_l01YH00onFUP3<UP03oiJF05VF00?o00002P000ol0000=0003o`00008000Co003o0`001?l0
0?lF0003oiJF00VF000eUP03oiJF00NF0_n8UP03oiJF04>F00?oUYH0F9H00ol0000Eo`D000?o0000
0P001?l00?l30004o`00oaH000?oUYH02IH003JF00?oUYH01YH00onFUP14UP03oiJF042F00?oUYH0
AIH2oeNF00?o00002004o`h000?o00000P001?l00?l30004o`00oaH000?oUYH02IH003NF00?oUYH0
1IH00onFUP3AUP03oiKo05BF00?o00002@03o`h01_l20005o`000?l00P000ol0000D0003oiJF00VF
000gUP03oiJF00FF00?oUYH0AYH00onFUP0lUP03oiJF04VF0omDUP03o`0000X000?o00003@000ol0
00020004o`0000?o0P04oa@000?oUYH02IH003BF00CoUYKo1iH00onFUP16UP03oiJF03bF00?oUYH0
BIH4oe>F00?o00006P000ol000020003o`0001h000?oUYH02IH003FF0_l8UP03oiJF0=:F00?oUYH0
DiH00ol0000I00?o0P03oal000?oUYH02IH003nF0_m9UP;o>9H2ojBF00?o0000@0000onFUP09UP00
?iH00onFUP3oURVF00?o0000@0000onFUP09UP00?iH00onFUP1;UP03oiJF0=ZF00?o0000@0000onF
UP09UP00?iH00onFUP1;UP03oiJF03:F0_nVUP03o`00040000?oUYH02IH003nF00?oUYH0oiHYUP03
o`00040000?oUYH02IH003nF00?oUYH0CIH00onFUP3HUP03o`00040000?oUYH02IH003nF00?oUYH0
OYH00onFUP2WUP03o`00040000?oUYH02IH003nF0_ooURZF00?o0000@0000onFUP09UP00?iH00onF
UP1?UP;o:iH00onFUP2YUP03o`00040000?oUYH02IH003nF00?oUYH0O9H00onFUP2YUP03o`000400
00?oUYH02IH003nF00?oUYH0DYH00onFUP3CUP03o`00040000?oUYH02IH003nF00?oUYH0DYH00onF
UP0UUP03oiJF0:^F00?o0000@0000onFUP09UP00?iH00onFUP3oURVFA?l;UP00?iH00onFUP1DUP03
oiJF0?nF8IH003nF0_miUP03oiJF0?bF000oUP03oiJF0?nFN9H003nF00?oUYH0EYH2oonF89H003nF
00?oUYH0MYH00onFUP3nUP00?iH00onFUP1IUP03oiJF0?nF79H003NF00?oUYH01IH00onFUP1IUP03
oiJF01RF00?oUYH0oiH1UP00=iH00onFUP05UP03oiJF07>F00?oUYH0oiH2UP00=9H6o`FF0_mLUP03
oiJF0?nF6YH003BF00CoUYKo1iH00onFUP1bUP03oiJF0?nF0iH003FF00?oU_l01iH00onFUP1MUP03
oiJF016F00?oUYH0oiH4UP00=YH2o`NF00?oUYH0GYH00onFUP3oUQNF000fUP;o1iH00onFUP1_UP;o
oiH7UP00=iH00onFUP05UP03oiJF062F00?oUYH0oiHEUP00?iH2oonFNIH003nF00?oUYH0KIH00onF
UP3oUPRF000oUP03oiJF06:F00?oUYH0oiHCUP00?iH00onFUP1[UP03oiJF0?nF2YH003nF00?oUYH0
I9H00onFUP04UP03oiJF0?nF2YH003nF00?oUYH0IIH00onFUP3oUQ2F000oUP03oiJF06VF00?oUYH0
oiH<UP00?iH2ofNF0_l00iKoUP3oUPfF000oUP03oiJF06NF0_ooUPnF000oUP03oiJF06JF1?ooUPjF
000oUP03oiJF06NF00?oUYH0oiH>UP00?iH00onFUP3oUWRF003oU[ZF003oU[ZF003oU[ZF003oU[ZF
003oU[ZF003oU[ZF003oU[ZF000kUPCooiIkUP00>YH00onFUP02UP03oiJF00jF0olLUP?ooiI8UP00
>YH00onFUP02UP03oiJF00jF00?oUYH07YH00onFUP3oUTJF000=UP?o19H3o`03U_oo00:F0ol2UPGo
0YH6o`03U_oo00:F00?oUYH00_l3UPCo00BFoooo0YH7o`BF00?oUYH00iH4o`>F00?oUYH00_l2UP?o
00BFoonF0_l4UP03oiJF0?nFAYH000jF00?oUYH019H00onFo`02UP04oiJFo`:F00GoUYJFo`04UP04
oiJFo`:F00CoUYKo0YH01_nFU_nFo`JF00CoUYKo0YH01?nFU_l5UP03oiJF00:F00?oUYH00YH00onF
UP02UP04oiJFo`:F00CoUYKo0YH00onFUP03UP03oiJF0?nFAYH000jF00?oUYH019H00onFo`05UP04
oiJFo`>F00?oUYH00YH01?nFU_l2UP04oiJFo`:F00?oUYH00iH3o`>F00CoUYKo0YH01?nFU_l5UP05
oiJFU_l01IH00onFUP02UP03oiJF00>F00CoUYKo0YH00onFUP03UP03oiJF0?nFAYH000jF00CoUYKo
0iH00onFo`03o`:F00CoUYKo0iH00onFUP02UP04oiJFo`:F00CoUYKo0YH4o`03U_nF00:F00CoUYKo
0iH3o`:F00?oUYH00iH01OnFUYKo00BF0ol3UP03oiJF00>F00CoUYKo0YH00onFUP03UP03oiJF0?nF
AYH000jF1?l3UP03oiKo00:F00CoUYKo0YH01OnFUYKo00BF00?oUYH00_l01IKoUYKo00:F00KoUYKo
U_l3UP04oiJFo`FF00CoUYKo1IH01OnFUYKo00ZF00CoUYKo0YH2o`05U_ooU_l01IH00onFUP3oUTJF
000>UP04oiJFo`:F0_l2UP;o0iH01?nFUYH4o`>F0_l01IKooiKo00:F0ol2UP;o0iH3o`:F1ol3UP03
oiJF00>F00GoUYJFo`05UP03oiJF00>F0ol01IKooiKo00:F00?oUYH019H00onFUP3oUTJF000>UP05
oiJFU_l02YH00onFUP04UP03oiJF00^F00?oUYH05IH00onFUP03UP03oiJF00:F00CoUYJF0_lFUP03
oiJF0?nFAYH000fF1_l2UP03oiJF00BF0_l5UP;o19H00onFUP06UP03oiJF01BF0_l5UP?o0iH3o`03
U_nF01>F0oooUTRF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF
003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF
003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF003oU[ZF
003oU[ZF003oU[ZF003oU[ZF0000\
\>"],
  ImageRangeCache->{{{0, 440.125}, {217.062, 0}} -> {-1.06583, -0.648944, 
  0.00597935, 0.00597935}, {{11, 345.438}, {211.875, 
  5.125}} -> {-8.35334, -7.14665, 0.131353, 0.0741996}, {{362.188, 429.062}, {
  141.938, 75.0625}} -> {-18.2976, -2.93092, 0.0502435, 0.0376827}, {{365.75, 
  385.625}, {137.125, 110.562}} -> {-37.8054, -9.3806, 0.10063, 0.10063}, {{
  365.75, 385.625}, {106.375, 79.8125}} -> {-37.8054, -12.475, 0.10063, 
  0.10063}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of the fields vs phase", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MultipleListPlot[TbBx, TbBz, PlotJoined -> True, 
      AxesLabel -> {"\<phase[mm]\>", "\<Field [T]\>"}, 
      PlotLegend -> {"\<Hor.\>", "\<Vert\>"}, LegendSize -> {0.4, 0.4}]\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49443 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.404762 0.380952 0.247214 0.380952 [
[ 0 0 0 0 ]
[ 1 .49443 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0117721 0.785714 0.482655 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.0340136 0.01941 0.84882 [
[.19388 .00691 -5 -14 ]
[.19388 .00691 5 0 ]
[.36395 .00691 -8 -14 ]
[.36395 .00691 8 0 ]
[.53401 .00691 -8 -14 ]
[.53401 .00691 8 0 ]
[.70408 .00691 -8 -14 ]
[.70408 .00691 8 0 ]
[.87415 .00691 -8 -14 ]
[.87415 .00691 8 0 ]
[1.025 .01941 0 -7 ]
[1.025 .01941 57.75 7 ]
[.01131 .10429 -19 -7 ]
[.01131 .10429 0 7 ]
[.01131 .18917 -19 -7 ]
[.01131 .18917 0 7 ]
[.01131 .27406 -19 -7 ]
[.01131 .27406 0 7 ]
[.01131 .35894 -19 -7 ]
[.01131 .35894 0 7 ]
[.01131 .44382 -19 -7 ]
[.01131 .44382 0 7 ]
[.01131 .5287 -19 -7 ]
[.01131 .5287 0 7 ]
[.01131 .61358 -19 -7 ]
[.01131 .61358 0 7 ]
[.02381 .64303 -23.375 0 ]
[.02381 .64303 23.375 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19388 .01941 m
.19388 .02566 L
s
gsave
.19388 .00691 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.36395 .01941 m
.36395 .02566 L
s
gsave
.36395 .00691 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.53401 .01941 m
.53401 .02566 L
s
gsave
.53401 .00691 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.70408 .01941 m
.70408 .02566 L
s
gsave
.70408 .00691 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.87415 .01941 m
.87415 .02566 L
s
gsave
.87415 .00691 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(25) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05782 .01941 m
.05782 .02316 L
s
.09184 .01941 m
.09184 .02316 L
s
.12585 .01941 m
.12585 .02316 L
s
.15986 .01941 m
.15986 .02316 L
s
.22789 .01941 m
.22789 .02316 L
s
.2619 .01941 m
.2619 .02316 L
s
.29592 .01941 m
.29592 .02316 L
s
.32993 .01941 m
.32993 .02316 L
s
.39796 .01941 m
.39796 .02316 L
s
.43197 .01941 m
.43197 .02316 L
s
.46599 .01941 m
.46599 .02316 L
s
.5 .01941 m
.5 .02316 L
s
.56803 .01941 m
.56803 .02316 L
s
.60204 .01941 m
.60204 .02316 L
s
.63605 .01941 m
.63605 .02316 L
s
.67007 .01941 m
.67007 .02316 L
s
.7381 .01941 m
.7381 .02316 L
s
.77211 .01941 m
.77211 .02316 L
s
.80612 .01941 m
.80612 .02316 L
s
.84014 .01941 m
.84014 .02316 L
s
.90816 .01941 m
.90816 .02316 L
s
.94218 .01941 m
.94218 .02316 L
s
.97619 .01941 m
.97619 .02316 L
s
.25 Mabswid
0 .01941 m
1 .01941 L
s
gsave
1.025 .01941 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(phase) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.250000 14.000000 moveto
(@) show
94.187500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
112.812500 14.000000 moveto
(D) show
116.750000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.02381 .10429 m
.03006 .10429 L
s
gsave
.01131 .10429 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .18917 m
.03006 .18917 L
s
gsave
.01131 .18917 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .27406 m
.03006 .27406 L
s
gsave
.01131 .27406 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .35894 m
.03006 .35894 L
s
gsave
.01131 .35894 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .44382 m
.03006 .44382 L
s
gsave
.01131 .44382 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .5287 m
.03006 .5287 L
s
gsave
.01131 .5287 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .61358 m
.03006 .61358 L
s
gsave
.01131 .61358 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.7) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.02381 .03639 m
.02756 .03639 L
s
.02381 .05336 m
.02756 .05336 L
s
.02381 .07034 m
.02756 .07034 L
s
.02381 .08732 m
.02756 .08732 L
s
.02381 .12127 m
.02756 .12127 L
s
.02381 .13824 m
.02756 .13824 L
s
.02381 .15522 m
.02756 .15522 L
s
.02381 .1722 m
.02756 .1722 L
s
.02381 .20615 m
.02756 .20615 L
s
.02381 .22313 m
.02756 .22313 L
s
.02381 .2401 m
.02756 .2401 L
s
.02381 .25708 m
.02756 .25708 L
s
.02381 .29103 m
.02756 .29103 L
s
.02381 .30801 m
.02756 .30801 L
s
.02381 .32499 m
.02756 .32499 L
s
.02381 .34196 m
.02756 .34196 L
s
.02381 .37591 m
.02756 .37591 L
s
.02381 .39289 m
.02756 .39289 L
s
.02381 .40987 m
.02756 .40987 L
s
.02381 .42684 m
.02756 .42684 L
s
.02381 .4608 m
.02756 .4608 L
s
.02381 .47777 m
.02756 .47777 L
s
.02381 .49475 m
.02756 .49475 L
s
.02381 .51173 m
.02756 .51173 L
s
.02381 .54568 m
.02756 .54568 L
s
.02381 .56265 m
.02756 .56265 L
s
.02381 .57963 m
.02756 .57963 L
s
.02381 .59661 m
.02756 .59661 L
s
.02381 .00243 m
.02756 .00243 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -84.375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Field) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 14.000000 moveto
(@) show
94.500000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(T) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
101.812500 14.000000 moveto
(D) show
105.750000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .01941 m
.2619 .17216 L
.5 .30624 L
.7381 .39546 L
.97619 .42571 L
s
.0001 w
.02381 .01941 -1.875 0 Mabsadd m
.02381 .01941 0 2.5 Mabsadd L
.02381 .01941 1.875 0 Mabsadd L
.02381 .01941 0 -2.5 Mabsadd L
.02381 .01941 -1.875 0 Mabsadd L closepath F
.2619 .17216 -1.875 0 Mabsadd m
.2619 .17216 0 2.5 Mabsadd L
.2619 .17216 1.875 0 Mabsadd L
.2619 .17216 0 -2.5 Mabsadd L
.2619 .17216 -1.875 0 Mabsadd L closepath F
.5 .30624 -1.875 0 Mabsadd m
.5 .30624 0 2.5 Mabsadd L
.5 .30624 1.875 0 Mabsadd L
.5 .30624 0 -2.5 Mabsadd L
.5 .30624 -1.875 0 Mabsadd L closepath F
.7381 .39546 -1.875 0 Mabsadd m
.7381 .39546 0 2.5 Mabsadd L
.7381 .39546 1.875 0 Mabsadd L
.7381 .39546 0 -2.5 Mabsadd L
.7381 .39546 -1.875 0 Mabsadd L closepath F
.97619 .42571 -1.875 0 Mabsadd m
.97619 .42571 0 2.5 Mabsadd L
.97619 .42571 1.875 0 Mabsadd L
.97619 .42571 0 -2.5 Mabsadd L
.97619 .42571 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.02381 .60332 m
.2619 .56163 L
.5 .43307 L
.7381 .23626 L
.97619 .01472 L
s
.0001 w
[ ] 0 setdash
.02381 .60332 0 2.5 Mabsadd m
.02381 .60332 -0.56518 .7779 Mabsadd L
.02381 .60332 -2.37764 .77254 Mabsadd L
.02381 .60332 -0.91448 -0.29713 Mabsadd L
.02381 .60332 -1.46946 -2.02254 Mabsadd L
.02381 .60332 0 -0.96154 Mabsadd L
.02381 .60332 1.46946 -2.02254 Mabsadd L
.02381 .60332 .91448 -0.29713 Mabsadd L
.02381 .60332 2.37764 .77254 Mabsadd L
.02381 .60332 .56518 .7779 Mabsadd L
.02381 .60332 0 2.5 Mabsadd L closepath F
.2619 .56163 0 2.5 Mabsadd m
.2619 .56163 -0.56518 .7779 Mabsadd L
.2619 .56163 -2.37764 .77254 Mabsadd L
.2619 .56163 -0.91448 -0.29713 Mabsadd L
.2619 .56163 -1.46946 -2.02254 Mabsadd L
.2619 .56163 0 -0.96154 Mabsadd L
.2619 .56163 1.46946 -2.02254 Mabsadd L
.2619 .56163 .91448 -0.29713 Mabsadd L
.2619 .56163 2.37764 .77254 Mabsadd L
.2619 .56163 .56518 .7779 Mabsadd L
.2619 .56163 0 2.5 Mabsadd L closepath F
.5 .43307 0 2.5 Mabsadd m
.5 .43307 -0.56518 .7779 Mabsadd L
.5 .43307 -2.37764 .77254 Mabsadd L
.5 .43307 -0.91448 -0.29713 Mabsadd L
.5 .43307 -1.46946 -2.02254 Mabsadd L
.5 .43307 0 -0.96154 Mabsadd L
.5 .43307 1.46946 -2.02254 Mabsadd L
.5 .43307 .91448 -0.29713 Mabsadd L
.5 .43307 2.37764 .77254 Mabsadd L
.5 .43307 .56518 .7779 Mabsadd L
.5 .43307 0 2.5 Mabsadd L closepath F
.7381 .23626 0 2.5 Mabsadd m
.7381 .23626 -0.56518 .7779 Mabsadd L
.7381 .23626 -2.37764 .77254 Mabsadd L
.7381 .23626 -0.91448 -0.29713 Mabsadd L
.7381 .23626 -1.46946 -2.02254 Mabsadd L
.7381 .23626 0 -0.96154 Mabsadd L
.7381 .23626 1.46946 -2.02254 Mabsadd L
.7381 .23626 .91448 -0.29713 Mabsadd L
.7381 .23626 2.37764 .77254 Mabsadd L
.7381 .23626 .56518 .7779 Mabsadd L
.7381 .23626 0 2.5 Mabsadd L closepath F
.97619 .01472 0 2.5 Mabsadd m
.97619 .01472 -0.56518 .7779 Mabsadd L
.97619 .01472 -2.37764 .77254 Mabsadd L
.97619 .01472 -0.91448 -0.29713 Mabsadd L
.97619 .01472 -1.46946 -2.02254 Mabsadd L
.97619 .01472 0 -0.96154 Mabsadd L
.97619 .01472 1.46946 -2.02254 Mabsadd L
.97619 .01472 .91448 -0.29713 Mabsadd L
.97619 .01472 2.37764 .77254 Mabsadd L
.97619 .01472 .56518 .7779 Mabsadd L
.97619 .01472 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
.82381 .17102 m
.82381 .3234 L
.97619 .3234 L
.97619 .17102 L
F
1 g
.82381 .17102 m
.82381 .3234 L
.97619 .3234 L
.97619 .17102 L
F
0 g
.001 w
[ ] 0 setdash
.82381 .17102 m
.97619 .17102 L
.97619 .3234 L
.82381 .3234 L
.82381 .17102 L
s
% Start of sub-graphic
p
0.82381 0.171023 0.97619 0.323404 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0396825 0.396825 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0714286 0.35119 0.468254 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00935 w
[ .5 3 ] 0 Mabsdash
0 .5 m
1 .5 L
s
.00094 w
[ ] 0 setdash
.5 .5 0 2.5 Mabsadd m
.5 .5 -0.56518 .7779 Mabsadd L
.5 .5 -2.37764 .77254 Mabsadd L
.5 .5 -0.91448 -0.29713 Mabsadd L
.5 .5 -1.46946 -2.02254 Mabsadd L
.5 .5 0 -0.96154 Mabsadd L
.5 .5 1.46946 -2.02254 Mabsadd L
.5 .5 .91448 -0.29713 Mabsadd L
.5 .5 2.37764 .77254 Mabsadd L
.5 .5 .56518 .7779 Mabsadd L
.5 .5 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .26984 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Vert) show
84.187500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% Start of sub-graphic
p
0.0535714 0.531746 0.35119 0.928571 MathSubStart
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00935 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
.00094 w
.5 .5 -1.875 0 Mabsadd m
.5 .5 0 2.5 Mabsadd L
.5 .5 1.875 0 Mabsadd L
.5 .5 0 -2.5 Mabsadd L
.5 .5 -1.875 0 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .73016 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Hor) show
81.687500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
84.687500 14.000000 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .49443 L
0 .49443 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{469, 231.812},
  ImageMargins->{{35, 0}, {0, 5.4375}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007E0000i`P10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nF
eYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nF
eYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH004jF1?lZUP?o0YH3obJF0ol00iKoo`02obFF1?l3UP?o
9IH4o`:F1?o5UP00DYH00onFUP0XUP04oiJFo`>F00?oUYH099H00onFUP04UP03oiJF02:F00OoUYJF
oiKo00>F00?oUYH08YH01OnFUYKo00FF00?oUYH0`YH005:F00?oUYH0:9H01?nFU_l3UP03oiJF02BF
00?oUYH019H00onFUP0SUP03oiJF00:F00GoUYJFo`0UUP03oiJF00JF00?oUYH0`YH005:F00?oUYH0
:9H01?nFU_l3UP03oiJF02BF00?oUYH019H00onFUP0TUP05oiJFU_l00iH00onFUP0TUP03oiJF00FF
00?oUYH0`YH005:F00?oUYH0:9H01?nFU_l3UP03oiJF02BF00?oUYH019H00onFUP0UUP04oiJFo`>F
00?oUYH09IH00onFUP04UP03oiJF0<:F001>UPCo:iH01?nFU_l3UP03oiJF02BF00?oUYH01?lXUP04
oiJFo`>F00?oUYH09IH00onFUP04olFF001?UP03oiJF02^F00CoUYKo0iH00onFUP0TUP05oiJFU_l0
9iH01?nFU_l2UP05oiJFU_l099H01?nFU_l3UP03oiJF0<FF000SUP03oiJF02VF1?lYUP;o0iH3obJF
0_l3UPCo9IH2o`BF0olVUP;o19H4obJF0onKUP008iH2oonF59H00onFUP0GUP?o5IH3ofRF000SUP03
oiJF0?nF4iH00onFUP0GUP03oiJF01NF00?oUYH0IYH002>F00?oUYH0oiH1UP;o49H3o`:F0ol019Ko
oiH7o`>F0_l2UP04oiJFUP?o00BFoonF1Ol019KooiH2o`BF00?oUYH0IYH002>F00?oUYH0oiH2UP;o
3iH01?nFU_l2UP06oiJFoiKo0YH00onFo`02UP03oiKo00:F00?oU_l019H01?nFU_l2UP04oiJFo`:F
00CoUYKo1IH00onFUP1VUP0079KooaCo2IH01?nFU_l2UP06oiJFoiKo0YH01?nFUYH2o`03U_nF00>F
00?oUYH00YH01?nFU_l2UP04oiJFo`:F00CoUYKo1IH00onFUP1VUP008IH3o`03U_nF00FF00?oUYH0
1YH00onFUP07UP03oiJF00JF00?oUYH01YH00onFUP07UP03oiJF00JF00?oUYH01YH00onFUP07UP03
oiJF00JF00?oUYH01YH00onFUP06UP03oiJF00NF00?oUYH01YH00onFUP06UP03oiJF00NF00?oUYH0
1YH00onFUP06UP03oiJF00NF00?oUYH01YH00onFUP06UP03oiJF00NF00?oUYH01YH00onFUP06UP03
oiJF00NF00?oUYH01YH00onFUP06UP03oiJF00FF0ol?UP04oiJFo`:F00CoUYKo0YH3o`:F00CoUYJF
1?l00iKoUP03UP04oiJFo`:F00CoUYKo0YH01?nFU_l5UP03oiJF06JF000RUP;o0YH2obVF00?oUYH0
;9H00onFUP0[UP03oiJF02bF00?oUYH0;9H00onFUP0YUP;o00BFoiJF0_l00iKoUP03UP03oiKo00:F
00?oU_l00YH00onFo`04UP;o00FFoonFo`02UP;o00FFoonFo`05UP03oiJF06JF000SUP03oiJF00:F
00?oUYH0n9H00onFUP0AUP;o00>FoiH00YH00onFo`02UP?o0iH3o`:F0_l2UP04oiJFUP;o00FFoiJF
o`02UP;o00FFoiJFo`06UP03oiJF06JF000SUP03oiJF00>F0_ooUQBF00?oUYH04IH00onFUP0GUP03
oiJF06JF000SUP;o1YH2ooBF00?oUYH06IH2oa>F0olEUP?oJ9H002>F00?oUYH01iH00onFUP3`UP03
oiJF0;:F000SUP03oiJF00RF0_ooUZJF000SUP03oiJF00ZF00?oUYH0jiH00onFUP2dUP008iH00onF
UP0;UP;ooiJSUP008iH2o`jF00?oUYH0iYH00onFUP2fUP008iH00onFUP0>UP;oiIH00onFUP2gUP00
8iH00onFUP0@UP03oiJF0?nFWIH002>F00?oUYH04IH2on2F00?oUYH0^IH002>F0_lDUP03oiJF0?nF
VYH002>F00?oUYH059H2omZF0_nmUP008iH00onFUP0FUP;ooiJHUP008iH00onFUP0HUP03oiJF0=>F
00?oUYH0_YH002>F00?oUYH06IH2om>F00?oUYH0_YH002>F0_lLUP03oiJF0?nFTYH002>F00?oUYH0
79H2olfF00?oUYH0`IH002>F00?oUYH07YH00onFUP3oUXnF000?UP?o0iH01?nFUYH3o`NF00?oUYH0
7iH2olRF00?oUYH0`iH000jF00GoUYJFo`07UP03oiJF00JF00?oUYH08IH00onFUP3oUXbF000>UP05
oiJFU_l01iH00onFUP06UP;o8iH2oonFS9H000jF00GoUYJFo`07UP03oiJF00JF00?oUYH099H00onF
UP2oUP03oiJF0<JF000>UP05oiJFU_l01iH00onFUP06UP03oiJF02FF0_ooUXVF000>UP05oiJFU_l0
1iH00onFUP06UP03oiJF02NF0_njUP;obYH000jF00GoUYJFo`07UP03oiJF00JF0_lZUP03oiJF0?nF
Q9H000nF0ol7UP;o29H00onFUP0ZUP;o]IH00onFUP3;UP008iH00onFUP0/UP03oiJF0;:F00?oUYH0
biH002>F00?oUYH0;IH2oonFPIH002>F00?oUYH0;iH00onFUP2/UP;ociH002>F0_laUP;ooiInUP00
8iH00onFUP0bUP03oiJF0:NF00?oUYH0d9H002>F00?oUYH0<iH2oonFNiH002>F00?oUYH0=IH00onF
UP2RUP03oiJF0=:F000SUP03oiJF03JF0_nQUP03oiJF0=>F000SUP;o>IH2oonFMYH002>F00?oUYH0
>YH00onFUP2JUP03oiJF0=FF000SUP03oiJF03^F0_ooUW>F000SUP03oiJF03fF0_nEUP03oiJF0=RF
000SUP;o?YH3oiBF00?oUYH0f9H002>F00?oUYH0?9H6oonFKYH002>F00?oUYH0?IH3o`:F00?oUYH0
S9H2ombF000?UP?o0iH00onFo`03o`RF00?oUYH0?YH00onFUP02UP;ooiI[UP003YH01OnFUYKo00BF
00GoUYJFo`07UP03oiJF04FF0_n8UP03oiJF0=fF000>UP05oiJFU_l01IH00onFUP08UP;oB9H2oonF
IiH000jF00GoUYJFo`06UP03oiJF00NF00?oUYH0BIH00onFUP21UP03oiJF0=nF000>UP05oiJFU_l0
1iH00onFUP06UP03oiJF04ZF0_n0UP03oiJF08bFB?l<UP003YH01OnFUYKo00NF00?oUYH01YH00onF
UP1<UP;ooiH>UP03o`0004@000?oUYH02YH000jF00GoUYJFo`04UP04oiJFo`RF00?oUYH0CYH2ogZF
00?oUYH0SYH00ol000140003oiJF00ZF000?UP?o1YH2o`VF0_mAUP03oiJF0?nF2IH00ol000140003
oiJF00ZF000SUP03oiJF056F0_mdUP;oTYH00ol000140003oiJF00ZF000SUP03oiJF05>F0_ooUPNF
00?o0000A0000onFUP0:UP008iH00onFUP1EUP;ooiH5UP03o`0004@000?oUYH02YH002>F0_mHUP03
oiJF06^F00?oUYH0TiH00ol000140003oiJF00ZF000SUP03oiJF05RF0_ooUP:F00?o0000A0000onF
UP0:UP008iH00onFUP1JUP;oIYH00onFUP2FUP03o`0004@000?oUYH02YH002>F00?oUYH0G9H2of>F
00?oUYH0UiH00ol000140003oiJF00ZF000SUP03oiJF05jF0_mPUP;oVIH00ol000140003oiJF00ZF
000SUP;oHIH00onFUP1LUPCoV9H00ol000140003oiJF00ZF000SUP03oiJF066F0_mJUP04oiJFoiZF
00?o0000A0000onFUP0:UP008iH00onFUP1SUP;oF9H00onFUP2KUP03o`0004@000?oUYH02YH002>F
00?oUYH0IIH2ooBF00?o0000A0000onFUP0:UP008iH00onFUP1WUP03oiJF052F00?oUYH0WYH00ol0
00140003oiJF00ZF000SUP;oJIH2oo6F00?o00007P000ol0000300;o0P03o`<000?o00004`000onF
UP0:UP008iH00onFUP1ZUP;oBiH2oj:F00?o00002P000ol0000@0003o`3o00<000Co003o0P001Ol0
003o01H000?oUYH02YH000nF0ol3UP03oiKo00?o29H00onFUP1/UP;okIH00ol00002o`8000?o0000
0_l00`3oo`0200;o0P000ol00002o`H000?o0?l00`000ol000030005o`000?l05P000onFUP0:UP00
3YH01OnFUYKo00RF00?oUYH01IH00onFUP1^UP03oiJF04BF00?oUYH0XiH00ol0000:00?o40000ol0
o`0300Co0P001Ol0003o01H000?oUYH02YH000jF00GoUYJFo`08UP03oiJF00FF0_m`UP;oA9H00onF
UP2SUP03o`0000/000?o00003P001Ol0003o008000Co003o0P001Ol0003o01H000?oUYH02YH000jF
00GoUYJFo`08UP03oiJF00FF00?oUYH0LIH2ocnF00?oUYH0YYH00ol0000L0005o`000?l00`02o`80
1olE0003oiJF00ZF000>UP05oiJFU_l01IH3o`RF00?oUYH0LiH2ocfF00?oUYH0YYH00ol0000K0003
o`00008000?o00002P000ol0000D0003oiJF00ZF000>UP05oiJFU_l01iH00onFUP06UP03oiJF07FF
00?oUYH0hiH00ol0000J00?o0P03o`/000?o000050000onFUP0:UP003YH01OnFUYKo00BF00GoUYJF
o`07UP03oiJF07JF0_lgUP;oZYH00ol000140003oiJF00ZF000?UP?o1YH3o`RF0_miUP;ohIH00ol0
00140003oiJF00ZF000SUP03oiJF07ZF0_laUP03oiJF0:^F00?o0000A0000onFUP0:UP008iH00onF
UP1lUP03oiJF0=bF00?o0000A0000onFUP0:UP008iH00onFUP1mUP?o:YH00onFUP2^UP03o`0004@0
00?oUYH02YH002>F0_moUP?ofYH00ol000140003oiJF00ZF000SUP03oiJF07jF1_lTUP03oiJF0;2F
00?o0000A0000onFUP0:UP008iH00onFUP1oUP03oiJF00:F0olPUP03oiJF0;6F00?o0000A0000onF
UP0:UP008iH00onFUP27UP;odYH00ol000140003oiJF00ZF000SUP03oiJF08VF0olIUP03oiJF0;>F
00?o0000A0000onFUP0:UP008iH2ohfF0oo<UP03o`0004@000?oUYH02YH002>F00?oUYH0SiH3oa2F
00?oUYH0]YH00ol000140003oiJF00ZF000SUP03oiJF09:F0_o7UP03o`0004@000?oUYH02YH002>F
00?oUYH0U9H3o`RF0_njUP03o`0004@000?oUYH02YH002>F00?oUYH0UiH3ol6F00?o0000A0000onF
UP0:UP008iH2oi^F0_l00iKoUP2lUP03o`0004@000?oUYH02YH002>F00?oUYH0W9H3okbF00?o0000
A0000onFUP0:UP003iH3o`>F00?oUYH00YH00onFUP06UP03oiJF09ZF00?oUYH00YH3okVF00?o0000
A0000onFUP0:UP003YH01OnFUYKo00NF00?oUYH01YH00onFUP2JUP03oiJF00FF0onfUP03o`0004@0
00?oUYH02YH000jF00GoUYJFo`04UPKo1YH2ojJF0_ndUP03o`0004@000?oUYH02YH000jF00GoUYJF
o`04UP04oiJFo`RF00?oUYH0UiH00onFUP0=UP?o/IH00ol000140003oiJF00ZF000>UP05oiJFU_l0
1IH00onFo`08UP03oiJF0:ZF0on^UP03o`0004@000?oUYH02YH000jF00GoUYJFo`06UP;o29H00onF
UP2DUP;o5iH2ojbF00?o0000A0000onFUP0:UP003YH01OnFUYKo00JF0_l8UP03oiJF0:nF0onYUP03
o`0004@000?oUYH02YH000nF0ol8UP03oiJF00JF0_nCUP03oiJF01fF0onVUP03o`0001X00ol200?o
0P03o`800ol20003o`0001<000?oUYH02YH002>F00?oUYH0]IH3oj>F00?o00006`000ol000020004
o`00o`<000Co003o6@000onFUP0:UP008iH00onFUP2?UP03oiJF02JF0_nQUP03o`0000/000?o0000
3@000ol000020004o`00o`<000Co003o6@000onFUP0:UP008iH00onFUP2?UP03oiJF02RF0onNUP03
o`0001Oo10000ol000020004o`00o`<000Co003o6@000onFUP0:UP008iH00onFUP2mUPCoVYH00ol0
000:00?o3P06o`8000Go0000o`020003o`0001L000?oUYH02YH002>F0_n=UP;o<YH5oiJF00?o0000
2`000ol0000=0003o`00008000Co00000ol200Co5`000onFUP0:UP008iH00onFUP2oUP?o0iH7ohnF
00?o00006`000ol000020003o`00024000?oUYH02YH002>F00?oUYH0RYH00onFUP0cUP;o2YH7ohRF
00?o00006P03o`800olR0003oiJF00ZF000SUP03oiJF0<2F00?oUYH049H8oh2F00?o0000A0000onF
UP0:UP008iH2ohRF00?oUYH0DIH7ogVF00?o0000A0000onFUP0:UP008iH00onFUP3RUPOoLYH00ol0
00140003oiJF00ZF000SUP03oiJF08FF00?oUYH0HIH8ofZF00?o0000A0000onFUP0:UP008iH00onF
UP24UP03oiJF06ZF1omSUP03o`0004@000?oUYH02YH002>F00?oUYH0n9H7o`>F00?oUYH0EYH00ol0
00140003oiJF00ZF000SUP;oPYH2ogbF1OmGUP03o`0004@000?oUYH02YH002>F00?oUYH0OYH00onF
o`20UP?oEiH00ol000140003oiJF00ZF000SUP03oiJF07jF0on1UP03oiJF05JF00?o0000A0000onF
UP0:UP003iH3o`>F00?oU_l00ol8UP03oiJF07bF00?oU_l00ooIUP03o`0004@000?oUYH02YH000jF
00GoUYJFo`08UP03oiJF00FF00?oUYH0O9H01?nFU_oKUP03o`0004@000?oUYH02YH000jF00GoUYJF
o`08UP03oiJF00FF0_mjUP03oiJF0=nF00?o0000A0000onFUP0:UP003YH01OnFUYKo00RF00?oUYH0
1IH00onFUP3oUUbF00?o0000A0000onFUP0:UP003YH01OnFUYKo00RF00?oUYH01IH00onFUP1eUP;o
i9H00ol000140003oiJF00ZF000>UP05oiJFU_l019H4o`RF00?oUYH0LiH00onFUP3UUTSo39H000jF
00GoUYJFo`05UP03oiJF00RF0_mcUP03oiJF0?nF>iH000nF0ol6UPCo1iH00onFUP1_UP;ooiHoUP00
8iH00onFUP3oU[2F000SUP03oiJF06bF0_ooUT:F000SUP03oiJF06ZF00?oUYH0oiI3UP008iH2ofZF
00?oUYH0oiI4UP008iH00onFUP1VUP;ooiI8UP008iH00onFUP3oU[2F000SUP03oiJF06>F00?oUYH0
oiI:UP008iH00onFUP1PUP03oiJF0?nFCIH002>F0_mQUP03oiJF0?nFCIH002>F00?oUYH0GIH00onF
UP3oUU2F000SUP03oiJF0?nF/9H002>F00?oUYH0FYH00onFUP3oUU>F000SUP;oF9H00onFUP3oUUJF
000SUP03oiJF05NF00?oUYH0oiIFUP008iH00onFUP1DUP03oiJF0?nFFIH000nF0ol3UP03oiJF00?o
29H00onFUP3oU[2F000>UP05oiJFU_l019H01OnFUYKo00NF00?oUYH0DIH00onFUP3oUUbF000>UP05
oiJFU_l019H01OnFUYKo00NF0_m?UP03oiJF0?nFGiH000jF00GoUYJFo`04UP05oiJFU_l01iH00onF
UP1=UP03oiJF0?nFH9H000jF00GoUYJFo`04UPCo29H00onFUP1:UP;ooiITUP003YH01OnFUYKo00FF
00?oUYH029H00onFUP3oU[2F000>UP05oiJFU_l01IH2o`VF00?oUYH0AiH2oonFIiH000nF0ol8UP;o
1iH2odJF00?oUYH0oiIXUP008iH00onFUP14UP03oiJF0?nFJIH002>F00?oUYH0@IH2oonFKIH002>F
00?oUYH0?9H2oonFLYH002>F0_lnUP;ooiIaUP008iH00onFUP0gUP;o0YH5oonFL9H002>F00?oUYH0
<9H2o`:F00?oUYH01YH00onFUP3oUW2F000SUP03oiJF02fF00?oUYH0oiJ0UP008iH00onFUP0VUP03
oiJF00;ooiJ5UP008iH2ob2F0_l00iKoo`3oUXbF000SUP03oiJF01bF00?oUYH0oiJAUP008iH00onF
UP0EUP03oiJF00;ooiJFUP008iH00onFUP0>UP03oiJF00;ooiJMUP008iH00onFUP0:UP;ooiJTUP00
8IH4o`BF0_l2UP03oiJF0?nFYYH002:F0_l2UP;ooiJ^UP003iH3o`>F00GoUYJFo`07UPCooiJaUP00
3YH01OnFUYKo00JF00?oUYH01YH2oonF/YH000jF00GoUYJFo`06UP03oiJF00NF0_ooU[6F000>UP05
oiJFU_l01iH00onFUP06UP03oiJF0?nF/9H000jF00GoUYJFo`07UP03oiJF0?nF^IH000jF00GoUYJF
o`07UP03oiJF0?nF^IH000jF00GoUYJFo`04UP05oiJFU_l0oiJjUP003iH3o`JF1?ooU[ZF003oU]JF
003oU]JF003oU]JF003oU]JF003oU]JF000YUP?o2IH3oonFWYH002VF00?oUYH02iH00onFUP3oUYbF
000=UP?o19H3o`03U_oo00:F0ol2UPGo0iH00onFUP03UP?o1IH00onFUP3oUYbF000>UP03oiJF00BF
00?oU_l00YH01?nFU_l2UP05oiJFU_l019H00onFUP04UP03oiJF00BF00?oUYH0oiJLUP003YH00onF
UP04UP03oiKo00FF00CoUYKo0iH00onFUP02UP03oiJF00BF00?oUYH019H00onFUP3oUYbF000>UP04
oiJFo`>F00?oU_l00ol2UP04oiJFo`>F00?oUYH00YH00onFUP04UP03oiJF00BF00?oUYH0oiJLUP00
3YH4o`>F00?oU_l00YH01?nFU_l2UP05oiJFU_l019H00onFUP04UP03oiJF00BF00?oUYH0oiJLUP00
3YH01?nFU_l2UP;o0YH2o`>F00CoUYJF1?l4UP05oiJFU_l00YH01?nFU_l3UP03oiJF0?nFW9H000jF
00GoUYJFo`0:UP03oiJF00BF00?oUYH00YH01OnFUYKo00:F00CoUYKo0iH00onFUP3oUYbF000=UPKo
0YH00onFUP04UP;o1IH2o`BF0ol00iKoo`05o`04U_oooonFWYH00?nFeYH00?nFeYH00?nFeYH00?nF
eYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nFeYH00?nF
eYH00?nFeYH00?nFeYH00001\
\>"],
  ImageRangeCache->{{{0, 468}, {230.812, 0}} -> {-1.06582, -0.648944, 
  0.00562315, 0.00562315}, {{11.6875, 367.375}, {225.312, 
  5.4375}} -> {-3.75911, -0.135937, 0.107208, 0.004296}, {{385.125, 456.25}, {
  150.938, 79.8125}} -> {-18.2938, -2.93006, 0.0472413, 0.035431}, {{388.938, 
  410.062}, {145.812, 117.625}} -> {-37.8229, -9.38175, 0.0946755, 
  0.0946755}, {{388.938, 410.062}, {113.062, 84.875}} -> {-37.8229, -12.4824, 
  0.0946755, 0.0946755}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
Evaluator->"Local",
WindowSize->{630, 715},
WindowMargins->{{147, Automatic}, {Automatic, 15}},
CellGroupingRules->"NormalGrouping",
ShowCellLabel->False,
Magnification->1,
StyleDefinitions -> "Report.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000ad2<?oYonl3<`920dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 45, 0, 62, "Title"],
Cell[1779, 53, 85, 3, 82, "Author"],

Cell[CellGroupData[{
Cell[1889, 60, 51, 1, 63, "Section"],
Cell[1943, 63, 2027, 30, 322, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4007, 98, 49, 0, 67, "Section"],

Cell[CellGroupData[{
Cell[4081, 102, 149, 3, 64, "Input"],
Cell[4233, 107, 359, 7, 37, "Print"],
Cell[4595, 116, 126, 2, 52, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4770, 124, 28, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[4823, 128, 85, 1, 40, "Subsection"],
Cell[4911, 131, 11957, 183, 3680, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16905, 319, 107, 3, 24, "Subsection"],
Cell[17015, 324, 10496, 164, 3152, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[27548, 493, 29, 0, 24, "Subsection"],
Cell[27580, 495, 563, 10, 192, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28180, 510, 36, 0, 24, "Subsection"],
Cell[28219, 512, 1195, 19, 432, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[29463, 537, 39, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[29527, 541, 32, 0, 40, "Subsection"],

Cell[CellGroupData[{
Cell[29584, 545, 91, 1, 30, "Subsubsection"],
Cell[29678, 548, 3135, 78, 486, "Text",
  Evaluatable->False],
Cell[32816, 628, 832, 18, 255, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33697, 652, 33, 0, 40, "Subsection"],

Cell[CellGroupData[{
Cell[33755, 656, 45, 0, 30, "Subsubsection"],
Cell[33803, 658, 975, 24, 167, "Commentary",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[34815, 687, 45, 0, 30, "Subsubsection"],
Cell[34863, 689, 268, 6, 79, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[35192, 702, 24, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[35241, 706, 114, 2, 96, "Input"],
Cell[35358, 710, 523, 11, 39, "Print"],
Cell[35884, 723, 1413, 31, 39, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[37346, 760, 26, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[37397, 764, 36, 0, 40, "Subsection"],

Cell[CellGroupData[{
Cell[37458, 768, 1191, 27, 240, "Input"],
Cell[38652, 797, 69, 1, 37, "Print"],
Cell[38724, 800, 62845, 1593, 292, 35987, 1257, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101606, 2398, 75, 0, 30, "Subsubsection"],
Cell[101684, 2400, 400, 7, 80, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[102133, 2413, 27, 0, 40, "Subsection"],

Cell[CellGroupData[{
Cell[102185, 2417, 341, 7, 128, "Input"],
Cell[102529, 2426, 205643, 5311, 289, 159183, 4733, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[308209, 7742, 68, 0, 30, "Subsubsection"],
Cell[308280, 7744, 393, 6, 102, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[308734, 7757, 49, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[308808, 7761, 41, 0, 30, "Subsubsection"],

Cell[CellGroupData[{
Cell[308874, 7765, 138, 2, 64, "Input"],
Cell[309015, 7769, 911474, 48614, 381, 851657, 47871, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1220538, 56389, 56, 0, 30, "Subsubsection"],
Cell[1220597, 56391, 59, 1, 32, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1220693, 56397, 129, 5, 30, "Subsubsection"],
Cell[1220825, 56404, 50, 1, 32, "Input"],

Cell[CellGroupData[{
Cell[1220900, 56409, 63, 1, 32, "Input"],
Cell[1220966, 56412, 44, 1, 46, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1221071, 56420, 48, 0, 41, "Section"],
Cell[1221122, 56422, 506, 8, 192, "Input"],

Cell[CellGroupData[{
Cell[1221653, 56434, 58, 0, 40, "Subsection"],

Cell[CellGroupData[{
Cell[1221736, 56438, 225, 4, 64, "Input"],
Cell[1221964, 56444, 33674, 1181, 235, 22596, 1039, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1255641, 57627, 130, 3, 46, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1255820, 57636, 49, 0, 40, "Subsection"],

Cell[CellGroupData[{
Cell[1255894, 57640, 213, 4, 64, "Input"],
Cell[1256110, 57646, 37064, 1317, 254, 24682, 1159, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1293177, 58965, 130, 3, 46, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

